// Copyright (c) 2026 Marshall A. Greenblatt. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//    * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//    * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//    * Neither the name of Google Inc. nor the name Chromium Embedded
// Framework nor the names of its contributors may be used to endorse
// or promote products derived from this software without specific prior
// written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// ---------------------------------------------------------------------------
//
// This file is generated by the make_pack_header.py tool.
//

#ifndef CEF_INCLUDE_CEF_PACK_STRINGS_H_
#define CEF_INCLUDE_CEF_PACK_STRINGS_H_
#pragma once

// ---------------------------------------------------------------------------
// From app_locale_settings.h:

#define IDS_WEB_FONT_FAMILY 50043
#define IDS_WEB_FONT_SIZE 50044

// ---------------------------------------------------------------------------
// From auto_image_annotation_strings.h:

#define IDS_AX_UNLABELED_IMAGE_ROLE_DESCRIPTION 50050
#define IDS_AX_IMAGE_ELIGIBLE_FOR_ANNOTATION 50052
#define IDS_AX_IMAGE_ANNOTATION_PENDING 50053
#define IDS_AX_IMAGE_ANNOTATION_ADULT 50054
#define IDS_AX_IMAGE_ANNOTATION_NO_DESCRIPTION 50055
#define IDS_AX_IMAGE_ANNOTATION_OCR_CONTEXT 50056
#define IDS_AX_IMAGE_ANNOTATION_DESCRIPTION_CONTEXT 50057
#define IDS_AX_IMAGE_ANNOTATION_ICON_PLUS 50058
#define IDS_AX_IMAGE_ANNOTATION_ICON_ARROW_BACKWARD 50059
#define IDS_AX_IMAGE_ANNOTATION_ICON_ARROW_FORWARD 50060
#define IDS_AX_IMAGE_ANNOTATION_ICON_CALL 50061
#define IDS_AX_IMAGE_ANNOTATION_ICON_CHAT 50062
#define IDS_AX_IMAGE_ANNOTATION_ICON_CHECK 50063
#define IDS_AX_IMAGE_ANNOTATION_ICON_X 50064
#define IDS_AX_IMAGE_ANNOTATION_ICON_DELETE 50065
#define IDS_AX_IMAGE_ANNOTATION_ICON_EDIT 50066
#define IDS_AX_IMAGE_ANNOTATION_ICON_EMOJI 50067
#define IDS_AX_IMAGE_ANNOTATION_ICON_END_CALL 50068
#define IDS_AX_IMAGE_ANNOTATION_ICON_V_DOWNWARD 50069
#define IDS_AX_IMAGE_ANNOTATION_ICON_HEART 50070
#define IDS_AX_IMAGE_ANNOTATION_ICON_HOME 50071
#define IDS_AX_IMAGE_ANNOTATION_ICON_INFO 50072
#define IDS_AX_IMAGE_ANNOTATION_ICON_LAUNCH_APPS 50073
#define IDS_AX_IMAGE_ANNOTATION_ICON_THUMBS_UP 50074
#define IDS_AX_IMAGE_ANNOTATION_ICON_THREE_BARS 50075
#define IDS_AX_IMAGE_ANNOTATION_ICON_THREE_DOTS 50076
#define IDS_AX_IMAGE_ANNOTATION_ICON_NOTIFICATIONS 50077
#define IDS_AX_IMAGE_ANNOTATION_ICON_PAUSE 50078
#define IDS_AX_IMAGE_ANNOTATION_ICON_PLAY 50079
#define IDS_AX_IMAGE_ANNOTATION_ICON_REFRESH 50080
#define IDS_AX_IMAGE_ANNOTATION_ICON_MAGNIFYING_GLASS 50081
#define IDS_AX_IMAGE_ANNOTATION_ICON_SEND 50082
#define IDS_AX_IMAGE_ANNOTATION_ICON_SETTINGS 50083
#define IDS_AX_IMAGE_ANNOTATION_ICON_SHARE 50084
#define IDS_AX_IMAGE_ANNOTATION_ICON_STAR 50085
#define IDS_AX_IMAGE_ANNOTATION_ICON_TAKE_PHOTO 50086
#define IDS_AX_IMAGE_ANNOTATION_ICON_TIME 50087
#define IDS_AX_IMAGE_ANNOTATION_ICON_VIDEOCAM 50088
#define IDS_AX_IMAGE_ANNOTATION_ICON_EXPAND 50089
#define IDS_AX_IMAGE_ANNOTATION_ICON_CONTRACT 50090
#define IDS_AX_IMAGE_ANNOTATION_ICON_GOOGLE 50091
#define IDS_AX_IMAGE_ANNOTATION_ICON_TWITTER 50092
#define IDS_AX_IMAGE_ANNOTATION_ICON_FACEBOOK 50093
#define IDS_AX_IMAGE_ANNOTATION_ICON_ASSISTANT 50094
#define IDS_AX_IMAGE_ANNOTATION_ICON_WEATHER 50095
#define IDS_AX_IMAGE_ANNOTATION_ICON_SHOPPING_CART 50096
#define IDS_AX_IMAGE_ANNOTATION_ICON_UPLOAD 50097
#define IDS_AX_IMAGE_ANNOTATION_ICON_QUESTION 50098
#define IDS_AX_IMAGE_ANNOTATION_ICON_MIC 50099
#define IDS_AX_IMAGE_ANNOTATION_ICON_MIC_MUTE 50100
#define IDS_AX_IMAGE_ANNOTATION_ICON_GALLERY 50101
#define IDS_AX_IMAGE_ANNOTATION_ICON_COMPASS 50102
#define IDS_AX_IMAGE_ANNOTATION_ICON_PEOPLE 50103
#define IDS_AX_IMAGE_ANNOTATION_ICON_ARROW_UPWARD 50104
#define IDS_AX_IMAGE_ANNOTATION_ICON_ENVELOPE 50105
#define IDS_AX_IMAGE_ANNOTATION_ICON_EMOJI_FACE 50106
#define IDS_AX_IMAGE_ANNOTATION_ICON_PAPERCLIP 50107
#define IDS_AX_IMAGE_ANNOTATION_ICON_CAST 50108
#define IDS_AX_IMAGE_ANNOTATION_ICON_VOLUME_UP 50109
#define IDS_AX_IMAGE_ANNOTATION_ICON_VOLUME_DOWN 50110
#define IDS_AX_IMAGE_ANNOTATION_ICON_VOLUME_STATE 50111
#define IDS_AX_IMAGE_ANNOTATION_ICON_VOLUME_MUTE 50112
#define IDS_AX_IMAGE_ANNOTATION_ICON_STOP 50113
#define IDS_AX_IMAGE_ANNOTATION_ICON_SHOPPING_BAG 50114
#define IDS_AX_IMAGE_ANNOTATION_ICON_LIST 50115
#define IDS_AX_IMAGE_ANNOTATION_ICON_LOCATION 50116
#define IDS_AX_IMAGE_ANNOTATION_ICON_CALENDAR 50117
#define IDS_AX_IMAGE_ANNOTATION_ICON_THUMBS_DOWN 50118
#define IDS_AX_IMAGE_ANNOTATION_ICON_HEADSET 50119
#define IDS_AX_IMAGE_ANNOTATION_ICON_REDO 50120
#define IDS_AX_IMAGE_ANNOTATION_ICON_UNDO 50121
#define IDS_AX_IMAGE_ANNOTATION_ICON_DOWNLOAD 50122
#define IDS_AX_IMAGE_ANNOTATION_ICON_ARROW_DOWNWARD 50123
#define IDS_AX_IMAGE_ANNOTATION_ICON_V_UPWARD 50124
#define IDS_AX_IMAGE_ANNOTATION_ICON_V_FORWARD 50125
#define IDS_AX_IMAGE_ANNOTATION_ICON_V_BACKWARD 50126
#define IDS_AX_IMAGE_ANNOTATION_ICON_HISTORY 50127
#define IDS_AX_IMAGE_ANNOTATION_ICON_PERSON 50128
#define IDS_AX_IMAGE_ANNOTATION_ICON_HAPPY_FACE 50129
#define IDS_AX_IMAGE_ANNOTATION_ICON_SAD_FACE 50130
#define IDS_AX_IMAGE_ANNOTATION_ICON_MOON 50131
#define IDS_AX_IMAGE_ANNOTATION_ICON_CLOUD 50132
#define IDS_AX_IMAGE_ANNOTATION_ICON_SUN 50133

// ---------------------------------------------------------------------------
// From blink_strings.h:

#define IDS_DETAILS_WITHOUT_SUMMARY_LABEL 46510
#define IDS_FORM_CALENDAR_CLEAR 46511
#define IDS_FORM_CALENDAR_TODAY 46512
#define IDS_FORM_SUBMIT_LABEL 46513
#define IDS_FORM_INPUT_ALT 46514
#define IDS_FORM_RESET_LABEL 46515
#define IDS_FORM_FILE_BUTTON_LABEL 46516
#define IDS_FORM_MULTIPLE_FILES_BUTTON_LABEL 46517
#define IDS_FORM_FILE_NO_FILE_LABEL 46518
#define IDS_FORM_FILE_MULTIPLE_UPLOAD 46519
#define IDS_FORM_OTHER_COLOR_LABEL 46520
#define IDS_FORM_OTHER_DATE_LABEL 46521
#define IDS_FORM_OTHER_MONTH_LABEL 46522
#define IDS_FORM_OTHER_WEEK_LABEL 46523
#define IDS_FORM_PLACEHOLDER_FOR_DAY_OF_MONTH_FIELD 46524
#define IDS_FORM_PLACEHOLDER_FOR_MONTH_FIELD 46525
#define IDS_FORM_PLACEHOLDER_FOR_YEAR_FIELD 46526
#define IDS_FORM_SELECT_MENU_LIST_TEXT 46527
#define IDS_FORM_THIS_MONTH_LABEL 46528
#define IDS_FORM_THIS_WEEK_LABEL 46529
#define IDS_FORM_WEEK_NUMBER_LABEL 46530
#define IDS_DEBUGGER_PAUSED_IN_ANOTHER_TAB 46531
#define IDS_VIEW_SOURCE_LINE_WRAP 46532
#define IDS_FORM_INPUT_WEEK_TEMPLATE 46533
#define IDS_FORM_VALIDATION_VALUE_MISSING_MULTIPLE_FILE 46534
#define IDS_FORM_VALIDATION_TYPE_MISMATCH 46535
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_EMPTY 46536
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_EMPTY_DOMAIN 46537
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_EMPTY_LOCAL 46538
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_INVALID_DOMAIN 46539
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_INVALID_DOTS 46540
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_INVALID_LOCAL 46541
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_NO_AT_SIGN 46542
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_MULTIPLE_EMAIL 46543
#define IDS_FORM_VALIDATION_VALUE_NOT_EQUAL 46544
#define IDS_FORM_VALIDATION_VALUE_NOT_EQUAL_DATETIME 46545
#define IDS_FORM_VALIDATION_RANGE_UNDERFLOW 46546
#define IDS_FORM_VALIDATION_RANGE_UNDERFLOW_DATETIME 46547
#define IDS_FORM_VALIDATION_RANGE_OVERFLOW 46548
#define IDS_FORM_VALIDATION_RANGE_OVERFLOW_DATETIME 46549
#define IDS_FORM_VALIDATION_REVERSED_RANGE_OUT_OF_RANGE_TIME 46550
#define IDS_FORM_VALIDATION_RANGE_REVERSED 46551
#define IDS_FORM_VALIDATION_RANGE_INVALID_DATETIME 46552
#define IDS_FORM_VALIDATION_BAD_INPUT_DATETIME 46553
#define IDS_FORM_VALIDATION_BAD_INPUT_NUMBER 46554
#define IDS_PRETTY_PRINT_JSON 46555
#define IDS_FORM_VALIDATION_VALUE_MISSING 46556
#define IDS_FORM_VALIDATION_VALUE_MISSING_CHECKBOX 46557
#define IDS_FORM_VALIDATION_VALUE_MISSING_FILE 46558
#define IDS_FORM_VALIDATION_VALUE_MISSING_RADIO 46559
#define IDS_FORM_VALIDATION_VALUE_MISSING_SELECT 46560
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL 46561
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_URL 46562
#define IDS_FORM_VALIDATION_PATTERN_MISMATCH 46563
#define IDS_FORM_VALIDATION_STEP_MISMATCH 46564
#define IDS_FORM_VALIDATION_STEP_MISMATCH_CLOSE_TO_LIMIT 46565
#define IDS_FORM_VALIDATION_TOO_LONG 46566
#define IDS_FORM_VALIDATION_TOO_SHORT 46567
#define IDS_FORM_VALIDATION_TOO_SHORT_PLURAL 46568
#define IDS_MEDIA_SESSION_DATA_SOURCE 46569
#define IDS_MEDIA_SESSION_FILE_SOURCE 46570
#define IDS_MEDIA_OVERFLOW_MENU_CLOSED_CAPTIONS 46571
#define IDS_MEDIA_OVERFLOW_MENU_CLOSED_CAPTIONS_SUBMENU_TITLE 46572
#define IDS_MEDIA_TRACK_IDENTIFIER_VERBOSE_TITLE_NUMBERED 46573
#define IDS_MEDIA_OVERFLOW_MENU_SHOW_AUDIO_TRACK_MENU_BUTTON 46574
#define IDS_MEDIA_OVERFLOW_MENU_SHOW_VIDEO_TRACK_MENU_BUTTON 46575
#define IDS_MEDIA_OVERFLOW_MENU_TRACK_SELECTION_SUBMENU_TITLE 46576
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED 46577
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_SUBMENU_TITLE 46578
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_0_25X_TITLE 46579
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_0_5X_TITLE 46580
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_0_75X_TITLE 46581
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_NORMAL_TITLE 46582
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_1_25X_TITLE 46583
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_1_5X_TITLE 46584
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_1_75X_TITLE 46585
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_2X_TITLE 46586
#define IDS_MEDIA_OVERFLOW_MENU_CAST 46587
#define IDS_MEDIA_OVERFLOW_MENU_ENTER_FULLSCREEN 46588
#define IDS_MEDIA_OVERFLOW_MENU_EXIT_FULLSCREEN 46589
#define IDS_MEDIA_OVERFLOW_MENU_MUTE 46590
#define IDS_MEDIA_OVERFLOW_MENU_UNMUTE 46591
#define IDS_MEDIA_OVERFLOW_MENU_PLAY 46592
#define IDS_MEDIA_OVERFLOW_MENU_PAUSE 46593
#define IDS_MEDIA_OVERFLOW_MENU_DOWNLOAD 46594
#define IDS_MEDIA_OVERFLOW_MENU_ENTER_PICTURE_IN_PICTURE 46595
#define IDS_MEDIA_OVERFLOW_MENU_EXIT_PICTURE_IN_PICTURE 46596
#define IDS_MEDIA_PICTURE_IN_PICTURE_INTERSTITIAL_TEXT 46597
#define IDS_MEDIA_REMOTING_CAST_TEXT 46598
#define IDS_MEDIA_REMOTING_CAST_TO_UNKNOWN_DEVICE_TEXT 46599
#define IDS_MEDIA_REMOTING_STOP_TEXT 46600
#define IDS_MEDIA_REMOTING_STOP_BY_PLAYBACK_QUALITY_TEXT 46601
#define IDS_MEDIA_REMOTING_STOP_BY_ERROR_TEXT 46602
#define IDS_MEDIA_SCRUBBING_MESSAGE_TEXT 46603
#define IDS_MEDIA_TRACKS_NO_LABEL 46604
#define IDS_MEDIA_TRACKS_OFF 46605
#define IDS_PLUGIN_INITIALIZATION_ERROR 46606
#define IDS_MEDIA_PLAYBACK_ERROR 46607
#define IDS_UNITS_KIBIBYTES 46608
#define IDS_UNITS_MEBIBYTES 46609
#define IDS_UNITS_GIBIBYTES 46610
#define IDS_UNITS_TEBIBYTES 46611
#define IDS_UNITS_PEBIBYTES 46612

// ---------------------------------------------------------------------------
// From branded_strings.h:

#define IDS_RELAUNCH_CONFIRMATION_DIALOG_TITLE 800
#define IDS_SETTINGS_ABOUT_PROGRAM 801
#define IDS_SETTINGS_GET_HELP_USING_CHROME 802
#define IDS_SETTINGS_UPGRADE_UPDATING 803
#define IDS_SETTINGS_UPGRADE_UPDATING_PERCENT 804
#define IDS_SETTINGS_UPGRADE_SUCCESSFUL_RELAUNCH 805
#define IDS_SETTINGS_UPGRADE_UP_TO_DATE 806
#define IDS_SETTINGS_CHECK_PASSWORDS_ERROR_OFFLINE 809
#define IDS_SETTINGS_CHECK_PASSWORDS_ERROR_SIGNED_OUT 810
#define IDS_SETTINGS_CHECK_PASSWORDS_ERROR_NO_PASSWORDS 811
#define IDS_SETTINGS_CHECK_PASSWORDS_ERROR_QUOTA_LIMIT_GOOGLE_ACCOUNT 812
#define IDS_SETTINGS_CHECK_PASSWORDS_ERROR_QUOTA_LIMIT 813
#define IDS_SETTINGS_CHECK_PASSWORDS_ERROR_GENERIC 814
#define IDS_SETTINGS_NO_COMPROMISED_CREDENTIALS_LABEL 815
#define IDS_SETTINGS_SIGNED_OUT_USER_LABEL 816
#define IDS_SETTINGS_SIGNED_OUT_USER_HAS_COMPROMISED_CREDENTIALS_LABEL 817
#define IDS_SETTINGS_WEAK_PASSWORDS_DESCRIPTION_GENERATION 818
#define IDS_SETTINGS_COMPROMISED_EDIT_DISCLAIMER_DESCRIPTION 819
#define IDS_SETTINGS_AUTOFILL_AI_WHEN_ON_USE_TO_FILL 820
#define IDS_SETTINGS_DEFAULT_BROWSER_DEFAULT 821
#define IDS_SETTINGS_DEFAULT_BROWSER_DEFAULT_THANK_YOU 822
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT 823
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT_USER_VALUE 824
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT_AND_PIN 825
#define IDS_SETTINGS_DEFAULT_BROWSER_ERROR 826
#define IDS_SETTINGS_DEFAULT_BROWSER_SECONDARY 827
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_WHEN_ON_BULLET_TWO 828
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_WHEN_ON_BULLET_TWO 829
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_THINGS_TO_CONSIDER_BULLET_TWO 830
#define IDS_SETTINGS_PRELOAD_PAGES_THINGS_TO_CONSIDER_BULLET_ONE 831
#define IDS_SETTINGS_SPELLING_PREF_DESC 832
#define IDS_SETTINGS_RESTART_TO_APPLY_CHANGES 833
#define IDS_SETTINGS_SIGNIN_ALLOWED 834
#define IDS_SETTINGS_SIGNIN_ALLOWED_DESC 835
#define IDS_SETTINGS_SIGNIN_ALLOWED_DESC_2 836
#define IDS_SETTINGS_SITE_SETTINGS_PDFS_BLOCKED 837
#define IDS_SETTINGS_SITE_SITE_DETAILS_CAMERA_BLOCKED_BY_OS 838
#define IDS_SETTINGS_SITE_SITE_DETAILS_MICROPHONE_BLOCKED_BY_OS 839
#define IDS_SETTINGS_SITE_SITE_DETAILS_LOCATION_BLOCKED_BY_OS 840
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_BLOCKED_BY_OS 841
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_BLOCKED_BY_OS 842
#define IDS_SETTINGS_SITE_SETTINGS_MIC_BLOCKED_BY_OS 843
#define IDS_SETTINGS_SITE_DATA_PAGE_CLEAR_ON_EXIT_WITH_EXCEPTION_RADIO_SUBLABEL 844
#define IDS_SETTINGS_SITE_DATA_PAGE_DELETE_ON_EXIT_EXCEPTIONS_SUB_HEADING 845
#define IDS_SETTINGS_PRIVACY_GUIDE_PROMO_BODY 846
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_STANDARD_PROTECTION_FEATURE_DESCRIPTION2 847
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_STANDARD_PROTECTION_PRIVACY_DESCRIPTION1 848
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_PRIVACY_SANDBOX_SUB_LABEL 849
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_WAA_SUB_LABEL 850
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_FEATURE_DESCRIPTION3 851
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_PRIVACY_DESCRIPTION2 852
#define IDS_SETTINGS_PRIVACY_SANDBOX_LEARN_MORE_DIALOG_TOPICS_TITLE 853
#define IDS_SETTINGS_PRIVACY_SANDBOX_AD_MEASUREMENT_DIALOG_DESCRIPTION 854
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_SETTING_SUBLABEL 855
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_AND_NOTIFICATIONS_SETTING_SUBLABEL 856
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_TWO 857
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_BULLET_TWO 858
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_WHEN_ON_BULLET_ONE 859
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_LEARN_MORE_LABEL 860
#define IDS_SETTINGS_SECURE_DNS_DESCRIPTION 861
#define IDS_SETTINGS_SYNC_DISCONNECT_DELETE_PROFILE_WARNING_WITH_COUNTS_SINGULAR 862
#define IDS_SETTINGS_SYNC_DISCONNECT_DELETE_PROFILE_WARNING_WITH_COUNTS_PLURAL 863
#define IDS_SETTINGS_SYNC_DISCONNECT_DELETE_PROFILE_WARNING_WITHOUT_COUNTS 864
#define IDS_SETTINGS_CUSTOMIZE_YOUR_CHROME_PROFILE 865
#define IDS_SETTING_NAME_YOUR_PROFILE 866
#define IDS_SETTINGS_PEOPLE_SIGN_IN_PROMPT_SECONDARY_WITH_ACCOUNT 867
#define IDS_SETTINGS_PEOPLE_EXPLICIT_SIGN_IN_PROMPT_SECONDARY_WITH_NO_ACCOUNT 868
#define IDS_SETTINGS_PEOPLE_EXPLICIT_SIGN_IN_PROMPT_SECONDARY_WITH_NO_ACCOUNT_WITH_BOOKMARKS 869
#define IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_TITLE 870
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTIONS_TITLE 872
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTIONS_DESC 873
#define IDS_SETTINGS_PEOPLE_SIGNIN_SECTION_SIGNED_OUT_TITLE 874
#define IDS_SETTINGS_SYNC_DATA_ENCRYPTED_TEXT 875
#define IDS_SETTINGS_SYNC_DISCONNECT_TITLE 876
#define IDS_SETTINGS_SUGGEST_PREF_DESC 877
#define IDS_SETTINGS_SEARCH_AGGREGATOR_PREF_DESC 878
#define IDS_SETTINGS_SYNC_SIGN_IN_PROMPT_WITH_NO_ACCOUNT 879
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_DESC 880
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_DESC_WITH_LINKED_SERVICES 881
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_LINKED_SERVICES_DESC 882
#define IDS_SETTINGS_ERROR_PASSPHRASE_USER_ERROR_DESCRIPTION 883
#define IDS_SETTINGS_ERROR_TRUSTED_VAULT_USER_ERROR_DESCRIPTION 884
#define IDS_SETTINGS_ERROR_UPGRADE_CLIENT_USER_ERROR_DESCRIPTION 885
#define IDS_SETTINGS_PENDING_STATE_DESCRIPTION 886
#define IDS_SETTINGS_ERROR_PASSPHRASE_USER_ERROR_DESCRIPTION_WITH_EMAIL 887
#define IDS_SETTINGS_SIGN_OUT 888
#define IDS_SETTINGS_ACCOUNT_DATA_DASHBOARD 889
#define IDS_SETTINGS_ENCRYPT_ACCOUNT_DATA_WITH_PASSPHRASE_LABEL 890
#define IDS_SETTINGS_ENCRYPT_ACCOUNT_DATA_WITH_PASSPHRASE_EXPLANATION_TEXT 891
#define IDS_SETTINGS_PASSPHRASE_RESET_HINT_ACCOUNT_DATA_ENCRYPTION 892
#define IDS_SETTINGS_PAGE_CONTENT_THINGS_TO_CONSIDER_BULLET_TWO 893
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_SETTING_DESCRIPTION 894
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_SETTING_DESCRIPTION 895
#define IDS_SETTINGS_PERFORMANCE_PRELOAD_TOGGLE_SUMMARY 896
#define IDS_SETTINGS_SYSTEM_BACKGROUND_APPS_LABEL 899
#define IDS_SETTINGS_RESET_PROFILE_FEEDBACK 900
#define IDS_SETTINGS_SAFETY_HUB_ENTRY_POINT_NOTHING_TO_DO 901
#define IDS_SETTINGS_SAFETY_HUB_ENTRY_POINT_HEADER 902
#define IDS_SETTINGS_SAFETY_HUB_EMPTY_STATE_MODULE_SUBHEADER 903
#define IDS_SETTINGS_SAFETY_HUB_VERSION_MODULE_UPPERCASE_NAME 904
#define IDS_SETTINGS_SAFETY_HUB_VERSION_MODULE_LOWERCASE_NAME 905
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_NO_PASSWORDS 906
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_MODULE_HEADER 907
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_DATA_HEADER 908
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_DATA_SUBHEADER 909
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_INCOGNITO_HEADER 910
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_SAFE_BROWSING_SUBHEADER 911
#define IDS_SETTINGS_SAFETY_HUB_VERSION_CARD_HEADER_RESTART 912
#define IDS_SETTINGS_SAFETY_HUB_VERSION_CARD_HEADER_UPDATED 913
#define IDS_SETTINGS_SAFETY_HUB_VERSION_NAVIGATION_ARIA_LABEL 914
#define IDS_SETTINGS_SAFETY_HUB_VERSION_RELAUNCH_ARIA_LABEL 915
#define IDS_SETTINGS_SAFETY_HUB_UNUSED_SITE_PERMISSIONS_REMOVED_ONE_PERMISSION_LABEL 916
#define IDS_SETTINGS_SAFETY_HUB_UNUSED_SITE_PERMISSIONS_REMOVED_TWO_PERMISSIONS_LABEL 917
#define IDS_SETTINGS_SAFETY_HUB_UNUSED_SITE_PERMISSIONS_REMOVED_THREE_PERMISSIONS_LABEL 918
#define IDS_SETTINGS_SAFETY_HUB_UNUSED_SITE_PERMISSIONS_REMOVED_FOUR_OR_MORE_PERMISSIONS_LABEL 919
#define IDS_SETTINGS_SAFETY_HUB_ABUSIVE_NOTIFICATION_PERMISSIONS_SETTING_SUBLABEL 920
#define IDS_SETTINGS_SECURITY_PASSWORDS_LEAK_DETECTION_DESC 921
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_HOW_IT_WORKS_CONTENT 922
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_UNRECOGNIZED_SITES_DESCRIPTION 923
#define IDS_SETTINGS_SECURITY_BUNDLE_ENHANCED_BULLET_ONE 924
#define IDS_SETTINGS_SECURE_CONNECTIONS_SECTION_DESCRIPTION 925
#define IDS_SETTINGS_HTTPS_FIRST_MODE_SUBTITLE 926
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_FULL_SUBLABEL 927
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_INCOGNITO_SUBLABEL 928
#define IDS_SETTINGS_HTTPS_FIRST_MODE_DISABLED_SUBLABEL 929
#define IDS_PRODUCT_NAME 930
#define IDS_SHORT_PRODUCT_NAME 931
#define IDS_FIRST_RUN_DIALOG_WINDOW_TITLE 937
#define IDS_TERMS_DIALOG_ACCEPT 938
#define IDS_TERMS_DIALOG_CANCEL 939
#define IDS_TERMS_DIALOG_TITLE 940
#define IDS_TERMS_DIALOG_ACCESSIBILITY_LABEL 941
#define IDS_PRODUCT_LOGO_ENTERPRISE_ALT_TEXT 945
#define IDS_TASK_MANAGER_TITLE 947
#define IDS_TASK_MANAGER_SEARCH_PLACEHOLDER 948
#define IDS_TASK_MANAGER_SEARCH_ACCESSIBILITY_NAME 949
#define IDS_TASK_MANAGER_CLEAR_SEARCH_BUTTON_ACCESSIBILITY_NAME 950
#define IDS_TASK_MANAGER_KILL_ACCESSIBILITY_NAME 951
#define IDS_TASK_MANAGER_TASK_KILL_SUCCESS_ACCESSIBILITY_MESSAGE 952
#define IDS_TASK_MANAGER_TASK_KILL_FAIL_ACCESSIBILITY_MESSAGE 953
#define IDS_TASK_MANAGER_CATEGORY_TABS_AND_EXTENSIONS_NAME 954
#define IDS_TASK_MANAGER_CATEGORY_SYSTEM_NAME 955
#define IDS_TASK_MANAGER_CATEGORY_BROWSER_NAME 956
#define IDS_TASK_MANAGER_CATEGORY_ALL_NAME 957
#define IDS_SESSION_CRASHED_VIEW_UMA_OPTIN 958
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_TOO_MANY_BOOKMARKS_BODY 959
#define IDS_RESET_PROFILE_SETTINGS_EXPLANATION_IN_BULLET_POINTS 960
#define IDS_BROWSER_WINDOW_TITLE_FORMAT 961
#define IDS_CAPTIVE_PORTAL_BROWSER_WINDOW_TITLE_FORMAT 962
#define IDS_ACCESSIBLE_BROWSER_WINDOW_TITLE_FORMAT 963
#define IDS_ACCESSIBLE_BETA_BROWSER_WINDOW_TITLE_FORMAT 964
#define IDS_ACCESSIBLE_DEV_BROWSER_WINDOW_TITLE_FORMAT 965
#define IDS_ACCESSIBLE_CANARY_BROWSER_WINDOW_TITLE_FORMAT 966
#define IDS_ABOUT_VERSION_COMPANY_NAME 967
#define IDS_ABOUT_VERSION_COPYRIGHT 968
#define IDS_ABOUT_TERMS_OF_SERVICE 972
#define IDS_LINUX_OBSOLETE 978
#define IDS_ACCNAME_APP 979
#define IDS_COULDNT_STARTUP_PROFILE_ERROR 981
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_HELP_TEXT_NO_DEVICES 982
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_HELP_TEXT_NO_DEVICES_ORIGIN 983
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TEXT_DEVICE_NOT_FOUND 984
#define IDS_FR_CUSTOMIZE_DEFAULT_BROWSER 988
#define IDS_DEFAULT_BROWSER_CHANGED_MESSAGE 989
#define IDS_STATUS_TRAY_KEEP_CHROME_RUNNING_IN_BACKGROUND 990
#define IDS_STATUS_TRAY_KEEP_CHROME_RUNNING_IN_BACKGROUND_SETTING 991
#define IDS_CANT_WRITE_USER_DIRECTORY_SUMMARY 992
#define IDS_PROFILE_TOO_NEW_ERROR 994
#define IDS_PREFERENCES_UNREADABLE_ERROR 995
#define IDS_PREFERENCES_CORRUPT_ERROR 996
#define IDS_DESKTOP_SHORTCUT_COMMENT 997
#define IDS_PASSWORD_MANAGER_ONBOARDING_DETAILS_C 998
#define IDS_PASSWORD_MANAGER_TITLE_BRAND 999
#define IDS_PASSWORD_BUBBLES_PASSWORD_MANAGER_LINK_TEXT_SAVING_ON_DEVICE 1000
#define IDS_PASSWORD_MANAGER_SAVE_PASSWORD_SIGNED_OUT_MESSAGE_DESCRIPTION 1001
#define IDS_PASSWORD_MANAGER_UPDATE_PASSWORD_SIGNED_OUT_MESSAGE_DESCRIPTION 1002
#define IDS_PASSWORD_MANAGER_IMPORT_DIALOG_TITLE 1023
#define IDS_PASSWORD_MANAGER_EXPORT_DIALOG_TITLE 1024
#define IDS_DEFAULT_BROWSER_INFOBAR_TEXT 1032
#define IDS_DEFAULT_BROWSER_PIN_INFOBAR_TEXT 1033
#define IDS_DEFAULT_BROWSER_MODAL_TITLE_WITH_SETTINGS_ILLUSTRATION 1034
#define IDS_DEFAULT_BROWSER_MODAL_BODY_WITH_SETTINGS_ILLUSTRATION 1035
#define IDS_DEFAULT_BROWSER_MODAL_BODY_WITH_SETTINGS_ILLUSTRATION_UNPINNED 1036
#define IDS_DEFAULT_BROWSER_MODAL_TITLE_WITHOUT_SETTINGS_ILLUSTRATION 1037
#define IDS_DEFAULT_BROWSER_MODAL_BODY_WITHOUT_SETTINGS_ILLUSTRATION 1038
#define IDS_DEFAULT_BROWSER_MODAL_BODY_WITHOUT_SETTINGS_ILLUSTRATION_UNPINNED 1039
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_TITLE 1040
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_BODY 1041
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_STEPS_PINNED_COMBINED 1042
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_UNKNOWN_SOURCE 1044
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_BLOCKED_LEARN_MORE_LINK 1045
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_DEEP_SCANNING_PROMPT_LOCAL_DECRYPTION 1046
#define IDS_DOWNLOAD_STATUS_CRX_INSTALL_RUNNING 1047
#define IDS_PROMPT_DOWNLOAD_CHANGES_SETTINGS 1048
#define IDS_PROMPT_MALICIOUS_DOWNLOAD_URL 1049
#define IDS_PROMPT_MALICIOUS_DOWNLOAD_CONTENT 1050
#define IDS_BLOCK_REASON_PROMPT_FOR_SCANNING 1051
#define IDS_BLOCK_DOWNLOAD_REASON_DANGEROUS_FILETYPE 1052
#define IDS_BLOCK_DOWNLOAD_REASON_DANGEROUS 1053
#define IDS_BLOCK_DOWNLOAD_REASON_DANGEROUS_COOKIE_THEFT 1054
#define IDS_BLOCK_DOWNLOAD_REASON_UNCOMMON 1055
#define IDS_BLOCK_DOWNLOAD_REASON_UNCOMMON_SUSPICIOUS_ARCHIVE 1056
#define IDS_BLOCK_DOWNLOAD_REASON_POTENTIALLY_UNWANTED 1057
#define IDS_BLOCK_DOWNLOAD_REASON_INSECURE 1058
#define IDS_BLOCK_DOWNLOAD_REASON_UNVERIFIED_NO_SAFE_BROWSING 1059
#define IDS_DOWNLOAD_WARNING_BYPASS_PROMPT_LEARN_MORE_LINK 1060
#define IDS_DOWNLOAD_WARNING_BYPASS_PROMPT_LEARN_MORE_LINK_ACCESSIBLE 1061
#define IDS_ABANDON_DOWNLOAD_DIALOG_BROWSER_MESSAGE 1062
#define IDS_MISSING_GOOGLE_API_KEYS 1064
#define IDS_EXTENSION_INSTALLED_HEADING 1065
#define IDS_EXTENSION_UNINSTALL_PROMPT_REMOVE_DATA_CHECKBOX 1066
#define IDS_EXTENSION_ALERT_ITEM_BLOCKLISTED_MALWARE 1067
#define IDS_EXTENSIONS_ALERT_ITEM_BLOCKLISTED_MALWARE_TITLE 1068
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_KEEP_DIALOG_DESCRIPTION 1069
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_DISABLED_DIALOG_DESCRIPTION 1070
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_DISABLED_SUBTITLE 1071
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_DISABLED_SUBTITLE 1072
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_REMOVE_BUTTON_ACC_LABEL 1073
#define IDS_SAFETY_CHECK_EXTENSIONS_MALWARE 1074
#define IDS_SAFETY_CHECK_EXTENSIONS_POLICY_VIOLATION 1075
#define IDS_SAFETY_CHECK_EXTENSIONS_UNPUBLISHED 1076
#define IDS_EXTENSIONS_SAFETY_CHECK_PRIMARY_LABEL 1077
#define IDS_EXTENSIONS_SAFETY_CHECK_OFFSTORE 1078
#define IDS_EXTENSIONS_SAFETY_CHECK_OFFSTORE_ON 1079
#define IDS_EXTENSIONS_SAFETY_CHECK_OFFSTORE_OFF 1080
#define IDS_EXTENSIONS_SAFETY_CHECK_NO_PRIVACY_PRACTICES 1081
#define IDS_EXTENSIONS_SC_DESCRIPTION 1082
#define IDS_EXTENSIONS_ITEM_SHOW_ACCESS_REQUESTS_IN_TOOLBAR 1083
#define IDS_EXTENSIONS_INCOGNITO_WARNING 1084
#define IDS_EXTENSIONS_UNINSTALL 1085
#define IDS_EXTENSIONS_SHORTCUT_SCOPE_IN_CHROME 1086
#define IDS_PENDING_CHANGE_WARNING 1087
#define IDS_EXTENSIONS_MULTIPLE_UNSUPPORTED_DISABLED_BODY 1088
#define IDS_EXTENSIONS_SINGLE_UNSUPPORTED_DISABLED_BODY 1089
#define IDS_APPMENU_TOOLTIP 1090
#define IDS_APPMENU_TOOLTIP_UPDATE_AVAILABLE 1091
#define IDS_APPMENU_TOOLTIP_ALERT 1092
#define IDS_OPEN_IN_CHROME 1093
#define IDS_ABOUT 1094
#define IDS_RELAUNCH_TO_UPDATE 1095
#define IDS_CUSTOMIZE_CHROME 1099
#define IDS_OTHER_CHROME_PROFILES_TITLE 1100
#define IDS_MANAGE_CHROME_PROFILES 1101
#define IDS_VIEW_PASSWORDS 1102
#define IDS_CHROME_SIGNIN_TITLE 1103
#define IDS_PROFILES_DICE_SYNC_PROMO 1104
#define IDS_SYNC_WRONG_EMAIL 1105
#define IDS_SYNC_USED_PROFILE_ERROR 1106
#define IDS_SESSION_RESTORE_TURN_OFF_RESTORE_FROM_SESSION 1107
#define IDS_SESSION_RESTORE_TURN_OFF_RESTORE_FROM_RESTART 1108
#define IDS_SESSION_RESTORE_TURN_ON 1109
#define IDS_SESSION_RESTORE_LINK 1110
#define IDS_SESSION_RESTORE_LINK_ARIA_LABEL 1111
#define IDS_ENTERPRISE_VALUE_PROPOSITION_PROFILE_REQUIRED_BY_ORG_TITLE 1112
#define IDS_AI_SIGNIN_PROMO_SUBTITLE 1113
#define IDS_AI_SIGNIN_PROMO_AVATAR_PILL_TEXT 1114
#define IDS_ENTERPRISE_SIGNIN_TITLE 1115
#define IDS_ENTERPRISE_SIGNIN_EXPLANATION_WITHOUT_PROFILE_CREATION 1116
#define IDS_ENTERPRISE_SIGNIN_EXPLANATION_WITH_PROFILE_CREATION 1117
#define IDS_ENTERPRISE_VALUE_PROPOSITION_PROFILE_REQUIRED_BY_ORG_KNOWN_DOMAIN_TITLE 1118
#define IDS_ENTERPRISE_VALUE_PROPOSITION_PROFILE_SUGGESTED_TITLE 1119
#define IDS_MANAGEMENT_DIALOG_BROWSER_MANAGED 1120
#define IDS_MANAGEMENT_DIALOG_BROWSER_MANAGED_BY 1121
#define IDS_MANAGEMENT_DIALOG_BROWSER_MANAGED_BY_MULTIPLE_ORGANIZATIONS 1122
#define IDS_MANAGED_PROFILE_INTERSTITIAL_PRIMARY_PARAGRAPH 1123
#define IDS_EXTENSION_ASKS_IDENTITY_WHILE_SIGNED_IN_WEB_ONLY_TITLE 1124
#define IDS_EXTENSION_ASKS_IDENTITY_WHILE_SIGNED_IN_WEB_ONLY_BODY_PART_1 1125
#define IDS_EXTENSION_ASKS_IDENTITY_WHILE_SIGNED_IN_WEB_ONLY_TITLE_FALLBACK 1126
#define IDS_ABOUT_BROWSER_SWITCH_DESCRIPTION_UNKNOWN_BROWSER 1127
#define IDS_ABOUT_BROWSER_SWITCH_DESCRIPTION_KNOWN_BROWSER 1128
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CATEGORY_YOUR_CHROME 1129
#define IDS_NTP_CUSTOMIZE_BUTTON_LABEL 1130
#define IDS_NTP_MODULES_SETUP_LIST_TITLE 1131
#define IDS_NTP_CUSTOMIZE_CHROME_RESET_TO_CLASSIC_CHROME_LABEL 1132
#define IDS_NTP_CUSTOMIZATION_PROMO 1133
#define IDS_NTP_MOBILE_PROMO_TITLE 1134
#define IDS_NTP_MOBILE_PROMO_PASSWORDS_TITLE 1135
#define IDS_NTP_SIGN_IN_PROMO_WITH_BOOKMARKS 1136
#define IDS_IPH_CUSTOMIZE_CHROME_AUTO_OPEN_BODY 1137
#define IDS_IPH_CUSTOMIZE_CHROME_AUTO_OPEN_SCREENREADER 1138
#define IDS_IPH_REALBOX_CONTEXTUAL_ENTRYPOINT 1139
#define IDS_IPH_REALBOX_CONTEXTUAL_ENTRYPOINT_SCREENREADER 1140
#define IDS_SIGNIN_EMAIL_CONFIRMATION_TITLE 1141
#define IDS_AVATAR_BUTTON_INTERCEPT_BUBBLE_CHROME_SIGNIN_TEXT 1142
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_TITLE 1143
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_DECLINE_TEXT 1144
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_CREATE_BUBBLE_TITLE_V2 1145
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_TITLE 1146
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_DESC_V2 1147
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_DESC_V2_SUPERVISED 1148
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_CONSUMER_BUBBLE_DESC 1149
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_CREATE_BUBBLE_DESC 1150
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_SUBTITLE 1151
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_SUBTITLE_WITH_BOOKMARKS 1152
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_SUBTITLE_SUPERVISED 1153
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_IPH_TEXT_SIGNIN_REMINDER 1154
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_IPH_TEXT_SIGNIN_REMINDER_SCREENREADER 1155
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_NO_UNSYNCED_TITLE 1156
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_NO_UNSYNCED_BODY 1157
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_NO_UNSYNCED_DATA_BODY 1158
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_VERIFY_BODY 1159
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_VERIFY_BODY_WITH_COUNT 1160
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_UNSYNCED_BODY 1161
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_UNSYNCED_BODY_WITH_COUNT 1162
#define IDS_CLOSE_WARNING_FOR_CLEAR_COOKIES_ON_EXIT_TEXT 1163
#define IDS_SYNC_PASSPHRASE_DIALOG_FOOTER 1164
#define IDS_SYNC_PASSPHRASE_DIALOG_FOOTER_LINK_ACC 1165
#define IDS_SYNC_PASSPHRASE_DIALOG_BODY 1166
#define IDS_AVATAR_BUTTON_INTERCEPT_BUBBLE_CHROME_SIGNIN_ACCESSIBILITY_LABEL 1167
#define IDS_AVATAR_BUTTON_SIGNIN_PENDING_ACCESSIBILITY_LABEL 1168
#define IDS_AUTOFILL_SIGNIN_PROMO_SUBTITLE_PASSWORD 1169
#define IDS_AUTOFILL_SIGNIN_PROMO_SUBTITLE_ADDRESS 1170
#define IDS_PROFILE_CUSTOMIZATION_TEXT 1171
#define IDS_PROFILE_CUSTOMIZATION_TITLE_V2 1172
#define IDS_PROFILE_MENU_SIGNIN_PROMO_BUTTON 1177
#define IDS_PROFILE_MENU_PLACEHOLDER_PROFILE_NAME 1178
#define IDS_PROFILE_MENU_SIGN_OUT_WHEN_SIGNIN_PENDING 1179
#define IDS_PROFILE_MENU_PROFILES_LIST_TITLE 1180
#define IDS_PROFILE_MENU_MANAGE_PROFILES 1181
#define IDS_PROFILE_MENU_SIGN_OUT 1182
#define IDS_PROFILE_MENU_ADD_PROFILE 1183
#define IDS_APP_ALSO_DELETE_APPS_DATA 1185
#define IDS_APP_SHORTCUTS_SUBDIR_NAME 1186
#define IDS_APP_SHORTCUTS_SUBDIR_NAME_CANARY 1187
#define IDS_MEDIA_STREAM_STATUS_TRAY_TEXT_AUDIO_AND_VIDEO 1191
#define IDS_MEDIA_STREAM_STATUS_TRAY_TEXT_AUDIO_ONLY 1192
#define IDS_MEDIA_STREAM_STATUS_TRAY_TEXT_VIDEO_ONLY 1193
#define IDS_WEBHID_SYSTEM_TRAY_ICON_TITLE 1194
#define IDS_WEBUSB_SYSTEM_TRAY_ICON_TITLE 1195
#define IDS_PROFILE_IN_USE_POSIX 1196
#define IDS_LOGIN_POD_USER_REMOVE_WARNING_SYNC 1198
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_INTRO_TITLE 1199
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_INTRO_TEXT 1200
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_YOUR_CHROME_TITLE 1201
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_YOUR_CHROME_TEXT 1202
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_GUEST_TEXT 1203
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_FRIENDS_TEXT 1204
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_OUTRO_TEXT 1205
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_OUTRO_ADD_USER 1206
#define IDS_TUTORIAL_PASSWORD_MANAGER_OPEN_APP_MENU 1207
#define IDS_TUTORIAL_PASSWORD_MANAGER_CLICK_PASSWORD_MANAGER 1208
#define IDS_TUTORIAL_PASSWORD_MANAGER_SUCCESS_BODY 1209
#define IDS_PASSWORD_MANAGER_IPH_CREATE_SHORTCUT_BODY 1210
#define IDS_EXTENSIONS_SETTINGS_API_SECOND_LINE_START_PAGES 1211
#define IDS_EXTENSIONS_SETTINGS_API_SECOND_LINE_START_AND_SEARCH 1212
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES_ACTIVE_SHORTCUTS_EXPLANATION 1213
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES_INACTIVE_SHORTCUTS_EXPLANATION 1214
#define IDS_WEBSTORE_APP_DESCRIPTION 1215
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_BUBBLE_TEXT 1224
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_BUBBLE_TEXT_ONCE 1225
#define IDS_CONTENT_CONTEXT_SPELLING_BUBBLE_TEXT 1226
#define IDS_CONTENT_CONTEXT_OPENLINKNEWTAB_INAPP 1227
#define IDS_CONTENT_CONTEXT_OPENLINKOFFTHERECORD_INAPP 1228
#define IDS_AVATAR_BUTTON_MAKING_CHROME_YOURS 1229
#define IDS_AVATAR_BUTTON_SIGNIN_PROMO 1230
#define IDS_UPDATE_RECOMMENDED_DIALOG_TITLE 1231
#define IDS_UPDATE_RECOMMENDED 1232
#define IDS_RELAUNCH_AND_UPDATE 1233
#define IDS_UPDATE_RECOMMENDED_DIALOG_TITLE_ALT 1234
#define IDS_UPDATE_RECOMMENDED_ALT 1235
#define IDS_REINSTALL_APP 1236
#define IDS_UPGRADE_BUBBLE_MENU_ITEM 1237
#define IDS_UPGRADE_BUBBLE_TITLE 1238
#define IDS_UPGRADE_BUBBLE_TEXT 1239
#define IDS_SYNC_ERROR_USER_MENU_UPGRADE_BUTTON 1240
#define IDS_SYNC_ERROR_PASSPHRASE_USER_MENU_ERROR_DESCRIPTION 1241
#define IDS_SYNC_ERROR_TRUSTED_VAULT_USER_MENU_ERROR_DESCRIPTION 1242
#define IDS_SYNC_ERROR_UPGRADE_CLIENT_USER_MENU_TITLE 1243
#define IDS_SYNC_ERROR_UPGRADE_CLIENT_USER_MENU_ERROR_DESCRIPTION 1244
#define IDS_SYNC_UPGRADE_CLIENT 1245
#define IDS_SYNC_UPGRADE_CLIENT_BUTTON 1246
#define IDS_RECOVERY_BUBBLE_TITLE 1247
#define IDS_RUN_RECOVERY 1248
#define IDS_RECOVERY_BUBBLE_TEXT 1249
#define IDS_CRITICAL_NOTIFICATION_TITLE 1250
#define IDS_CRITICAL_NOTIFICATION_TITLE_ALTERNATE 1251
#define IDS_CRITICAL_NOTIFICATION_TEXT 1252
#define IDS_DESKTOP_MEDIA_PICKER_SOURCE_TYPE_TAB 1253
#define IDS_DESKTOP_MEDIA_PICKER_SCREEN_PERMISSION_TEXT_MAC 1254
#define IDS_DESKTOP_MEDIA_PICKER_SCREEN_PERMISSION_TEXT_PERIOD_MAC 1255
#define IDS_DESKTOP_MEDIA_PICKER_WINDOW_PERMISSION_TEXT_MAC 1256
#define IDS_DESKTOP_MEDIA_PICKER_WINDOW_PERMISSION_TEXT_PERIOD_MAC 1257
#define IDS_DESKTOP_MEDIA_PICKER_PERMISSION_RESTART_TEXT_MAC 1258
#define IDS_DESKTOP_MEDIA_PICKER_SYSTEM_AUDIO_PERMISSION_TEXT_MAC 1259
#define IDS_SIDE_PANEL_CUSTOMIZE_CHROME_TITLE 1277
#define IDS_HISTORY_HISTORY_MENU_ITEM 1278
#define IDS_LENS_SEND_FEEDBACK 1279
#define IDS_LENS_SEND_FEEDBACK_PLACEHOLDER 1280
#define IDS_SIDE_PANEL_LENS_OVERLAY_PINNABLE_IPH 1281
#define IDS_SIDE_PANEL_LENS_OVERLAY_PINNABLE_IPH_SCREENREADER 1282
#define IDS_SIDE_PANEL_LENS_OVERLAY_PINNABLE_FOLLOWUP_IPH 1283
#define IDS_SIDE_PANEL_LENS_OVERLAY_PINNABLE_FOLLOWUP_IPH_SCREENREADER 1284
#define IDS_LENS_OVERLAY_COPY 1285
#define IDS_LENS_OVERLAY_COPY_TEXT 1286
#define IDS_LENS_OVERLAY_COPY_TOAST_MESSAGE 1287
#define IDS_LENS_OVERLAY_COPY_AS_IMAGE_TOAST_MESSAGE 1288
#define IDS_LENS_OVERLAY_FEEDBACK_TOAST_MESSAGE 1289
#define IDS_LENS_OVERLAY_FEEDBACK_TOAST_MESSAGE_ALT 1290
#define IDS_LENS_OVERLAY_SEND_FEEDBACK_BUTTON_LABEL 1291
#define IDS_LENS_OVERLAY_CLOSE_FEEDBACK_TOAST_ACCESSIBILITY_LABEL 1292
#define IDS_LENS_OVERLAY_MORE_OPTIONS_BUTTON_LABEL 1293
#define IDS_LENS_OVERLAY_MY_ACTIVITY 1294
#define IDS_LENS_OVERLAY_TOAST_PAGE_CONTENT_NOT_FOUND_MESSAGE 1295
#define IDS_LENS_OVERLAY_TOAST_DISMISS_MESSAGE 1296
#define IDS_LENS_OVERLAY_TRANSLATE 1297
#define IDS_LENS_OVERLAY_SELECT_TEXT 1298
#define IDS_LENS_OVERLAY_COPY_AS_IMAGE 1299
#define IDS_LENS_OVERLAY_SAVE_AS_IMAGE 1300
#define IDS_LENS_OVERLAY_LEARN_MORE 1301
#define IDS_LENS_OVERLAY_INITIAL_TOAST_LABEL 1302
#define IDS_LENS_OVERLAY_INITIAL_TOAST_MESSAGE 1303
#define IDS_LENS_OVERLAY_INITIAL_TOAST_LABEL_SIMPLIFIED 1304
#define IDS_LENS_OVERLAY_INITIAL_TOAST_MESSAGE_SIMPLIFIED 1305
#define IDS_LENS_OVERLAY_INITIAL_TOAST_MESSAGE_SELECT_TEXT 1306
#define IDS_LENS_OVERLAY_INITIAL_TOAST_ERROR_MESSAGE 1307
#define IDS_LENS_OVERLAY_INITIAL_TOAST_ERROR_EXIT_BUTTON_TEXT 1308
#define IDS_LENS_OVERLAY_CURSOR_TOOLTIP_DRAG_MESSAGE 1309
#define IDS_LENS_OVERLAY_CURSOR_TOOLTIP_TEXT_HIGHLIGHT_MESSAGE 1310
#define IDS_LENS_OVERLAY_CURSOR_TOOLTIP_CLICK_MESSAGE 1311
#define IDS_LENS_OVERLAY_CURSOR_TOOLTIP_LIVE_PAGE_MESSAGE 1312
#define IDS_LENS_OVERLAY_AUTO_DETECT_LANGUAGE_LABEL 1313
#define IDS_LENS_OVERLAY_TRANSLATE_BUTTON_LABEL 1314
#define IDS_LENS_OVERLAY_SOURCE_LANGUAGE_PICKER_MENU_TITLE 1315
#define IDS_LENS_OVERLAY_TARGET_LANGUAGE_PICKER_MENU_TITLE 1316
#define IDS_LENS_OVERLAY_RECENT_LANGUAGES_LABEL 1317
#define IDS_LENS_OVERLAY_ALL_LANGUAGES_LABEL 1318
#define IDS_LENS_OVERLAY_DETECTED_LABEL 1319
#define IDS_LENS_OVERLAY_DETECT_LANGUAGE_LABEL 1320
#define IDS_LENS_OVERLAY_RENDERER_LABEL 1321
#define IDS_LENS_OVERLAY_CLOSE_TRANSLATE_SCREEN_LABEL 1322
#define IDS_LENS_OVERLAY_LANGUAGE_PICKER_LABEL 1323
#define IDS_LENS_OVERLAY_SOURCE_LANGUAGE_ACCESSIBILITY_LABEL 1324
#define IDS_LENS_OVERLAY_TARGET_LANGUAGE_ACCESSIBILITY_LABEL 1325
#define IDS_LENS_OVERLAY_SEARCH_LANGUAGE_PICKER_LABEL 1326
#define IDS_LENS_OVERLAY_TOP_LEFT_CORNER_SLIDER_ACCESSIBILITY_LABEL 1327
#define IDS_LENS_OVERLAY_TOP_RIGHT_CORNER_SLIDER_ACCESSIBILITY_LABEL 1328
#define IDS_LENS_OVERLAY_BOTTOM_RIGHT_CORNER_SLIDER_ACCESSIBILITY_LABEL 1329
#define IDS_LENS_OVERLAY_BOTTOM_LEFT_CORNER_SLIDER_ACCESSIBILITY_LABEL 1330
#define IDS_LENS_OVERLAY_SEARCH_SCREENSHOT_ACCESSIBILITY_LABEL 1331
#define IDS_LENS_OVERLAY_TRANSLATE_BUTTON_IPH 1332
#define IDS_LENS_OVERLAY_TRANSLATE_BUTTON_IPH_SCREENREADER 1333
#define IDS_CONTENT_CONTEXT_LENS_OVERLAY 1334
#define IDS_CONTENT_LENS_OVERLAY_ENTRYPOINT_LABEL 1335
#define IDS_CONTENT_LENS_OVERLAY_HOMEWORK_ENTRYPOINT_LABEL 1336
#define IDS_CONTENT_LENS_OVERLAY_ASK_GOOGLE_ENTRYPOINT_LABEL 1337
#define IDS_SIDE_PANEL_LENS_OVERLAY_TOOLBAR_TOOLTIP 1338
#define IDS_LENS_OVERLAY_ENTRYPOINT_LABEL_ALT1 1339
#define IDS_LENS_OVERLAY_ENTRYPOINT_LABEL_ALT2 1340
#define IDS_LENS_OVERLAY_ENTRYPOINT_LABEL_ALT3 1341
#define IDS_LENS_OVERLAY_IMAGE_ENTRYPOINT_LABEL_ALT1 1342
#define IDS_LENS_OVERLAY_IMAGE_ENTRYPOINT_LABEL_ALT2 1343
#define IDS_LENS_OVERLAY_IMAGE_ENTRYPOINT_LABEL_ALT3 1344
#define IDS_LENS_OVERLAY_TAB_ENTRYPOINT_LABEL 1345
#define IDS_LENS_OVERLAY_VIDEO_ENTRYPOINT_LABEL_ALT1 1346
#define IDS_LENS_OVERLAY_VIDEO_ENTRYPOINT_LABEL_ALT2 1347
#define IDS_LENS_OVERLAY_VIDEO_ENTRYPOINT_LABEL_ALT3 1348
#define IDS_AI_MODE_ENTRYPOINT_LABEL 1349
#define IDS_SIDE_PANEL_LENS_OVERLAY_GENERIC_ERROR_PAGE_FIRST_LINE 1350
#define IDS_SIDE_PANEL_LENS_OVERLAY_GENERIC_ERROR_PAGE_SECOND_LINE 1351
#define IDS_SIDE_PANEL_LENS_OVERLAY_PROTECTED_PAGE_ERROR_FIRST_LINE 1352
#define IDS_SIDE_PANEL_LENS_OVERLAY_PROTECTED_PAGE_ERROR_SECOND_LINE 1353
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_CANCEL_BUTTON 1354
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_CONTINUE_BUTTON 1355
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_CSB_DESCRIPTION 1356
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_NON_BLOCKING_DESCRIPTION 1357
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_DESCRIPTION 1358
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_LEARN_MORE_LINK 1359
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_LEARN_MORE_ABOUT_GOOGLE_LENS_LINK 1360
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_TITLE 1361
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_TAB_TO_CONTINUE 1362
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_GOT_IT 1363
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_REMIND_ME_LATER 1364
#define IDS_SHOW_LENS_OVERLAY 1366
#define IDS_CONTEXT_MENU_SHOW_GOOGLE_LENS_SHORTCUT 1365
#define IDS_LENS_CONTEXTUAL_SEARCH_DEFAULT_QUERY 1367
#define IDS_LENS_CONTEXTUAL_SEARCH_ZERO_STATE_QUERY 1368
#define IDS_LENS_COMPOSEBOX_HINT_TEXT 1369
#define IDS_LENS_COMPOSEBOX_HINT_TEXT_SEARCH_PAGE 1370
#define IDS_LENS_COMPOSEBOX_HINT_TEXT_SELECT_PAGE 1371
#define IDS_LENS_COMPOSEBOX_HINT_TEXT_ASK_ANYTHING 1372
#define IDS_AI_MODE_ASK_ABOUT_THIS_TAB 1373
#define IDS_AI_MODE_NEW_SEARCH 1374
#define IDS_CONTEXT_MENU_SHOW_AI_MODE_OMNIBOX_BUTTON 1375
#define IDS_RELAUNCH_RECOMMENDED_TITLE 1379
#define IDS_RELAUNCH_RECOMMENDED_BODY 1380
#define IDS_RELAUNCH_REQUIRED_TITLE_DAYS 1381
#define IDS_RELAUNCH_REQUIRED_TITLE_HOURS 1382
#define IDS_RELAUNCH_REQUIRED_TITLE_MINUTES 1383
#define IDS_RELAUNCH_REQUIRED_TITLE_SECONDS 1384
#define IDS_RELAUNCH_REQUIRED_BODY 1385
#define IDS_ADVANCED_PROTECTION_RELAUNCH_REQUIRED_BODY 1386
#define IDS_ENTERPRISE_STARTUP_CLOUD_POLICY_ENROLLMENT_TOOLTIP 1387
#define IDS_ENTERPRISE_STARTUP_CLOUD_POLICY_ENROLLMENT_ERROR 1388
#define IDS_ENTERPRISE_STARTUP_RELAUNCH_BUTTON 1389
#define IDS_DESKTOP_MEDIA_PICKER_TITLE_WEB_CONTENTS_ONLY 1390
#define IDS_IDLE_BUBBLE_TITLE_CLOSE 1391
#define IDS_IDLE_BUBBLE_BODY_CLOSE_AND_CLEAR 1392
#define IDS_IDLE_BUBBLE_BODY_CLEAR 1393
#define IDS_IDLE_BUBBLE_BODY_CLOSE 1394
#define IDS_IDLE_TIMEOUT_CLOSE_TITLE 1395
#define IDS_IDLE_TIMEOUT_CLEAR_TITLE 1396
#define IDS_IDLE_TIMEOUT_CLOSE_AND_CLEAR_TITLE 1397
#define IDS_IDLE_TIMEOUT_CLOSE_BODY 1398
#define IDS_IDLE_TIMEOUT_CLEAR_BODY 1399
#define IDS_IDLE_TIMEOUT_CLOSE_AND_CLEAR_BODY 1400
#define IDS_IDLE_DISMISS_BUTTON 1401
#define IDS_HATS_BUBBLE_TITLE 1402
#define IDS_EXTENSION_PERMISSIONS_BLOCKED_BY_PARENT_PROMPT_MESSAGE 1404
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_TITLE_APP 1405
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_TITLE_EXTENSION 1406
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_TITLE_THEME 1407
#define IDS_EXTENSION_EXTERNAL_INITIAL_INSTALL_PROMPT_TITLE_EXTENSION 1408
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_ABORT_BUTTON 1409
#define IDS_ENTERPRISE_WELCOME_PROFILE_INFORMATION_DETAILS 1410
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE 1411
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_V2 1412
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_KEEP_EVERYTHING_IN_CHROME 1413
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE 1414
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_KEEP_WORK_AND_LIFE_SEPARATE 1415
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_GOT_ANOTHER_GOOGLE_ACCOUNT 1416
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_KEEP_TASKS_SEPARATE 1417
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_PROFILE_TYPE_CHOICE_TITLE 1418
#define IDS_PROFILE_PICKER_IPH_FOR_PROFILES_TEXT 1419
#define IDS_PROFILE_PICKER_IPH_FOR_ADD_PROFILE_TEXT 1420
#define IDS_PROFILE_PICKER_PROFILE_SWITCH_TITLE 1421
#define IDS_PROFILE_PICKER_PROFILE_SWITCH_SUBTITLE 1422
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_NOT_SUPPORTED_BY_GLIC_FLOW_BODY 1423
#define IDS_FRE_SIGN_IN_TITLE_0 1424
#define IDS_FRE_DEFAULT_BROWSER_TITLE 1425
#define IDS_FRE_DEFAULT_BROWSER_AND_PINNING_TITLE 1426
#define IDS_FRE_DEFAULT_BROWSER_SUBTITLE_NEW 1427
#define IDS_FRE_DEFAULT_BROWSER_AND_PINNING_SUBTITLE 1428
#define IDS_FRE_DEFAULT_BROWSER_ILLUSTRATION_ALT_TEXT 1429
#define IDS_APP_MENU_TOOLTIP_DEFAULT_PROMPT 1430
#define IDS_APP_MENU_BUTTON_DEFAULT_PROMPT 1431
#define IDS_SET_BROWSER_AS_DEFAULT_MENU_ITEM 1432
#define IDS_FRE_REFRESH_DEFAULT_BROWSER_TITLE 1433
#define IDS_FRE_REFRESH_DEFAULT_BROWSER_SUBTITLE 1434
#define IDS_PROFILE_SWITCH_PROMO 1435
#define IDS_PROFILE_SWITCH_PROMO_SCREENREADER 1436
#define IDS_PASSWORD_MANAGER_IPH_BODY_WEB_APP_PROFILE_SWITCH 1437
#define IDS_SIGNOUT_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNOUT_IPH_TEXT 1438
#define IDS_SIGNOUT_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNOUT_IPH_TEXT_SCREENREADER 1439
#define IDS_QUIET_NOTIFICATION_IPH_TEXT 1440
#define IDS_QUIET_NOTIFICATION_IPH_TEXT_SCREENREADER 1441
#define IDS_CHROMELABS_RELAUNCH_FOOTER_MESSAGE 1442
#define IDS_SERIAL_DEVICE_CHOOSER_AUTHORIZE_BLUETOOTH 1443
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_NOTIFICATION_TITLE 1444
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_MESSAGE_TITLE 1445
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_MESSAGE_DESCRIPTION 1446
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_MESSAGE_DESCRIPTION_UPDATED 1447
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_MESSAGE_ACCEPT 1448
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_OPTIMIZATION_LINK_ROW_ENABLED 1453
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_OPTIMIZATION_LINK_ROW_DISABLED 1454
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_DESCRIPTION 1455
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_ALLOWED_SUB_LABEL 1456
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_SUB_LABEL 1457
#define IDS_MEMORY_SAVER_DIALOG_BODY 1523
#define IDS_MEMORY_SAVER_MODE_PROMO_TITLE 1524
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_BODY_V1 1525
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_BODY_SINGULAR_V1 1526
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_TITLE_UPDATED_V3 1527
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_SIGNED_IN 1528
#define IDS_CREATE_SHORTCUT_NOT_APPS_DIALOG_SUBTITLE 1529
#define IDS_CLEAR_BROWSING_DATA_TOAST_BODY 1531
#define IDS_SKILL_SAVED_TOAST_BUTTON 1532
#define IDS_GLIC_PROMO_TITLE 1533
#define IDS_GLIC_TAB_STRIP_BUTTON_TOOLTIP 1534
#define IDS_GLIC_TAB_STRIP_BUTTON_TOOLTIP_CLOSE 1535
#define IDS_GLIC_THREE_DOT_MENU_ITEM 1536
#define IDS_GLIC_STATUS_ICON_TOOLTIP 1537
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CANARY 1538
#define IDS_GLIC_STATUS_ICON_TOOLTIP_DEV 1539
#define IDS_GLIC_STATUS_ICON_TOOLTIP_BETA 1540
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CLOSE 1541
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CLOSE_CANARY 1542
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CLOSE_DEV 1543
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CLOSE_BETA 1544
#define IDS_GLIC_STATUS_ICON_TOOLTIP_TOGGLE 1545
#define IDS_GLIC_STATUS_ICON_TOOLTIP_TOGGLE_CANARY 1546
#define IDS_GLIC_STATUS_ICON_TOOLTIP_TOGGLE_DEV 1547
#define IDS_GLIC_STATUS_ICON_TOOLTIP_TOGGLE_BETA 1548
#define IDS_GLIC_STATUS_ICON_MENU_SHOW 1549
#define IDS_GLIC_STATUS_ICON_MENU_CLOSE 1550
#define IDS_GLIC_STATUS_ICON_MENU_TOGGLE 1551
#define IDS_GLIC_INELIGIBLE_PROFILE_NOTICE 1552
#define IDS_SETTINGS_GLIC_PAGE_TITLE 1553
#define IDS_SETTINGS_GLIC_SECTION_TITLE 1554
#define IDS_SETTINGS_GLIC_ROW_LABEL 1555
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE 1556
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_SUBLABEL 1557
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_GLIC 1558
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_GLIC_NO_PROFILE 1559
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_GLIC 1560
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_GLIC_NO_PROFILE 1561
#define IDS_PROFILE_PICKER_ADD_PROFILE_HELPER_GLIC 1562
#define IDS_GLIC_CONTEXTUAL_CUEING_ANNOUNCEMENT 1563
#define IDS_GLIC_BUTTON_ENTRYPOINT_ASK_BROWSER_LABEL 1564
#define IDS_EXTENSION_INSTALLED_PROMO_EXPLICIT_SIGNIN_MESSAGE 1565
#define IDS_BOOKMARK_INSTALLED_PROMO_EXPLICIT_SIGNIN_MESSAGE 1566
#define IDS_BOOKMARK_INSTALLED_BUBBLE_PROMO_EXPLICIT_SIGNIN_MESSAGE 1567
#define IDS_DICE_MIGRATION_CONFIRMATION_TOAST_MESSAGE 1568
#define IDS_DICE_MIGRATION_CONFIRMATION_TOAST_BUTTON 1569
#define IDS_PROFILE_MENU_ACCOUNT_SETTINGS_BUTTON 1570
#define IDS_IOS_DESKTOP_ESB_PROMO_BUBBLE_DESCRIPTION_REMINDER 1571
#define IDS_IOS_DESKTOP_ESB_PROMO_BUBBLE_TITLE_QR 1572
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_FOOTER_DESCRIPTION_REMINDER 1573
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_FOOTER_TITLE 1574
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_BUTTON_ACCEPT_QR 1575
#define IDS_IOS_DESKTOP_PROMO_QR_CODE_ALT_TEXT 1576
#define IDS_IOS_DESKTOP_PROMO_REMINDER_CONFIRMATION 1577
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_REMINDER_CONFIRMATION 1578
#define IDS_IOS_DESKTOP_LENS_PROMO_BUBBLE_DESCRIPTION_REMINDER 1579
#define IDS_IOS_DESKTOP_LENS_PROMO_BUBBLE_TITLE_QR 1580
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_FOOTER_DESCRIPTION_QR 1581
#define IDS_IOS_DESKTOP_LENS_PROMO_NOTIFICATION_TITLE 1582
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_NOTIFICATION_TITLE 1583
#define IDS_IOS_DESKTOP_PRICE_TRACKING_DESCRIPTION_QR 1584
#define IDS_IOS_DESKTOP_PRICE_TRACKING_REMINDER_CONFIRMATION 1585
#define IDS_IOS_DESKTOP_SAFE_BROWSING_PROMO_NOTIFICATION_TITLE 1586
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_BUBBLE_DESCRIPTION_QR 1587
#define IDS_IOS_DESKTOP_TAB_GROUPS_REMINDER_CONFIRMATION 1588
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_TITLE 1589
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_BODY 1590
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_GOT_IT_BUTTON 1591
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_LEARN_MORE_BUTTON 1592
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_SEARCH_SETTINGS_BUTTON 1593
#define IDS_REPORT_UNSAFE_SITE_DIALOG_TITLE 1594
#define IDS_REPORT_UNSAFE_SITE_DIALOG_DESCRIPTION 1595
#define IDS_REPORT_UNSAFE_SITE_DIALOG_FOOTER 1596
#define IDS_INDIGO_ENTRYPOINT_CHIP_TEXT 1597
#define IDS_INDIGO_ENTRYPOINT_CHIP_TOOLTIP_TEXT 1598

// ---------------------------------------------------------------------------
// From cef_strings.h:

#define IDS_TEXT_FILES 59110
#define IDS_CONTENT_CONTEXT_NO_SPELLING_SUGGESTIONS 59111

// ---------------------------------------------------------------------------
// From components_branded_strings.h:

#define IDS_ERRORPAGES_SUGGESTION_NETWORK_PREDICTION_BODY 35390
#define IDS_ERRORPAGES_SUGGESTION_FIREWALL_CONFIG_HEADER 35391
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_CLIENT 35392
#define IDS_ERRORPAGES_SUGGESTION_PROXY_DISABLE_PLATFORM 35393
#define IDS_FLAGS_UI_RELAUNCH_NOTICE 35396
#define IDS_CRASH_DISABLED_MESSAGE 35397
#define IDS_SHORT_PRODUCT_LOGO_ALT_TEXT 35398
#define IDS_VERSION_UI_LICENSE 35399
#define IDS_PAGE_INFO_INTERNAL_PAGE 35402
#define IDS_SESSION_CRASHED_VIEW_MESSAGE 35403
#define IDS_BLUETOOTH_DEVICE_CHOOSER_AUTHORIZE_BLUETOOTH 35404
#define IDS_INTERNAL_DEBUG_PAGES_DISABLED_BODY 35405

// ---------------------------------------------------------------------------
// From components_strings.h:

#define IDS_ASH_ARC_APP_COMPAT_DISABLED_COMPAT_MODE_BUTTON_TOOLTIP_PHONE 35420
#define IDS_ASH_ARC_APP_COMPAT_RESIZE_CONFIRM_TITLE 35421
#define IDS_ASH_ARC_APP_COMPAT_RESIZE_CONFIRM_BODY 35422
#define IDS_ASH_ARC_APP_COMPAT_RESIZE_CONFIRM_ACCEPT 35423
#define IDS_ASH_ARC_APP_COMPAT_RESIZE_CONFIRM_DONT_ASK_ME 35424
#define IDS_ASH_ARC_NEARBY_SHARE_FILE_PREPARATION_PROGRESS 35425
#define IDS_ASH_ARC_NEARBY_SHARE_FILES_PREPARATION_PROGRESS 35426
#define IDS_ASH_ARC_NEARBY_SHARE_ERROR_DIALOG_MESSAGE 35427
#define IDS_ASH_ARC_NEARBY_SHARE_ERROR_DIALOG_MESSAGE_PH 35428
#define IDS_ASH_ARC_NEARBY_SHARE_LOW_DISK_SPACE_DIALOG_TITLE 35429
#define IDS_ASH_ARC_NEARBY_SHARE_LOW_DISK_SPACE_DIALOG_MESSAGE 35430
#define IDS_ASH_ARC_NEARBY_SHARE_LOW_DISK_SPACE_DIALOG_MESSAGE_PH 35431
#define IDS_ASH_ARC_NEARBY_SHARE_LOW_DISK_SPACE_DIALOG_STORAGE_BUTTON 35432
#define IDS_ARC_COMPAT_MODE_RESIZE_TOGGLE_MENU_RESIZE_SETTINGS 35433
#define IDS_ARC_COMPAT_MODE_RESIZE_TOGGLE_MENU_TITLE 35434
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_TITLE 35435
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_BODY 35436
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_BODY_UNRESIZABLE 35437
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_CLOSE 35438
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_LINK 35439
#define IDS_ARC_COMPAT_MODE_DISABLE_RESIZE_LOCK_TOAST 35440
#define IDS_ARC_GHOST_WINDOW_APP_LAUNCHING_ICON 35441
#define IDS_ARC_GHOST_WINDOW_APP_LAUNCHING_THROBBER 35442
#define IDS_ARC_GHOST_WINDOW_APP_LAUNCHING_MESSAGE 35443
#define IDS_ARC_GHOST_WINDOW_APP_LAUNCHING_AOD_MESSAGE 35444
#define IDS_ARC_GHOST_WINDOW_APP_FIXUP_MESSAGE 35445
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_TITLE 35446
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_BODY 35447
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_BODY_WITH_LEARN_MORE 35448
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_SUBSCRIPTION_BODY_WITH_LEARN_MORE 35449
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_LEARN_MORE_LABEL 35450
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_ALLOW_BUTTON 35451
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_DONT_ALLOW_BUTTON 35452
#define IDS_ARC_VM_DATA_MIGRATION_NOTIFICATION_TITLE 35453
#define IDS_ARC_VM_DATA_MIGRATION_NOTIFICATION_DAYS_UNTIL_DEADLINE 35454
#define IDS_ARC_VM_DATA_MIGRATION_NOTIFICATION_ACCEPT_BUTTON_LABEL 35455
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_TITLE 35456
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_SAVE_WORK_MESSAGE 35457
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_DAYS_UNTIL_DEADLINE 35458
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_UPDATE_NOW_BUTTON_LABEL 35459
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_SKIP_BUTTON_LABEL 35460
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_UPDATE_BUTTON_LABEL 35461
#define IDS_ARC_VM_DATA_MIGRATION_LOADING_SCREEN_MESSAGE 35462
#define IDS_ARC_VM_DATA_MIGRATION_WELCOME_SCREEN_TITLE 35463
#define IDS_ARC_VM_DATA_MIGRATION_WHAT_TO_EXPECT_TITLE 35464
#define IDS_ARC_VM_DATA_MIGRATION_UPDATE_DESCRIPTION 35465
#define IDS_ARC_VM_DATA_MIGRATION_BLOCKING_BEHAVIOR_DESCRIPTION 35466
#define IDS_ARC_VM_DATA_MIGRATION_CONNECT_TO_CHARGER_MESSAGE 35467
#define IDS_ARC_VM_DATA_MIGRATION_NOT_ENOUGH_FREE_DISK_SPACE_MESSAGE 35468
#define IDS_ARC_VM_DATA_MIGRATION_NOT_ENOUGH_BATTERY_MESSAGE 35469
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_UPDATE_BUTTON_LABEL 35470
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_SKIP_BUTTON_LABEL 35471
#define IDS_ARC_VM_DATA_MIGRATION_RESUME_SCREEN_TITLE 35472
#define IDS_ARC_VM_DATA_MIGRATION_RESUME_DESCRIPTION 35473
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_RESUME_BUTTON_LABEL 35474
#define IDS_ARC_VM_DATA_MIGRATION_PROGRESS_SCREEN_TITLE 35475
#define IDS_ARC_VM_DATA_MIGRATION_PROGRESS_DESCRIPTION 35476
#define IDS_ARC_VM_DATA_MIGRATION_SUCCESS_SCREEN_TITLE 35477
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_FINISH_BUTTON_LABEL 35478
#define IDS_ARC_VM_DATA_MIGRATION_FAILURE_SCREEN_TITLE 35479
#define IDS_ARC_VM_DATA_MIGRATION_FAILURE_DESCRIPTION 35480
#define IDS_ARC_VM_DATA_MIGRATION_SEND_FEEDBACK_MESSAGE 35481
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_REPORT_BUTTON_LABEL 35482
#define IDS_ARC_VM_PRELOAD_NOTIFICATION_TITLE 35483
#define IDS_ARC_VM_PRELOAD_STARTED_MESSAGE 35484
#define IDS_ARC_VM_PRELOAD_SUCCEEDED_MESSAGE 35485
#define IDS_ARC_VM_PRELOAD_FAILED_MESSAGE 35486
#define IDS_AUTOFILL_NO_THANKS_DESKTOP_LOCAL_SAVE 35487
#define IDS_AUTOFILL_NO_THANKS_DESKTOP_UPLOAD_SAVE 35488
#define IDS_AUTOFILL_SAVE_IBAN_BUBBLE_SAVE_NO_THANKS 35489
#define IDS_AUTOFILL_MANDATORY_REAUTH_OPT_IN_NO_THANKS 35490
#define IDS_AUTOFILL_MANDATORY_REAUTH_OPT_IN_ACCEPT 35491
#define IDS_AUTOFILL_GOOGLE_PAY_LOGO_ACCESSIBLE_NAME 35494
#define IDS_AUTOFILL_GOOGLE_WALLET_LOGO_ACCESSIBLE_NAME 35495
#define IDS_AUTOFILL_CHROME_LOGO_ACCESSIBLE_NAME 35496
#define IDS_AUTOFILL_FIELD_LABEL_PHONE 35497
#define IDS_AUTOFILL_FIELD_LABEL_BILLING_ADDRESS 35498
#define IDS_AUTOFILL_SAVE_CARD_BUBBLE_LOCAL_SAVE_ACCEPT 35500
#define IDS_AUTOFILL_SAVE_CARD_BUBBLE_UPLOAD_SAVE_ACCEPT 35501
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CONTINUE 35503
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_TITLE_LOCAL 35504
#define IDS_AUTOFILL_SAVE_CARD_ONLY_PROMPT_EXPLANATION_LOCAL 35506
#define IDS_AUTOFILL_SAVE_CARD_WITH_CVC_PROMPT_EXPLANATION_LOCAL 35507
#define IDS_AUTOFILL_SAVE_CVC_PROMPT_TITLE_LOCAL 35508
#define IDS_AUTOFILL_SAVE_CVC_PROMPT_EXPLANATION_LOCAL 35509
#define IDS_AUTOFILL_FIX_FLOW_PROMPT_SAVE_CARD_LABEL 35510
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_TITLE_TO_CLOUD 35511
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_TITLE_TO_CLOUD_V4 35513
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_TITLE_TO_CLOUD_SECURITY 35514
#define IDS_AUTOFILL_SAVE_CVC_PROMPT_TITLE_TO_CLOUD 35515
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CARD_DESCRIPTION 35516
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CARD_DESCRIPTION_WITH_NICKNAME 35517
#define IDS_AUTOFILL_CARD_SAVED 35521
#define IDS_AUTOFILL_CVC_SAVED 35522
#define IDS_AUTOFILL_DONE 35523
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_EXPLANATION 35524
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_TO_WALLET_EXPLANATION 35526
#define IDS_AUTOFILL_SAVE_CVC_PROMPT_EXPLANATION_UPLOAD 35527
#define IDS_AUTOFILL_SAVE_CVC_TO_WALLET_PROMPT_EXPLANATION_UPLOAD 35528
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_EXPLANATION_SECURITY 35529
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_TO_WALLET_EXPLANATION_SECURITY 35530
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CARDHOLDER_NAME 35535
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CARDHOLDER_NAME_TOOLTIP 35536
#define IDS_AUTOFILL_SAVE_CARD_CARDHOLDER_NAME_FIX_FLOW_HEADER 35537
#define IDS_AUTOFILL_SAVE_CARD_UPDATE_EXPIRATION_DATE_TITLE 35538
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_EXPLANATION_TOOLTIP 35541
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_EXPLANATION_AND_CARDHOLDER_NAME_TOOLTIP 35542
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_LOADING_THROBBER_ACCESSIBLE_NAME 35543
#define IDS_AUTOFILL_SAVE_IBAN_PROMPT_LOADING_THROBBER_ACCESSIBLE_NAME 35544
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_TITLE 35545
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_EXPLANATION_LOCAL 35546
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_EXPLANATION_UPLOAD 35547
#define IDS_AUTOFILL_SAVE_AND_FILL_TO_WALLET_DIALOG_EXPLANATION_UPLOAD 35548
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_CARD_NUMBER_LABEL 35549
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_CVC_LABEL 35550
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_CVC_PLACEHOLDER 35551
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_EXPIRATION_DATE_LABEL 35552
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_EXPIRATION_DATE_PLACEHOLDER 35553
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_NAME_ON_CARD_LABEL 35554
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_ACCEPT 35555
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_INVALID_CARD_NUMBER 35556
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_INVALID_CVC 35557
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_INVALID_EXPIRATION_DATE 35558
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_INVALID_NAME_ON_CARD 35559
#define IDS_AUTOFILL_PENDING_DIALOG_LOADING_ACCESSIBILITY_DESCRIPTION 35560
#define IDS_AUTOFILL_MASKED_SERVER_CARD_RISK_BASED_UNMASKING_ERROR_TITLE 35561
#define IDS_AUTOFILL_VIRTUAL_CARD_TEMPORARY_ERROR_TITLE 35562
#define IDS_AUTOFILL_VIRTUAL_CARD_PERMANENT_ERROR_TITLE 35563
#define IDS_AUTOFILL_VIRTUAL_CARD_TEMPORARY_ERROR_DESCRIPTION 35564
#define IDS_AUTOFILL_VIRTUAL_CARD_PERMANENT_ERROR_DESCRIPTION 35565
#define IDS_AUTOFILL_VIRTUAL_CARD_NOT_ELIGIBLE_ERROR_TITLE 35566
#define IDS_AUTOFILL_VIRTUAL_CARD_NOT_ELIGIBLE_ERROR_DESCRIPTION 35567
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_TEMPORARY_ERROR_TITLE 35568
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_PERMANENT_ERROR_TITLE 35569
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_TEMPORARY_ERROR_DESCRIPTION 35570
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_PERMANENT_ERROR_DESCRIPTION 35571
#define IDS_AUTOFILL_ERROR_DIALOG_NEGATIVE_BUTTON_LABEL 35572
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_ERROR_TRY_AGAIN_CVC 35573
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_ERROR_TRY_AGAIN_SECURITY_CODE 35574
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_ERROR_PERMANENT 35575
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_ERROR_NETWORK 35576
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_SECURITY_CODE_POSITION_BACK_OF_CARD 35577
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_SECURITY_CODE_POSITION_FRONT_OF_CARD 35578
#define IDS_AUTOFILL_CARD_UNMASK_CVC_IMAGE_DESCRIPTION 35579
#define IDS_AUTOFILL_CARD_UNMASK_CVC_IMAGE_DESCRIPTION_FOR_AMEX 35580
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_INSTRUCTIONS_DEFAULT 35581
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_INSTRUCTIONS_EXPIRED_CARD 35582
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_INSTRUCTIONS_VIRTUAL_CARD 35583
#define IDS_AUTOFILL_CARD_UNMASK_VERIFICATION_TITLE 35584
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_TITLE 35588
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_TITLE_SECURITY_CODE 35589
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_EXPIRED_TITLE 35590
#define IDS_AUTOFILL_CARD_UNMASK_CONFIRM_BUTTON 35605
#define IDS_AUTOFILL_CARD_UNMASK_VERIFY_BUTTON 35606
#define IDS_AUTOFILL_CARD_UNMASK_EXPIRATION_MONTH 35607
#define IDS_AUTOFILL_CARD_UNMASK_EXPIRATION_YEAR 35608
#define IDS_AUTOFILL_CARD_UNMASK_VERIFICATION_IN_PROGRESS 35609
#define IDS_AUTOFILL_CARD_UNMASK_VERIFICATION_SUCCESS 35610
#define IDS_AUTOFILL_CARD_UNMASK_INVALID_EXPIRATION_DATE 35611
#define IDS_AUTOFILL_EXPIRATION_DATE_SEPARATOR 35612
#define IDS_AUTOFILL_CARD_UNMASK_NEW_CARD_LINK 35613
#define IDS_AUTOFILL_DIALOG_PLACEHOLDER_CVC 35614
#define IDS_AUTOFILL_DIALOG_ACCESSIBLE_NAME_SECURITY_CODE 35615
#define IDS_AUTOFILL_CARD_UNMASK_PROGRESS_BAR_MESSAGE 35616
#define IDS_AUTOFILL_MASKED_SERVER_CARD_RISK_BASED_UNMASK_PROGRESS_BAR_MESSAGE 35617
#define IDS_AUTOFILL_CARD_UNMASK_PROGRESS_DIALOG_TITLE 35618
#define IDS_AUTOFILL_IBAN_UNMASK_PROGRESS_DIALOG_TITLE 35619
#define IDS_AUTOFILL_IBAN_UNMASK_PROGRESS_BAR_MESSAGE 35620
#define IDS_AUTOFILL_CARD_UNMASK_CONFIRMATION_DIALOG_TITLE 35621
#define IDS_AUTOFILL_CARD_UNMASK_CANCEL_BUTTON_LABEL 35622
#define IDS_AUTOFILL_CARD_UNMASK_CONFIRMATION_MESSAGE 35623
#define IDS_AUTOFILL_3DS_FETCH_VCN_PROGRESS_DIALOG_LOADING_MESSAGE 35625
#define IDS_AUTOFILL_3DS_FETCH_VCN_PROGRESS_DIALOG_CONFIRMATION_MESSAGE 35626
#define IDS_AUTOFILL_IBAN_UNMASK_ERROR_DIALOG_TITLE 35627
#define IDS_AUTOFILL_IBAN_UNMASK_ERROR_DIALOG_MESSAGE 35628
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_TITLE 35638
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_TITLE_ERROR 35639
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_INSTRUCTION 35640
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_OK_BUTTON_LABEL 35641
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_INSTRUCTION_ERROR 35642
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_CANCEL_BUTTON_LABEL 35643
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_CANCEL_BUTTON_LABEL_ERROR 35644
#define IDS_AUTOFILL_WEBAUTHN_VERIFY_PENDING_DIALOG_TITLE 35645
#define IDS_AUTOFILL_WEBAUTHN_VERIFY_PENDING_DIALOG_CANCEL_BUTTON_LABEL 35646
#define IDS_AUTOFILL_WALLET_MANAGEMENT_LINK_TEXT 35647
#define IDS_AUTOFILL_FROM_GOOGLE_ACCOUNT_LONG 35648
#define IDS_AUTOFILL_SAVE_IBAN_PROMPT_TITLE_LOCAL 35649
#define IDS_AUTOFILL_SAVE_IBAN_LABEL 35650
#define IDS_AUTOFILL_IBANS_TITLE 35651
#define IDS_AUTOFILL_SAVE_IBAN_BUBBLE_SAVE_ACCEPT 35652
#define IDS_AUTOFILL_SAVE_IBAN_PROMPT_NICKNAME 35653
#define IDS_AUTOFILL_SAVE_IBAN_PLACEHOLDER 35654
#define IDS_IBAN_NICKNAME_COUNT_BY 35655
#define IDS_AUTOFILL_IBAN_SAVED 35656
#define IDS_AUTOFILL_MANAGE_SAVED_PAYMENT_METHODS 35657
#define IDS_AUTOFILL_SAVE_IBAN_PROMPT_TITLE_SERVER 35658
#define IDS_AUTOFILL_UPLOAD_IBAN_PROMPT_EXPLANATION 35659
#define IDS_AUTOFILL_UPLOAD_IBAN_TO_WALLET_PROMPT_EXPLANATION 35660
#define IDS_AUTOFILL_MANDATORY_REAUTH_OPT_IN_TITLE 35666
#define IDS_AUTOFILL_MANDATORY_REAUTH_OPT_IN_EXPLANATION 35667
#define IDS_AUTOFILL_MANDATORY_REAUTH_ICON_TOOLTIP 35668
#define IDS_AUTOFILL_MANDATORY_REAUTH_CONFIRMATION_TITLE 35669
#define IDS_AUTOFILL_MANDATORY_REAUTH_CONFIRMATION_EXPLANATION 35670
#define IDS_AUTOFILL_MANDATORY_REAUTH_CONFIRMATION_SETTINGS_LINK 35671
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_TITLE 35675
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_EDUCATIONAL_BODY_LABEL 35676
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_LEARN_MORE_LINK_LABEL 35677
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CARD_NUMBER_LABEL 35678
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_ENROLLED_CARD_UNMASK_PROGRESS_DIALOG_TITLE 35679
#define IDS_AUTOFILL_VIRTUAL_CARD_ENTRY_PREFIX 35680
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_FALLBACK_ICON_TOOLTIP 35681
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_TITLE_VIRTUAL_CARD 35682
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_EDUCATIONAL_BODY_LABEL_VIRTUAL_CARD 35683
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_LEARN_MORE_LINK_LABEL_VIRTUAL_CARD 35684
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CARD_NUMBER_LABEL_VIRTUAL_CARD 35685
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_EXP_DATE_LABEL_VIRTUAL_CARD 35686
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CARDHOLDER_NAME_LABEL_VIRTUAL_CARD 35687
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CVC_LABEL_VIRTUAL_CARD 35688
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_VIRTUAL_CARD_LABEL 35689
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_ICON_TOOLTIP_VIRTUAL_CARD 35690
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_BUTTON_TOOLTIP_NORMAL_VIRTUAL_CARD 35691
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_BUTTON_TOOLTIP_CLICKED_VIRTUAL_CARD 35692
#define IDS_AUTOFILL_VIRTUAL_CARD_SUGGESTION_IPH_BUBBLE_LABEL 35693
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_ACCEPT_BUTTON_LABEL 35694
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DIALOG_TITLE_LABEL 35695
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DIALOG_CONTENT_LABEL 35696
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DECLINE_BUTTON_LABEL_SKIP 35697
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DECLINE_BUTTON_LABEL_NO_THANKS 35698
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_LEARN_MORE_LINK_LABEL 35699
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_CARD_IMAGE_TOOLTIP 35700
#define IDS_AUTOFILL_VIRTUAL_CARD_SUGGESTION_OPTION_VALUE 35701
#define IDS_AUTOFILL_IBAN_SUGGESTION_OPTION_VALUE 35702
#define IDS_AUTOFILL_VIRTUAL_CARD_NUMBER_SWITCH_LABEL 35703
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_LOADING_THROBBER_ACCESSIBLE_NAME 35704
#define IDS_AUTOFILL_VIRTUAL_CARD_STANDALONE_CVC_SUGGESTION_IPH_BUBBLE_LABEL 35716
#define IDS_AUTOFILL_VIRTUAL_CARD_STANDALONE_CVC_SUGGESTION_IPH_BUBBLE_LABEL_SCREENREADER 35717
#define IDS_AUTOFILL_VIRTUAL_CARD_STANDALONE_CVC_SUGGESTION_TITLE 35718
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CARD_NUMBER_LABEL_VIRTUAL_CARD_IOS 35719
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_EXP_DATE_LABEL_VIRTUAL_CARD_IOS 35720
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_NAME_ON_CARD_LABEL_VIRTUAL_CARD_IOS 35721
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CVC_LABEL_VIRTUAL_CARD_IOS 35722
#define IDS_AUTOFILL_VIRTUAL_CARD_DISABLED_SUGGESTION_OPTION_VALUE 35723
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_SUGGESTION_IPH_BUBBLE_LABEL 35724
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_SUGGESTION_IPH_BUBBLE_LABEL_SCREENREADER 35725
#define IDS_AUTOFILL_CARD_BNPL_AFFIRM_OR_ZIP_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP 35726
#define IDS_AUTOFILL_CARD_BNPL_AFFIRM_OR_ZIP_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP_SCREENREADER 35727
#define IDS_AUTOFILL_CARD_BNPL_AFFIRM_ZIP_OR_KLARNA_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP 35728
#define IDS_AUTOFILL_CARD_BNPL_AFFIRM_ZIP_OR_KLARNA_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP_SCREENREADER 35729
#define IDS_AUTOFILL_CARD_BNPL_SUGGESTION_WITH_GOOGLE_PAY_IPH_BUBBLE_LABEL_DESKTOP 35730
#define IDS_AUTOFILL_CARD_BNPL_SUGGESTION_WITH_GOOGLE_PAY_IPH_BUBBLE_LABEL_DESKTOP_SCREENREADER 35731
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_AFFIRM_AND_AFTERPAY 35732
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_ZIP 35733
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_KLARNA 35734
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_AFFIRM_AND_AFTERPAY 35735
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_ZIP 35736
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_KLARNA 35737
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_CLEAR_FORM_TO_ENABLE 35738
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_NOT_SUPPORTED_BY_MERCHANT 35739
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_CHECKOUT_AMOUNT_TOO_LOW 35740
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_CHECKOUT_AMOUNT_TOO_HIGH 35741
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_AI_FOOTNOTE 35742
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_FOOTNOTE_FOR_AI_AMOUNT_EXTRACTION_NOTE 35743
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_FOOTNOTE_HIDE_OPTION 35744
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_FOOTNOTE_HIDE_OPTION_PAYMENT_SETTINGS_LINK_TEXT 35745
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_TITLE 35746
#define IDS_AUTOFILL_BNPL_SELECT_PROVIDER_TITLE_DESCRIPTION 35747
#define IDS_AUTOFILL_CARD_BNPL_LINKED_ISSUER_PILL_LABEL 35748
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_SUGGESTION_IPH_BUBBLE_FALLBACK_LABEL 35749
#define IDS_AUTOFILL_DISABLED_VIRTUAL_CARD_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP 35750
#define IDS_AUTOFILL_DISABLED_VIRTUAL_CARD_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP_SCREENREADER 35751
#define IDS_AUTOFILL_CARD_AUTH_SELECTION_DIALOG_TITLE_MULTIPLE_OPTIONS 35752
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_ISSUER_CONFIRMATION_TEXT 35753
#define IDS_AUTOFILL_AUTHENTICATION_MODE_SECURITY_CODE 35754
#define IDS_AUTOFILL_AUTHENTICATION_MODE_GET_TEXT_MESSAGE 35755
#define IDS_AUTOFILL_AUTHENTICATION_MODE_TEXT_MESSAGE 35756
#define IDS_AUTOFILL_AUTHENTICATION_MODE_GET_EMAIL 35757
#define IDS_AUTOFILL_AUTHENTICATION_MODE_THREE_DOMAIN_SECURE 35758
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_CURRENT_INFO_NOT_SEEN_TEXT 35759
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_OK_BUTTON_LABEL_CONTINUE 35760
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_OK_BUTTON_LABEL_SEND 35761
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_CVC_CHALLENGE_INFO 35762
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_THREE_DOMAIN_SECURE_CHALLENGE_INFO 35763
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_TITLE 35764
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_FOOTER_MESSAGE 35765
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_NEW_CODE_MESSAGE 35766
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_TEXTFIELD_PLACEHOLDER_MESSAGE 35767
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_PENDING_MESSAGE 35768
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_VERIFICATION_CODE_EXPIRED_LABEL 35769
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_ENTER_CORRECT_CODE_LABEL 35770
#define IDS_AUTOFILL_LOADING_AND_CONSENT_DIALOG_TITLE_VCN_3DS 35771
#define IDS_AUTOFILL_PAYMENTS_WINDOW_USER_CONSENT_DIALOG_DESCRIPTION_VCN_3DS 35772
#define IDS_AUTOFILL_PAYMENTS_WINDOW_USER_CONSENT_DIALOG_OK_BUTTON_LABEL_VCN_3DS 35773
#define IDS_AUTOFILL_PAYMENTS_WINDOW_USER_CONSENT_DIALOG_ACCEPTANCE_ACCESSIBILITY_ANNOUNCEMENT 35774
#define IDS_AUTOFILL_REGULAR_CARD_MANUAL_FALLBACK_BUBBLE_CARD_NUMBER_LABEL_IOS 35775
#define IDS_AUTOFILL_BNPL_PAY_LATER_OPTIONS_TEXT 35776
#define IDS_AUTOFILL_BNPL_CREDIT_CARD_SUGGESTION_LABEL 35777
#define IDS_AUTOFILL_BNPL_CREDIT_CARD_SUGGESTION_LABEL_TWO_ISSUERS 35778
#define IDS_AUTOFILL_BNPL_CREDIT_CARD_SUGGESTION_LABEL_THREE_ISSUERS 35779
#define IDS_AUTOFILL_BNPL_SUGGESTION_LABEL_FOR_UNAVAILABLE_PURCHASE 35780
#define IDS_AUTOFILL_BNPL_SETTINGS_LABEL 35781
#define IDS_AUTOFILL_BNPL_SETTINGS_SUBLABEL 35782
#define IDS_AUTOFILL_BNPL_AFFIRM 35783
#define IDS_AUTOFILL_BNPL_ZIP 35784
#define IDS_AUTOFILL_BNPL_AFTER_PAY 35785
#define IDS_AUTOFILL_BNPL_KLARNA 35786
#define IDS_AUTOFILL_GOOGLE_PAY_AND_AFFIRM_LOGO_ACCESSIBLE_NAME 35787
#define IDS_AUTOFILL_GOOGLE_PAY_AND_ZIP_LOGO_ACCESSIBLE_NAME 35788
#define IDS_AUTOFILL_GOOGLE_PAY_AND_AFTERPAY_LOGO_ACCESSIBLE_NAME 35789
#define IDS_AUTOFILL_GOOGLE_PAY_AND_KLARNA_LOGO_ACCESSIBLE_NAME 35790
#define IDS_AUTOFILL_BNPL_FILLED_CARD_INFORMATION_BUBBLE_TITLE 35791
#define IDS_AUTOFILL_BNPL_FILLED_CARD_INFORMATION_BUBBLE_EDUCATIONAL_BODY_LABEL 35792
#define IDS_AUTOFILL_BNPL_FILLED_CARD_SNACKBAR_MESSAGE_TEXT 35793
#define IDS_AUTOFILL_BNPL_TOS_OK_BUTTON_LABEL 35794
#define IDS_AUTOFILL_BNPL_TOS_CANCEL_BUTTON_LABEL 35795
#define IDS_AUTOFILL_BNPL_TOS_TITLE_DESCRIPTION 35796
#define IDS_AUTOFILL_BNPL_TOS_UNLINKED_TITLE 35798
#define IDS_AUTOFILL_BNPL_TOS_LINKED_TITLE 35799
#define IDS_AUTOFILL_BNPL_TOS_REVIEW_TEXT 35800
#define IDS_AUTOFILL_BNPL_TOS_REVIEW_TEXT_WALLET_BRANDING 35801
#define IDS_AUTOFILL_BNPL_TOS_APPROVE_TEXT 35802
#define IDS_AUTOFILL_BNPL_TOS_LINK_TEXT 35803
#define IDS_AUTOFILL_BNPL_FETCH_VCN_PROGRESS_DIALOG_TITLE 35804
#define IDS_AUTOFILL_BNPL_PROGRESS_DIALOG_LOADING_MESSAGE 35805
#define IDS_AUTOFILL_BNPL_FETCH_VCN_PROGRESS_DIALOG_CONFIRMATION_MESSAGE 35806
#define IDS_AUTOFILL_BNPL_ERROR_DIALOG_TITLE 35807
#define IDS_AUTOFILL_BNPL_TEMPORARY_ERROR_DESCRIPTION 35808
#define IDS_AUTOFILL_BNPL_PERMANENT_ERROR_DESCRIPTION 35809
#define IDS_AUTOFILL_BNPL_ERROR_OK_BUTTON 35810
#define IDS_AUTOFILL_BNPL_UNSUPPORTED_CURRENCY_ERROR_DIALOG_TITLE 35812
#define IDS_AUTOFILL_BNPL_UNSUPPORTED_CURRENCY_ERROR_DESCRIPTION 35813
#define IDS_AUTOFILL_CREDIT_CARD_BENEFIT_TEXT_FOR_SUGGESTIONS 35814
#define IDS_AUTOFILL_CREDIT_CARD_BENEFIT_IPH_BUBBLE_LABEL 35815
#define IDS_AUTOFILL_CREDIT_CARD_BENEFIT_IPH_BUBBLE_LABEL_SCREENREADER 35816
#define IDS_AUTOFILL_SETTINGS_PAGE_CARD_BENEFITS_LABEL 35817
#define IDS_AUTOFILL_SETTINGS_PAGE_CARD_BENEFITS_TOGGLE_SUBLABEL_WITH_LEARN_LINK 35818
#define IDS_AUTOFILL_SETTINGS_PAGE_CARD_BENEFITS_TOGGLE_SUBLABEL_WITH_ISSUER_TERMS_APPLY_TEXT_AND_LEARN_LINK 35819
#define IDS_AUTOFILL_SETTINGS_PAGE_BENEFITS_TERMS_TAG_FOR_CREDIT_CARD_LIST_ENTRY 35820
#define IDS_AUTOFILL_SETTINGS_PAGE_BENEFITS_TERMS_ARIA_LABEL 35821
#define IDS_AUTOFILL_OFFERS_CASHBACK 35828
#define IDS_AUTOFILL_CARD_LINKED_OFFER_REMINDER_TITLE 35829
#define IDS_AUTOFILL_OFFERS_REMINDER_POSITIVE_BUTTON_LABEL 35830
#define IDS_AUTOFILL_PROMO_CODE_SUGGESTIONS_FOOTER_TEXT 35831
#define IDS_AUTOFILL_OFFERS_REMINDER_ICON_TOOLTIP_TEXT 35832
#define IDS_AUTOFILL_OFFERS_REMINDER_DESCRIPTION_TEXT 35833
#define IDS_AUTOFILL_PROMO_CODE_OFFERS_REMINDER_TITLE 35836
#define IDS_AUTOFILL_GPAY_PROMO_CODE_OFFERS_REMINDER_TITLE 35837
#define IDS_AUTOFILL_PROMO_CODE_OFFER_BUTTON_TOOLTIP_NORMAL 35838
#define IDS_AUTOFILL_PROMO_CODE_OFFER_BUTTON_TOOLTIP_CLICKED 35839
#define IDS_AUTOFILL_GPAY_PROMO_CODE_OFFERS_REMINDER_VALUE_PROP_TEXT 35840
#define IDS_AUTOFILL_PROMO_CODE_OFFERS_USE_THIS_CODE_TEXT 35841
#define IDS_AUTOFILL_PAYMENTS_OTP_VERIFICATION_DIALOG_CANT_FIND_CODE_MESSAGE 35842
#define IDS_AUTOFILL_PAYMENTS_OTP_VERIFICATION_DIALOG_OTP_INPUT_HINT 35843
#define IDS_AUTOFILL_PAYMENTS_OTP_VERIFICATION_DIALOG_POSITIVE_BUTTON_LABEL 35844
#define IDS_AUTOFILL_PAYMENTS_OTP_VERIFICATION_DIALOG_NEGATIVE_BUTTON_LABEL 35845
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_PAYMENT_METHOD_MANDATORY_REAUTH_LABEL 35901
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_PAYMENT_METHOD_MANDATORY_REAUTH_SUBLABEL 35902
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_CVC_STORAGE_LABEL 35905
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_CVC_STORAGE_ARIA_LABEL_FOR_NO_CVC_SAVED 35906
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_CVC_STORAGE_SUBLABEL 35907
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_CVC_STORAGE_WITH_DELETE_LINK_SUBLABEL 35908
#define IDS_AUTOFILL_SETTINGS_PAGE_BULK_REMOVE_CVC_TITLE 35909
#define IDS_AUTOFILL_SETTINGS_PAGE_BULK_REMOVE_CVC_DESCRIPTION 35910
#define IDS_AUTOFILL_SETTINGS_PAGE_BULK_REMOVE_CVC_FROM_WALLET_DESCRIPTION 35911
#define IDS_AUTOFILL_SETTINGS_PAGE_CVC_TAG_FOR_CREDIT_CARD_LIST_ENTRY 35912
#define IDS_AUTOFILL_CVC_SUGGESTION_MAIN_TEXT 35915
#define IDS_AUTOFILL_SETTINGS_PAGE_CVC_SAVED_LABEL 35916
#define IDS_AUTOFILL_SETTINGS_PAGE_SUMMARY_SEPARATED_BY_PIPE 35917
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_SUCCESS_TITLE_TEXT 35921
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_FAILURE_TITLE_TEXT 35922
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_SUCCESS_TITLE_TEXT 35923
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_FAILURE_TITLE_TEXT 35924
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_SUCCESS_TITLE_TEXT 35925
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_FAILURE_TITLE_TEXT 35926
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 35927
#define IDS_AUTOFILL_SAVE_CARD_TO_WALLET_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 35928
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 35929
#define IDS_AUTOFILL_SAVE_CARD_TO_WALLET_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 35930
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 35931
#define IDS_AUTOFILL_SAVE_IBAN_TO_WALLET_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 35932
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 35933
#define IDS_AUTOFILL_SAVE_IBAN_TO_WALLET_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 35934
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_FAILURE_HIT_MAX_STRIKE_DESCRIPTION_TEXT 35935
#define IDS_AUTOFILL_SAVE_IBAN_TO_WALLET_CONFIRMATION_FAILURE_HIT_MAX_STRIKE_DESCRIPTION_TEXT 35936
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 35937
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 35938
#define IDS_AUTOFILL_SAVE_CARD_AND_VIRTUAL_CARD_ENROLL_CONFIRMATION_BUTTON_TEXT 35939
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_FAILURE_OK_BUTTON_ACCESSIBLE_NAME 35940
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_FAILURE_OK_BUTTON_ACCESSIBLE_NAME 35941
#define IDS_AUTOFILL_CLEAR_FORM_MENU_ITEM 35943
#define IDS_AUTOFILL_UNDO_MENU_ITEM 35944
#define IDS_AUTOFILL_WARNING_INSECURE_CONNECTION 35945
#define IDS_AUTOFILL_WARNING_MIXED_FORM 35946
#define IDS_AUTOFILL_DELETE_AUTOCOMPLETE_SUGGESTION_CONFIRMATION_BODY 35950
#define IDS_AUTOFILL_DELETE_CREDIT_CARD_SUGGESTION_CONFIRMATION_BODY 35951
#define IDS_AUTOFILL_DELETE_PROFILE_SUGGESTION_CONFIRMATION_BODY 35952
#define IDS_AUTOFILL_REMOVE_HOME_PROFILE_SUGGESTION_CONFIRMATION_TITLE 35953
#define IDS_AUTOFILL_REMOVE_HOME_PROFILE_SUGGESTION_CONFIRMATION_BODY 35954
#define IDS_AUTOFILL_REMOVE_WORK_PROFILE_SUGGESTION_CONFIRMATION_TITLE 35955
#define IDS_AUTOFILL_REMOVE_WORK_PROFILE_SUGGESTION_CONFIRMATION_BODY 35956
#define IDS_AUTOFILL_REMOVE_ACCOUNT_NAME_AND_EMAIL_PROFILE_SUGGESTION_CONFIRMATION_TITLE 35957
#define IDS_AUTOFILL_REMOVE_ACCOUNT_NAME_AND_EMAIL_PROFILE_SUGGESTION_CONFIRMATION_BODY 35958
#define IDS_AUTOFILL_REMOVE_SUGGESTION_BUTTON 35959
#define IDS_AUTOFILL_DELETE_SUGGESTION_BUTTON 35960
#define IDS_AUTOFILL_DELETE_AUTOCOMPLETE_SUGGESTION_TOOLTIP 35961
#define IDS_AUTOFILL_AUTOCOMPLETE_ENTRY_DELETED_A11Y_HINT 35962
#define IDS_AUTOFILL_DELETE_AUTOCOMPLETE_SUGGESTION_A11Y_HINT 35963
#define IDS_HOME_SUGGESTION_VOICE_OVER 35964
#define IDS_WORK_SUGGESTION_VOICE_OVER 35965
#define IDS_AUTOFILL_CC_AMEX 35966
#define IDS_AUTOFILL_CC_AMEX_SHORT 35967
#define IDS_AUTOFILL_CC_DINERS 35968
#define IDS_AUTOFILL_CC_DISCOVER 35969
#define IDS_AUTOFILL_CC_ELO 35970
#define IDS_AUTOFILL_CC_GOOGLE_PAY 35971
#define IDS_AUTOFILL_CC_JCB 35972
#define IDS_AUTOFILL_CC_MASTERCARD 35973
#define IDS_AUTOFILL_CC_MIR 35974
#define IDS_AUTOFILL_CC_TROY 35975
#define IDS_AUTOFILL_CC_UNION_PAY 35976
#define IDS_AUTOFILL_CC_VERVE 35977
#define IDS_AUTOFILL_CC_VISA 35978
#define IDS_AUTOFILL_CC_GENERIC 35979
#define IDS_AUTOFILL_IBAN_GENERIC 35980
#define IDS_AUTOFILL_LOYALTY_CARD_GENERIC 35981
#define IDS_AUTOFILL_LOYALTY_CARDS_SUBMENU_TITLE 35982
#define IDS_AUTOFILL_LOYALTY_CARDS_ALL_YOUR_CARDS_SUBMENU_TITLE 35983
#define IDS_AUTOFILL_ADDRESS_SUMMARY_SEPARATOR 35984
#define IDS_AUTOFILL_DEVELOPER_TOOLS 35985
#define IDS_AUTOFILL_TEST_ADDRESS_BY_COUNTRY 35986
#define IDS_AUTOFILL_TEST_ADDRESS_SELECTED_A11Y_HINT 35987
#define IDS_AUTOFILL_A11Y_ANNOUNCE_FILLED_FORM 35988
#define IDS_AUTOFILL_A11Y_ANNOUNCE_EXPANDABLE_ONLY_ENTRY 35989
#define IDS_AUTOFILL_A11Y_ANNOUNCE_FILLED_CARD_INFORMATION_ENTRY 35990
#define IDS_AUTOFILL_A11Y_ANNOUNCE_EDIT_ADDRESS_PROFILE_POPUP_OPTION_SELECTED 35991
#define IDS_AUTOFILL_A11Y_ANNOUNCE_DELETE_ADDRESS_PROFILE_POPUP_OPTION_SELECTED 35992
#define IDS_AUTOFILL_A11Y_ANNOUNCE_CLEARED_FORM 35993
#define IDS_AUTOFILL_A11Y_ANNOUNCE_FILL_ADDRESS_GROUP_POPUP_OPTION_SELECTED 35994
#define IDS_AUTOFILL_FILL_ADDRESS_GROUP_POPUP_OPTION_SELECTED 35995
#define IDS_AUTOFILL_A11Y_ANNOUNCE_FILL_NAME_GROUP_POPUP_OPTION_SELECTED 35996
#define IDS_AUTOFILL_FILL_NAME_GROUP_POPUP_OPTION_SELECTED 35997
#define IDS_AUTOFILL_A11Y_ANNOUNCE_FILL_EVERYTHING_FROM_ADDRESS_PROFILE_POPUP_OPTION_SELECTED 35998
#define IDS_AUTOFILL_HIDE_SUGGESTIONS 35999
#define IDS_AUTOFILL_EDIT_ADDRESS_PROFILE_POPUP_OPTION_SELECTED 36000
#define IDS_AUTOFILL_DELETE_ADDRESS_PROFILE_POPUP_OPTION_SELECTED 36001
#define IDS_AUTOFILL_HOUSE_NUMBER_SUGGESTION_SECONDARY_TEXT_OPTION_SELECTED 36002
#define IDS_AUTOFILL_STREET_NAME_SUGGESTION_SECONDARY_TEXT_OPTION_SELECTED 36003
#define IDS_AUTOFILL_HOUSE_NUMBER_SUGGESTION_SECONDARY_TEXT 36004
#define IDS_AUTOFILL_STREET_NAME_SUGGESTION_SECONDARY_TEXT 36005
#define IDS_AUTOFILL_FILL_EVERYTHING_FROM_ADDRESS_PROFILE_POPUP_OPTION_SELECTED 36006
#define IDS_AUTOFILL_IDENTITY_CREDENTIAL_PROVIDED_MINOR_TEXT 36007
#define IDS_AUTOFILL_IDENTITY_CREDENTIAL_VERIFIED_MINOR_TEXT 36008
#define IDS_AUTOFILL_IDENTITY_CREDENTIAL_VERIFIED_EMAIL_LABEL 36009
#define IDS_AUTOFILL_IDENTITY_CREDENTIAL_LABEL_TEXT 36010
#define IDS_AUTOFILL_MANAGE_ADDRESSES 36011
#define IDS_AUTOFILL_MANAGE_PAYMENT_METHODS 36012
#define IDS_AUTOFILL_MANAGE_PASSWORDS 36013
#define IDS_AUTOFILL_MANAGE_LOYALTY_CARDS 36014
#define IDS_AUTOFILL_MANAGE_LOYALTY_CARDS_A11Y_HINT 36015
#define IDS_AUTOFILL_SCAN_CREDIT_CARD 36016
#define IDS_AUTOFILL_SHOW_ALL_SAVED_FALLBACK 36017
#define IDS_AUTOFILL_SAVE_AND_FILL_SUGGESTION_TITLE 36018
#define IDS_AUTOFILL_LOCAL_SAVE_AND_FILL_SUGGESTION_DESCRIPTION 36019
#define IDS_AUTOFILL_SERVER_SAVE_AND_FILL_SUGGESTION_DESCRIPTION 36020
#define IDS_AUTOFILL_POPUP_ACCESSIBLE_NODE_DATA 36021
#define IDS_AUTOFILL_IPH_EXTERNAL_ACCOUNT_PROFILE_SUGGESTION 36022
#define IDS_AUTOFILL_IPH_HOME_AND_WORK_ACCOUNT_PROFILE_SUGGESTION 36023
#define IDS_AUTOFILL_IPH_HOME_AND_WORK_ACCOUNT_PROFILE_SUGGESTION_SCREENREADER 36024
#define IDS_AUTOFILL_IPH_HOME_AND_WORK_ACCOUNT_PROFILE_SUGGESTION_TITLE 36025
#define IDS_AUTOFILL_IPH_ACCOUNT_NAME_EMAIL_SUGGESTION 36026
#define IDS_AUTOFILL_IPH_ACCOUNT_NAME_EMAIL_SUGGESTION_SCREENREADER 36027
#define IDS_AUTOFILL_IPH_ACCOUNT_NAME_EMAIL_SUGGESTION_TITLE 36028
#define IDS_AUTOFILL_SUGGESTION_LABEL_SEPARATOR 36029
#define IDS_AUTOFILL_CREDIT_CARD_EXPIRATION_DATE_ABBR 36030
#define IDS_AUTOFILL_CREDIT_CARD_EXPIRATION_DATE_ABBR_V2 36031
#define IDS_AUTOFILL_CREDIT_CARD_TWO_LINE_LABEL_FROM_NAME 36032
#define IDS_AUTOFILL_CREDIT_CARD_TWO_LINE_LABEL_FROM_CARD_NUMBER 36033
#define IDS_AUTOFILL_LOADING_REGIONS 36034
#define IDS_AUTOFILL_ADDRESSES 36035
#define IDS_AUTOFILL_ADDRESSES_TABLE_ARIA_LABEL 36036
#define IDS_AUTOFILL_ENABLE_PROFILES_TOGGLE_SUBLABEL 36037
#define IDS_AUTOFILL_LOCAL_PROFILE_ICON_ACCESSIBILITY_LABEL 36038
#define IDS_AUTOFILL_HOME_PROFILE_ICON_ACCESSIBILITY_LABEL 36039
#define IDS_AUTOFILL_WORK_PROFILE_ICON_ACCESSIBILITY_LABEL 36040
#define IDS_AUTOFILL_ENABLE_CREDIT_CARDS_TOGGLE_SUBLABEL 36041
#define IDS_AUTOFILL_DELETE_ACCOUNT_ADDRESS_RECORD_TYPE_NOTICE 36042
#define IDS_AUTOFILL_DELETE_SYNC_ADDRESS_RECORD_TYPE_NOTICE 36043
#define IDS_AUTOFILL_DELETE_LOCAL_ADDRESS_RECORD_TYPE_NOTICE 36044
#define IDS_AUTOFILL_SAVE_IN_ACCOUNT_MESSAGE_ADDRESS_RECORD_TYPE_NOTICE 36045
#define IDS_AUTOFILL_SAVE_IN_ACCOUNT_MESSAGE_ADDRESS_MIGRATION_RECORD_TYPE_NOTICE 36046
#define IDS_AUTOFILL_ADDRESS_ALREADY_SAVED_IN_ACCOUNT_RECORD_TYPE_NOTICE 36047
#define IDS_AUTOFILL_ADDRESS_WILL_BE_SAVED_IN_ACCOUNT_RECORD_TYPE_NOTICE 36048
#define IDS_AUTOFILL_ADDRESS_HOME_RECORD_TYPE_NOTICE 36049
#define IDS_AUTOFILL_ADDRESS_WORK_RECORD_TYPE_NOTICE 36050
#define IDS_AUTOFILL_ADDRESS_HOME_AND_WORK_RECORD_TYPE_NOTICE 36051
#define IDS_AUTOFILL_EDIT_ADDRESS_REQUIRED_FIELD_FORM_ERROR 36052
#define IDS_AUTOFILL_EDIT_ADDRESS_REQUIRED_FIELDS_FORM_ERROR 36053
#define IDS_AUTOFILL_LOCAL_ADDRESS_ICON_A11Y_LABEL 36054
#define IDS_AUTOFILL_HOME_ADDRESS_ICON_A11Y_LABEL 36055
#define IDS_AUTOFILL_WORK_ADDRESS_ICON_A11Y_LABEL 36056
#define IDS_AUTOFILL_HOME_WORK_ADDRESS_EDIT_A11Y_LABEL 36057
#define IDS_AUTOFILL_SYNC_TOGGLE_LABEL 36058
#define IDS_AUTOFILL_ADDRESSES_SETTINGS_TITLE 36059
#define IDS_AUTOFILL_ADDRESSES_SETTINGS_SUBLABEL 36060
#define IDS_AUTOFILL_PAYMENT_METHODS 36061
#define IDS_AUTOFILL_PAYMENT_METHODS_TABLE_ARIA_LABEL 36062
#define IDS_AUTOFILL_ENABLE_PROFILES_TOGGLE_LABEL 36063
#define IDS_AUTOFILL_DISABLE_SETTINGS_EXPLANATION_TITLE 36064
#define IDS_AUTOFILL_DISABLE_SETTINGS_EXPLANATION 36065
#define IDS_AUTOFILL_DISABLE_SETTINGS_BUTTON_LABEL 36066
#define IDS_AUTOFILL_ENABLE_CREDIT_CARDS_TOGGLE_LABEL 36067
#define IDS_AUTOFILL_DELETE_ADDRESS_CONFIRMATION_DIALOG_TITLE 36068
#define IDS_SYNC_DATATYPE_PAYMENTS_AND_INFO 36078
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_OK_BUTTON_LABEL 36087
#define IDS_AUTOFILL_SAVE_ADDRESS_WITH_MORE_INFO_ADDRESS_PROMPT_TITLE 36088
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_MIGRATION_OK_BUTTON_LABEL 36089
#define IDS_AUTOFILL_ACCOUNT_MIGRATE_ADDRESS_PROMPT_TITLE 36090
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_OK_BUTTON_LABEL 36091
#define IDS_AUTOFILL_ADD_NEW_INFO_ADDRESS_PROMPT_TITLE 36092
#define IDS_AUTOFILL_UPDATE_ADDRESS_ADD_NEW_INFO_PROMPT_OK_BUTTON_LABEL 36093
#define IDS_AUTOFILL_ADDRESS_MIGRATION_TO_ACCOUNT_PROMPT_OK_BUTTON_LABEL 36094
#define IDS_AUTOFILL_ADDRESS_MIGRATION_TO_ACCOUNT_PROMPT_CANCEL_BUTTON_LABEL 36095
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_NEW_VALUES_SECTION_LABEL 36096
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_OLD_VALUES_SECTION_LABEL 36097
#define IDS_AUTOFILL_MIGRATE_ADDRESS_PROMPT_CANCEL_BUTTON_LABEL 36098
#define IDS_AUTOFILL_SAVE_IN_ACCOUNT_PROMPT_ADDRESS_SOURCE_NOTICE 36099
#define IDS_AUTOFILL_UPDATE_PROMPT_ACCOUNT_ADDRESS_SOURCE_NOTICE 36100
#define IDS_AUTOFILL_SYNCABLE_PROFILE_MIGRATION_PROMPT_NOTICE 36101
#define IDS_AUTOFILL_LOCAL_PROFILE_MIGRATION_PROMPT_NOTICE 36102
#define IDS_AUTOFILL_SAVE_PROMPT_ADDRESS_SECTION_A11Y_LABEL 36103
#define IDS_AUTOFILL_SAVE_PROMPT_PHONE_SECTION_A11Y_LABEL 36104
#define IDS_AUTOFILL_SAVE_PROMPT_EMAIL_SECTION_A11Y_LABEL 36105
#define IDS_AUTOFILL_CONTACT_INFO_TITLE 36128
#define IDS_AUTOFILL_PAYMENTS_TITLE 36129
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_TITLE 36106
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_CANCEL_BUTTON_LABEL 36130
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_EDIT_BUTTON_TOOLTIP 36110
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_TITLE 36108
#define IDS_AUTOFILL_UPDATE_ADDRESS_ADD_NEW_INFO_PROMPT_CANCEL_BUTTON_LABEL 36131
#define IDS_AUTOFILL_ADD_NEW_ADDRESS_PROMPT_TITLE 36132
#define IDS_AUTOFILL_ADD_NEW_ADDRESS_EDITOR_TITLE 36133
#define IDS_AUTOFILL_ADD_NEW_ADDRESS_INTO_CHROME_PROMPT_BODY_TEXT 36134
#define IDS_AUTOFILL_ADD_NEW_ADDRESS_INTO_ACCOUNT_PROMPT_BODY_TEXT 36135
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_CANCEL_BUTTON_LABEL 36136
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_NAME_EMAIL_HOME_WORK_MERGE_PROMPT_TITLE 36137
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_NAME_EMAIL_HOME_WORK_MERGE_OK_BUTTON_LABEL 36138
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_NAME_EMAIL_HOME_WORK_MERGE_CANCEL_BUTTON_LABEL 36139
#define IDS_AUTOFILL_EDIT_ADDRESS_DIALOG_TITLE 36111
#define IDS_AUTOFILL_EDIT_ADDRESS_DIALOG_OK_BUTTON_LABEL_SAVE 36140
#define IDS_AUTOFILL_MIGRATE_ADDRESS_DIALOG_OK_BUTTON_LABEL_SAVE 36141
#define IDS_AUTOFILL_EDIT_ADDRESS_DIALOG_OK_BUTTON_LABEL_UPDATE 36142
#define IDS_AUTOFILL_ADD_NEW_ADDRESS_DIALOG_OK_BUTTON_LABEL 36143
#define IDS_AUTOFILL_EDIT_ADDRESS_DIALOG_CANCEL_BUTTON_LABEL 36144
#define IDS_AUTOFILL_EXPANDABLE_SUGGESTION_FILL_ADDRESS_A11Y_ADDON 36145
#define IDS_AUTOFILL_EXPANDABLE_SUGGESTION_EXPAND_SHORTCUT 36146
#define IDS_AUTOFILL_EXPANDABLE_SUGGESTION_EXPAND_SHORTCUT_RTL 36147
#define IDS_AUTOFILL_EXPANDABLE_SUGGESTION_SUBMENU_HINT 36148
#define IDS_AUTOFILL_SIGNIN_PROMO_TITLE_PASSWORD 36149
#define IDS_AUTOFILL_VERIFY_PROMO_SUBTITLE_PASSWORD 36150
#define IDS_AUTOFILL_POPUP_SEARCH_BAR_CLEAR_SEARCH_BUTTON_A11Y_NAME 36151
#define IDS_AUTOFILL_POPUP_SEARCH_BAR_PASSWORDS_INPUT_PLACEHOLDER 36152
#define IDS_AUTOFILL_AT_MEMORY_POPUP_SEARCH_BAR_PLACEHOLDER 36153
#define IDS_AUTOFILL_POPUP_SEARCH_BAR_PASSWORDS_NOT_FOUND 36154
#define IDS_AUTOFILL_SIGNIN_PROMO_TITLE_ADDRESS 36155
#define IDS_AUTOFILL_VERIFY_PROMO_SUBTITLE_ADDRESS 36156
#define IDS_AUTOFILL_IPH_LOYALTY_CARD_SUGGESTION_TITLE 36157
#define IDS_AUTOFILL_IPH_LOYALTY_CARD_SUGGESTION_BODY 36158
#define IDS_AUTOFILL_IPH_LOYALTY_CARD_SUGGESTION_SCREENREADER 36159
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_RECOVERY_SHOWN_A11Y_ANNOUNCEMENT 36160
#define IDS_AUTOFILL_IDENTITY_DOCS_TITLE 36161
#define IDS_AUTOFILL_IDENTITY_DOCS_OPT_IN_TOGGLE_LABEL 36162
#define IDS_AUTOFILL_IDENTITY_DOCS_OPT_IN_TOGGLE_SUB_LABEL 36163
#define IDS_AUTOFILL_TRAVEL_TITLE 36164
#define IDS_AUTOFILL_TRAVEL_OPT_IN_TOGGLE_LABEL 36165
#define IDS_AUTOFILL_TRAVEL_OPT_IN_TOGGLE_SUB_LABEL 36166
#define IDS_AUTOFILL_ADDRESS_EDIT_DIALOG_HISPANIC_MUNICIPIO 36167
#define IDS_AUTOFILL_ADDRESS_EDIT_DIALOG_FRENCH_LOCALITY_2 36168
#define IDS_AUTOFILL_ADDRESS_EDIT_DIALOG_JAPANESE_ALTERNATIVE_NAME 36169
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_ENTITY_NAME 36171
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_ENTITY_NAME 36172
#define IDS_AUTOFILL_AI_ID_CARD_ENTITY_NAME 36173
#define IDS_AUTOFILL_AI_PASSPORT_ENTITY_NAME 36174
#define IDS_AUTOFILL_AI_VEHICLE_ENTITY_NAME 36175
#define IDS_AUTOFILL_AI_KNOWN_TRAVELER_NUMBER_ENTITY_NAME 36176
#define IDS_AUTOFILL_AI_REDRESS_NUMBER_ENTITY_NAME 36177
#define IDS_AUTOFILL_AI_FLIGHT_RESERVATION_ENTITY_NAME 36178
#define IDS_AUTOFILL_AI_ORDER_ENTITY_NAME 36179
#define IDS_AUTOFILL_AI_DRIVERS_LICENSES_TITLE 36180
#define IDS_AUTOFILL_AI_NATIONAL_IDS_TITLE 36181
#define IDS_AUTOFILL_AI_PASSPORTS_TITLE 36182
#define IDS_AUTOFILL_AI_VEHICLES_TITLE 36183
#define IDS_AUTOFILL_AI_TRAVEL_INFO_TITLE 36184
#define IDS_AUTOFILL_AI_FLIGHT_RESERVATIONS_TITLE 36185
#define IDS_AUTOFILL_AI_ORDERS_TITLE 36186
#define IDS_AUTOFILL_AI_ADD_DRIVERS_LICENSE_ENTITY 36187
#define IDS_AUTOFILL_AI_ADD_NATIONAL_ID_CARD_ENTITY 36188
#define IDS_AUTOFILL_AI_ADD_PASSPORT_ENTITY 36189
#define IDS_AUTOFILL_AI_ADD_VEHICLE_ENTITY 36190
#define IDS_AUTOFILL_AI_ADD_KNOWN_TRAVELER_NUMBER_ENTITY 36191
#define IDS_AUTOFILL_AI_ADD_REDRESS_NUMBER_ENTITY 36192
#define IDS_AUTOFILL_AI_EDIT_DRIVERS_LICENSE_ENTITY 36193
#define IDS_AUTOFILL_AI_EDIT_NATIONAL_ID_CARD_ENTITY 36194
#define IDS_AUTOFILL_AI_EDIT_PASSPORT_ENTITY 36195
#define IDS_AUTOFILL_AI_EDIT_VEHICLE_ENTITY 36196
#define IDS_AUTOFILL_AI_EDIT_KNOWN_TRAVELER_NUMBER_ENTITY 36197
#define IDS_AUTOFILL_AI_EDIT_REDRESS_NUMBER_ENTITY 36198
#define IDS_AUTOFILL_AI_DELETE_DRIVERS_LICENSE_ENTITY 36199
#define IDS_AUTOFILL_AI_DELETE_NATIONAL_ID_CARD_ENTITY 36200
#define IDS_AUTOFILL_AI_DELETE_PASSPORT_ENTITY 36201
#define IDS_AUTOFILL_AI_DELETE_VEHICLE_ENTITY 36202
#define IDS_AUTOFILL_AI_DELETE_KNOWN_TRAVELER_NUMBER_ENTITY 36203
#define IDS_AUTOFILL_AI_DELETE_REDRESS_NUMBER_ENTITY 36204
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_NAME_ATTRIBUTE_NAME 36205
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_STATE_ATTRIBUTE_NAME 36206
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_NUMBER_ATTRIBUTE_NAME 36207
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_NUMBER_ATTRIBUTE_NAME_NEW 36208
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_EXPIRATION_DATE_ATTRIBUTE_NAME 36209
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_ISSUE_DATE_ATTRIBUTE_NAME 36210
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_NAME_ATTRIBUTE_NAME 36211
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_NUMBER_ATTRIBUTE_NAME 36212
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_COUNTRY_ATTRIBUTE_NAME 36213
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_COUNTRY_ATTRIBUTE_NAME_NEW 36214
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_EXPIRATION_DATE_ATTRIBUTE_NAME 36215
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_ISSUE_DATE_ATTRIBUTE_NAME 36216
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_ISSUE_DATE_ATTRIBUTE_NAME_NEW 36217
#define IDS_AUTOFILL_AI_KNOWN_TRAVELER_NUMBER_NAME_ATTRIBUTE_NAME 36218
#define IDS_AUTOFILL_AI_KNOWN_TRAVELER_NUMBER_ATTRIBUTE_NAME 36219
#define IDS_AUTOFILL_AI_KNOWN_TRAVELER_NUMBER_EXPIRATION_DATE_ATTRIBUTE_NAME 36220
#define IDS_AUTOFILL_AI_REDRESS_NUMBER_NAME_ATTRIBUTE_NAME 36221
#define IDS_AUTOFILL_AI_REDRESS_NUMBER_ATTRIBUTE_NAME 36222
#define IDS_AUTOFILL_AI_PASSPORT_NAME_ATTRIBUTE_NAME 36223
#define IDS_AUTOFILL_AI_PASSPORT_NUMBER_ATTRIBUTE_NAME 36224
#define IDS_AUTOFILL_AI_PASSPORT_COUNTRY_ATTRIBUTE_NAME 36225
#define IDS_AUTOFILL_AI_PASSPORT_EXPIRATION_DATE_ATTRIBUTE_NAME 36226
#define IDS_AUTOFILL_AI_PASSPORT_ISSUE_DATE_ATTRIBUTE_NAME 36227
#define IDS_AUTOFILL_AI_VEHICLE_MAKE_ATTRIBUTE_NAME 36228
#define IDS_AUTOFILL_AI_VEHICLE_MODEL_ATTRIBUTE_NAME 36229
#define IDS_AUTOFILL_AI_VEHICLE_YEAR_ATTRIBUTE_NAME 36230
#define IDS_AUTOFILL_AI_VEHICLE_OWNER_ATTRIBUTE_NAME 36231
#define IDS_AUTOFILL_AI_VEHICLE_PLATE_NUMBER_ATTRIBUTE_NAME 36232
#define IDS_AUTOFILL_AI_VEHICLE_PLATE_STATE_ATTRIBUTE_NAME 36233
#define IDS_AUTOFILL_AI_VEHICLE_VEHICLE_IDENTIFICATION_NUMBER_ATTRIBUTE_NAME 36234
#define IDS_AUTOFILL_AI_ORDER_ID_ATTRIBUTE_NAME 36235
#define IDS_AUTOFILL_AI_ORDER_ACCOUNT_ATTRIBUTE_NAME 36236
#define IDS_AUTOFILL_AI_ORDER_DATE_ATTRIBUTE_NAME 36237
#define IDS_AUTOFILL_AI_ORDER_MERCHANT_NAME_ATTRIBUTE_NAME 36238
#define IDS_AUTOFILL_AI_ORDER_MERCHANT_DOMAIN_ATTRIBUTE_NAME 36239
#define IDS_AUTOFILL_AI_ORDER_PRODUCT_NAMES_ATTRIBUTE_NAME 36240
#define IDS_AUTOFILL_AI_ORDER_GRAND_TOTAL_ATTRIBUTE_NAME 36241
#define IDS_AUTOFILL_AI_MANAGE_SUGGESTION_MAIN_TEXT 36242
#define IDS_AUTOFILL_AI_MANAGE_IDENTITY_DOCS_SUGGESTION_MAIN_TEXT 36243
#define IDS_AUTOFILL_AI_MANAGE_TRAVEL_SUGGESTION_MAIN_TEXT 36244
#define IDS_AUTOFILL_PREDICTION_IMPROVEMENTS_SAVE_DIALOG_NO_THANKS_BUTTON 36245
#define IDS_AUTOFILL_PREDICTION_IMPROVEMENTS_SAVE_DIALOG_SAVE_BUTTON 36246
#define IDS_AUTOFILL_PREDICTION_IMPROVEMENTS_UPDATE_DIALOG_UPDATE_BUTTON 36247
#define IDS_AUTOFILL_PREDICTION_IMPROVEMENTS_SAVE_DIALOG_FOOTER_DETAILS 36248
#define IDS_AUTOFILL_AI_OPT_IN_IPH_TITLE 36249
#define IDS_AUTOFILL_AI_OPT_IN_IPH_BODY 36250
#define IDS_AUTOFILL_AI_OPT_IN_IPH_TURN_ON 36251
#define IDS_AUTOFILL_AI_OPT_IN_IPH_MAYBE_LATER 36252
#define IDS_AUTOFILL_AI_VALUABLES_IPH_TITLE 36253
#define IDS_AUTOFILL_AI_VALUABLES_IPH_BODY 36254
#define IDS_AUTOFILL_AI_VALUABLES_IPH_SCREENREADER 36255
#define IDS_AUTOFILL_GOOGLE_WALLET_TITLE 36256
#define IDS_AUTOFILL_AI_SAVE_DRIVERS_LICENSE_ENTITY_DIALOG_TITLE 36257
#define IDS_AUTOFILL_AI_SAVE_NATIONAL_ID_CARD_ENTITY_DIALOG_TITLE 36258
#define IDS_AUTOFILL_AI_SAVE_ID_CARD_ENTITY_DIALOG_TITLE 36259
#define IDS_AUTOFILL_AI_SAVE_PASSPORT_ENTITY_DIALOG_TITLE 36260
#define IDS_AUTOFILL_AI_SAVE_VEHICLE_ENTITY_DIALOG_TITLE 36261
#define IDS_AUTOFILL_AI_SAVE_KNOWN_TRAVELER_NUMBER_ENTITY_DIALOG_TITLE 36262
#define IDS_AUTOFILL_AI_SAVE_REDRESS_NUMBER_ENTITY_DIALOG_TITLE 36263
#define IDS_AUTOFILL_AI_UPDATE_DRIVERS_LICENSE_ENTITY_DIALOG_TITLE 36264
#define IDS_AUTOFILL_AI_UPDATE_NATIONAL_ID_CARD_ENTITY_DIALOG_TITLE 36265
#define IDS_AUTOFILL_AI_UPDATE_ID_CARD_ENTITY_DIALOG_TITLE 36266
#define IDS_AUTOFILL_AI_UPDATE_PASSPORT_ENTITY_DIALOG_TITLE 36267
#define IDS_AUTOFILL_AI_UPDATE_VEHICLE_ENTITY_DIALOG_TITLE 36268
#define IDS_AUTOFILL_AI_UPDATE_KNOWN_TRAVELER_NUMBER_ENTITY_DIALOG_TITLE 36269
#define IDS_AUTOFILL_AI_UPDATE_REDRESS_NUMBER_ENTITY_DIALOG_TITLE 36270
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_SUBTITLE 36271
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_TO_WALLET_DIALOG_SUBTITLE 36272
#define IDS_AUTOFILL_AI_SAVE_ENTITY_DIALOG_SUBTITLE 36273
#define IDS_AUTOFILL_AI_SAVE_ENTITY_TO_WALLET_DIALOG_SUBTITLE 36274
#define IDS_AUTOFILL_MANAGE_YOUR_INFO_LINK 36275
#define IDS_AUTOFILL_AI_SAVE_ENTITY_TO_WALLET_DIALOG_SUBTITLE_NEW 36276
#define IDS_AUTOFILL_AI_SAVE_ENTITY_TO_WALLET_SETTINGS_SUBTITLE 36277
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_UPDATED_ATTRIBUTE_ACCESSIBLE_NAME 36278
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_NEW_ATTRIBUTE_ACCESSIBLE_NAME 36279
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_NEW_ATTRIBUTE_ACCESSIBLE_NAME_V2 36280
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_UPDATED_ATTRIBUTE_ACCESSIBLE_NAME_V2 36281
#define IDS_AUTOFILL_AI_WALLET_UPLOAD_THROBBER_ACCESSIBLE_NAME 36282
#define IDS_AUTOFILL_AI_LOCAL_SAVE_NOTIFICATION_TITLE 36283
#define IDS_AUTOFILL_AI_LOCAL_SAVE_NOTIFICATION_DESCRIPTION 36284
#define IDS_AUTOFILL_AI_LOCAL_SAVE_NOTIFICATION_DISMISS_BUTTON_LABEL 36285
#define IDS_AUTOFILL_AI_WALLET_UPDATE_OR_MIGRATE_FAILURE_NOTIFICATION 36286
#define IDS_AUTOFILL_AI_WALLET_FETCH_FAILURE_NOTIFICATION 36287
#define IDS_AUTOFILL_AI_FFR_WHEN_ON_TITLE 36315
#define IDS_AUTOFILL_AI_FFR_WHEN_ON_DESCRIPTION 36316
#define IDS_AUTOFILL_AI_FFR_CONSIDER_DESCRIPTION 36317
#define IDS_AUTOFILL_AI_FFR_CONSIDER_LEARN_MORE 36318
#define IDS_SETTINGS_AUTOFILL_AI_AUTHENTICATION_TOGGLE_TITLE 36319
#define IDS_SETTINGS_AUTOFILL_AI_AUTHENTICATION_TOGGLE_SUBTITLE 36320
#define IDS_SETTINGS_AUTOFILL_AI_PAGE_TITLE 36321
#define IDS_SETTINGS_AUTOFILL_AI_WHEN_ON 36322
#define IDS_SETTINGS_AUTOFILL_AI_THINGS_TO_CONSIDER 36323
#define IDS_SETTINGS_AUTOFILL_SERVICE_PROVIDER 36324
#define IDS_SETTINGS_AUTOFILL_AI_TO_CONSIDER_DATA_USAGE 36325
#define IDS_SETTINGS_AUTOFILL_AI_DESCRIPTION 36326
#define IDS_SETTINGS_AUTOFILL_AI_TOGGLE_SUB_LABEL 36327
#define IDS_SETTINGS_AUTOFILL_AI_WHEN_ON_CAN_FILL_DIFFICULT_FIELDS 36328
#define IDS_BOOKMARK_BAR_FOLDER_NAME 36331
#define IDS_BOOKMARK_BAR_MOBILE_FOLDER_NAME 36332
#define IDS_BOOKMARK_BAR_OTHER_FOLDER_NAME 36333
#define IDS_BOOKMARK_BAR_MANAGED_FOLDER_DOMAIN_NAME 36334
#define IDS_BOOKMARK_BAR_MANAGED_FOLDER_DEFAULT_NAME 36335
#define IDS_BOOKMARK_EDITOR_TITLE 36336
#define IDS_BOOKMARK_MOVE_DIALOG_TITLE 36337
#define IDS_BOOKMARK_EDITOR_NEW_FOLDER_NAME 36338
#define IDS_BOOKMARK_BUBBLE_REMOVE_BOOKMARK 36339
#define IDS_BOOKMARK_MANAGER_NAME_INPUT_PLACE_HOLDER 36340
#define IDS_BOOKMARK_MANAGER_URL_INPUT_PLACE_HOLDER 36341
#define IDS_TOOLTIP_STAR 36342
#define IDS_CLEAR_BROWSING_DATA_CALCULATING 36343
#define IDS_DEL_BROWSING_HISTORY_COUNTER 36344
#define IDS_DEL_BROWSING_HISTORY_COUNTER_SYNCED 36345
#define IDS_DEL_NO_BROWSING_HISTORY_TEXT 36346
#define IDS_DEL_NO_BROWSING_HISTORY_SYNC_TEXT 36347
#define IDS_DEL_BROWSING_HISTORY_DOMAIN_COUNT_TEXT 36348
#define IDS_DEL_BROWSING_HISTORY_DOMAIN_COUNT_SYNC_TEXT 36349
#define IDS_DEL_BROWSING_HISTORY_COUNTER_MULTIPLE_DOMAINS_TEXT 36350
#define IDS_DEL_BROWSING_HISTORY_COUNTER_SINGLE_DOMAIN_TEXT 36351
#define IDS_DEL_BROWSING_HISTORY_COUNTER_SINGLE_DOMAIN_SYNC_TEXT 36352
#define IDS_DEL_CACHE_COUNTER_UPPER_ESTIMATE 36353
#define IDS_DEL_CACHE_COUNTER_ALMOST_EMPTY 36354
#define IDS_DEL_CACHE_COUNTER_BASIC 36355
#define IDS_DEL_CACHE_COUNTER_UPPER_ESTIMATE_BASIC 36356
#define IDS_DEL_CACHE_COUNTER_ALMOST_EMPTY_BASIC 36357
#define IDS_ANDROID_DEL_CACHE_COUNTER_ADVANCED 36358
#define IDS_ANDROID_DEL_CACHE_COUNTER_ADVANCED_UPPER_ESTIMATE 36359
#define IDS_ANDROID_DEL_CACHE_COUNTER_ADVANCED_ALMOST_EMPTY 36360
#define IDS_DEL_PASSWORDS_COUNTER 36361
#define IDS_DEL_PASSWORDS_COUNTER_SYNCED 36362
#define IDS_DEL_ACCOUNT_PASSWORDS_COUNTER 36363
#define IDS_DEL_PASSWORDS_DOMAINS_DISPLAY 36364
#define IDS_DEL_PASSWORDS_COUNTER_AND_X_MORE 36365
#define IDS_DEL_SIGNIN_DATA_COUNTER 36366
#define IDS_DEL_PASSWORDS_AND_SIGNIN_DATA_COUNTER_NONE 36367
#define IDS_DEL_PASSWORDS_AND_SIGNIN_DATA_COUNTER_COMBINATION 36368
#define IDS_DEL_SITE_SETTINGS_COUNTER 36369
#define IDS_DEL_AUTOFILL_COUNTER_EMPTY 36370
#define IDS_DEL_AUTOFILL_COUNTER_PAYMENT_METHODS 36371
#define IDS_DEL_AUTOFILL_COUNTER_ADDRESSES 36372
#define IDS_DEL_AUTOFILL_COUNTER_SUGGESTIONS 36373
#define IDS_DEL_AUTOFILL_COUNTER_USER_ANNOTATION_ENTRIES 36374
#define IDS_DEL_AUTOFILL_COUNTER_SUGGESTIONS_LONG 36375
#define IDS_DEL_AUTOFILL_COUNTER_SUGGESTIONS_SHORT 36376
#define IDS_DEL_AUTOFILL_COUNTER_ONE_TYPE_SYNCED 36377
#define IDS_DEL_AUTOFILL_COUNTER_TWO_TYPES 36378
#define IDS_DEL_AUTOFILL_COUNTER_TWO_TYPES_SYNCED 36379
#define IDS_DEL_AUTOFILL_COUNTER_THREE_TYPES 36380
#define IDS_DEL_AUTOFILL_COUNTER_THREE_TYPES_SYNCED 36381
#define IDS_DEL_AUTOFILL_SYNCABLE_NON_SYNCABLE_COMBINATION 36382
#define IDS_DEL_COOKIES_COUNTER 36383
#define IDS_DEL_COOKIES_COUNTER_ADVANCED 36384
#define IDS_DEL_COOKIES_COUNTER_ADVANCED_WITH_SIGNED_IN_EXCEPTION 36385
#define IDS_ANDROID_DEL_COOKIES_COUNTER_ADVANCED 36386
#define IDS_DEL_DOWNLOADS_COUNTER 36387
#define IDS_DEL_HOSTED_APPS_COUNTER 36388
#define IDS_DEL_HOSTED_APPS_COUNTER_AND_X_MORE 36389
#define IDS_DEL_TABS_COUNTER 36390
#define IDS_TABS_COUNT 36391
#define IDS_WINDOWS_COUNT 36392
#define IDS_DEL_TABS_MULTIWINDOW_COUNTER 36393
#define IDS_DEL_GOOGLE_COOKIES_SIGNOUT_LINK 36394
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_TITLE 36395
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_CONTENT 36396
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_NO_THANKS 36397
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_GET_DISCOUNTS 36398
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_ACCEPTED_CONFIRMATION_TITLE 36399
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_ACCEPTED_CONFIRMATION_CONTENT 36400
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_ACCEPTED_CONFIRMATION_DONE 36401
#define IDS_NATIVE_NTP_CART_DISCOUNT_CONSENT_ACCEPT_BUTTON 36402
#define IDS_NATIVE_NTP_CART_DISCOUNT_CONSENT_TITLE 36403
#define IDS_NATIVE_NTP_CART_DISCOUNT_CONSENT_BODY 36404
#define IDS_NTP_CART_DISCOUNT_STEP_ONE_CONTENT 36405
#define IDS_OMNIBOX_TRACK_PRICE 36406
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_TITLE 36407
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_DESCRIPTION 36408
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_EMAIL_DESCRIPTION 36409
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_ACTION_BUTTON 36410
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_ERROR_DESCRIPTION 36411
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_ERROR_BUTTON 36412
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_TITLE_FIRST_RUN 36413
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_DESCRIPTION_FIRST_RUN 36414
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_CANCEL_BUTTON 36415
#define IDS_PRICE_TRACKING_SAVE_DESCRIPTION 36416
#define IDS_PRICE_TRACKING_SAVE_LOCATION 36417
#define IDS_PRICE_TRACKING_EMAIL_CONSENT_BODY 36418
#define IDS_PRICE_TRACKING_EMAIL_CONSENT_TITLE 36419
#define IDS_PRICE_TRACKING_EMAIL_CONSENT_LEARN_MORE_LINK_TEXT 36420
#define IDS_PRICE_TRACKING_NOT_NOW 36421
#define IDS_PRICE_TRACKING_YES_IM_IN 36422
#define IDS_OMNIBOX_TRACKING_PRICE 36423
#define IDS_OMNIBOX_TRACKING_PRICE_DIALOG_TITLE 36424
#define IDS_OMNIBOX_TRACKING_PRICE_DIALOG_ACTION_BUTTON 36425
#define IDS_OMNIBOX_TRACKING_PRICE_DIALOG_UNTRACK_BUTTON 36426
#define IDS_OMNIBOX_PRICE_TRACKING_OFF_DIALOG_TITLE 36427
#define IDS_OMNIBOX_PRICE_TRACKING_OFF_DIALOG_DESCRIPTION 36428
#define IDS_OMNIBOX_PRICE_TRACKING_OFF_DIALOG_DESCRIPTION_BOOKMARK_REMOVED 36429
#define IDS_OMNIBOX_PRICE_TRACKING_OFF_DIALOG_ACTION_BUTTON 36430
#define IDS_BOOKMARK_STAR_DIALOG_TRACK_PRICE_DESCRIPTION 36431
#define IDS_BOOKMARK_STAR_DIALOG_TRACK_PRICE_DESCRIPTION_EMAIL_OFF 36432
#define IDS_BOOKMARKS_MANAGER_TRACKED_PRODUCTS 36433
#define IDS_BOOKMARKS_MANAGER_UNTRACK_BUTTON 36434
#define IDS_PRICE_TRACKING_SIDE_PANEL_IPH 36435
#define IDS_SIDE_PANEL_TRACKED_PRODUCTS 36436
#define IDS_PRICE_TRACKING_CHIP_IPH 36437
#define IDS_SIDE_PANEL_UNTRACK_BUTTON 36438
#define IDS_SIDE_PANEL_TRACK_BUTTON 36439
#define IDS_BOOKMARKS_MENU_UNTRACK_PRICE 36440
#define IDS_BOOKMARKS_MENU_TRACK_PRICE 36441
#define IDS_PRICE_TRACKING_UNTRACK_PRODUCT_ACCESSIBILITY 36442
#define IDS_PRICE_TRACKING_TRACK_PRODUCT_ACCESSIBILITY 36443
#define IDS_PRICE_TRACKING_SIDE_PANEL_ERROR_BUTTON 36444
#define IDS_PRICE_TRACKING_SETTINGS_TITLE 36445
#define IDS_PRICE_TRACKING_SETTINGS_EMAIL_DESCRIPTION 36446
#define IDS_PRICE_TRACKING_SETTINGS_POPUP_DESCRIPTION 36447
#define IDS_PRICE_TRACKING_SIDE_PANEL_ERROR_MESSAGE 36448
#define IDS_SHOPPING_COLLECTION_IPH_TITLE 36449
#define IDS_SHOPPING_COLLECTION_IPH_BODY 36450
#define IDS_SHOPPING_INSIGHTS_SIDE_PANEL_TITLE 36451
#define IDS_PRICE_HISTORY_TITLE 36452
#define IDS_PRICE_HISTORY_TITLE_MULTIPLE_OPTIONS 36453
#define IDS_PRICE_HISTORY_MULTIPLE_OPTIONS_LOW_PRICE 36454
#define IDS_PRICE_HISTORY_MULTIPLE_OPTIONS_HIGH_PRICE 36455
#define IDS_PRICE_HISTORY_MULTIPLE_OPTIONS_TYPICAL_PRICE 36456
#define IDS_SHOPPING_INSIGHTS_SIDE_PANEL_TRACK_PRICE_TITLE 36457
#define IDS_SHOPPING_INSIGHTS_ICON_TOOLTIP_TEXT 36458
#define IDS_SHOPPING_INSIGHTS_BUYING_OPTIONS 36459
#define IDS_PRICE_HISTORY_TODAY_PRICE 36460
#define IDS_PRICE_HISTORY_YESTERDAY_PRICE 36461
#define IDS_PRICE_HISTORY_DESCRIPTION 36462
#define IDS_PRICE_HISTORY_GRAPH_ACCESSIBILITY 36463
#define IDS_SHOPPING_INSIGHTS_COLLECT_FEEDBACK 36464
#define IDS_SHOPPING_INSIGHTS_FEEDBACK_FORM_TITLE 36465
#define IDS_PRICE_HISTORY_SINGLE_OPTION_LOW_PRICE 36466
#define IDS_PRICE_HISTORY_SINGLE_OPTION_HIGH_PRICE 36467
#define IDS_PRICE_HISTORY_SINGLE_OPTION_TYPICAL_PRICE 36468
#define IDS_SHOPPING_INSIGHTS_SIDE_PANEL_TRACK_PRICE_DESCRIPTION 36469
#define IDS_SHOPPING_INSIGHTS_SIDE_PANEL_TRACK_PRICE_ERROR 36470
#define IDS_DISCOUNT_USE_THIS_CODE_AT_CHECKOUT_WITH_EXPIRATION_DATE 36471
#define IDS_DISCOUNT_USE_THIS_CODE_AT_CHECKOUT 36472
#define IDS_DISCOUNT_EXPIRATION_DATE 36473
#define IDS_TWO_STRINGS_CONNECTOR 36474
#define IDS_TWO_STRINGS_CONNECTOR_WITH_SPACE 36475
#define IDS_SELLER_TERMS_AND_CONDITIONS_DIALOG_TITLE 36476
#define IDS_SELLER_TERMS_AND_CONDITIONS_DIALOG_FOOTER 36477
#define IDS_SEE_SELLER_TERMS_AND_CONDITIONS 36478
#define IDS_DISCOUNTS_COUPON_CODE_BUTTON_TOOLTIP 36479
#define IDS_DISCOUNTS_COUPON_CODE_BUTTON_TOOLTIP_CLICKED 36480
#define IDS_PRICE_DROP_POPUP_CONTENT_TITLE 36493
#define IDS_PRICE_DROP_POPUP_CONTENT_TEXT 36494
#define IDS_PRICE_DROP_POPUP_ACTION_BUTTON 36495
#define IDS_PRICE_DROP_POPUP_UNTRACK_BUTTON 36496
#define IDS_PRICE_RANGE_ALL_OPTIONS 36497
#define IDS_PRICE_RANGE_ALL_OPTIONS_ONE_TYPICAL_PRICE 36498
#define IDS_PRICE_RANGE_SINGLE_OPTION 36499
#define IDS_PRICE_RANGE_SINGLE_OPTION_ONE_TYPICAL_PRICE 36500
#define IDS_PRICE_TRACKING_DESCRIPTION 36501
#define IDS_PRICE_INSIGHTS_BUYING_OPTIONS_TITLE 36502
#define IDS_PRICE_INSIGHTS_BUYING_OPTIONS_SUBTITLE 36503
#define IDS_PRICE_INSIGHTS_TRACK_BUTTON_TITLE 36504
#define IDS_PRICE_INSIGHTS_TRACKING_BUTTON_TITLE 36505
#define IDS_INSIGHTS_ICON_EXPANDED_TEXT_GOOD_DEAL 36506
#define IDS_INSIGHTS_RICH_IPH_TEXT 36507
#define IDS_PRICE_INSIGHTS_ACCESSIBILITY 36508
#define IDS_PRICE_INSIGHTS_GRAPH_ACCESSIBILITY_LABEL 36509
#define IDS_PRICE_INSIGHTS_SNACKBAR_BUTTON_TITLE 36510
#define IDS_PRICE_INSIGHTS_SNACKBAR_MESSAGE_TITLE_NOTIFICATION_DISABLED 36511
#define IDS_PRICE_INSIGHTS_SNACKBAR_MESSAGE_TITLE_NOTIFICATION_ENABLED 36512
#define IDS_PRICE_RANGE_ACCESSIBILITY_DESCRIPTION 36513
#define IDS_BUYING_OPTIONS_ACCESSIBILITY_DESCRIPTION 36514
#define IDS_PRICE_TRACKING_DESCRIPTION_TRACKED 36515
#define IDS_PRICE_HISTORY_TITLE_WITH_VARIANTS 36516
#define IDS_IOS_PRICE_INSIGHTS_PRICE_TRACK_PERMISSION_REDIRECT_ALERT_TITLE 36517
#define IDS_IOS_PRICE_INSIGHTS_PRICE_TRACK_PERMISSION_REDIRECT_ALERT_MESSAGE 36518
#define IDS_IOS_PRICE_INSIGHTS_PRICE_TRACK_PERMISSION_REDIRECT_ALERT_CLOSE 36519
#define IDS_IOS_PRICE_INSIGHTS_PRICE_TRACK_PERMISSION_REDIRECT_ALERT_REDIRECT 36520
#define IDS_PRICE_INSIGHTS_UNTRACK_SNACKBAR_MESSAGE 36521
#define IDS_PRICE_INSIGHTS_UNTRACK_SNACKBAR_BUTTON_TITLE 36522
#define IDS_PRICE_HISTORY_TITLE_SINGLE_OPTION 36523
#define IDS_SHOPPING_INSIGHTS_ICON_EXPANDED_TEXT_LOW_PRICE 36524
#define IDS_SHOPPING_INSIGHTS_ICON_EXPANDED_TEXT_HIGH_PRICE 36525
#define IDS_SHOPPING_COLLECTION_FOLDER_NAME 36526
#define IDS_DISCOUNT_CODE_COPY_BUTTON_TEXT 36527
#define IDS_DISCOUNT_ICON_EXPANDED_TEXT 36528
#define IDS_SETTINGS_TITLE 36537
#define IDS_SETTINGS_HIDE_ADVANCED_SETTINGS 36538
#define IDS_SETTINGS_SHOW_ADVANCED_SETTINGS 36539
#define IDS_NETWORK_PREDICTION_ENABLED_DESCRIPTION 36540
#define IDS_SYSTEM_TITLE 36541
#define IDS_OPTIONS_PROXIES_CONFIGURE_BUTTON 36542
#define IDS_COMPOSE_SUGGESTION_MAIN_TEXT 36543
#define IDS_COMPOSE_CONTEXT_MENU_TEXT 36544
#define IDS_COMPOSE_SUGGESTION_LABEL 36545
#define IDS_COMPOSE_SUGGESTION_SAVED_TEXT 36546
#define IDS_COMPOSE_SUGGESTION_SAVED_LABEL 36547
#define IDS_COMPOSE_SUGGESTION_AX_MESSAGE_ON_SHOW_PROACTIVE 36548
#define IDS_COMPOSE_SUGGESTION_AX_MESSAGE_ON_SHOW_RESUME 36549
#define IDS_COMPOSE_DONT_SHOW_ON_THIS_SITE_CHILD_SUGGESTION_TEXT 36550
#define IDS_COMPOSE_DISABLE_HELP_ME_WRITE_CHILD_SUGGESTION_TEXT 36551
#define IDS_COMPOSE_GO_TO_SETTINGS_CHILD_SUGGESTION_TEXT 36552
#define IDS_COMPOSE_FRE_TITLE 36553
#define IDS_COMPOSE_FRE_MAIN_TOP 36554
#define IDS_COMPOSE_FRE_MAIN_MID 36555
#define IDS_COMPOSE_FRE_MAIN_MID_ENTERPRISE 36556
#define IDS_COMPOSE_FRE_OK_BUTTON 36557
#define IDS_COMPOSE_FRE_MSBB_TITLE 36558
#define IDS_COMPOSE_FRE_MSBB_MAIN 36559
#define IDS_COMPOSE_FRE_MSBB_SETTINGS_BUTTON 36560
#define IDS_COMPOSE_MSBB_IPH_BUBBLE_TEXT 36561
#define IDS_COMPOSE_MSBB_IPH_BUBBLE_TEXT_SCREENREADER 36562
#define IDS_COMPOSE_MSBB_IPH_BUBBLE_CLOSE_BUTTON_LABEL_TEXT 36563
#define IDS_COMPOSE_DIALOG_TITLE 36564
#define IDS_COMPOSE_INPUT_PLACEHOLDER_TITLE 36565
#define IDS_COMPOSE_INPUT_PLACEHOLDER_LINE_1 36566
#define IDS_COMPOSE_INPUT_PLACEHOLDER_LINE_2 36567
#define IDS_COMPOSE_INPUT_PLACEHOLDER_LINE_3 36568
#define IDS_COMPOSE_INPUT_FOOTER 36569
#define IDS_COMPOSE_INPUT_FOOTER_ENTERPRISE 36570
#define IDS_COMPOSE_INPUT_MODE_POLISH 36571
#define IDS_COMPOSE_INPUT_MODE_ELABORATE 36572
#define IDS_COMPOSE_INPUT_MODE_FORMALIZE 36573
#define IDS_COMPOSE_SUBMIT_BUTTON 36574
#define IDS_COMPOSE_EDIT_UPDATE_BUTTON 36575
#define IDS_COMPOSE_EDIT 36576
#define IDS_COMPOSE_MODIFIERS_MENU_TITLE 36577
#define IDS_COMPOSE_MODIFIERS_MENU_LABEL 36578
#define IDS_COMPOSE_MENU_RETRY_OPTION 36579
#define IDS_COMPOSE_MENU_LENGTH_TITLE 36580
#define IDS_COMPOSE_MENU_SHORTER_OPTION 36581
#define IDS_COMPOSE_MENU_LONGER_OPTION 36582
#define IDS_COMPOSE_MENU_TONE_TITLE 36583
#define IDS_COMPOSE_MENU_CASUAL_OPTION 36584
#define IDS_COMPOSE_MENU_FORMAL_OPTION 36585
#define IDS_COMPOSE_UNDO_BUTTON_TEXT 36586
#define IDS_COMPOSE_UNDO_LABEL 36587
#define IDS_COMPOSE_REDO_BUTTON_TEXT 36588
#define IDS_COMPOSE_REDO_LABEL 36589
#define IDS_COMPOSE_RESUBMIT 36590
#define IDS_COMPOSE_INSERT_BUTTON 36591
#define IDS_COMPOSE_REPLACE_BUTTON 36592
#define IDS_COMPOSE_THUMBS_DOWN 36593
#define IDS_COMPOSE_THUMBS_UP 36594
#define IDS_COMPOSE_RESULT_TEXT_LABEL 36595
#define IDS_COMPOSE_RESULT_LOADING_A11Y_MESSAGE 36596
#define IDS_COMPOSE_RESULT_UPDATED_A11Y_MESSAGE 36597
#define IDS_COMPOSE_UNDO_RESULT_A11Y_MESSAGE 36598
#define IDS_COMPOSE_REDO_RESULT_A11Y_MESSAGE 36599
#define IDS_COMPOSE_ERROR_TOO_SHORT 36600
#define IDS_COMPOSE_ERROR_TOO_LONG 36601
#define IDS_COMPOSE_ERROR_TRY_AGAIN 36602
#define IDS_COMPOSE_ERROR_TRY_AGAIN_LATER 36603
#define IDS_COMPOSE_ERROR_FILTERED 36604
#define IDS_COMPOSE_ERROR_FILTERED_BACK_BUTTON 36605
#define IDS_COMPOSE_ERROR_UNSUPPORTED_LANGUAGE 36606
#define IDS_COMPOSE_ERROR_PERMISSION_DENIED 36607
#define IDS_COMPOSE_ERROR_REQUEST_THROTTLED 36608
#define IDS_COMPOSE_ERROR_OFFLINE 36609
#define IDS_COMPOSE_FOOTER_FISHFOOD 36610
#define IDS_COMPOSE_EXPERIMENTAL_DISCLAIMER_FOOTER 36611
#define IDS_COMPOSE_REFINEMENTS_EXPERIMENTAL_DISCLAIMER_FOOTER 36612
#define IDS_COMPOSE_FOOTER_FISHFOOD_ON_DEVICE_USED 36613
#define IDS_COMPOSE_FEEDBACK_PLACEHOLDER 36614
#define IDS_CRASH_TITLE 36615
#define IDS_CRASH_CRASH_COUNT_BANNER_FORMAT 36616
#define IDS_CRASH_SHOW_DEVELOPER_DETAILS 36617
#define IDS_CRASH_CAPTURE_TIME_FORMAT 36618
#define IDS_CRASH_REPORT_STATUS 36619
#define IDS_CRASH_REPORT_STATUS_NOT_UPLOADED 36620
#define IDS_CRASH_REPORT_STATUS_PENDING 36621
#define IDS_CRASH_REPORT_STATUS_PENDING_USER_REQUESTED 36622
#define IDS_CRASH_REPORT_STATUS_UPLOADED 36623
#define IDS_CRASH_REPORT_UPLOADED_ID 36624
#define IDS_CRASH_REPORT_UPLOADED_TIME 36625
#define IDS_CRASH_REPORT_LOCAL_ID 36626
#define IDS_CRASH_REPORT_FILE_SIZE 36627
#define IDS_CRASH_BUG_LINK_LABEL 36628
#define IDS_CRASH_NO_CRASHES_MESSAGE 36629
#define IDS_CRASH_DISABLED_HEADER 36630
#define IDS_CRASH_UPLOAD_MESSAGE 36631
#define IDS_CRASH_UPLOAD_NOW_LINK_TEXT 36632
#define IDS_HTTP_POST_WARNING_TITLE 36633
#define IDS_HTTP_POST_WARNING 36634
#define IDS_HTTP_POST_WARNING_RESEND 36635
#define IDS_DOM_DISTILLER_JAVASCRIPT_DISABLED_CONTENT 36636
#define IDS_DOM_DISTILLER_WEBUI_ENTRY_URL 36637
#define IDS_DOM_DISTILLER_WEBUI_ENTRY_ADD 36638
#define IDS_DOM_DISTILLER_WEBUI_ENTRY_ADD_FAILED 36639
#define IDS_DOM_DISTILLER_WEBUI_VIEW_URL 36640
#define IDS_DOM_DISTILLER_WEBUI_VIEW_URL_FAILED 36641
#define IDS_DOM_DISTILLER_WEBUI_REFRESH 36642
#define IDS_DOM_DISTILLER_WEBUI_FETCHING_ENTRIES 36643
#define IDS_DOM_DISTILLER_VIEWER_FAILED_TO_FIND_ARTICLE_TITLE 36644
#define IDS_DOM_DISTILLER_VIEWER_FAILED_TO_FIND_ARTICLE_CONTENT 36645
#define IDS_DOM_DISTILLER_VIEWER_LOADING_TITLE 36646
#define IDS_DOM_DISTILLER_VIEWER_CUSTOMIZE_APPEARANCE 36647
#define IDS_DOM_DISTILLER_VIEWER_FONT_STYLE 36648
#define IDS_DOM_DISTILLER_VIEWER_SANS_SERIF_FONT 36649
#define IDS_DOM_DISTILLER_VIEWER_SERIF_FONT 36650
#define IDS_DOM_DISTILLER_VIEWER_MONOSPACE_FONT 36651
#define IDS_DOM_DISTILLER_VIEWER_PAGE_COLOR 36652
#define IDS_DOM_DISTILLER_VIEWER_PAGE_COLOR_LIGHT 36653
#define IDS_DOM_DISTILLER_VIEWER_PAGE_COLOR_SEPIA 36654
#define IDS_DOM_DISTILLER_VIEWER_PAGE_COLOR_DARK 36655
#define IDS_DOM_DISTILLER_VIEWER_FONT_SIZE 36656
#define IDS_DOM_DISTILLER_VIEWER_FONT_SIZE_SMALL 36657
#define IDS_DOM_DISTILLER_VIEWER_FONT_SIZE_LARGE 36658
#define IDS_DOM_DISTILLER_VIEWER_CLOSE 36659
#define IDS_DOM_DISTILLER_VIEWER_NO_DATA_CONTENT 36660
#define IDS_DOM_DISTILLER_WEBUI_TITLE 36661
#define IDS_DOM_DISTILLER_VIEWER_TITLE_SUFFIX 36662
#define IDS_ENTERPRISE_COPY_PREVENTION_MISSING_LIST_ERROR 36663
#define IDS_ENTERPRISE_COPY_PREVENTION_DISABLE_CONTAINS_WILDCARD_ERROR 36664
#define IDS_ENTERPRISE_COPY_PREVENTION_WARNING_MESSAGE 36665
#define IDS_ENTERPRISE_DATA_CONTROLS_COPY_PREVENTION_WARNING_MESSAGE 36666
#define IDS_DATA_CONTROLS_CLIPBOARD_PASTE_BLOCK_TITLE 36667
#define IDS_DATA_CONTROLS_CLIPBOARD_PASTE_WARN_TITLE 36668
#define IDS_DATA_CONTROLS_CLIPBOARD_COPY_BLOCK_TITLE 36669
#define IDS_DATA_CONTROLS_CLIPBOARD_COPY_WARN_TITLE 36670
#define IDS_DATA_CONTROLS_CLIPBOARD_DRAG_BLOCK_TITLE 36671
#define IDS_DATA_CONTROLS_CLIPBOARD_SHARE_WARN_TITLE 36672
#define IDS_DATA_CONTROLS_CLIPBOARD_ACTION_WARN_TITLE 36673
#define IDS_DATA_CONTROLS_BLOCKED_LABEL 36674
#define IDS_DATA_CONTROLS_WARNED_LABEL 36675
#define IDS_DATA_CONTROLS_WARNED_LABEL_WITH_DOMAIN 36676
#define IDS_DATA_CONTROLS_PASTE_WARN_CONTINUE_BUTTON 36677
#define IDS_DATA_CONTROLS_COPY_WARN_CONTINUE_BUTTON 36678
#define IDS_DATA_CONTROLS_SHARE_WARN_CONTINUE_BUTTON 36679
#define IDS_DATA_CONTROLS_PASTE_WARN_CANCEL_BUTTON 36680
#define IDS_DATA_CONTROLS_COPY_WARN_CANCEL_BUTTON 36681
#define IDS_DATA_CONTROLS_SHARE_WARN_CANCEL_BUTTON 36682
#define IDS_DATA_CONTROLS_BLOCKED_LABEL_WITH_DOMAIN 36683
#define IDS_ERRORPAGE_NET_BUTTON_DETAILS 36684
#define IDS_ERRORPAGE_NET_BUTTON_HIDE_DETAILS 36685
#define IDS_ERRORPAGES_BUTTON_RELOAD 36686
#define IDS_ERRORPAGES_BUTTON_SHOW_SAVED_COPY 36687
#define IDS_ERRORPAGE_FUN_DISABLED 36688
#define IDS_ERRORPAGES_SUGGESTION_RELOAD_REPOST_SUMMARY 36693
#define IDS_ERRORPAGES_SUGGESTION_CHECK_CONNECTION_HEADER 36694
#define IDS_ERRORPAGES_SUGGESTION_CHECK_CONNECTION_BODY 36695
#define IDS_ERRORPAGES_SUGGESTION_SECURE_DNS_CONFIG_HEADER 36696
#define IDS_ERRORPAGES_SUGGESTION_SECURE_DNS_CONFIG_BODY 36697
#define IDS_ERRORPAGES_SUGGESTION_DNS_CONFIG_HEADER 36698
#define IDS_ERRORPAGES_SUGGESTION_DNS_CONFIG_BODY 36699
#define IDS_ERRORPAGES_SUGGESTION_NETWORK_PREDICTION_HEADER 36700
#define IDS_ERRORPAGES_SUGGESTION_FIREWALL_CONFIG_BODY 36701
#define IDS_ERRORPAGES_SUGGESTION_PROXY_CONFIG_HEADER 36702
#define IDS_ERRORPAGES_SUGGESTION_PROXY_CONFIG_BODY 36703
#define IDS_ERRORPAGES_SUGGESTION_CAPTIVE_PORTAL_SIGNIN 36704
#define IDS_ERRORPAGES_SUGGESTION_VIEW_POLICIES_HEADER 36706
#define IDS_ERRORPAGES_SUGGESTION_VIEW_POLICIES_BODY 36707
#define IDS_ERRORPAGES_SUGGESTION_UNSUPPORTED_CIPHER_HEADER 36708
#define IDS_ERRORPAGES_SUGGESTION_UNSUPPORTED_CIPHER_BODY 36709
#define IDS_ERRORPAGES_SUGGESTION_NAVIGATE_TO_ORIGIN 36710
#define IDS_ERRORPAGES_HEADING_NOT_AVAILABLE 36711
#define IDS_ERRORPAGES_HEADING_NETWORK_ACCESS_DENIED 36712
#define IDS_ERRORPAGES_HEADING_INTERNET_DISCONNECTED 36713
#define IDS_ERRORPAGES_HEADING_YOU_ARE_OFFLINE 36714
#define IDS_ERRORPAGES_MESSAGE_IWA_INVALID_WEB_BUNDLE 36715
#define IDS_ERRORPAGES_MESSAGE_IWA_CONNECTION_REFUSED 36716
#define IDS_ERRORPAGES_MESSAGE_IWA_INSTALLED_IN_DEV_MODE 36717
#define IDS_ERRORPAGES_MESSAGE_IWA_PAGE_NOT_FOUND 36718
#define IDS_ERRORPAGES_HEADING_CACHE_READ_FAILURE 36719
#define IDS_ERRORPAGES_HEADING_CONNECTION_INTERRUPTED 36720
#define IDS_ERRORPAGES_HEADING_NOT_FOUND 36721
#define IDS_ERRORPAGES_HEADING_FILE_NOT_FOUND 36722
#define IDS_ERRORPAGES_HEADING_BLOCKED 36723
#define IDS_ERRORPAGES_HEADING_BLOCKED_SCHEME 36724
#define IDS_ERRORPAGES_SUMMARY_NOT_AVAILABLE 36725
#define IDS_ERRORPAGES_SUMMARY_TIMED_OUT 36726
#define IDS_ERRORPAGES_SUMMARY_CONNECTION_RESET 36727
#define IDS_ERRORPAGES_SUMMARY_CONNECTION_CLOSED 36728
#define IDS_ERRORPAGES_SUMMARY_CONNECTION_FAILED 36729
#define IDS_ERRORPAGES_SUMMARY_NETWORK_CHANGED 36730
#define IDS_ERRORPAGES_SUMMARY_CONNECTION_REFUSED 36731
#define IDS_ERRORPAGES_SUMMARY_NAME_NOT_RESOLVED 36732
#define IDS_ERRORPAGES_SUMMARY_ICANN_NAME_COLLISION 36733
#define IDS_ERRORPAGES_SUMMARY_ADDRESS_UNREACHABLE 36734
#define IDS_ERRORPAGES_SUMMARY_FILE_ACCESS_DENIED 36735
#define IDS_ERRORPAGES_SUMMARY_NETWORK_ACCESS_DENIED 36736
#define IDS_ERRORPAGES_SUMMARY_PROXY_CONNECTION_FAILED 36737
#define IDS_ERRORPAGES_SUMMARY_CACHE_READ_FAILURE 36738
#define IDS_ERRORPAGES_SUMMARY_NETWORK_IO_SUSPENDED 36739
#define IDS_ERRORPAGES_SUMMARY_NOT_FOUND 36740
#define IDS_ERRORPAGES_SUMMARY_FILE_NOT_FOUND 36741
#define IDS_ERRORPAGES_SUMMARY_TOO_MANY_REDIRECTS 36742
#define IDS_ERRORPAGES_SUMMARY_EMPTY_RESPONSE 36743
#define IDS_ERRORPAGES_SUMMARY_INVALID_RESPONSE 36744
#define IDS_ERRORPAGES_SUMMARY_DNS_PROBE_RUNNING 36745
#define IDS_ERRORPAGES_HEADING_ACCESS_DENIED 36746
#define IDS_ERRORPAGES_HEADING_FILE_ACCESS_DENIED 36747
#define IDS_ERRORPAGES_SUMMARY_FORBIDDEN 36748
#define IDS_ERRORPAGES_SUMMARY_GONE 36749
#define IDS_ERRORPAGES_HEADING_PAGE_NOT_WORKING 36750
#define IDS_ERRORPAGES_SUMMARY_CONTACT_SITE_OWNER 36751
#define IDS_ERRORPAGES_SUMMARY_WEBSITE_CANNOT_HANDLE_REQUEST 36752
#define IDS_ERRORPAGES_SUMMARY_GATEWAY_TIMEOUT 36753
#define IDS_ERRORPAGES_SUMMARY_SSL_SECURITY_ERROR 36754
#define IDS_ERRORPAGES_SUMMARY_SSL_VERSION_OR_CIPHER_MISMATCH 36755
#define IDS_ERRORPAGES_HEADING_INSECURE_CONNECTION 36756
#define IDS_ERRORPAGES_SUMMARY_BAD_SSL_CLIENT_AUTH_CERT 36757
#define IDS_ERRORPAGES_SUMMARY_SSL_CLIENT_AUTH_SIGNATURE_FAILED 36758
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_EXTENSION 36759
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_ADMINISTRATOR 36760
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_SECURITY 36761
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_LOCAL_NETWORK_ACCESS_CHECKS 36762
#define IDS_ERRORPAGES_HTTP_POST_WARNING 36763
#define IDS_ERRORPAGES_HEADING_LINKPREVIEW_NON_HTTPS_FORBIDDEN 36764
#define IDS_ERRORPAGES_SUMMARY_LINKPREVIEW_NON_HTTPS_FORBIDDEN 36765
#define IDS_ERRORPAGES_SUGGESTION_LIST_HEADER 36766
#define IDS_ERRORPAGES_SUGGESTION_CHECK_CONNECTION_SUMMARY 36767
#define IDS_ERRORPAGES_SUGGESTION_CHECK_PROXY_FIREWALL_DNS_SUMMARY 36769
#define IDS_ERRORPAGES_SUGGESTION_CHECK_PROXY_FIREWALL_SECURE_DNS_SUMMARY 36770
#define IDS_ERRORPAGES_SUGGESTION_CHECK_FIREWALL_ANTIVIRUS_SUMMARY 36771
#define IDS_ERRORPAGES_SUGGESTION_CHECK_PROXY_FIREWALL_SUMMARY 36772
#define IDS_ERRORPAGES_SUGGESTION_CHECK_PROXY_ADDRESS_SUMMARY 36773
#define IDS_ERRORPAGES_SUGGESTION_CONTACT_ADMIN_SUMMARY 36774
#define IDS_ERRORPAGES_SUGGESTION_CONTACT_ADMIN_SUMMARY_STANDALONE 36775
#define IDS_ERRORPAGES_SUGGESTION_LEARNMORE_SUMMARY 36776
#define IDS_ERRORPAGES_SUGGESTION_LEARNMORE_SUMMARY_STANDALONE 36777
#define IDS_ERRORPAGES_SUGGESTION_DELETE_COOKIES_SUMMARY 36778
#define IDS_ERRORPAGES_SUGGESTION_CHECK_HARDWARE_SUMMARY 36782
#define IDS_ERRORPAGES_SUGGESTION_CHECK_WIFI_SUMMARY 36783
#define IDS_ERRORPAGES_SUGGESTION_DISABLE_EXTENSION_SUMMARY 36784
#define IDS_ERRORPAGES_CHECK_TYPO_SUMMARY 36785
#define IDS_ERRORPAGES_GAME_INSTRUCTIONS 36789
#define IDS_ERRORPAGE_DINO_GAME_DESCRIPTION 36790
#define IDS_ERRORPAGE_DINO_ARIA_LABEL 36791
#define IDS_ERRORPAGE_DINO_GAME_START 36792
#define IDS_ERRORPAGE_DINO_GAME_OVER 36793
#define IDS_ERRORPAGE_DINO_HIGH_SCORE 36794
#define IDS_ERRORPAGE_DINO_JUMP 36795
#define IDS_ERRORPAGE_DINO_SLOW_SPEED_TOGGLE 36796
#define IDS_ERRORPAGES_GAME_INSTRUCTIONS_TOUCH 36797
#define IDS_ERRORPAGES_GAME_INSTRUCTIONS_KEYBOARD 36798
#define IDS_ERRORPAGES_GAME_INSTRUCTIONS_HYBRID 36799
#define IDS_ERRORPAGE_DINO_ARIA_LABEL_TOUCH 36800
#define IDS_ERRORPAGE_DINO_ARIA_LABEL_KEYBOARD 36801
#define IDS_ERRORPAGE_DINO_ARIA_LABEL_HYBRID 36802
#define IDS_ERRORPAGES_HEADING_BLOCKED_IN_INCOGNITO_BY_ADMINISTRATOR 36803
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_IN_INCOGNITO_BY_ADMINISTRATOR 36804
#define IDS_FIND_IN_PAGE_ACCESSIBLE_TITLE 36805
#define IDS_FIND_IN_PAGE_COUNT 36806
#define IDS_ACCESSIBLE_FIND_IN_PAGE_COUNT 36807
#define IDS_ACCESSIBLE_FIND_IN_PAGE_NO_RESULTS 36808
#define IDS_FIND_IN_PAGE_PREVIOUS_TOOLTIP 36809
#define IDS_FIND_IN_PAGE_NEXT_TOOLTIP 36810
#define IDS_FIND_IN_PAGE_CLOSE_TOOLTIP 36811
#define IDS_FLAGS_UI_SEARCH_PLACEHOLDER 36812
#define IDS_FLAGS_UI_SEARCH_LABEL 36813
#define IDS_FLAGS_UI_TITLE 36814
#define IDS_FLAGS_UI_PAGE_RESET 36815
#define IDS_FLAGS_UI_PAGE_WARNING 36816
#define IDS_FLAGS_UI_PAGE_WARNING_EXPLANATION 36817
#define IDS_FLAGS_UI_OWNER_WARNING 36818
#define IDS_FLAGS_UI_AVAILABLE_FEATURE 36819
#define IDS_FLAGS_UI_UNAVAILABLE_FEATURE 36820
#define IDS_FLAGS_UI_ENABLED_FEATURE 36821
#define IDS_FLAGS_UI_DISABLED_FEATURE 36822
#define IDS_FLAGS_UI_NO_RESULTS 36823
#define IDS_FLAGS_UI_NOT_AVAILABLE_ON_PLATFORM 36824
#define IDS_FLAGS_UI_RELAUNCH 36825
#define IDS_FLAGS_UI_CLEAR_SEARCH 36826
#define IDS_FLAGS_UI_RESET_ACKNOWLEDGED 36827
#define IDS_FLAGS_UI_EXPERIMENT_ENABLED 36828
#define IDS_FLAGS_UI_SEARCH_RESULTS_SINGULAR 36829
#define IDS_FLAGS_UI_SEARCH_RESULTS_PLURAL 36830
#define IDS_DEPRECATED_FEATURES_SEARCH_PLACEHOLDER 36831
#define IDS_DEPRECATED_FEATURES_TITLE 36832
#define IDS_DEPRECATED_FEATURES_HEADING 36833
#define IDS_DEPRECATED_FEATURES_PAGE_WARNING_EXPLANATION 36834
#define IDS_DEPRECATED_FEATURES_NO_RESULTS 36835
#define IDS_EXIT_FULLSCREEN_MODE 36836
#define IDS_FULLSCREEN_HOLD_TO_EXIT_FULLSCREEN 36837
#define IDS_FULLSCREEN_HOLD_TO_EXIT_FULLSCREEN_WITH_ORIGIN 36838
#define IDS_FULLSCREEN_PRESS_TO_EXIT_FULLSCREEN 36839
#define IDS_FULLSCREEN_PRESS_TO_EXIT_FULLSCREEN_WITH_ORIGIN 36840
#define IDS_FULLSCREEN_PRESS_TO_EXIT_FULLSCREEN_TWO_KEYS 36841
#define IDS_PRESS_TO_EXIT_MOUSELOCK 36842
#define IDS_PRESS_TO_EXIT_MOUSELOCK_WITH_ORIGIN 36843
#define IDS_PRESS_TO_EXIT_MOUSELOCK_TWO_KEYS 36844
#define IDS_FULLSCREEN_HOLD_TO_SEE_DOWNLOADS 36845
#define IDS_FULLSCREEN_PRESS_TO_SEE_DOWNLOADS 36846
#define IDS_FULLSCREEN_PRESS_TO_SEE_DOWNLOADS_AND_EXIT 36847
#define IDS_FULLSCREEN_HOLD_TO_SEE_DOWNLOADS_AND_EXIT 36848
#define IDS_FULLSCREEN_TOUCH_BASED_EXIT_FULLSCREEN_WITH_ORIGIN 36849
#define IDS_FULLSCREEN_TOUCH_BASED_EXIT_FULLSCREEN 36850
#define IDS_TOUCH_BASED_EXIT_MOUSELOCK_WITH_ORIGIN 36851
#define IDS_TOUCH_BASED_EXIT_MOUSELOCK 36852
#define IDS_FULLSCREEN_TOUCH_BASED_INSTRUCTIONS_TO_SEE_DOWNLOADS 36853
#define IDS_FULLSCREEN_TOUCH_BASED_INSTRUCTIONS_TO_SEE_DOWNLOADS_AND_EXIT 36854
#define IDS_GLOBAL_MEDIA_CONTROLS_BACK_TO_TAB 36855
#define IDS_GLOBAL_MEDIA_CONTROLS_DISMISS_ICON_TOOLTIP_TEXT 36856
#define IDS_GLOBAL_MEDIA_CONTROLS_CAST_HEADER_TEXT 36857
#define IDS_GLOBAL_MEDIA_CONTROLS_CLOSE_DEVICE_LIST_TEXT 36858
#define IDS_GLOBAL_MEDIA_CONTROLS_UNKNOWN_SOURCE_TEXT 36859
#define IDS_GLOBAL_MEDIA_CONTROLS_UNKNOWN_DEVICE_TEXT 36860
#define IDS_GLOBAL_MEDIA_CONTROLS_MEDIA_LIVE_TEXT 36861
#define IDS_HEAVY_AD_INTERVENTION_BUTTON_DETAILS 36862
#define IDS_HEAVY_AD_INTERVENTION_HEADING 36863
#define IDS_HEAVY_AD_INTERVENTION_SUMMARY 36864
#define IDS_HEAVY_AD_INTERVENTION_BUTTON_RELOAD 36865
#define IDS_HISTORY_CLUSTERS_ACTION_MENU_DESCRIPTION 36866
#define IDS_HISTORY_CLUSTERS_DELETE_PRIOR_VISITS_CONFIRM_BUTTON 36867
#define IDS_HISTORY_CLUSTERS_DELETE_PRIOR_VISITS_WARNING 36868
#define IDS_HISTORY_CLUSTERS_BY_GROUP_TAB_LABEL 36869
#define IDS_HISTORY_CLUSTERS_BY_DATE_TAB_LABEL 36870
#define IDS_HISTORY_CLUSTERS_CLUSTER_LABEL_SEARCH_TERMS 36871
#define IDS_HISTORY_CLUSTERS_CLUSTER_LABEL_MULTIPLE_HOSTNAMES 36872
#define IDS_HISTORY_CLUSTERS_CLUSTER_LABEL_OTHER_MATCHING_VISITS 36873
#define IDS_HISTORY_CLUSTERS_HIDE_PAGE 36874
#define IDS_HISTORY_CLUSTERS_HIDE_VISITS 36875
#define IDS_HISTORY_CLUSTERS_LOAD_MORE_BUTTON_LABEL 36876
#define IDS_HISTORY_CLUSTERS_NO_RESULTS 36877
#define IDS_HISTORY_CLUSTERS_NO_SEARCH_RESULTS 36878
#define IDS_HISTORY_CLUSTERS_SHOW_SIDE_PANEL 36879
#define IDS_HISTORY_CLUSTERS_OPEN_ALL_IN_TABGROUP 36880
#define IDS_HISTORY_CLUSTERS_OPEN_INCOGNITO 36881
#define IDS_HISTORY_CLUSTERS_OPEN_IN_NEW_TAB 36882
#define IDS_HISTORY_CLUSTERS_OPEN_IN_NEW_WINDOW 36883
#define IDS_HISTORY_CLUSTERS_RELATED_SEARCHES_HEADER 36884
#define IDS_HISTORY_CLUSTERS_REMOVE_ALL_ITEMS 36885
#define IDS_HISTORY_CLUSTERS_REMOVE_PAGE 36886
#define IDS_HISTORY_CLUSTERS_REMOVE_ITEM_TOAST 36887
#define IDS_HISTORY_CLUSTERS_REMOVE_SELECTED_ITEMS 36888
#define IDS_HISTORY_CLUSTERS_SAVED_IN_TABGROUP_LABEL 36889
#define IDS_HISTORY_CLUSTERS_CUT 36890
#define IDS_HISTORY_CLUSTERS_COPY 36891
#define IDS_HISTORY_CLUSTERS_PASTE 36892
#define IDS_HISTORY_CLUSTERS_COPY_LINK 36893
#define IDS_HISTORY_CLUSTERS_SHOW_LESS_BUTTON_LABEL 36894
#define IDS_HISTORY_CLUSTERS_SHOW_MORE_BUTTON_LABEL 36895
#define IDS_HISTORY_ACTION_MENU_DESCRIPTION 36896
#define IDS_HISTORY_ACTOR_TASK_TOOLTIP 36897
#define IDS_HISTORY_ARIA_ROLE_DESCRIPTION 36898
#define IDS_HISTORY_CANCEL_EDITING_BUTTON 36899
#define IDS_HISTORY_DATE_WITH_RELATIVE_TIME 36900
#define IDS_HISTORY_DELETE_PRIOR_VISITS_CONFIRM_BUTTON 36901
#define IDS_HISTORY_DELETE_PRIOR_VISITS_WARNING 36902
#define IDS_HISTORY_DELETE_SELECTED_ENTRIES_BUTTON 36903
#define IDS_HISTORY_ENTRY_ACCESSIBILITY_DELETE 36904
#define IDS_HISTORY_ENTRY_ACCESSIBILITY_LABEL 36905
#define IDS_HISTORY_ENTRY_BOOKMARKED 36906
#define IDS_HISTORY_ENTRY_SUMMARY 36907
#define IDS_HISTORY_FOUND_SEARCH_RESULTS 36908
#define IDS_HISTORY_OTHER_FORMS_OF_HISTORY_GMA_ONLY 36909
#define IDS_HISTORY_OTHER_FORMS_OF_HISTORY_GAA_ONLY 36910
#define IDS_HISTORY_OTHER_FORMS_OF_HISTORY_GMA_AND_GAA 36911
#define IDS_HISTORY_LOADING 36912
#define IDS_HISTORY_MORE_FROM_SITE 36913
#define IDS_HISTORY_NO_RESULTS 36914
#define IDS_HISTORY_NO_SEARCH_RESULTS 36915
#define IDS_HISTORY_OPEN_CLEAR_BROWSING_DATA_DIALOG 36916
#define IDS_HISTORY_OTHER_SESSIONS_COLLAPSE_SESSION 36917
#define IDS_HISTORY_OTHER_SESSIONS_EXPAND_SESSION 36918
#define IDS_HISTORY_OTHER_SESSIONS_HIDE_FOR_NOW 36919
#define IDS_HISTORY_OTHER_SESSIONS_OPEN_ALL 36920
#define IDS_HISTORY_REMOVE_BOOKMARK 36921
#define IDS_HISTORY_REMOVE_PAGE 36922
#define IDS_HISTORY_REMOVE_PAGE_SUCCESS 36923
#define IDS_HISTORY_REMOVE_SELECTED_ITEMS 36924
#define IDS_HISTORY_SEARCH_BUTTON 36925
#define IDS_HISTORY_SEARCH_RESULT 36926
#define IDS_HISTORY_SEARCH_RESULTS 36927
#define IDS_HISTORY_SEARCH_EXACT_MATCH_RESULT 36928
#define IDS_HISTORY_SEARCH_EXACT_MATCH_RESULTS 36929
#define IDS_HISTORY_SEARCH_EMBEDDINGS_MATCH_RESULT 36930
#define IDS_HISTORY_SEARCH_EMBEDDINGS_MATCH_RESULTS 36931
#define IDS_HISTORY_SHOW_HISTORY 36932
#define IDS_HISTORY_SHOW_SIDE_PANEL 36933
#define IDS_HISTORY_SHOWFULLHISTORY_LINK 36934
#define IDS_HISTORY_SOURCE_FILTER_CHIP_ACTOR 36935
#define IDS_HISTORY_SOURCE_FILTER_CHIP_USER 36936
#define IDS_HISTORY_CLOSE_AND_RETURN_TO_PREFIX 36937
#define IDS_HISTORY_START_EDITING_BUTTON 36938
#define IDS_HISTORY_TITLE 36939
#define IDS_HISTORY_UNKNOWN_DEVICE 36940
#define IDS_HISTORY_SYNC_PROMO_TITLE 36941
#define IDS_HISTORY_SYNC_PROMO_BODY_SIGNED_OUT 36942
#define IDS_HISTORY_SYNC_PROMO_BODY_SIGN_IN_PENDING 36943
#define IDS_HISTORY_SYNC_PROMO_BODY_SIGN_IN_PENDING_SYNC_HISTORY_ON 36944
#define IDS_HISTORY_SYNC_PROMO_BODY_SIGNED_IN 36945
#define IDS_HISTORY_EMBEDDINGS_DISCLAIMER 36946
#define IDS_HISTORY_EMBEDDINGS_DISCLAIMER_LOGGING_OFF 36947
#define IDS_HISTORY_EMBEDDINGS_PROMO_LABEL 36948
#define IDS_HISTORY_EMBEDDINGS_PROMO_CLOSE 36949
#define IDS_HISTORY_EMBEDDINGS_PROMO_HEADING 36950
#define IDS_HISTORY_EMBEDDINGS_PROMO_BODY 36951
#define IDS_HISTORY_EMBEDDINGS_ANSWERS_PROMO_HEADING 36952
#define IDS_HISTORY_EMBEDDINGS_ANSWERS_PROMO_BODY 36953
#define IDS_HISTORY_EMBEDDIGNS_PROMO_SETTINGS_LINK_TEXT 36954
#define IDS_HISTORY_EMBEDDINGS_SHOW_BY_ARIA_LABEL 36955
#define IDS_HISTORY_EMBEDDINGS_SHOW_BY_DATE 36956
#define IDS_HISTORY_EMBEDDINGS_SHOW_BY_GROUP 36957
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_1 36958
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_2 36959
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_3 36960
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_1_ARIA_LABEL 36961
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_2_ARIA_LABEL 36962
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_3_ARIA_LABEL 36963
#define IDS_HISTORY_EMBEDDINGS_HEADING 36964
#define IDS_HISTORY_EMBEDDINGS_HEADING_LOADING 36965
#define IDS_HISTORY_EMBEDDINGS_WITH_ANSWERS_RESULTS_HEADING 36966
#define IDS_HISTORY_EMBEDDINGS_FOOTER 36967
#define IDS_HISTORY_EMBEDDINGS_FEEDBACK_PLACEHOLDER 36968
#define IDS_HISTORY_EMBEDDINGS_IPH_BODY 36969
#define IDS_HISTORY_EMBEDDINGS_IPH_ACTION 36970
#define IDS_HISTORY_EMBEDDINGS_SEARCH_PROMPT 36971
#define IDS_HISTORY_EMBEDDINGS_SEARCH_ANSWERS_ALTERNATIVE_PROMPT_1 36972
#define IDS_HISTORY_EMBEDDINGS_SEARCH_ANSWERS_ALTERNATIVE_PROMPT_2 36973
#define IDS_HISTORY_EMBEDDINGS_SEARCH_ANSWERS_ALTERNATIVE_PROMPT_3 36974
#define IDS_HISTORY_EMBEDDINGS_SEARCH_ANSWERS_ALTERNATIVE_PROMPT_4 36975
#define IDS_HISTORY_EMBEDDINGS_ANSWER_HEADING 36976
#define IDS_HISTORY_EMBEDDINGS_ANSWER_LOADING_HEADING 36977
#define IDS_HISTORY_EMBEDDINGS_ANSWER_SOURCE_VISIT_DATE_LABEL 36978
#define IDS_HISTORY_EMBEDDINGS_ANSWERER_ERROR_UNANSWERABLE 36979
#define IDS_HISTORY_EMBEDDINGS_ANSWERER_ERROR_MODEL_UNAVAILABLE 36980
#define IDS_HISTORY_EMBEDDINGS_ANSWERER_ERROR_TRY_AGAIN 36981
#define IDS_COMPARE_HISTORY_EMPTY 36982
#define IDS_COMPARE_HISTORY_HEADER 36983
#define IDS_COMPARE_HISTORY_INFO 36984
#define IDS_COMPARE_HISTORY_MENU_ARIA_LABEL 36985
#define IDS_COMPARE_HISTORY_MENU_ITEM 36986
#define IDS_COMPARE_HISTORY_REMOVE 36987
#define IDS_COMPARE_HISTORY_ROW 36988
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE 36989
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE_IFRAME 36990
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE_NONSTANDARD_URL 36991
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE_NONSTANDARD_URL_IFRAME 36992
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE_EXTENSION 36993
#define IDS_JAVASCRIPT_MESSAGEBOX_SUPPRESS_OPTION 36994
#define IDS_BEFOREUNLOAD_MESSAGEBOX_TITLE 36995
#define IDS_BEFOREUNLOAD_APP_MESSAGEBOX_TITLE 36996
#define IDS_BEFOREUNLOAD_MESSAGEBOX_OK_BUTTON_LABEL 36997
#define IDS_BEFOREUNLOAD_MESSAGEBOX_MESSAGE 36998
#define IDS_BEFORERELOAD_MESSAGEBOX_TITLE 36999
#define IDS_BEFORERELOAD_APP_MESSAGEBOX_TITLE 37000
#define IDS_BEFORERELOAD_MESSAGEBOX_OK_BUTTON_LABEL 37001
#define IDS_LIVE_CAPTION_BUBBLE_TITLE 37002
#define IDS_LIVE_CAPTION_BUBBLE_CLOSE 37003
#define IDS_LIVE_CAPTION_BUBBLE_EXPAND 37004
#define IDS_LIVE_CAPTION_BUBBLE_COLLAPSE 37005
#define IDS_LIVE_CAPTION_BUBBLE_BACK_TO_TAB 37006
#define IDS_LIVE_CAPTION_BUBBLE_PIN 37007
#define IDS_LIVE_CAPTION_BUBBLE_UNPIN 37008
#define IDS_LIVE_CAPTION_BUBBLE_ERROR 37009
#define IDS_LIVE_CAPTION_BUBBLE_CONTENT_SETTINGS 37010
#define IDS_LIVE_CAPTION_BUBBLE_MEDIA_FOUNDATION_RENDERER_ERROR 37011
#define IDS_LIVE_CAPTION_BUBBLE_MEDIA_FOUNDATION_RENDERER_ERROR_CHECKBOX 37012
#define IDS_LIVE_CAPTION_BUBBLE_APPEAR_SCREENREADER_ANNOUNCEMENT 37013
#define IDS_LIVE_CAPTION_CAPTION_LANGUAGE_AUTODETECTED 37014
#define IDS_LIVE_CAPTION_TRANSLATED_CAPTION_LANGUAGE 37015
#define IDS_LIVE_CAPTION_TRANSLATED_CAPTION_LANGUAGE_AUTODETECTED 37016
#define IDS_LIVE_CAPTION_BUBBLE_CAPTION_SETTINGS 37017
#define IDS_LIVE_CAPTION_BUBBLE_SCROLL_BUTTON_SCROLLING 37018
#define IDS_LIVE_CAPTION_BUBBLE_SCROLL_BUTTON_LOCKED 37019
#define IDS_LIVE_CAPTION_DOWNLOAD_PROGRESS 37020
#define IDS_LIVE_CAPTION_LANGUAGE_DOWNLOAD_FAILED 37021
#define IDS_LIVE_CAPTION_TRANSLATING 37022
#define IDS_LOGIN_DIALOG_TITLE 37023
#define IDS_LOGIN_DIALOG_OK_BUTTON_LABEL 37024
#define IDS_LOGIN_DIALOG_AUTHORITY 37025
#define IDS_LOGIN_DIALOG_PROXY_AUTHORITY 37026
#define IDS_LOGIN_DIALOG_NOT_PRIVATE 37027
#define IDS_LOGIN_DIALOG_USERNAME_FIELD 37028
#define IDS_LOGIN_DIALOG_PASSWORD_FIELD 37029
#define IDS_MANAGEMENT_TITLE 37030
#define IDS_MANAGEMENT_TOOLBAR_TITLE 37031
#define IDS_MANAGEMENT_SUBTITLE_MANAGED_BY 37033
#define IDS_MANAGEMENT_NOT_MANAGED_SUBTITLE 37034
#define IDS_MANAGEMENT_SUBTITLE 37035
#define IDS_MANAGEMENT_SUBTITLE_BROWSER_AND_PROFILE_DIFFERENT_MANAGED_BY 37036
#define IDS_MANAGEMENT_SUBTITLE_BROWSER_MANAGED_AND_PROFILE_MANAGED_BY 37037
#define IDS_MANAGEMENT_SUBTITLE_BROWSER_AND_PROFILE_SAME_MANAGED_BY 37038
#define IDS_MANAGEMENT_SUBTITLE_PROFILE_MANAGED_BY 37039
#define IDS_MANAGEMENT_BROWSER_NOTICE 37040
#define IDS_MANAGEMENT_NOT_MANAGED_NOTICE 37041
#define IDS_MANAGEMENT_PROFILE_NOTICE 37042
#define IDS_MANAGEMENT_LEARN_MORE_ACCCESSIBILITY_TEXT 37043
#define IDS_MANAGEMENT_EXTENSION_REPORTING 37099
#define IDS_MANAGEMENT_EXTENSIONS_INSTALLED 37100
#define IDS_MANAGEMENT_EXTENSIONS_INSTALLED_BY 37101
#define IDS_MANAGEMENT_EXTENSIONS_NAME 37102
#define IDS_MANAGEMENT_EXTENSIONS_PERMISSIONS 37103
#define IDS_MANAGEMENT_APPLICATION_REPORTING 37104
#define IDS_MANAGEMENT_APPLICATIONS_INSTALLED 37105
#define IDS_MANAGEMENT_APPLICATIONS_INSTALLED_BY 37106
#define IDS_MANAGEMENT_APPLICATIONS_NAME 37107
#define IDS_MANAGEMENT_APPLICATIONS_PERMISSIONS 37108
#define IDS_MANAGEMENT_APPLICATIONS_RUN_ON_OS_LOGIN 37109
#define IDS_MANAGEMENT_MANAGED_WEBSITES 37110
#define IDS_MANAGEMENT_MANAGED_WEBSITES_EXPLANATION 37111
#define IDS_MANAGEMENT_MANAGED_WEBSITES_BY_EXPLANATION 37112
#define IDS_MANAGEMENT_BROWSER_REPORTING_EXPLANATION 37113
#define IDS_MANAGEMENT_EXTENSION_REPORT_MACHINE_NAME 37114
#define IDS_MANAGEMENT_EXTENSION_REPORT_MACHINE_NAME_ADDRESS 37115
#define IDS_MANAGEMENT_EXTENSION_REPORT_USERNAME 37116
#define IDS_MANAGEMENT_EXTENSION_REPORT_VERSION 37117
#define IDS_MANAGEMENT_EXTENSION_REPORT_EXTENSIONS_PLUGINS 37118
#define IDS_MANAGEMENT_EXTENSION_REPORT_USER_BROWSING_DATA 37119
#define IDS_MANAGEMENT_EXTENSION_REPORT_PERF_CRASH 37120
#define IDS_MANAGEMENT_EXTENSION_REPORT_VISITED_URL 37121
#define IDS_MANAGEMENT_LEGACY_TECH_REPORT 37122
#define IDS_MANAGEMENT_LEGACY_TECH_REPORT_NO_LINK 37123
#define IDS_MANAGEMENT_THREAT_PROTECTION_MORE 37124
#define IDS_MANAGEMENT_FILE_ATTACHED_EVENT 37125
#define IDS_MANAGEMENT_FILE_DOWNLOADED_EVENT 37126
#define IDS_MANAGEMENT_TEXT_ENTERED_EVENT 37127
#define IDS_MANAGEMENT_PAGE_PRINTED_EVENT 37128
#define IDS_MANAGEMENT_FILE_TRANSFER_EVENT 37129
#define IDS_MANAGEMENT_SCREEN_CAPTURE_EVENT 37130
#define IDS_MANAGEMENT_EXTENSION_TELEMETRY_EVENT 37131
#define IDS_MANAGEMENT_FILE_ATTACHED_VISIBLE_DATA 37132
#define IDS_MANAGEMENT_FILE_DOWNLOADED_VISIBLE_DATA 37133
#define IDS_MANAGEMENT_TEXT_ENTERED_VISIBLE_DATA 37134
#define IDS_MANAGEMENT_PAGE_PRINTED_VISIBLE_DATA 37135
#define IDS_MANAGEMENT_FILE_TRANSFER_VISIBLE_DATA 37136
#define IDS_MANAGEMENT_SCREEN_CAPTURE_DATA 37137
#define IDS_MANAGEMENT_EXTENSION_TELEMETRY_VISIBLE_DATA 37138
#define IDS_MANAGEMENT_BROWSER_REPORTING 37139
#define IDS_MANAGEMENT_PROFILE_REPORTING_EXPLANATION 37147
#define IDS_MANAGEMENT_PROFILE_REPORTING_OVERVIEW 37148
#define IDS_MANAGEMENT_PROFILE_REPORTING_USERNAME 37149
#define IDS_MANAGEMENT_PROFILE_REPORTING_BROWSER 37150
#define IDS_MANAGEMENT_PROFILE_REPORTING_POLICY 37151
#define IDS_MANAGEMENT_PROFILE_REPORTING_LEARN_MORE 37152
#define IDS_MANAGEMENT_PROFILE_REPORTING_EXTENSION 37153
#define IDS_MANAGEMENT_DEVICE_SIGNALS_DISCLOSURE 37158
#define IDS_MANAGEMENT_THREAT_PROTECTION 37159
#define IDS_MANAGEMENT_THREAT_PROTECTION_DESCRIPTION 37160
#define IDS_MANAGEMENT_THREAT_PROTECTION_DESCRIPTION_BY 37161
#define IDS_MANAGEMENT_CONNECTORS_EVENT 37162
#define IDS_MANAGEMENT_CONNECTORS_VISIBLE_DATA 37163
#define IDS_MANAGEMENT_ENTERPRISE_REPORTING_EVENT 37164
#define IDS_MANAGEMENT_PAGE_VISITED_EVENT 37165
#define IDS_MANAGEMENT_PAGE_VISITED_VISIBLE_DATA 37166
#define IDS_MANAGEMENT_ENTERPRISE_REPORTING_VISIBLE_DATA 37167
#define IDS_MANAGEMENT_DIALOG_BROWSING_DATA_MANAGEMENT 37168
#define IDS_MANAGEMENT_DIALOG_DEVICE_SIGNALS 37169
#define IDS_MANAGEMENT_DIALOG_PROFILE_MANAGED_BY 37170
#define IDS_MANAGEMENT_DIALOG_THINGS_TO_CONSIDER_SUBTITLE 37171
#define IDS_MANAGED_PROFILE_INTERSTITIAL_TAB_TITLE 37172
#define IDS_MANAGEMENT_BANNER_PROMOTION_TITLE 37173
#define IDS_MANAGEMENT_BANNER_PROMOTION_DESC 37174
#define IDS_MANAGEMENT_BANNER_PROMOTION_BTN 37175
#define IDS_MANAGEMENT_BANNER_ARIA_LABEL 37176
#define IDS_MANAGEMENT_BANNER_NEW_TAB_ARIA_DESCRIPTION 37177
#define IDS_MANAGEMENT_BANNER_DISMISS_ARIA_LABEL 37178
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_PREVIOUS_TRACK 37179
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_SEEK_BACKWARD 37180
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_REPLAY_10 37181
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_PLAY 37182
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_PAUSE 37183
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_FORWARD_10 37184
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_SEEK_FORWARD 37185
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_NEXT_TRACK 37186
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_ENTER_PIP 37187
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_EXIT_PIP 37188
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_MUTE 37189
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_UNMUTE 37190
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_SHOW_DEVICE_LIST 37191
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_HIDE_DEVICE_LIST 37192
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_STOP_CASTING 37193
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_TIME_SCRUBBER 37194
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACCESSIBLE_NAME 37195
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_LABEL 37196
#define IDS_DEFAULT_TAB_TITLE 37197
#define IDS_DOWNLOAD_TAB_TITLE 37198
#define IDS_SAD_TAB_TITLE 37199
#define IDS_SAD_TAB_MESSAGE 37200
#define IDS_SAD_TAB_HELP_MESSAGE 37201
#define IDS_SAD_TAB_HELP_LINK 37202
#define IDS_SAD_TAB_RELOAD_LABEL 37203
#define IDS_SAD_TAB_RELOAD_TITLE 37206
#define IDS_SAD_TAB_OOM_MESSAGE_TABS 37207
#define IDS_SAD_TAB_OOM_MESSAGE_NOTABS 37208
#define IDS_SAD_TAB_RELOAD_TRY 37209
#define IDS_SAD_TAB_RELOAD_INCOGNITO 37210
#define IDS_SAD_TAB_RELOAD_CLOSE_TABS 37211
#define IDS_SAD_TAB_RELOAD_CLOSE_NOTABS 37212
#define IDS_SAD_TAB_RELOAD_RESTART_BROWSER 37213
#define IDS_SAD_TAB_RELOAD_RESTART_DEVICE 37214
#define IDS_SAD_TAB_ERROR_CODE 37216
#define IDS_NEW_TAB_TITLE 37217
#define IDS_NEW_INCOGNITO_TAB_TITLE 37218
#define IDS_INCOGNITO_TAB_LEARN_MORE_ACCESSIBILITY_LABEL 37219
#define IDS_NEW_TAB_OTR_HEADING 37220
#define IDS_NEW_TAB_OTR_DESCRIPTION 37221
#define IDS_NEW_TAB_OTR_LEARN_MORE_LINK 37222
#define IDS_NEW_TAB_OTR_MESSAGE_WARNING 37223
#define IDS_NEW_TAB_UNDO_THUMBNAIL_REMOVE 37224
#define IDS_NEW_TAB_OTR_TITLE 37225
#define IDS_NEW_TAB_OTR_SUBTITLE 37226
#define IDS_NEW_TAB_OTR_SUBTITLE_WITH_READING_LIST 37227
#define IDS_NEW_TAB_OTR_NOT_SAVED 37228
#define IDS_NEW_TAB_OTR_VISIBLE 37229
#define IDS_NEW_TAB_OPENS_HC_ARTICLE_IN_NEW_TAB 37230
#define IDS_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA_HINT 37231
#define IDS_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA_SUGGESTION_CONTENTS 37232
#define IDS_ACC_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA_SUFFIX 37233
#define IDS_ACC_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA 37234
#define IDS_OMNIBOX_PEDAL_MANAGE_PASSWORDS_HINT 37235
#define IDS_OMNIBOX_PEDAL_MANAGE_PASSWORDS_SUGGESTION_CONTENTS 37236
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_PASSWORDS_SUFFIX 37237
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_PASSWORDS 37238
#define IDS_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD_HINT 37239
#define IDS_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD_SUGGESTION_CONTENTS 37240
#define IDS_ACC_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD_SUFFIX 37241
#define IDS_ACC_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD 37242
#define IDS_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_HINT 37243
#define IDS_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUGGESTION_CONTENTS 37244
#define IDS_ACC_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUFFIX 37245
#define IDS_ACC_OMNIBOX_PEDAL_LAUNCH_INCOGNITO 37246
#define IDS_OMNIBOX_PEDAL_TRANSLATE_HINT 37247
#define IDS_OMNIBOX_PEDAL_TRANSLATE_SUGGESTION_CONTENTS 37248
#define IDS_ACC_OMNIBOX_PEDAL_TRANSLATE_SUFFIX 37249
#define IDS_ACC_OMNIBOX_PEDAL_TRANSLATE 37250
#define IDS_OMNIBOX_PEDAL_UPDATE_CHROME_HINT 37251
#define IDS_OMNIBOX_PEDAL_UPDATE_CHROME_SUGGESTION_CONTENTS 37252
#define IDS_ACC_OMNIBOX_PEDAL_UPDATE_CHROME_SUFFIX 37253
#define IDS_ACC_OMNIBOX_PEDAL_UPDATE_CHROME 37254
#define IDS_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_SUGGESTION_CONTENTS 37255
#define IDS_ACC_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_SUFFIX 37256
#define IDS_ACC_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK 37257
#define IDS_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_V2_HINT 37258
#define IDS_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_V2_SUGGESTION_CONTENTS 37259
#define IDS_ACC_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_V2_SUFFIX 37260
#define IDS_ACC_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_V2 37261
#define IDS_OMNIBOX_PEDAL_MANAGE_SECURITY_SETTINGS_HINT 37262
#define IDS_OMNIBOX_PEDAL_MANAGE_SECURITY_SETTINGS_SUGGESTION_CONTENTS 37263
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SECURITY_SETTINGS_SUFFIX 37264
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SECURITY_SETTINGS 37265
#define IDS_OMNIBOX_PEDAL_MANAGE_COOKIES_HINT 37266
#define IDS_OMNIBOX_PEDAL_MANAGE_COOKIES_SUGGESTION_CONTENTS 37267
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_COOKIES_SUFFIX 37268
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_COOKIES 37269
#define IDS_OMNIBOX_PEDAL_MANAGE_ADDRESSES_HINT 37270
#define IDS_OMNIBOX_PEDAL_MANAGE_ADDRESSES_SUGGESTION_CONTENTS 37271
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_ADDRESSES_SUFFIX 37272
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_ADDRESSES 37273
#define IDS_OMNIBOX_PEDAL_MANAGE_SYNC_HINT 37274
#define IDS_OMNIBOX_PEDAL_MANAGE_SYNC_SUGGESTION_CONTENTS 37275
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SYNC_SUFFIX 37276
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SYNC 37277
#define IDS_OMNIBOX_PEDAL_MANAGE_SYNC_HINT_UPDATED 37278
#define IDS_OMNIBOX_PEDAL_MANAGE_SYNC_SUGGESTION_CONTENTS_UPDATED 37279
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SYNC_SUFFIX_UPDATED 37280
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SYNC_UPDATED 37281
#define IDS_OMNIBOX_PEDAL_MANAGE_SITE_SETTINGS_HINT 37282
#define IDS_OMNIBOX_PEDAL_MANAGE_SITE_SETTINGS_SUGGESTION_CONTENTS 37283
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SITE_SETTINGS_SUFFIX 37284
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SITE_SETTINGS 37285
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_DOC_HINT 37286
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_DOC_SUGGESTION_CONTENTS 37287
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_DOC_SUFFIX 37288
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_DOC 37289
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SHEET_HINT 37290
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SHEET_SUGGESTION_CONTENTS 37291
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SHEET_SUFFIX 37292
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SHEET 37293
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SLIDE_HINT 37294
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SLIDE_SUGGESTION_CONTENTS 37295
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SLIDE_SUFFIX 37296
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SLIDE 37297
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_CALENDAR_EVENT_HINT 37298
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_CALENDAR_EVENT_SUGGESTION_CONTENTS 37299
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_CALENDAR_EVENT_SUFFIX 37300
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_CALENDAR_EVENT 37301
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SITE_HINT 37302
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SITE_SUGGESTION_CONTENTS 37303
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SITE_SUFFIX 37304
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SITE 37305
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_KEEP_NOTE_HINT 37306
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_KEEP_NOTE_SUGGESTION_CONTENTS 37307
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_KEEP_NOTE_SUFFIX 37308
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_KEEP_NOTE 37309
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_FORM_HINT 37310
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_FORM_SUGGESTION_CONTENTS 37311
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_FORM_SUFFIX 37312
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_FORM 37313
#define IDS_OMNIBOX_PEDAL_SEE_CHROME_TIPS_HINT 37314
#define IDS_OMNIBOX_PEDAL_SEE_CHROME_TIPS_SUGGESTION_CONTENTS 37315
#define IDS_ACC_OMNIBOX_PEDAL_SEE_CHROME_TIPS_SUFFIX 37316
#define IDS_ACC_OMNIBOX_PEDAL_SEE_CHROME_TIPS 37317
#define IDS_OMNIBOX_PEDAL_MANAGE_GOOGLE_ACCOUNT_HINT 37318
#define IDS_OMNIBOX_PEDAL_MANAGE_GOOGLE_ACCOUNT_SUGGESTION_CONTENTS 37319
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_GOOGLE_ACCOUNT_SUFFIX 37320
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_GOOGLE_ACCOUNT 37321
#define IDS_OMNIBOX_PEDAL_CHANGE_GOOGLE_PASSWORD_HINT 37322
#define IDS_OMNIBOX_PEDAL_CHANGE_GOOGLE_PASSWORD_SUGGESTION_CONTENTS 37323
#define IDS_ACC_OMNIBOX_PEDAL_CHANGE_GOOGLE_PASSWORD_SUFFIX 37324
#define IDS_ACC_OMNIBOX_PEDAL_CHANGE_GOOGLE_PASSWORD 37325
#define IDS_OMNIBOX_PEDAL_CLOSE_INCOGNITO_WINDOWS_HINT 37326
#define IDS_OMNIBOX_PEDAL_CLOSE_INCOGNITO_WINDOWS_SUGGESTION_CONTENTS 37327
#define IDS_ACC_OMNIBOX_PEDAL_CLOSE_INCOGNITO_WINDOWS_SUFFIX 37328
#define IDS_ACC_OMNIBOX_PEDAL_CLOSE_INCOGNITO_WINDOWS 37329
#define IDS_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME_HINT 37330
#define IDS_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME_SUGGESTION_CONTENTS 37331
#define IDS_ACC_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME_SUFFIX 37332
#define IDS_ACC_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME 37333
#define IDS_OMNIBOX_PEDAL_FIND_MY_PHONE_HINT 37334
#define IDS_OMNIBOX_PEDAL_FIND_MY_PHONE_SUGGESTION_CONTENTS 37335
#define IDS_ACC_OMNIBOX_PEDAL_FIND_MY_PHONE_SUFFIX 37336
#define IDS_ACC_OMNIBOX_PEDAL_FIND_MY_PHONE 37337
#define IDS_OMNIBOX_PEDAL_MANAGE_GOOGLE_PRIVACY_HINT 37338
#define IDS_OMNIBOX_PEDAL_MANAGE_GOOGLE_PRIVACY_SUGGESTION_CONTENTS 37339
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_GOOGLE_PRIVACY_SUFFIX 37340
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_GOOGLE_PRIVACY 37341
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS_HINT 37342
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS_SUGGESTION_CONTENTS 37343
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS_SUFFIX 37344
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS 37345
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_DOWNLOADS_HINT 37346
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_DOWNLOADS_SUGGESTION_CONTENTS 37347
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_DOWNLOADS_SUFFIX 37348
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_DOWNLOADS 37349
#define IDS_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY_HINT 37350
#define IDS_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY_SUGGESTION_CONTENTS 37351
#define IDS_ACC_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY_SUFFIX 37352
#define IDS_ACC_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY 37353
#define IDS_OMNIBOX_PEDAL_SHARE_THIS_PAGE_HINT 37354
#define IDS_OMNIBOX_PEDAL_SHARE_THIS_PAGE_SUGGESTION_CONTENTS 37355
#define IDS_ACC_OMNIBOX_PEDAL_SHARE_THIS_PAGE_SUFFIX 37356
#define IDS_ACC_OMNIBOX_PEDAL_SHARE_THIS_PAGE 37357
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_ACCESSIBILITY_HINT 37358
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_ACCESSIBILITY_SUGGESTION_CONTENTS 37359
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_ACCESSIBILITY_SUFFIX 37360
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_ACCESSIBILITY 37361
#define IDS_OMNIBOX_PEDAL_CUSTOMIZE_CHROME_FONTS_HINT 37362
#define IDS_OMNIBOX_PEDAL_CUSTOMIZE_CHROME_FONTS_SUGGESTION_CONTENTS 37363
#define IDS_ACC_OMNIBOX_PEDAL_CUSTOMIZE_CHROME_FONTS_SUFFIX 37364
#define IDS_ACC_OMNIBOX_PEDAL_CUSTOMIZE_CHROME_FONTS 37365
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_THEMES_HINT 37366
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_THEMES_SUGGESTION_CONTENTS 37367
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_THEMES_SUFFIX 37368
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_THEMES 37369
#define IDS_OMNIBOX_PEDAL_CUSTOMIZE_SEARCH_ENGINES_HINT 37370
#define IDS_OMNIBOX_PEDAL_CUSTOMIZE_SEARCH_ENGINES_SUGGESTION_CONTENTS 37371
#define IDS_ACC_OMNIBOX_PEDAL_CUSTOMIZE_SEARCH_ENGINES_SUFFIX 37372
#define IDS_ACC_OMNIBOX_PEDAL_CUSTOMIZE_SEARCH_ENGINES 37373
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROMEOS_ACCESSIBILITY_HINT 37374
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROMEOS_ACCESSIBILITY_SUGGESTION_CONTENTS 37375
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROMEOS_ACCESSIBILITY_SUFFIX 37376
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROMEOS_ACCESSIBILITY 37377
#define IDS_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_HINT 37378
#define IDS_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_SUGGESTION_CONTENTS 37379
#define IDS_ACC_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_SUFFIX 37380
#define IDS_ACC_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER 37381
#define IDS_ANDROID_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_HINT 37382
#define IDS_ANDROID_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_HINT 37383
#define IDS_ANDROID_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUGGESTION_CONTENTS 37384
#define IDS_ANDROID_ACC_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUFFIX 37385
#define IDS_ANDROID_ACC_OMNIBOX_PEDAL_LAUNCH_INCOGNITO 37386
#define IDS_IOS_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA_HINT 37387
#define IDS_IOS_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_HINT 37388
#define IDS_IOS_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_SUGGESTION_CONTENTS 37389
#define IDS_IOS_ACC_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_SUFFIX 37390
#define IDS_IOS_ACC_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER 37391
#define IDS_IOS_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD_HINT 37392
#define IDS_IOS_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_HINT 37393
#define IDS_IOS_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_HINT 37394
#define IDS_IOS_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS_HINT 37395
#define IDS_IOS_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY_HINT 37396
#define IDS_IOS_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME_HINT 37397
#define IDS_IOS_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUGGESTION_CONTENTS 37398
#define IDS_IOS_OMNIBOX_PEDAL_MANAGE_PASSWORDS_HINT 37399
#define IDS_AUTOCOMPLETE_SEARCH_DESCRIPTION 37400
#define IDS_AUTOCOMPLETE_ASK_DESCRIPTION 37401
#define IDS_AUTOCOMPLETE_SEARCH_IN_SIDE_PANEL_DESCRIPTION 37402
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_LABEL 37403
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_LABEL_ALT 37404
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_LABEL_ALT2 37405
#define IDS_OMNIBOX_TOOLBELT_LABEL 37406
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_HINT 37407
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_SUGGESTION_CONTENTS 37408
#define IDS_ACC_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_SUFFIX 37409
#define IDS_ACC_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION 37410
#define IDS_STARTER_PACK_BOOKMARKS_ACTION_HINT 37411
#define IDS_STARTER_PACK_BOOKMARKS_ACTION_SUGGESTION_CONTENTS 37412
#define IDS_ACC_STARTER_PACK_BOOKMARKS_ACTION_SUFFIX 37413
#define IDS_ACC_STARTER_PACK_BOOKMARKS_ACTION 37414
#define IDS_STARTER_PACK_HISTORY_ACTION_HINT 37415
#define IDS_STARTER_PACK_HISTORY_ACTION_SUGGESTION_CONTENTS 37416
#define IDS_ACC_STARTER_PACK_HISTORY_ACTION_SUFFIX 37417
#define IDS_ACC_STARTER_PACK_HISTORY_ACTION 37418
#define IDS_STARTER_PACK_TABS_ACTION_HINT 37419
#define IDS_STARTER_PACK_TABS_ACTION_SUGGESTION_CONTENTS 37420
#define IDS_ACC_STARTER_PACK_TABS_ACTION_SUFFIX 37421
#define IDS_ACC_STARTER_PACK_TABS_ACTION 37422
#define IDS_STARTER_PACK_AI_MODE_ACTION_HINT 37423
#define IDS_STARTER_PACK_AI_MODE_ACTION_SUGGESTION_CONTENTS 37424
#define IDS_ACC_STARTER_PACK_AI_MODE_ACTION_SUFFIX 37425
#define IDS_ACC_STARTER_PACK_AI_MODE_ACTION 37426
#define IDS_EMPTY_KEYWORD_VALUE 37427
#define IDS_EMPTY_STARTER_PACK_AI_MODE_VALUE 37428
#define IDS_LINK_FROM_CLIPBOARD 37429
#define IDS_TEXT_FROM_CLIPBOARD 37430
#define IDS_IMAGE_FROM_CLIPBOARD 37431
#define IDS_SECURE_CONNECTION_EV 37432
#define IDS_SECURE_VERBOSE_STATE 37433
#define IDS_NOT_SECURE_VERBOSE_STATE 37434
#define IDS_DANGEROUS_VERBOSE_STATE 37435
#define IDS_OFFLINE_VERBOSE_STATE 37436
#define IDS_OMNIBOX_EMPTY_HINT 37437
#define IDS_OMNIBOX_EMPTY_HINT_WITH_DSE_NAME 37438
#define IDS_OMNIBOX_EMPTY_HINT_WITH_DSE_NAME_FOR_AI_MODE 37439
#define IDS_OMNIBOX_NAVATTACH_GALLERY 37440
#define IDS_OMNIBOX_NAVATTACH_FILES 37441
#define IDS_OMNIBOX_NAVATTACH_TABS 37442
#define IDS_FUSEBOX_ADD_CURRENT_TAB 37443
#define IDS_FUSEBOX_UPLOAD_FAILED 37444
#define IDS_OMNIBOX_CREATE_IMAGE 37445
#define IDS_OMNIBOX_EMPTY_HINT_FOR_IMAGE_GENERATION 37446
#define IDS_FUSEBOX_TOOLS_HEADER 37447
#define IDS_FUSEBOX_MODELS_HEADER 37448
#define IDS_FUSEBOX_MODEL_PRO 37449
#define IDS_OMNIBOX_ADDITIONAL_TEXT_DASH_TEMPLATE 37451
#define IDS_OMNIBOX_TAB_SUGGEST_HINT 37452
#define IDS_OMNIBOX_HISTORY_EMBEDDING_HINT 37453
#define IDS_OMNIBOX_FILE 37454
#define IDS_OMNIBOX_READER_MODE 37455
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_BUGANIZER 37456
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_COMMA_SEPARATED_VALUES 37457
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_APPS_SCRIPT 37458
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_DOCS 37459
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_DRAWINGS 37460
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_DRIVE 37461
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_DRIVE_FOLDER 37462
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_FORMS 37463
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_JAMBOARD 37464
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_PHOTOS 37465
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_SITES 37466
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_SHEETS 37467
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_SLIDES 37468
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_IMAGE_JPEG 37469
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_IMAGE_PNG 37470
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_IMAGE_SVG 37471
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_JIRA 37472
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_JSON 37473
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_MARKDOWN 37474
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_MS_EXCEL 37475
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_MS_POWERPOINT 37476
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_MS_WORD 37477
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_OPEN_DOCUMENT_PRESENTATION 37478
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_OPEN_DOCUMENT_SPREADSHEET 37479
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_OPEN_DOCUMENT_TEXT 37480
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_PDF 37481
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_PLAIN_TEXT 37482
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_RICH_TEXT_FORMAT 37483
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_SALESFORCE 37484
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_SLACK 37485
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_VIDEO_MP4 37486
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_VIDEO_QUICKTIME 37487
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_VIDEO_WEBM 37488
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_ZIP_FILE 37489
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_TEMPLATE 37490
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_TEMPLATE_WITHOUT_DATE 37491
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_TEMPLATE_WITHOUT_OWNER 37492
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_TEMPLATE_WITHOUT_FILE_TYPE_DESCRIPTION 37493
#define IDS_PERSON_SUGGESTION_DESCRIPTION 37494
#define IDS_ACCURACY_CHECK_VERBOSE_STATE 37495
#define IDS_OMNIBOX_HISTORY_CLUSTERS_SEARCH_HINT 37496
#define IDS_OMNIBOX_ACTION_HISTORY_CLUSTERS_SEARCH_HINT 37497
#define IDS_OMNIBOX_ACTION_HISTORY_CLUSTERS_SEARCH_SUGGESTION_CONTENTS 37498
#define IDS_ACC_OMNIBOX_ACTION_HISTORY_CLUSTERS_SEARCH_SUFFIX 37499
#define IDS_ACC_OMNIBOX_ACTION_HISTORY_CLUSTERS_SEARCH 37500
#define IDS_ACC_OMNIBOX_ACTION_IN_SUGGEST_SUFFIX 37501
#define IDS_ACC_OMNIBOX_ACTION_IN_SUGGEST 37502
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_CALL_HINT 37503
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_CALL_CONTENTS 37504
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_DIRECTIONS_HINT 37505
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_DIRECTIONS_CONTENTS 37506
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_REVIEWS_HINT 37507
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_REVIEWS_CONTENTS 37508
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_AIM_HINT 37509
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_AIM_CONTENTS 37510
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_TAB_SWITCH_HINT 37511
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_TAB_SWITCH_CONTENTS 37512
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_WEBSITE_HINT 37513
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_WEBSITE_CONTENTS 37514
#define IDS_ACC_OMNIBOX_ACTION_IN_EXTENSION_SUGGEST_SUFFIX 37515
#define IDS_AI_MODE_ENTRYPOINT_HINT 37516
#define IDS_ACC_SEND_BUTTON_SEARCH_OR_NAVIGATE 37517
#define IDS_ACC_SEND_BUTTON_SEND_TO_AI 37518
#define IDS_ACC_SEND_BUTTON_CREATE_IMAGE 37519
#define IDS_ACC_REMOVE_IMAGE_ATTACHMENT 37520
#define IDS_ACC_REMOVE_ATTACHMENT 37521
#define IDS_ACC_AI_MODE_SELECTED 37522
#define IDS_ACC_CREATE_IMAGE_SELECTED 37523
#define IDS_ACC_AUTOCOMPLETE_HISTORY 37524
#define IDS_ACC_AUTOCOMPLETE_SEARCH_HISTORY 37525
#define IDS_ACC_AUTOCOMPLETE_SEARCH 37526
#define IDS_ACC_AUTOCOMPLETE_SUGGESTED_SEARCH 37527
#define IDS_ACC_AUTOCOMPLETE_SUGGESTED_SEARCH_ENTITY 37528
#define IDS_ACC_AUTOCOMPLETE_QUICK_ANSWER 37529
#define IDS_ACC_AUTOCOMPLETE_BOOKMARK 37530
#define IDS_ACC_AUTOCOMPLETE_CLIPBOARD_IMAGE 37531
#define IDS_ACC_AUTOCOMPLETE_CLIPBOARD_TEXT 37532
#define IDS_ACC_AUTOCOMPLETE_CLIPBOARD_URL 37533
#define IDS_ACC_SEARCH_ICON 37534
#define IDS_ACC_AUTOCOMPLETE_N_OF_M 37535
#define IDS_ACC_TAB_SWITCH_SUFFIX 37536
#define IDS_ACC_TAB_SWITCH_BUTTON_FOCUSED_PREFIX 37537
#define IDS_ACC_TAB_SWITCH_BUTTON 37538
#define IDS_ACC_MULTIPLE_ACTIONS_SUFFIX 37539
#define IDS_ACC_KEYWORD_SUFFIX 37540
#define IDS_ACC_KEYWORD_MODE 37541
#define IDS_ACC_ASK_KEYWORD_MODE 37542
#define IDS_ACC_KEYWORD_MODE_WITH_SHORTCUT 37543
#define IDS_ACC_ASK_KEYWORD_MODE_WITH_SHORTCUT 37544
#define IDS_OMNIBOX_KEYWORD_TEXT_MD 37545
#define IDS_ACC_THUMBS_UP_SUGGESTION_FOCUSED_PREFIX 37546
#define IDS_ACC_THUMBS_UP_SUGGESTION_BUTTON 37547
#define IDS_ACC_THUMBS_DOWN_SUGGESTION_FOCUSED_PREFIX 37548
#define IDS_ACC_THUMBS_DOWN_SUGGESTION_BUTTON 37549
#define IDS_ACC_REMOVE_SUGGESTION_SUFFIX 37550
#define IDS_ACC_REMOVE_SUGGESTION_FOCUSED_PREFIX 37551
#define IDS_ACC_REMOVE_SUGGESTION_BUTTON 37552
#define IDS_ACC_AI_MODE_PLACEHOLDER_TEXT 37553
#define IDS_ACC_AI_MODE_BUTTON_FOCUSED 37554
#define IDS_ACC_CHROME_TIP 37555
#define IDS_ACC_DISMISS_CHROME_TIP_SUFFIX 37556
#define IDS_ACC_DISMISS_CHROME_TIP_FOCUSED_PREFIX 37557
#define IDS_ACC_DISMISS_CHROME_TIP_BUTTON 37558
#define IDS_SEARCH_ENGINES_STARTER_PACK_BOOKMARKS_NAME 37559
#define IDS_SEARCH_ENGINES_STARTER_PACK_BOOKMARKS_KEYWORD 37560
#define IDS_SEARCH_ENGINES_STARTER_PACK_HISTORY_NAME 37561
#define IDS_SEARCH_ENGINES_STARTER_PACK_HISTORY_KEYWORD 37562
#define IDS_SEARCH_ENGINES_STARTER_PACK_TABS_NAME 37563
#define IDS_SEARCH_ENGINES_STARTER_PACK_TABS_KEYWORD 37564
#define IDS_SEARCH_ENGINES_STARTER_PACK_GEMINI_NAME 37565
#define IDS_SEARCH_ENGINES_STARTER_PACK_GEMINI_KEYWORD 37566
#define IDS_SEARCH_ENGINES_STARTER_PACK_PAGE_NAME 37567
#define IDS_SEARCH_ENGINES_STARTER_PACK_PAGE_KEYWORD 37568
#define IDS_SEARCH_ENGINES_STARTER_PACK_AI_MODE_NAME 37569
#define IDS_SEARCH_ENGINES_STARTER_PACK_AI_MODE_KEYWORD 37570
#define IDS_STARTER_PACK_PAGE_KEYWORD_TEXT 37571
#define IDS_STARTER_PACK_PAGE_EMPTY_QUERY_MATCH_TEXT 37572
#define IDS_OMNIBOX_INSTANT_KEYWORD_ASK_TEXT 37573
#define IDS_OMNIBOX_INSTANT_KEYWORD_SEARCH_TEXT 37574
#define IDS_OMNIBOX_SELECTED_KEYWORD_ASK_TEXT 37575
#define IDS_OMNIBOX_TAB_SEARCH_NO_RESULTS_FOUND 37576
#define IDS_OMNIBOX_GEMINI_IPH 37577
#define IDS_OMNIBOX_FEATURED_ENTERPRISE_SITE_SEARCH_IPH 37578
#define IDS_OMNIBOX_FEATURED_ENTERPRISE_SEARCH_AGGREGATOR_IPH 37579
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_SETTINGS_PROMO_IPH 37580
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_SETTINGS_PROMO_IPH_LINK_TEXT 37581
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_DISCLAIMER_IPH 37582
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_DISCLAIMER_IPH_LINK_TEXT 37583
#define IDS_ACC_OMNIBOX_IPH_LINK_SELECTED 37584
#define IDS_ACC_OMNIBOX_TOOLBELT_NEXT_SUFFIX 37585
#define IDS_OMNIBOX_HISTORY_SCOPE_PROMO_IPH 37586
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_SCOPE_PROMO_IPH 37587
#define IDS_OMNIBOX_ONE_LINE_CALCULATOR_SUGGESTION_TEMPLATE 37588
#define IDS_OMNIBOX_HEADER_POPULAR_TOPICS 37589
#define IDS_OMNIBOX_BOOKMARKS_SCOPE_PLACEHOLDER_TEXT 37590
#define IDS_OMNIBOX_HISTORY_SCOPE_PLACEHOLDER_TEXT 37591
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_SCOPE_PLACEHOLDER_TEXT 37592
#define IDS_OMNIBOX_TABS_SCOPE_PLACEHOLDER_TEXT 37593
#define IDS_OMNIBOX_GEMINI_SCOPE_PLACEHOLDER_TEXT 37594
#define IDS_OMNIBOX_PAGE_SCOPE_PLACEHOLDER_TEXT 37595
#define IDS_OMNIBOX_AI_MODE_SCOPE_PLACEHOLDER_TEXT 37596
#define IDS_OMNIBOX_HUB_OPEN_TABS_HEADER 37597
#define IDS_OMNIBOX_HUB_SEARCH_HEADER 37598
#define IDS_OMNIBOX_HUB_HISTORY_HEADER 37599
#define IDS_OMNIBOX_HUB_TYPED_MATCH_HEADER 37600
#define IDS_PAGE_INFO_SECURE_SUMMARY 37601
#define IDS_PAGE_INFO_MIXED_CONTENT_SUMMARY 37602
#define IDS_PAGE_INFO_MIXED_CONTENT_SUMMARY_SHORT 37603
#define IDS_PAGE_INFO_NOT_SECURE_SUMMARY 37604
#define IDS_PAGE_INFO_NOT_SECURE_SUMMARY_SHORT 37605
#define IDS_PAGE_INFO_SAFE_BROWSING_SUMMARY 37606
#define IDS_PAGE_INFO_EXTENSION_PAGE 37607
#define IDS_PAGE_INFO_VIEW_SOURCE_PAGE 37608
#define IDS_PAGE_INFO_DEVTOOLS_PAGE 37609
#define IDS_PAGE_INFO_READER_MODE_PAGE_SECURE 37610
#define IDS_PAGE_INFO_READER_MODE_PAGE 37611
#define IDS_PAGE_INFO_SAFETY_TIP_MORE_INFO_LINK 37612
#define IDS_PAGE_INFO_SAFETY_TIP_LOOKALIKE_LEAVE_BUTTON 37613
#define IDS_PAGE_INFO_SAFETY_TIP_LOOKALIKE_TITLE 37614
#define IDS_PAGE_INFO_SAFETY_TIP_DESCRIPTION 37615
#define IDS_PAGE_INFO_FILE_PAGE 37616
#define IDS_PAGE_INFO_SECURE_DETAILS 37617
#define IDS_PAGE_INFO_MIXED_CONTENT_DETAILS 37618
#define IDS_PAGE_INFO_LEGACY_TLS_DETAILS 37619
#define IDS_PAGE_INFO_NOT_SECURE_DETAILS 37620
#define IDS_PAGE_INFO_MALWARE_DETAILS 37621
#define IDS_PAGE_INFO_SOCIAL_ENGINEERING_DETAILS 37622
#define IDS_PAGE_INFO_UNWANTED_SOFTWARE_DETAILS 37623
#define IDS_PAGE_INFO_SECURITY_TAB_INSECURE_IDENTITY 37624
#define IDS_PAGE_INFO_CHANGE_PASSWORD_SUMMARY 37625
#define IDS_PAGE_INFO_CHANGE_PASSWORD_SAVED_PASSWORD_SUMMARY 37626
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_SAVED 37627
#define IDS_PAGE_INFO_CHECK_PASSWORDS_BUTTON 37628
#define IDS_PAGE_INFO_INVALID_CERTIFICATE_DESCRIPTION 37629
#define IDS_PAGE_INFO_RESET_INVALID_CERTIFICATE_DECISIONS_BUTTON 37630
#define IDS_PAGE_INFO_HELP_CENTER_LINK 37631
#define IDS_PAGE_INFO_SECURITY_TAB_DEPRECATED_SIGNATURE_ALGORITHM 37632
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_CONNECTION_TEXT 37633
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_INSECURE_CONTENT_ERROR 37634
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_INSECURE_CONTENT_WARNING 37635
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_INSECURE_FORM_WARNING 37636
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_SENTENCE_LINK 37637
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTION_DETAILS 37638
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTION_DETAILS_AEAD 37639
#define IDS_PAGE_INFO_SECURITY_TAB_NOT_ENCRYPTED_CONNECTION_TEXT 37640
#define IDS_PAGE_INFO_SECURITY_TAB_SSL_VERSION 37641
#define IDS_PAGE_INFO_SECURITY_TAB_UNKNOWN_PARTY 37642
#define IDS_PAGE_INFO_SECURITY_TAB_WEAK_ENCRYPTION_CONNECTION_TEXT 37643
#define IDS_PAGE_INFO_CERT_INFO_BUTTON 37644
#define IDS_PAGE_INFO_ADDRESS 37645
#define IDS_PAGE_INFO_PARTIAL_ADDRESS 37646
#define IDS_PAGE_INFO_SECURITY_TAB_SECURE_IDENTITY_EV_VERIFIED 37647
#define IDS_PAGE_INFO_CERTIFICATE 37648
#define IDS_PAGE_INFO_CERTIFICATE_VALID_LINK 37649
#define IDS_PAGE_INFO_CERTIFICATE_INVALID_LINK 37650
#define IDS_PAGE_INFO_CERTIFICATE_BUTTON_TEXT 37651
#define IDS_PAGE_INFO_CERTIFICATE_VALID_PARENTHESIZED 37652
#define IDS_PAGE_INFO_CERTIFICATE_INVALID_PARENTHESIZED 37653
#define IDS_PAGE_INFO_CERTIFICATE_IS_VALID 37654
#define IDS_PAGE_INFO_CERTIFICATE_DETAILS 37655
#define IDS_PAGE_INFO_CERTIFICATE_VALID_LINK_TOOLTIP 37656
#define IDS_PAGE_INFO_CERTIFICATE_INVALID_LINK_TOOLTIP 37657
#define IDS_PAGE_INFO_QWAC_STATUS_TITLE 37658
#define IDS_PAGE_INFO_COOKIES 37660
#define IDS_PAGE_INFO_COOKIES_TOOLTIP 37661
#define IDS_PAGE_INFO_BUTTON_TEXT_AUTOMATIC_BY_DEFAULT 37662
#define IDS_PAGE_INFO_BUTTON_TEXT_MUTED_BY_DEFAULT 37663
#define IDS_PAGE_INFO_MENU_ITEM_DEFAULT_ALLOW 37664
#define IDS_PAGE_INFO_MENU_ITEM_DEFAULT_BLOCK 37665
#define IDS_PAGE_INFO_MENU_ITEM_DEFAULT_ASK 37666
#define IDS_PAGE_INFO_MENU_ITEM_ALLOW 37667
#define IDS_PAGE_INFO_MENU_ITEM_BLOCK 37668
#define IDS_PAGE_INFO_MENU_ITEM_ASK 37669
#define IDS_PAGE_INFO_MENU_ITEM_ADS_BLOCK 37670
#define IDS_PAGE_INFO_STATE_TEXT_ALLOWED 37671
#define IDS_PAGE_INFO_STATE_TEXT_ALLOWED_ONCE 37672
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED 37673
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED_IN_INCOGNITO 37674
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED_IN_GUEST 37675
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED_INSECURE 37676
#define IDS_PAGE_INFO_STATE_TEXT_MUTED 37677
#define IDS_PAGE_INFO_STATE_TEXT_ALLOWED_BY_DEFAULT 37678
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED_BY_DEFAULT 37679
#define IDS_PAGE_INFO_SELECTOR_TOOLTIP 37680
#define IDS_PAGE_INFO_SELECTOR_STORAGE_ACCESS_TOOLTIP 37681
#define IDS_PAGE_INFO_STATE_TEXT_AR_ASK 37682
#define IDS_PAGE_INFO_STATE_TEXT_AUTO_PICTURE_IN_PICTURE_ASK 37683
#define IDS_PAGE_INFO_STATE_TEXT_AUTOMATIC_DOWNLOADS_ASK 37684
#define IDS_PAGE_INFO_STATE_TEXT_BLUETOOTH_DEVICES_ASK 37685
#define IDS_PAGE_INFO_STATE_TEXT_CAMERA_ASK 37686
#define IDS_PAGE_INFO_STATE_TEXT_CAPTURED_SURFACE_CONTROL_ASK 37687
#define IDS_PAGE_INFO_STATE_TEXT_CAMERA_PAN_TILT_ZOOM_ASK 37688
#define IDS_PAGE_INFO_STATE_TEXT_CLIPBOARD_ASK 37689
#define IDS_PAGE_INFO_STATE_TEXT_FILE_SYSTEM_WRITE_ASK 37690
#define IDS_PAGE_INFO_STATE_TEXT_HAND_TRACKING_ASK 37691
#define IDS_PAGE_INFO_STATE_TEXT_HID_DEVICES_ASK 37692
#define IDS_PAGE_INFO_STATE_TEXT_KEYBOARD_LOCK_ASK 37693
#define IDS_PAGE_INFO_STATE_TEXT_LOCATION_ASK 37694
#define IDS_PAGE_INFO_STATE_TEXT_MIC_ASK 37695
#define IDS_PAGE_INFO_STATE_TEXT_MIDI_SYSEX_ASK 37696
#define IDS_PAGE_INFO_STATE_TEXT_NOTIFICATIONS_ASK 37697
#define IDS_PAGE_INFO_STATE_TEXT_POINTER_LOCK_ASK 37698
#define IDS_PAGE_INFO_STATE_TEXT_MOTION_AND_LIGHT_SENSORS_ASK 37699
#define IDS_PAGE_INFO_STATE_TEXT_MOTION_SENSORS_ASK 37700
#define IDS_PAGE_INFO_STATE_TEXT_USB_ASK 37701
#define IDS_PAGE_INFO_STATE_TEXT_VR_ASK 37702
#define IDS_PAGE_INFO_STATE_TEXT_FONT_ACCESS_ASK 37703
#define IDS_PAGE_INFO_STATE_TEXT_SERIAL_ASK 37704
#define IDS_PAGE_INFO_STATE_TEXT_IDLE_DETECTION_ASK 37705
#define IDS_PAGE_INFO_STATE_TEXT_WINDOW_MANAGEMENT_ASK 37706
#define IDS_PAGE_INFO_STATE_TEXT_BLUETOOTH_SCANNING_ASK 37707
#define IDS_PAGE_INFO_STATE_TEXT_STORAGE_ACCESS_ASK 37708
#define IDS_PAGE_INFO_STATE_TEXT_WEB_APP_INSTALLATION_ASK 37709
#define IDS_PAGE_INFO_STATE_TEXT_WEB_PRINTING_ASK 37710
#define IDS_PAGE_INFO_STATE_TEXT_LOCAL_NETWORK_ACCESS_ASK 37711
#define IDS_PAGE_INFO_STATE_TEXT_LOCAL_NETWORK_ASK 37712
#define IDS_PAGE_INFO_STATE_TEXT_LOOPBACK_NETWORK_ASK 37713
#define IDS_PAGE_INFO_USB_DEVICE_SECONDARY_LABEL 37714
#define IDS_PAGE_INFO_USB_DEVICE_ALLOWED_BY_POLICY_LABEL 37715
#define IDS_PAGE_INFO_DELETE_USB_DEVICE_WITH_NAME 37716
#define IDS_PAGE_INFO_SERIAL_PORT_SECONDARY_LABEL 37717
#define IDS_PAGE_INFO_SERIAL_PORT_ALLOWED_BY_POLICY_LABEL 37718
#define IDS_PAGE_INFO_DELETE_SERIAL_PORT_WITH_NAME 37719
#define IDS_PAGE_INFO_BLUETOOTH_DEVICE_SECONDARY_LABEL 37720
#define IDS_PAGE_INFO_DELETE_BLUETOOTH_DEVICE_WITH_NAME 37721
#define IDS_PAGE_INFO_HID_DEVICE_SECONDARY_LABEL 37722
#define IDS_PAGE_INFO_HID_DEVICE_ALLOWED_BY_POLICY_LABEL 37723
#define IDS_PAGE_INFO_DELETE_HID_DEVICE_WITH_NAME 37724
#define IDS_PAGE_INFO_SMART_CARD_READER_ALLOWED_BY_POLICY_LABEL 37725
#define IDS_PAGE_INFO_SMART_CARD_READER_SECONDARY_LABEL 37726
#define IDS_PAGE_INFO_DELETE_SMART_CARD_READER_WITH_NAME 37727
#define IDS_PAGE_INFO_SITE_SETTINGS_LINK 37728
#define IDS_PAGE_INFO_SITE_SETTINGS_TOOLTIP 37729
#define IDS_PAGE_INFO_CAMERA_SYSTEM_SETTINGS_DESCRIPTION 37732
#define IDS_PAGE_INFO_MICROPHONE_SYSTEM_SETTINGS_DESCRIPTION 37733
#define IDS_PAGE_INFO_LOCATION_SYSTEM_SETTINGS_DESCRIPTION 37734
#define IDS_PAGE_INFO_CLIPBOARD_SYSTEM_SETTINGS_DESCRIPTION 37735
#define IDS_PAGE_INFO_SETTINGS_OF_A_SYSTEM_LINK 37736
#define IDS_PAGE_INFO_PERMISSION_ALLOWED_BY_POLICY 37737
#define IDS_PAGE_INFO_PERMISSION_BLOCKED_BY_POLICY 37738
#define IDS_PAGE_INFO_PERMISSION_ASK_BY_POLICY 37739
#define IDS_PAGE_INFO_PERMISSION_ALLOWED_BY_EXTENSION 37740
#define IDS_PAGE_INFO_PERMISSION_BLOCKED_BY_EXTENSION 37741
#define IDS_PAGE_INFO_PERMISSION_ASK_BY_EXTENSION 37742
#define IDS_PAGE_INFO_PERMISSION_AUTOMATICALLY_BLOCKED 37743
#define IDS_PAGE_INFO_PERMISSION_ADS_SUBTITLE 37744
#define IDS_PAGE_INFO_PERMISSION_MANAGED_BY_POLICY 37745
#define IDS_PAGE_INFO_PERMISSION_MANAGED_BY_EXTENSION 37746
#define IDS_PAGE_INFO_INFOBAR_TEXT 37747
#define IDS_PAGE_INFO_INFOBAR_BUTTON 37748
#define IDS_PAGE_INFO_PERMISSION_USING_NOW 37749
#define IDS_PAGE_INFO_PERMISSION_RECENTLY_USED 37750
#define IDS_PAGE_INFO_PERMISSION_USED_TIME_AGO 37751
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS 37752
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_SYNC 37753
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_SIGNED_IN_NON_SYNC 37754
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_ENTERPRISE 37755
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_ENTERPRISE_WITH_ORG_NAME 37756
#define IDS_PAGE_INFO_CHANGE_PASSWORD_BUTTON 37757
#define IDS_PAGE_INFO_PROTECT_ACCOUNT_BUTTON 37758
#define IDS_PAGE_INFO_IGNORE_PASSWORD_WARNING_BUTTON 37759
#define IDS_PAGE_INFO_ALLOWLIST_PASSWORD_REUSE_BUTTON 37760
#define IDS_PAGE_INFO_BILLING_SUMMARY 37761
#define IDS_PAGE_INFO_BILLING_DETAILS 37762
#define IDS_PAGE_INFO_VR_PRESENTING_TEXT 37763
#define IDS_PAGE_INFO_VR_TURN_OFF_BUTTON_TEXT 37764
#define IDS_CERT_INFO_SUBJECT_GROUP 37765
#define IDS_CERT_INFO_ISSUER_GROUP 37766
#define IDS_CERT_INFO_COMMON_NAME_LABEL 37767
#define IDS_CERT_INFO_ORGANIZATION_LABEL 37768
#define IDS_CERT_INFO_ORGANIZATIONAL_UNIT_LABEL 37769
#define IDS_CERT_INFO_SERIAL_NUMBER_LABEL 37770
#define IDS_CERT_INFO_VALIDITY_GROUP 37771
#define IDS_CERT_INFO_ISSUED_ON_LABEL 37772
#define IDS_CERT_INFO_EXPIRES_ON_LABEL 37773
#define IDS_CERT_INFO_FINGERPRINTS_GROUP 37774
#define IDS_CERT_INFO_SHA256_FINGERPRINT_LABEL 37775
#define IDS_CERT_INFO_SHA256_SPKI_FINGERPRINT_LABEL 37776
#define IDS_CERT_DETAILS_EXTENSIONS 37777
#define IDS_CERT_X509_SUBJECT_ALT_NAME 37778
#define IDS_PAGE_INFO_SECURITY_SUBPAGE_BUTTON 37779
#define IDS_PAGE_INFO_SECURITY_SUBPAGE_HEADER 37780
#define IDS_PAGE_INFO_PERMISSIONS_SUBPAGE_BUTTON_TOOLTIP 37781
#define IDS_PAGE_INFO_PERMISSIONS_SUBPAGE_MANAGE_BUTTON 37782
#define IDS_PAGE_INFO_PERMISSIONS_SUBPAGE_MANAGE_BUTTON_TOOLTIP 37783
#define IDS_PAGE_INFO_PERMISSIONS_SUBPAGE_REMEMBER_THIS_SETTING 37784
#define IDS_PAGE_INFO_RESET_PERMISSIONS 37785
#define IDS_PAGE_INFO_ABOUT_THIS_SITE_HEADER 37786
#define IDS_PAGE_INFO_ABOUT_THIS_PAGE_TITLE 37787
#define IDS_PAGE_INFO_ABOUT_THIS_PAGE_DESCRIPTION_PLACEHOLDER 37788
#define IDS_PAGE_INFO_ABOUT_THIS_SITE_TOOLTIP 37789
#define IDS_PAGE_INFO_ABOUT_THIS_PAGE_TOOLTIP 37790
#define IDS_PAGE_INFO_ABOUT_THIS_SITE_SUBPAGE_FROM_LABEL 37791
#define IDS_PAGE_INFO_COOKIES_HEADER 37792
#define IDS_PAGE_INFO_COOKIES_DESCRIPTION 37793
#define IDS_PAGE_INFO_COOKIES_SETTINGS_LINK 37794
#define IDS_PAGE_INFO_BLOCK_THIRD_PARTY_COOKIES_MANAGED_BY_SETTINGS_TOOLTIP 37795
#define IDS_PAGE_INFO_COOKIES_ALLOWED_SITES_COUNT 37796
#define IDS_PAGE_INFO_COOKIES_DIALOG_BUTTON_TITLE 37797
#define IDS_PAGE_INFO_COOKIES_DIALOG_BUTTON_TOOLTIP 37798
#define IDS_PAGE_INFO_RWS_BUTTON_TOOLTIP 37799
#define IDS_PAGE_INFO_RWS_BUTTON_TITLE 37800
#define IDS_PAGE_INFO_RWS_BUTTON_SUBTITLE 37801
#define IDS_PAGE_INFO_COOKIES_SITE_NOT_WORKING_TITLE 37802
#define IDS_PAGE_INFO_TRACKING_PROTECTION_SITE_NOT_WORKING_DESCRIPTION_TEMPORARY 37803
#define IDS_PAGE_INFO_COOKIES_THIRD_PARTY_COOKIES_LABEL 37804
#define IDS_PAGE_INFO_TRACKING_PROTECTION_COOKIES_BLOCKED_RESTART_TITLE 37805
#define IDS_PAGE_INFO_TRACKING_PROTECTION_COOKIES_RESTART_DESCRIPTION 37806
#define IDS_PAGE_INFO_TRACKING_PROTECTION_PERMANENT_ALLOWED_TITLE 37807
#define IDS_PAGE_INFO_TRACKING_PROTECTION_COOKIES_PERMANENT_ALLOWED_DESCRIPTION 37808
#define IDS_PAGE_INFO_COOKIE_SYNC_DESCRIPTION 37809
#define IDS_PAGE_INFO_SYNC_SETTINGS_LINK 37810
#define IDS_MERCHANT_TRUST_SIDE_PANEL_TITLE 37811
#define IDS_PAGE_INFO_MERCHANT_TRUST_HEADER 37812
#define IDS_PAGE_INFO_MERCHANT_TRUST_DESCRIPTION 37813
#define IDS_PAGE_INFO_MERCHANT_TRUST_VIEW_ALL_REVIEWS 37814
#define IDS_PAGE_INFO_MERCHANT_TRUST_STAR_RATING_AND_COUNT_A11Y_DESCRIPTION 37815
#define IDS_PAGE_INFO_MERCHANT_TRUST_STAR_RATING_A11Y_DESCRIPTION 37816
#define IDS_PAGE_INFO_MERCHANT_TRUST_REVIEWS_SUMMARY_TITLE 37817
#define IDS_PAGE_INFO_HISTORY 37818
#define IDS_PAGE_INFO_HISTORY_LAST_VISIT_TODAY 37819
#define IDS_PAGE_INFO_HISTORY_LAST_VISIT_YESTERDAY 37820
#define IDS_PAGE_INFO_HISTORY_LAST_VISIT_DAYS 37821
#define IDS_PAGE_INFO_HISTORY_LAST_VISIT_DATE 37822
#define IDS_PAGE_INFO_ENTERPRISE_WARN_SUMMARY 37823
#define IDS_PAGE_INFO_ENTERPRISE_WARN_DETAILS 37824
#define IDS_PAGE_INFO_ENTERPRISE_BLOCK_SUMMARY 37825
#define IDS_PAGE_INFO_ENTERPRISE_BLOCK_DETAILS 37826
#define IDS_PAGE_INFO_AD_PRIVACY_HEADER 37827
#define IDS_PAGE_INFO_AD_PRIVACY_TOOLTIP 37828
#define IDS_PAGE_INFO_AD_PRIVACY_TOPICS_DESCRIPTION 37829
#define IDS_PAGE_INFO_AD_PRIVACY_FLEDGE_DESCRIPTION 37830
#define IDS_PAGE_INFO_AD_PRIVACY_TOPICS_AND_FLEDGE_DESCRIPTION 37831
#define IDS_PAGE_INFO_AD_PRIVACY_SUBPAGE_MANAGE_BUTTON 37832
#define IDS_PAINT_PREVIEW_COMPOSITOR_SERVICE_DISPLAY_NAME 37833
#define IDS_LEAK_CHECK_CREDENTIALS 37834
#define IDS_CREDENTIAL_LEAK_TITLE_CHANGE 37835
#define IDS_CREDENTIAL_LEAK_TITLE_CHECK_GPM 37836
#define IDS_CREDENTIAL_LEAK_CHECK_PASSWORDS_MESSAGE_GPM_BRANDED 37837
#define IDS_CREDENTIAL_LEAK_CHANGE_PASSWORD_MESSAGE_GPM_BRANDED 37838
#define IDS_CREDENTIAL_LEAK_CHANGE_AND_CHECK_PASSWORDS_MESSAGE_GPM_BRANDED 37839
#define IDS_CREDENTIAL_LEAK_CHECK_PASSWORDS_MESSAGE_GPM_NON_BRANDED 37840
#define IDS_CREDENTIAL_LEAK_CHANGE_PASSWORD_MESSAGE_GPM_NON_BRANDED 37841
#define IDS_CREDENTIAL_LEAK_CHANGE_AND_CHECK_PASSWORDS_MESSAGE_GPM_NON_BRANDED 37842
#define IDS_PASSWORD_MANAGER_LEAK_HELP_MESSAGE 37845
#define IDS_MANAGE_PASSWORDS_AUTO_SIGNIN_TITLE 37846
#define IDS_PASSWORD_MANAGER_EMPTY_LOGIN 37847
#define IDS_PASSWORD_MANAGER_MANAGE_PASSWORDS 37848
#define IDS_PASSWORD_MANAGER_MANAGE_PASSWORDS_AND_PASSKEYS 37849
#define IDS_PASSWORD_MANAGER_GENERATE_PASSWORD 37850
#define IDS_PASSWORD_MANAGER_SHOW_PASSWORDS_TAB_TITLE 37851
#define IDS_PASSWORD_MANAGER_DEFAULT_EXPORT_FILENAME 37852
#define IDS_PASSWORD_MANAGER_PASSWORD_FOR_ACCOUNT 37853
#define IDS_PASSWORD_MANAGER_USE_SCREEN_LOCK 37854
#define IDS_PASSWORD_MANAGER_PASSKEY 37855
#define IDS_PASSWORD_MANAGER_USE_GENERIC_DEVICE 37856
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_CHROME_PROFILE 37857
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_ICLOUD_KEYCHAIN 37858
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_GOOGLE_PASSWORD_MANAGER 37859
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_WINDOWS_HELLO 37860
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_PROVIDER 37861
#define IDS_PASSWORD_MANAGER_PASSWORD_FROM_GOOGLE_PASSWORD_MANAGER 37862
#define IDS_PASSWORD_MANAGER_USE_DIFFERENT_PASSKEY 37863
#define IDS_PASSWORD_MANAGER_USE_PASSKEY_OTHER_DEVICE 37864
#define IDS_PASSWORD_MANAGER_USE_PASSKEY 37865
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_TITLE_LINUX_BRANDED 37890
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_DESCRIPTION_LINUX_BRANDED 37891
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_TITLE_LINUX_NON_BRANDED 37892
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_DESCRIPTION_LINUX_NON_BRANDED 37893
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_ACCEPT_BUTTON_BRANDED 37897
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_ACCEPT_BUTTON_NON_BRANDED 37898
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_CANCEL_BUTTON 37899
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_NEVER_BUTTON 37900
#define IDS_PASSWORD_MANAGER_MANAGEMENT_BUBBLE_FOOTER_MOVE_PASSWORD 37901
#define IDS_PASSWORD_MANAGER_MANAGEMENT_BUBBLE_LINK_TEXT_MOVE_PASSWORD 37902
#define IDS_PASSWORD_MANAGER_MANUAL_FALLBACK_SUGGESTED_PASSWORDS_SECTION_TITLE 37903
#define IDS_PASSWORD_MANAGER_MANUAL_FALLBACK_ALL_PASSWORDS_SECTION_TITLE 37904
#define IDS_PASSWORD_MANAGER_MANUAL_FALLBACK_FILL_PASSWORD_ENTRY 37905
#define IDS_PASSWORD_MANAGER_MANUAL_FALLBACK_VIEW_DETAILS_ENTRY 37906
#define IDS_PASSWORD_MANAGER_PENDING_STATE 37907
#define IDS_PASSWORD_MANAGER_UI_TROUBLE_SIGNING_IN 37908
#define IDS_PASSWORD_MANAGER_UI_PROACTIVE_RECOVERY_SUGGESTION 37909
#define IDS_PASSWORD_MANAGER_UI_PROACTIVE_RECOVERY_FOOTER_BRANDED 37910
#define IDS_PASSWORD_MANAGER_UI_PROACTIVE_RECOVERY_FOOTER_NON_BRANDED 37911
#define IDS_PASSWORD_MANAGER_UI_BACKUP_PASSWORD_TAG 37912
#define IDS_PAYMENTS_TITLE 37913
#define IDS_PAYMENTS_ERROR_MESSAGE_DIALOG_TITLE 37914
#define IDS_PAYMENTS_METHOD_OF_PAYMENT_LABEL 37915
#define IDS_PAYMENTS_CONTACT_DETAILS_LABEL 37916
#define IDS_PAYMENTS_ADD_CONTACT_DETAILS_LABEL 37917
#define IDS_PAYMENTS_EDIT_CONTACT_DETAILS_LABEL 37918
#define IDS_PAYMENTS_ADD_MORE_INFORMATION 37919
#define IDS_PAYMENTS_ADD_PHONE_NUMBER 37920
#define IDS_PAYMENTS_ADD_RECIPIENT 37921
#define IDS_PAYMENTS_ADD_VALID_ADDRESS 37922
#define IDS_PAYMENTS_ADD_EMAIL 37923
#define IDS_PAYMENTS_ADD_NAME 37924
#define IDS_PAYMENTS_ORDER_SUMMARY_LABEL 37925
#define IDS_PAYMENT_REQUEST_PAYMENT_METHOD_SECTION_NAME 37926
#define IDS_PAYMENT_REQUEST_CONTACT_INFO_SECTION_NAME 37927
#define IDS_PAYMENTS_SHIPPING_SUMMARY_LABEL 37928
#define IDS_PAYMENTS_SHIPPING_ADDRESS_LABEL 37929
#define IDS_PAYMENTS_SHIPPING_OPTION_LABEL 37930
#define IDS_PAYMENTS_DELIVERY_SUMMARY_LABEL 37931
#define IDS_PAYMENTS_DELIVERY_ADDRESS_LABEL 37932
#define IDS_PAYMENTS_DELIVERY_OPTION_LABEL 37933
#define IDS_PAYMENTS_PICKUP_SUMMARY_LABEL 37934
#define IDS_PAYMENTS_PICKUP_ADDRESS_LABEL 37935
#define IDS_PAYMENTS_PICKUP_OPTION_LABEL 37936
#define IDS_PAYMENTS_EDIT_BUTTON 37937
#define IDS_PAYMENTS_PAY_BUTTON 37938
#define IDS_PAYMENTS_CONTINUE_BUTTON 37939
#define IDS_PAYMENTS_ADD_CONTACT 37940
#define IDS_PAYMENTS_ADD_CARD 37941
#define IDS_PAYMENTS_ADD_ADDRESS 37942
#define IDS_PAYMENTS_EDIT_ADDRESS 37943
#define IDS_PAYMENTS_CANCEL_PAYMENT 37944
#define IDS_PAYMENTS_CONFIRM_BUTTON 37945
#define IDS_PAYMENTS_NAME_FIELD_IN_CONTACT_DETAILS 37946
#define IDS_PAYMENTS_PHONE_FIELD_IN_CONTACT_DETAILS 37947
#define IDS_PAYMENTS_EMAIL_FIELD_IN_CONTACT_DETAILS 37948
#define IDS_PAYMENTS_LOADING_MESSAGE 37949
#define IDS_PAYMENTS_PROCESSING_MESSAGE 37950
#define IDS_PAYMENTS_CHECKING_OPTION 37951
#define IDS_PAYMENTS_UPDATED_LABEL 37952
#define IDS_PAYMENTS_ERROR_MESSAGE 37953
#define IDS_PAYMENTS_CARD_AND_ADDRESS_SETTINGS 37954
#define IDS_PAYMENTS_CARD_AND_ADDRESS_SETTINGS_SIGNED_IN 37955
#define IDS_PAYMENTS_CARD_AND_ADDRESS_SETTINGS_SIGNED_OUT 37956
#define IDS_SETTINGS_CAN_MAKE_PAYMENT_TOGGLE_LABEL 37957
#define IDS_PAYMENTS_REQUIRED_FIELD_MESSAGE 37958
#define IDS_PAYMENTS_VALIDATION_INVALID_CREDIT_CARD_EXPIRED 37959
#define IDS_PAYMENTS_VALIDATION_UNSUPPORTED_CREDIT_CARD_TYPE 37960
#define IDS_PAYMENTS_PHONE_INVALID_VALIDATION_MESSAGE 37961
#define IDS_PAYMENTS_EMAIL_INVALID_VALIDATION_MESSAGE 37962
#define IDS_PAYMENTS_CARD_NUMBER_INVALID_VALIDATION_MESSAGE 37963
#define IDS_PAYMENTS_INVALID_ADDRESS 37964
#define IDS_PAYMENTS_BILLING_ADDRESS_REQUIRED 37965
#define IDS_PAYMENTS_MORE_INFORMATION_REQUIRED 37966
#define IDS_PAYMENTS_PHONE_NUMBER_REQUIRED 37967
#define IDS_PAYMENTS_RECIPIENT_REQUIRED 37968
#define IDS_PAYMENTS_EMAIL_REQUIRED 37969
#define IDS_PAYMENTS_NAME_REQUIRED 37970
#define IDS_PREF_EDIT_DIALOG_FIELD_REQUIRED_VALIDATION_MESSAGE 37971
#define IDS_PAYMENT_REQUEST_ORDER_SUMMARY_SECTION_TOTAL_FORMAT 37972
#define IDS_PAYMENT_REQUEST_ORDER_SUMMARY_SHEET_TOTAL_FORMAT 37973
#define IDS_PAYMENT_REQUEST_ORDER_SUMMARY_MORE_ITEMS 37974
#define IDS_PAYMENT_REQUEST_ORDER_SUMMARY_MULTIPLE_CURRENCY_INDICATOR 37975
#define IDS_PAYMENTS_SELECT_SHIPPING_ADDRESS_FOR_SHIPPING_METHODS 37976
#define IDS_PAYMENTS_UNSUPPORTED_SHIPPING_ADDRESS 37977
#define IDS_PAYMENTS_UNSUPPORTED_SHIPPING_OPTION 37978
#define IDS_PAYMENTS_SELECT_DELIVERY_ADDRESS_FOR_DELIVERY_METHODS 37979
#define IDS_PAYMENTS_UNSUPPORTED_DELIVERY_ADDRESS 37980
#define IDS_PAYMENTS_SELECT_PICKUP_ADDRESS_FOR_PICKUP_METHODS 37981
#define IDS_PAYMENTS_UNSUPPORTED_PICKUP_ADDRESS 37982
#define IDS_PAYMENTS_ANDROID_APP_ERROR 37983
#define IDS_PAYMENT_REQUEST_PAYMENT_METHODS_PREVIEW 37985
#define IDS_PAYMENT_REQUEST_SHIPPING_ADDRESSES_PREVIEW 37986
#define IDS_PAYMENT_REQUEST_SHIPPING_OPTIONS_PREVIEW 37987
#define IDS_PAYMENT_REQUEST_CONTACTS_PREVIEW 37988
#define IDS_PAYMENTS_BACK 37989
#define IDS_PAYMENTS_CLOSE 37990
#define IDS_PAYMENTS_EDIT 37991
#define IDS_PAYMENTS_ROW_ACCESSIBLE_NAME_FORMAT 37992
#define IDS_PAYMENTS_ROW_ACCESSIBLE_NAME_SELECTED_FORMAT 37993
#define IDS_PAYMENTS_PROFILE_LABELS_ACCESSIBLE_FORMAT 37994
#define IDS_PAYMENTS_ACCESSIBLE_LABEL_WITH_ERROR 37995
#define IDS_PAYMENTS_ORDER_SUMMARY_ACCESSIBLE_LABEL 37996
#define IDS_PAYMENTS_ITEM_ICON 37997
#define IDS_PAYMENT_HANDLER_SHEET_DESCRIPTION 37998
#define IDS_PAYMENT_HANDLER_SHEET_OPENED_HALF 37999
#define IDS_PAYMENT_HANDLER_SHEET_OPENED_FULL 38000
#define IDS_PAYMENT_HANDLER_SHEET_CLOSED 38001
#define IDS_PAYMENT_HANDLER_ICON 38002
#define IDS_SECURE_PAYMENT_CONFIRMATION_TITLE 38003
#define IDS_SECURE_PAYMENT_CONFIRMATION_INFORM_ONLY_TITLE 38004
#define IDS_SECURE_PAYMENT_CONFIRMATION_VERIFY_BUTTON_LABEL 38005
#define IDS_SECURE_PAYMENT_CONFIRMATION_FOOTNOTE_TEXT 38010
#define IDS_SECURE_PAYMENT_CONFIRMATION_FOOTNOTE_LINK_TEXT 38011
#define IDS_SECURE_PAYMENT_CONFIRMATION_OPT_OUT_TEXT 38012
#define IDS_SECURE_PAYMENT_CONFIRMATION_OPT_OUT_LINK_TEXT 38013
#define IDS_SECURE_PAYMENT_CONFIRMATION_CONFIRM_BUTTON_LABEL 38014
#define IDS_SECURE_PAYMENT_CONFIRMATION_OPT_OUT_AUTHENTICATOR_TEXT 38015
#define IDS_SECURE_PAYMENT_CONFIRMATION_STORE_LABEL 38016
#define IDS_SECURE_PAYMENT_CONFIRMATION_TOTAL_LABEL 38017
#define IDS_SECURE_PAYMENT_CONFIRMATION_OPT_OUT_LINK_LABEL 38018
#define IDS_SECURE_PAYMENT_CONFIRMATION_INLINE_TITLE 38019
#define IDS_NO_MATCHING_CREDENTIAL_DESCRIPTION 38020
#define IDS_SECURE_PAYMENT_CONFIRMATION_VERIFY_PURCHASE 38021
#define IDS_SECURE_PAYMENT_CONFIRMATION_INLINE_DESCRIPTION 38022
#define IDS_SECURE_PAYMENT_CONFIRMATION_OPT_OUT_LABEL 38007
#define IDS_PDF_DOWNLOAD_ORIGINAL 38031
#define IDS_PDF_DOWNLOAD_EDITED 38032
#define IDS_PDF_PRESENT 38033
#define IDS_PDF_NEED_PASSWORD 38034
#define IDS_PDF_PASSWORD_DIALOG_TITLE 38035
#define IDS_PDF_PASSWORD_SUBMIT 38036
#define IDS_PDF_PASSWORD_INVALID 38037
#define IDS_PDF_SIDEBAR_LABEL 38038
#define IDS_PDF_PAGE_LOADING 38039
#define IDS_PDF_ERROR_DIALOG_TITLE 38040
#define IDS_PDF_PAGE_LOAD_FAILED 38041
#define IDS_PDF_PAGE_RELOAD_BUTTON 38042
#define IDS_PDF_BOOKMARKS 38043
#define IDS_PDF_BOOKMARK_EXPAND_ICON_ARIA_LABEL 38044
#define IDS_PDF_PROPERTIES_DIALOG_TITLE 38045
#define IDS_PDF_PROPERTIES_FILE_NAME 38046
#define IDS_PDF_PROPERTIES_FILE_SIZE 38047
#define IDS_PDF_PROPERTIES_TITLE 38048
#define IDS_PDF_PROPERTIES_AUTHOR 38049
#define IDS_PDF_PROPERTIES_SUBJECT 38050
#define IDS_PDF_PROPERTIES_KEYWORDS 38051
#define IDS_PDF_PROPERTIES_CREATED 38052
#define IDS_PDF_PROPERTIES_MODIFIED 38053
#define IDS_PDF_PROPERTIES_APPLICATION 38054
#define IDS_PDF_PROPERTIES_PDF_PRODUCER 38055
#define IDS_PDF_PROPERTIES_PDF_VERSION 38056
#define IDS_PDF_PROPERTIES_PAGE_COUNT 38057
#define IDS_PDF_PROPERTIES_PAGE_SIZE 38058
#define IDS_PDF_PROPERTIES_PAGE_SIZE_VALUE_INCH 38059
#define IDS_PDF_PROPERTIES_PAGE_SIZE_VALUE_MM 38060
#define IDS_PDF_PROPERTIES_PAGE_SIZE_PORTRAIT 38061
#define IDS_PDF_PROPERTIES_PAGE_SIZE_LANDSCAPE 38062
#define IDS_PDF_PROPERTIES_PAGE_SIZE_SQUARE 38063
#define IDS_PDF_PROPERTIES_PAGE_SIZE_VARIABLE 38064
#define IDS_PDF_PROPERTIES_FAST_WEB_VIEW 38065
#define IDS_PDF_PROPERTIES_FAST_WEB_VIEW_NO 38066
#define IDS_PDF_PROPERTIES_FAST_WEB_VIEW_YES 38067
#define IDS_PDF_TOOLTIP_ROTATE_CCW 38068
#define IDS_PDF_ROTATION_STATE_LABEL_0 38069
#define IDS_PDF_ROTATION_STATE_LABEL_90 38070
#define IDS_PDF_ROTATION_STATE_LABEL_180 38071
#define IDS_PDF_ROTATION_STATE_LABEL_270 38072
#define IDS_PDF_TOOLTIP_DOWNLOAD 38073
#define IDS_PDF_TOOLTIP_PRINT 38074
#define IDS_PDF_TOOLTIP_FIT_PAGE 38075
#define IDS_PDF_TOOLTIP_FIT_WIDTH 38076
#define IDS_PDF_TWO_UP_VIEW_ENABLE 38077
#define IDS_PDF_ANNOTATIONS_SHOW_TOGGLE 38078
#define IDS_PDF_ZOOM_TEXT_INPUT_ARIA_LABEL 38079
#define IDS_PDF_TOOLTIP_ZOOM_IN 38080
#define IDS_PDF_TOOLTIP_ZOOM_OUT 38081
#define IDS_PDF_TOOLTIP_THUMBNAILS 38082
#define IDS_PDF_TOOLTIP_DOCUMENT_OUTLINE 38083
#define IDS_PDF_TOOLTIP_ATTACHMENTS 38084
#define IDS_PDF_TOOLTIP_DOWNLOAD_ATTACHMENT 38085
#define IDS_PDF_LABEL_PAGE_NUMBER 38086
#define IDS_PDF_LOADING_TO_A11Y_TREE 38087
#define IDS_PDF_LOADED_TO_A11Y_TREE 38088
#define IDS_PDF_OVERSIZE_ATTACHMENT_WARNING 38089
#define IDS_PDF_PAGE_INDEX 38090
#define IDS_PDF_DOCUMENT_PAGE_COUNT 38091
#define IDS_PDF_THUMBNAIL_PAGE_ARIA_LABEL 38092
#define IDS_PDF_ANNOTATION_PEN 38093
#define IDS_PDF_ANNOTATION_HIGHLIGHTER 38094
#define IDS_PDF_ANNOTATION_ERASER 38095
#define IDS_PDF_ANNOTATION_UNDO 38096
#define IDS_PDF_ANNOTATION_REDO 38097
#define IDS_PDF_ANNOTATION_COLOR_BLACK 38098
#define IDS_PDF_ANNOTATION_COLOR_RED 38099
#define IDS_PDF_ANNOTATION_COLOR_YELLOW 38100
#define IDS_PDF_ANNOTATION_COLOR_GREEN 38101
#define IDS_PDF_ANNOTATION_COLOR_WHITE 38102
#define IDS_PDF_ANNOTATION_COLOR_ORANGE 38103
#define IDS_PDF_ANNOTATION_COLOR_BLUE 38104
#define IDS_PDF_ANNOTATION_COLOR_LIGHT_GREY 38105
#define IDS_PDF_ANNOTATION_COLOR_LIGHT_ORANGE 38106
#define IDS_PDF_ANNOTATION_COLOR_LIGHT_GREEN 38107
#define IDS_PDF_ANNOTATION_COLOR_LIGHT_BLUE 38108
#define IDS_PDF_INK2_DRAW 38109
#define IDS_PDF_INK2_ANNOTATION_TOOL 38110
#define IDS_PDF_INK2_ANNOTATION_SIZE 38111
#define IDS_PDF_INK2_ANNOTATION_COLOR 38112
#define IDS_PDF_INK2_ANNOTATION_SIZE_EXTRA_THIN 38113
#define IDS_PDF_INK2_ANNOTATION_SIZE_THIN 38114
#define IDS_PDF_INK2_ANNOTATION_SIZE_MEDIUM 38115
#define IDS_PDF_INK2_ANNOTATION_SIZE_THICK 38116
#define IDS_PDF_INK2_ANNOTATION_SIZE_EXTRA_THICK 38117
#define IDS_PDF_INK2_ANNOTATION_COLOR_LIGHT_RED 38118
#define IDS_PDF_INK2_ANNOTATION_COLOR_LIGHT_YELLOW 38119
#define IDS_PDF_INK2_ANNOTATION_COLOR_DARK_GREY_1 38120
#define IDS_PDF_INK2_ANNOTATION_COLOR_DARK_GREY_2 38121
#define IDS_PDF_INK2_ANNOTATION_COLOR_RED_1 38122
#define IDS_PDF_INK2_ANNOTATION_COLOR_YELLOW_1 38123
#define IDS_PDF_INK2_ANNOTATION_COLOR_GREEN_1 38124
#define IDS_PDF_INK2_ANNOTATION_COLOR_CYAN_1 38125
#define IDS_PDF_INK2_ANNOTATION_COLOR_BLUE_1 38126
#define IDS_PDF_INK2_ANNOTATION_COLOR_TAN_1 38127
#define IDS_PDF_INK2_ANNOTATION_COLOR_RED_2 38128
#define IDS_PDF_INK2_ANNOTATION_COLOR_YELLOW_2 38129
#define IDS_PDF_INK2_ANNOTATION_COLOR_GREEN_2 38130
#define IDS_PDF_INK2_ANNOTATION_COLOR_CYAN_2 38131
#define IDS_PDF_INK2_ANNOTATION_COLOR_BLUE_2 38132
#define IDS_PDF_INK2_ANNOTATION_COLOR_TAN_2 38133
#define IDS_PDF_INK2_ANNOTATION_COLOR_RED_3 38134
#define IDS_PDF_INK2_ANNOTATION_COLOR_YELLOW_3 38135
#define IDS_PDF_INK2_ANNOTATION_COLOR_GREEN_3 38136
#define IDS_PDF_INK2_ANNOTATION_COLOR_CYAN_3 38137
#define IDS_PDF_INK2_ANNOTATION_COLOR_BLUE_3 38138
#define IDS_PDF_INK2_ANNOTATION_COLOR_TAN_3 38139
#define IDS_PDF_INK2_TEXT_ANNOTATION 38140
#define IDS_PDF_INK2_TEXT_FONT 38141
#define IDS_PDF_INK2_TEXT_FONT_SANS_SERIF 38142
#define IDS_PDF_INK2_TEXT_FONT_SERIF 38143
#define IDS_PDF_INK2_TEXT_FONT_MONOSPACE 38144
#define IDS_PDF_INK2_TEXT_FONT_SIZE 38145
#define IDS_PDF_INK2_TEXT_STYLES 38146
#define IDS_PDF_INK2_TEXT_STYLE_BOLD 38147
#define IDS_PDF_INK2_TEXT_STYLE_ITALIC 38148
#define IDS_PDF_INK2_TEXT_ALIGNMENT 38149
#define IDS_PDF_INK2_TEXT_ALIGN_LEFT 38150
#define IDS_PDF_INK2_TEXT_ALIGN_CENTER 38151
#define IDS_PDF_INK2_TEXT_ALIGN_RIGHT 38152
#define IDS_PDF_INK2_TEXT_COLOR 38153
#define IDS_AX_ROLE_DESCRIPTION_PDF_HIGHLIGHT 38154
#define IDS_AX_ROLE_DESCRIPTION_PDF_POPUP_NOTE 38155
#define IDS_PDF_TOOLTIP_SAVE_TO_DRIVE 38156
#define IDS_SAVE_TO_DRIVE_DIALOG_CANCEL_UPLOAD_BUTTON_LABEL 38157
#define IDS_SAVE_TO_DRIVE_DIALOG_CONNECTION_ERROR_MESSAGE 38158
#define IDS_SAVE_TO_DRIVE_DIALOG_ERROR_TITLE 38159
#define IDS_SAVE_TO_DRIVE_DIALOG_MANAGE_STORAGE_BUTTON_LABEL 38160
#define IDS_SAVE_TO_DRIVE_DIALOG_OPEN_IN_DRIVE_BUTTON_LABEL 38161
#define IDS_SAVE_TO_DRIVE_DIALOG_RETRY_BUTTON_LABEL 38162
#define IDS_SAVE_TO_DRIVE_DIALOG_SESSION_TIMEOUT_ERROR_MESSAGE 38163
#define IDS_SAVE_TO_DRIVE_DIALOG_STORAGE_FULL_ERROR_MESSAGE 38164
#define IDS_SAVE_TO_DRIVE_DIALOG_SUCCESS_MESSAGE 38165
#define IDS_SAVE_TO_DRIVE_DIALOG_SUCCESS_TITLE 38166
#define IDS_SAVE_TO_DRIVE_DIALOG_UNKNOWN_ERROR_MESSAGE 38167
#define IDS_SAVE_TO_DRIVE_DIALOG_UPLOAD_STATUS_DONE 38168
#define IDS_SAVE_TO_DRIVE_DIALOG_UPLOAD_STATUS_WITH_SEPARATOR 38169
#define IDS_SAVE_TO_DRIVE_DIALOG_UPLOADING_TITLE 38170
#define IDS_PDF_OCR_FEATURE_ALERT 38171
#define IDS_PDF_OCR_IN_PROGRESS 38172
#define IDS_PDF_OCR_COMPLETED 38173
#define IDS_PDF_OCR_NO_RESULT 38174
#define IDS_PDF_OCR_POSTAMBLE_PAGE 38175
#define IDS_PDF_SEARCHIFY_IN_PROGRESS 38176
#define IDS_GEOLOCATION_INFOBAR_TEXT 38177
#define IDS_GEOLOCATION_INFOBAR_PERMISSION_FRAGMENT 38214
#define IDS_MOTION_AND_LIGHT_SENSORS_PERMISSION_FRAGMENT 38215
#define IDS_MOTION_SENSORS_PERMISSION_FRAGMENT 38216
#define IDS_NOTIFICATION_PERMISSIONS_FRAGMENT 38217
#define IDS_MIDI_SYSEX_PERMISSION_FRAGMENT 38218
#define IDS_MEDIA_CAPTURE_AUDIO_ONLY_PERMISSION_FRAGMENT 38219
#define IDS_MEDIA_CAPTURE_AUDIO_ONLY_PERMISSION_FRAGMENT_WITH_COUNT 38220
#define IDS_MEDIA_CAPTURE_VIDEO_ONLY_PERMISSION_FRAGMENT 38221
#define IDS_MEDIA_CAPTURE_VIDEO_ONLY_PERMISSION_FRAGMENT_WITH_COUNT 38222
#define IDS_MEDIA_CAPTURE_CAMERA_PAN_TILT_ZOOM_PERMISSION_FRAGMENT 38223
#define IDS_MEDIA_CAPTURE_CAMERA_PAN_TILT_ZOOM_PERMISSION_FRAGMENT_WITH_COUNT 38224
#define IDS_ACCESSIBILITY_EVENTS_PERMISSION_FRAGMENT 38225
#define IDS_CLIPBOARD_PERMISSION_FRAGMENT 38226
#define IDS_VR_PERMISSION_FRAGMENT 38227
#define IDS_AR_PERMISSION_FRAGMENT 38228
#define IDS_HAND_TRACKING_PERMISSION_FRAGMENT 38229
#define IDS_KEYBOARD_LOCK_PERMISSIONS_FRAGMENT 38230
#define IDS_POINTER_LOCK_PERMISSIONS_FRAGMENT 38231
#define IDS_STORAGE_ACCESS_PERMISSION_TWO_ORIGIN_PROMPT_TITLE 38232
#define IDS_STORAGE_ACCESS_PERMISSION_FRAGMENT 38233
#define IDS_STORAGE_ACCESS_PERMISSION_EXPLANATION 38234
#define IDS_STORAGE_ACCESS_PERMISSION_TWO_ORIGIN_EXPLANATION 38235
#define IDS_STORAGE_ACCESS_PERMISSION_TWO_ORIGIN_LINK 38236
#define IDS_WINDOW_MANAGEMENT_PERMISSION_FRAGMENT 38237
#define IDS_FONT_ACCESS_PERMISSION_FRAGMENT 38238
#define IDS_IDLE_DETECTION_PERMISSION_FRAGMENT 38239
#define IDS_IDENTITY_PROVIDER_PERMISSION_FRAGMENT 38240
#define IDS_MULTI_DOWNLOAD_PERMISSION_FRAGMENT 38241
#define IDS_CAPTURED_SURFACE_CONTROL_PERMISSION_FRAGMENT 38242
#define IDS_WEB_APP_INSTALLATION_PERMISSION_FRAGMENT 38243
#define IDS_LOCAL_NETWORK_ACCESS_PERMISSION_FRAGMENT 38244
#define IDS_LOCAL_NETWORK_PERMISSION_FRAGMENT 38245
#define IDS_LOOPBACK_NETWORK_PERMISSION_FRAGMENT 38246
#define IDS_PERMISSION_ALLOW 38247
#define IDS_PERMISSION_DENY 38248
#define IDS_PERMISSION_ALLOW_THIS_TIME 38249
#define IDS_PERMISSION_ALLOW_EVERY_VISIT 38250
#define IDS_PERMISSION_ALLOW_WHILE_VISITING 38251
#define IDS_PERMISSION_DONT_ALLOW 38252
#define IDS_PERMISSION_NEVER_ALLOW 38253
#define IDS_PERMISSION_ALLOW_APPROXIMATE_GEO 38254
#define IDS_PERMISSION_ALLOW_PRECISE_GEO 38255
#define IDS_PERMISSION_ALLOW_PRECISE_GEO_DESCRIPTION 38256
#define IDS_PERMISSION_ALLOW_APPROXIMATE_GEO_DESCRIPTION 38257
#define IDS_PERMISSION_ALLOW_PRECISE_GEO_LONG_DESCRIPTION 38258
#define IDS_PERMISSION_ALLOW_APPROXIMATE_GEO_LONG_DESCRIPTION 38259
#define IDS_BLUETOOTH_DEVICE_CHOOSER_PROMPT 38260
#define IDS_BLUETOOTH_DEVICE_CHOOSER_NO_DEVICES_FOUND_PROMPT 38261
#define IDS_BLUETOOTH_DEVICE_CHOOSER_PAIR_BUTTON_TEXT 38262
#define IDS_BLUETOOTH_DEVICE_CHOOSER_SCANNING_LABEL 38263
#define IDS_BLUETOOTH_DEVICE_CHOOSER_SCANNING_LABEL_TOOLTIP 38264
#define IDS_BLUETOOTH_DEVICE_CHOOSER_ADAPTER_OFF 38265
#define IDS_BLUETOOTH_DEVICE_CHOOSER_TURN_ON_BLUETOOTH_LINK_TEXT 38266
#define IDS_BLUETOOTH_DEVICE_CHOOSER_AUTHORIZE_BLUETOOTH_LINK_TEXT 38267
#define IDS_DEVICE_CHOOSER_DEVICE_NAME_WITH_ID 38268
#define IDS_BLUETOOTH_SCANNING_PROMPT 38269
#define IDS_BLUETOOTH_SCANNING_DEVICE_UNKNOWN 38270
#define IDS_BLUETOOTH_SCANNING_PROMPT_NO_DEVICES_FOUND_PROMPT 38271
#define IDS_BLUETOOTH_SCANNING_PROMPT_ALLOW_BUTTON_TEXT 38272
#define IDS_BLUETOOTH_SCANNING_PROMPT_BLOCK_BUTTON_TEXT 38273
#define IDS_DEVICE_CHOOSER_CANCEL_BUTTON_TEXT 38274
#define IDS_DEVICE_CHOOSER_NO_DEVICES_FOUND_PROMPT 38275
#define IDS_USB_DEVICE_CHOOSER_PROMPT 38276
#define IDS_USB_DEVICE_CHOOSER_CONNECT_BUTTON_TEXT 38277
#define IDS_USB_DEVICE_CHOOSER_LOADING_LABEL 38278
#define IDS_USB_DEVICE_CHOOSER_LOADING_LABEL_TOOLTIP 38279
#define IDS_GEOLOCATION_PERMISSION_CHIP 38280
#define IDS_NOTIFICATION_PERMISSIONS_CHIP 38281
#define IDS_MIDI_SYSEX_PERMISSION_CHIP 38282
#define IDS_MEDIA_CAPTURE_AUDIO_ONLY_PERMISSION_CHIP 38283
#define IDS_MEDIA_CAPTURE_VIDEO_ONLY_PERMISSION_CHIP 38284
#define IDS_MEDIA_CAPTURE_VIDEO_AND_AUDIO_PERMISSION_CHIP 38285
#define IDS_CLIPBOARD_PERMISSION_CHIP 38286
#define IDS_SAA_PERMISSION_CHIP 38287
#define IDS_IDLE_DETECTION_PERMISSION_CHIP 38288
#define IDS_KEYBOARD_LOCK_PERMISSION_CHIP 38289
#define IDS_KEYBOARD_AND_POINTER_LOCK_PERMISSION_CHIP 38290
#define IDS_POINTER_LOCK_PERMISSION_CHIP 38291
#define IDS_WEB_APP_INSTALLATION_PERMISSION_CHIP 38292
#define IDS_MOTION_AND_LIGHT_SENSORS_PERMISSION_CHIP 38293
#define IDS_MOTION_SENSORS_PERMISSION_CHIP 38294
#define IDS_AR_PERMISSION_CHIP 38295
#define IDS_PERMISSIONS_AR_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38296
#define IDS_PERMISSIONS_AR_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38297
#define IDS_PERMISSIONS_AR_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38298
#define IDS_VR_PERMISSION_CHIP 38299
#define IDS_PERMISSIONS_VR_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38300
#define IDS_PERMISSIONS_VR_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38301
#define IDS_PERMISSIONS_VR_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38302
#define IDS_HAND_TRACKING_PERMISSION_CHIP 38303
#define IDS_HAND_TRACKING_PERMISSION_BLOCKED_CHIP 38304
#define IDS_PERMISSIONS_HAND_TRACKING_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38305
#define IDS_PERMISSIONS_HAND_TRACKING_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38306
#define IDS_PERMISSIONS_HAND_TRACKING_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38307
#define IDS_GEOLOCATION_PERMISSION_BLOCKED_CHIP 38308
#define IDS_NOTIFICATION_PERMISSIONS_BLOCKED_CHIP 38309
#define IDS_CAPTURED_SURFACE_CONTROL_PERMISSION_CHIP 38310
#define IDS_CAPTURED_SURFACE_CONTROL_PERMISSION_BLOCKED_CHIP 38311
#define IDS_PERMISSIONS_CAPTURED_SURFACE_CONTROL_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38312
#define IDS_PERMISSIONS_CAPTURED_SURFACE_CONTROL_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38313
#define IDS_PERMISSIONS_PERMISSION_ALLOWED_CONFIRMATION 38314
#define IDS_PERMISSIONS_PERMISSION_ALLOWED_ONCE_CONFIRMATION 38315
#define IDS_PERMISSIONS_PERMISSION_NOT_ALLOWED_CONFIRMATION 38316
#define IDS_PERMISSIONS_NOTIFICATION_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38317
#define IDS_PERMISSIONS_NOTIFICATION_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38318
#define IDS_PERMISSIONS_GEOLOCATION_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38319
#define IDS_PERMISSIONS_GEOLOCATION_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38320
#define IDS_PERMISSIONS_GEOLOCATION_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38321
#define IDS_PERMISSIONS_CAMERA_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38322
#define IDS_PERMISSIONS_CAMERA_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38323
#define IDS_PERMISSIONS_CAMERA_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38324
#define IDS_PERMISSIONS_MICROPHONE_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38325
#define IDS_PERMISSIONS_MICROPHONE_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38326
#define IDS_PERMISSIONS_MICROPHONE_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38327
#define IDS_PERMISSIONS_CAMERA_AND_MICROPHONE_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38328
#define IDS_PERMISSIONS_CAMERA_AND_MICROPHONE_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38329
#define IDS_PERMISSIONS_CAMERA_AND_MICROPHONE_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38330
#define IDS_PERMISSIONS_SAA_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38331
#define IDS_PERMISSIONS_SAA_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38332
#define IDS_PERMISSIONS_KEYBOARD_LOCK_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38333
#define IDS_PERMISSIONS_KEYBOARD_LOCK_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38334
#define IDS_PERMISSIONS_POINTER_LOCK_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38335
#define IDS_PERMISSIONS_POINTER_LOCK_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38336
#define IDS_PERMISSIONS_WEB_INSTALL_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38337
#define IDS_PERMISSIONS_WEB_INSTALL_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38338
#define IDS_PERMISSIONS_MOTION_AND_LIGHT_SENSORS_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38339
#define IDS_PERMISSIONS_MOTION_AND_LIGHT_SENSORS_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38340
#define IDS_PERMISSIONS_MOTION_AND_LIGHT_SENSORS_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38341
#define IDS_PERMISSIONS_MOTION_SENSORS_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38342
#define IDS_PERMISSIONS_MOTION_SENSORS_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38343
#define IDS_PERMISSIONS_MOTION_SENSORS_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38344
#define IDS_REQUEST_QUOTA_INFOBAR_TEXT 38348
#define IDS_REQUEST_LARGE_QUOTA_INFOBAR_TEXT 38349
#define IDS_REQUEST_QUOTA_PERMISSION_FRAGMENT 38350
#define IDS_EMBEDDED_PROMPT_ADMIN_BLOCKED 38351
#define IDS_EMBEDDED_PROMPT_ADMIN_ALLOWED 38352
#define IDS_EMBEDDED_PROMPT_PREVIOUSLY_ALLOWED 38353
#define IDS_EMBEDDED_PROMPT_PREVIOUSLY_NOT_ALLOWED 38354
#define IDS_PERMISSION_OFF_FOR_CHROME 38355
#define IDS_PERMISSION_CHROME_NEEDS_PERMISSION 38356
#define IDS_GEOLOCATION_NAME_FRAGMENT 38357
#define IDS_CAMERA_PERMISSION_NAME_FRAGMENT 38358
#define IDS_MICROPHONE_PERMISSION_NAME_FRAGMENT 38359
#define IDS_CAMERA_AND_MICROPHONE_PERMISSION_NAME_FRAGMENT 38360
#define IDS_MACOS_NAME_FRAGMENT 38361
#define IDS_WINDOWS_NAME_FRAGMENT 38362
#define IDS_CHROMEOS_NAME_FRAGMENT 38363
#define IDS_EMBEDDED_PROMPT_OK_LABEL 38365
#define IDS_EMBEDDED_PROMPT_CONTINUE_ALLOWING 38366
#define IDS_EMBEDDED_PROMPT_STOP_ALLOWING 38367
#define IDS_EMBEDDED_PROMPT_OPEN_SYSTEM_SETTINGS 38369
#define IDS_EMBEDDED_PROMPT_CONTINUE_NOT_ALLOWING 38370
#define IDS_PERMISSION_PROMPT_SURVEY_CUSTOM_INVITATION 38371
#define IDS_POLICY_DM_STATUS_SUCCESS 38375
#define IDS_POLICY_DM_STATUS_REQUEST_INVALID 38376
#define IDS_POLICY_DM_STATUS_REQUEST_FAILED 38377
#define IDS_POLICY_DM_STATUS_TEMPORARY_UNAVAILABLE 38378
#define IDS_POLICY_DM_STATUS_HTTP_STATUS_ERROR 38379
#define IDS_POLICY_DM_STATUS_RESPONSE_DECODING_ERROR 38380
#define IDS_POLICY_DM_STATUS_SERVICE_MANAGEMENT_NOT_SUPPORTED 38381
#define IDS_POLICY_DM_STATUS_SERVICE_DEVICE_NOT_FOUND 38382
#define IDS_POLICY_DM_STATUS_SERVICE_MANAGEMENT_TOKEN_INVALID 38383
#define IDS_POLICY_DM_STATUS_SERVICE_ACTIVATION_PENDING 38384
#define IDS_POLICY_DM_STATUS_SERVICE_INVALID_SERIAL_NUMBER 38385
#define IDS_POLICY_DM_STATUS_SERVICE_DEVICE_ID_CONFLICT 38386
#define IDS_POLICY_DM_STATUS_SERVICE_MISSING_LICENSES 38387
#define IDS_POLICY_DM_STATUS_SERVICE_DEPROVISIONED 38388
#define IDS_POLICY_DM_STATUS_SERVICE_POLICY_NOT_FOUND 38389
#define IDS_POLICY_DM_STATUS_UNKNOWN_ERROR 38390
#define IDS_POLICY_DM_STATUS_INVALID_PACKAGED_DEVICE_FOR_KIOSK 38391
#define IDS_POLICY_DM_STATUS_ORG_UNIT_ENROLLMENT_LIMIT_EXCEEDED 38392
#define IDS_POLICY_DM_STATUS_SERVICE_DOMAIN_MISMATCH 38393
#define IDS_POLICY_DM_STATUS_CANNOT_SIGN_REQUEST 38394
#define IDS_POLICY_DM_STATUS_REQUEST_TOO_LARGE 38395
#define IDS_POLICY_DM_STATUS_SERVICE_TOO_MANY_REQUESTS 38396
#define IDS_POLICY_DM_STATUS_SERVICE_DEVICE_NEEDS_RESET 38397
#define IDS_POLICY_DM_STATUS_CONSUMER_ACCOUNT_WITH_PACKAGED_LICENSE 38398
#define IDS_POLICY_DM_STATUS_ENTERPRISE_ACCOUNT_IS_NOT_ELIGIBLE_TO_ENROLL 38399
#define IDS_POLICY_ACTION_BLOCKED_BY_ORGANIZATION 38400
#define IDS_POLICY_ACTION_FORCED_SAVE_TO_CLOUD 38401
#define IDS_POLICY_VALIDATION_OK 38402
#define IDS_POLICY_VALIDATION_BAD_INITIAL_SIGNATURE 38403
#define IDS_POLICY_VALIDATION_BAD_SIGNATURE 38404
#define IDS_POLICY_VALIDATION_ERROR_CODE_PRESENT 38405
#define IDS_POLICY_VALIDATION_PAYLOAD_PARSE_ERROR 38406
#define IDS_POLICY_VALIDATION_WRONG_POLICY_TYPE 38407
#define IDS_POLICY_VALIDATION_WRONG_SETTINGS_ENTITY_ID 38408
#define IDS_POLICY_VALIDATION_BAD_TIMESTAMP 38409
#define IDS_POLICY_VALIDATION_BAD_DM_TOKEN 38410
#define IDS_POLICY_VALIDATION_BAD_DEVICE_ID 38411
#define IDS_POLICY_VALIDATION_BAD_USER 38412
#define IDS_POLICY_VALIDATION_POLICY_PARSE_ERROR 38413
#define IDS_POLICY_VALIDATION_BAD_KEY_VERIFICATION_SIGNATURE 38414
#define IDS_POLICY_VALIDATION_VALUE_WARNING 38415
#define IDS_POLICY_VALIDATION_VALUE_ERROR 38416
#define IDS_POLICY_VALIDATION_UNKNOWN_ERROR 38417
#define IDS_POLICY_STORE_STATUS_OK 38418
#define IDS_POLICY_STORE_STATUS_LOAD_ERROR 38419
#define IDS_POLICY_STORE_STATUS_STORE_ERROR 38420
#define IDS_POLICY_STORE_STATUS_PARSE_ERROR 38421
#define IDS_POLICY_STORE_STATUS_SERIALIZE_ERROR 38422
#define IDS_POLICY_STORE_STATUS_VALIDATION_ERROR 38423
#define IDS_POLICY_STORE_STATUS_BAD_STATE 38424
#define IDS_POLICY_STORE_STATUS_UNKNOWN_ERROR 38425
#define IDS_POLICY_ASSOCIATION_STATE_ACTIVE 38426
#define IDS_POLICY_ASSOCIATION_STATE_UNMANAGED 38427
#define IDS_POLICY_ASSOCIATION_STATE_DEPROVISIONED 38428
#define IDS_POLICY_TYPE_ERROR 38429
#define IDS_POLICY_OUT_OF_RANGE_ERROR 38430
#define IDS_POLICY_VALUE_FORMAT_ERROR 38431
#define IDS_POLICY_INVALID_FILE_EXTENSION_ERROR 38432
#define IDS_POLICY_INVALID_HASH_ERROR 38433
#define IDS_POLICY_INVALID_SELECTION_ERROR 38434
#define IDS_POLICY_PAPER_SIZE_CUSTOM_NO_SIZE_ERROR 38435
#define IDS_POLICY_PAPER_SIZE_NOT_CUSTOM_ERROR 38436
#define IDS_POLICY_INVALID_ACCOUNT_PATTERN_FORMAT_ERROR 38437
#define IDS_POLICY_INVALID_PROTOCOL_ERROR 38438
#define IDS_POLICY_INVALID_ORIGIN_ERROR 38439
#define IDS_POLICY_EMPTY_ORIGIN_LIST_ERROR 38440
#define IDS_POLICY_INVALID_EXTENSION_ID_ERROR 38442
#define IDS_POLICY_INVALID_UPDATE_URL_ERROR 38443
#define IDS_POLICY_URL_PATH_SPECIFIED_ERROR 38444
#define IDS_POLICY_MISSING_VENDOR_ID_ERROR 38445
#define IDS_POLICY_INVALID_NUMBER_OF_URLS_ERROR 38446
#define IDS_POLICY_BRUSCHETTA_UNINSTALLABLE_ERROR 38447
#define IDS_POLICY_CLOUD_SOURCE_ONLY_ERROR 38448
#define IDS_POLICY_CLOUD_USER_ONLY_ERROR 38449
#define IDS_POLICY_CLOUD_MANAGEMENT_ENROLLMENT_ONLY_ERROR 38450
#define IDS_POLICY_DEFAULT_SEARCH_DISABLED 38451
#define IDS_POLICY_NOT_SPECIFIED_ERROR 38452
#define IDS_POLICY_EXTENSION_SETTINGS_ORIGIN_LIMIT_WARNING 38453
#define IDS_POLICY_URL_ALLOW_BLOCK_LIST_MAX_FILTERS_LIMIT_WARNING 38454
#define IDS_POLICY_ERROR_WITH_PATH 38455
#define IDS_POLICY_SCHEMA_VALIDATION_ERROR 38456
#define IDS_POLICY_INVALID_JSON_ERROR 38457
#define IDS_POLICY_INVALID_URL_ERROR 38458
#define IDS_POLICY_URL_NOT_HTTPS_ERROR 38459
#define IDS_POLICY_INVALID_SEARCH_URL_ERROR 38460
#define IDS_POLICY_INVALID_SECURE_DNS_MODE_ERROR 38461
#define IDS_POLICY_SECURE_DNS_TEMPLATES_INVALID_ERROR 38462
#define IDS_POLICY_SECURE_DNS_SALT_INVALID_ERROR 38463
#define IDS_POLICY_SECURE_DNS_SALT_INVALID_SIZE_ERROR 38464
#define IDS_POLICY_SECURE_DNS_TEMPLATES_IRRELEVANT_MODE_ERROR 38465
#define IDS_POLICY_SECURE_DNS_TEMPLATES_INVALID_MODE_ERROR 38466
#define IDS_POLICY_SECURE_DNS_TEMPLATES_UNSET_MODE_ERROR 38467
#define IDS_POLICY_SECURE_DNS_TEMPLATES_NOT_SPECIFIED_ERROR 38468
#define IDS_POLICY_INVALID_PROXY_MODE_ERROR 38469
#define IDS_POLICY_OFF_CWS_URL_ERROR 38471
#define IDS_POLICY_HOMEPAGE_LOCATION_ERROR 38472
#define IDS_POLICY_PROXY_MODE_DISABLED_ERROR 38473
#define IDS_POLICY_PROXY_MODE_AUTO_DETECT_ERROR 38474
#define IDS_POLICY_PROXY_MODE_PAC_URL_ERROR 38475
#define IDS_POLICY_PROXY_MODE_FIXED_SERVERS_ERROR 38476
#define IDS_POLICY_PROXY_MODE_SYSTEM_ERROR 38477
#define IDS_POLICY_PROXY_BOTH_SPECIFIED_ERROR 38478
#define IDS_POLICY_PROXY_NEITHER_SPECIFIED_ERROR 38479
#define IDS_POLICY_PROXY_UNKNOWN_CONDITION 38480
#define IDS_POLICY_PROXY_INVALID_SCHEME_HOST_PORT 38481
#define IDS_POLICY_PROXY_INVALID_PROXY 38482
#define IDS_POLICY_PROXY_INVALID_DESTINATION 38483
#define IDS_POLICY_UNAFFILIATED_USER_ERROR 38484
#define IDS_POLICY_DEVELOPER_TOOLS_EXTENSIONS_CONFLICT_MESSAGE 38485
#define IDS_POLICY_OVERRIDDEN 38486
#define IDS_POLICY_VALUE_DEPRECATED 38487
#define IDS_POLICY_DEPENDENCY_ERROR 38488
#define IDS_POLICY_DEPENDENCY_ERROR_ANY_VALUE 38489
#define IDS_POLICY_IDLE_TIMEOUT_ACTIONS_DEPENDENCY_ERROR 38490
#define IDS_POLICY_USER_IS_NOT_AFFILIATED_ERROR 38491
#define IDS_POLICY_LEVEL_ERROR 38496
#define IDS_POLICY_OK 38497
#define IDS_POLICY_UNSET 38498
#define IDS_POLICY_UNKNOWN 38499
#define IDS_POLICY_PROTO_PARSING_ERROR 38500
#define IDS_POLICY_HEX_COLOR_ERROR 38501
#define IDS_POLICY_SITE_SEARCH_SETTINGS_MAX_PROVIDERS_LIMIT_ERROR 38502
#define IDS_POLICY_SITE_SEARCH_SETTINGS_MAX_FEATURED_PROVIDERS_LIMIT_ERROR 38503
#define IDS_POLICY_SITE_SEARCH_SETTINGS_DUPLICATED_SHORTCUT 38504
#define IDS_SEARCH_POLICY_SETTINGS_SHORTCUT_CONTAINS_SPACE 38505
#define IDS_SEARCH_POLICY_SETTINGS_SHORTCUT_STARTS_WITH_AT 38506
#define IDS_SEARCH_POLICY_SETTINGS_NO_VALID_PROVIDER 38507
#define IDS_SEARCH_POLICY_SETTINGS_SHORTCUT_IS_EMPTY 38508
#define IDS_SEARCH_POLICY_SETTINGS_NAME_IS_EMPTY 38509
#define IDS_SEARCH_POLICY_SETTINGS_URL_IS_EMPTY 38510
#define IDS_SEARCH_POLICY_SETTINGS_URL_DOESNT_SUPPORT_REPLACEMENT 38511
#define IDS_SEARCH_POLICY_SETTINGS_SHORTCUT_EQUALS_DSP_KEYWORD 38512
#define IDS_POLICY_SITE_SEARCH_SETTINGS_SHORTCUT_EQUALS_SEARCH_AGGREGATOR_KEYWORD 38513
#define IDS_SEARCH_POLICY_SETTINGS_URL_NOT_HTTPS 38514
#define IDS_POLICY_DATA_CONTROLS_MUTUALLY_EXCLUSIVE_KEYS 38515
#define IDS_POLICY_DATA_CONTROLS_MUTUALLY_EXCLUSIVE_KEY_SETS 38516
#define IDS_POLICY_DATA_CONTROLS_UNSUPPORTED_CONDITION 38517
#define IDS_POLICY_DATA_CONTROLS_UNSUPPORTED_RESTRICTION 38518
#define IDS_POLICY_DATA_CONTROLS_UNSUPPORTED_LEVEL 38519
#define IDS_POLICY_NTP_SHORTCUTS_MAX_SHORTCUTS_LIMIT_ERROR 38520
#define IDS_POLICY_NTP_SHORTCUTS_NO_VALID_PROVIDER 38521
#define IDS_POLICY_NTP_SHORTCUTS_DUPLICATED_URL 38522
#define IDS_POLICY_NTP_SHORTCUTS_NAME_TOO_LONG 38523
#define IDS_POLICY_NTP_SHORTCUTS_URL_TOO_LONG 38524
#define IDS_POLICY_TITLE 38525
#define IDS_POLICY_FILTER_PLACEHOLDER 38526
#define IDS_POLICY_RELOAD_POLICIES 38527
#define IDS_POLICY_RELOADING_POLICIES 38528
#define IDS_POLICY_RELOAD_POLICIES_DONE 38529
#define IDS_EXPORT_POLICIES_JSON 38530
#define IDS_EXPORT_POLICIES_JSON_DONE 38531
#define IDS_UPLOAD_REPORT 38532
#define IDS_REPORT_UPLOADING 38533
#define IDS_REPORT_UPLOADED 38534
#define IDS_POLICY_STATUS 38535
#define IDS_POLICY_STATUS_DEVICE 38536
#define IDS_POLICY_STATUS_USER 38537
#define IDS_POLICY_STATUS_MACHINE 38538
#define IDS_POLICY_STATUS_ERROR_MANAGED_NO_POLICY 38540
#define IDS_POLICY_STATUS_FLEX_ORG_NO_POLICY 38541
#define IDS_POLICY_LABEL_MACHINE_ENROLLMENT_DOMAIN 38542
#define IDS_POLICY_LABEL_MACHINE_ENROLLMENT_TOKEN 38543
#define IDS_POLICY_LABEL_MACHINE_ENROLLMENT_DEVICE_ID 38544
#define IDS_POLICY_LABEL_MACHINE_ENROLLMENT_MACHINE_NAME 38545
#define IDS_POLICY_LABEL_USERNAME 38546
#define IDS_POLICY_LABEL_GAIA_ID 38547
#define IDS_POLICY_LABEL_CLIENT_ID 38548
#define IDS_POLICY_LABEL_PROFILE_ID 38549
#define IDS_POLICY_LABEL_ASSET_ID 38550
#define IDS_POLICY_LABEL_LOCATION 38551
#define IDS_POLICY_LABEL_DIRECTORY_API_ID 38552
#define IDS_POLICY_LABEL_MANAGED_BY 38553
#define IDS_POLICY_LABEL_TIME_SINCE_LAST_FETCH_ATTEMPT 38554
#define IDS_POLICY_LABEL_TIME_SINCE_LAST_REFRESH 38555
#define IDS_POLICY_LABEL_LAST_CLOUD_REPORT_SENT_TIMESTAMP 38556
#define IDS_POLICY_NOT_SPECIFIED 38557
#define IDS_POLICY_LABEL_PUSH_POLICIES 38558
#define IDS_POLICY_PUSH_POLICIES_ON 38559
#define IDS_POLICY_PUSH_POLICIES_OFF 38560
#define IDS_POLICY_NEVER_FETCHED 38561
#define IDS_POLICY_LABEL_REFRESH_INTERVAL 38562
#define IDS_POLICY_LABEL_CONFLICT 38563
#define IDS_POLICY_LABEL_SUPERSEDING 38564
#define IDS_POLICY_LABEL_CONFLICT_VALUE 38565
#define IDS_POLICY_LABEL_SUPERSEDED_VALUE 38566
#define IDS_POLICY_LABEL_ERROR 38567
#define IDS_POLICY_LABEL_DEPRECATED 38568
#define IDS_POLICY_LABEL_FUTURE 38569
#define IDS_POLICY_LABEL_IGNORED 38570
#define IDS_POLICY_LABEL_VALUE 38571
#define IDS_POLICY_LABEL_VERSION 38572
#define IDS_POLICY_LABEL_STATUS 38573
#define IDS_POLICY_LABEL_INFO 38574
#define IDS_POLICY_LABEL_PRECEDENCE 38575
#define IDS_POLICY_SHOW_UNSET 38576
#define IDS_POLICY_NO_POLICIES_SET 38577
#define IDS_POLICY_HEADER_SCOPE 38578
#define IDS_POLICY_HEADER_LEVEL 38579
#define IDS_POLICY_HEADER_NAMESPACE 38580
#define IDS_POLICY_HEADER_NAME 38581
#define IDS_POLICY_HEADER_VALUE 38582
#define IDS_POLICY_HEADER_STATUS 38583
#define IDS_POLICY_HEADER_SOURCE 38584
#define IDS_POLICY_HEADER_WARNING 38585
#define IDS_POLICY_SHOW_MORE 38586
#define IDS_POLICY_SHOW_LESS 38587
#define IDS_POLICY_LEARN_MORE 38588
#define IDS_POLICY_SCOPE_USER 38589
#define IDS_POLICY_SCOPE_ALL_USERS 38590
#define IDS_POLICY_SCOPE_DEVICE 38591
#define IDS_POLICY_LEVEL_RECOMMENDED 38592
#define IDS_POLICY_LEVEL_MANDATORY 38593
#define IDS_POLICY_SOURCE_ENTERPRISE_DEFAULT 38594
#define IDS_POLICY_SOURCE_DEFAULT 38595
#define IDS_POLICY_SOURCE_COMMAND_LINE 38596
#define IDS_POLICY_SOURCE_CLOUD 38597
#define IDS_POLICY_SOURCE_MERGED 38598
#define IDS_POLICY_SOURCE_CLOUD_FROM_ASH 38599
#define IDS_POLICY_SOURCE_RESTRICTED_MANAGED_GUEST_SESSION_OVERRIDE 38600
#define IDS_POLICY_SOURCE_ACTIVE_DIRECTORY 38601
#define IDS_POLICY_SOURCE_PLATFORM 38602
#define IDS_POLICY_SOURCE_DEVICE_LOCAL_ACCOUNT_OVERRIDE 38603
#define IDS_POLICY_RISK_TAG_FULL_ADMIN_ACCESS 38604
#define IDS_POLICY_RISK_TAG_SYSTEM_SECURITY 38605
#define IDS_POLICY_RISK_TAG_WEBSITE_SHARING 38606
#define IDS_POLICY_RISK_TAG_ADMIN_SHARING 38607
#define IDS_POLICY_RISK_TAG_FILTERING 38608
#define IDS_POLICY_RISK_TAG_LOCAL_DATA_ACCESS 38609
#define IDS_POLICY_RISK_TAG_GOOGLE_SHARING 38610
#define IDS_POLICY_SHOW_EXPANDED_STATUS 38611
#define IDS_POLICY_HIDE_EXPANDED_STATUS 38612
#define IDS_POLICY_LIST_MERGING_WRONG_POLICY_TYPE_SPECIFIED 38613
#define IDS_POLICY_DICTIONARY_MERGING_WRONG_POLICY_TYPE_SPECIFIED 38614
#define IDS_POLICY_DICTIONARY_MERGING_POLICY_NOT_ALLOWED 38615
#define IDS_POLICY_CONFLICT_SAME_VALUE 38616
#define IDS_POLICY_CONFLICT_DIFF_VALUE 38617
#define IDS_POLICY_MIGRATED_OLD_POLICY 38618
#define IDS_POLICY_MIGRATED_NEW_POLICY 38619
#define IDS_POLICY_BLOCKED 38620
#define IDS_POLICY_INVALID 38621
#define IDS_POLICY_IGNORED_BY_GROUP_MERGING 38622
#define IDS_POLICY_INVALID_VALUE 38623
#define IDS_POLICY_IGNORED_MANDATORY_REPORTING_POLICY 38624
#define IDS_POLICY_IGNORED_CHROME_PROFILE 38625
#define IDS_POLICY_IGNORED_UNAFFILIATED 38626
#define IDS_POLICY_IGNORED_EXTENSION 38627
#define IDS_POLICY_PRECEDENCE_PLATFORM_MACHINE 38628
#define IDS_POLICY_PRECEDENCE_PLATFORM_USER 38629
#define IDS_POLICY_PRECEDENCE_CLOUD_MACHINE 38630
#define IDS_POLICY_PRECEDENCE_CLOUD_USER 38631
#define IDS_POLICY_SPELLCHECK_UNKNOWN_LANGUAGE 38632
#define IDS_POLICY_SPELLCHECK_BLOCKLIST_IGNORE 38633
#define IDS_POLICY_DEFAULT_GEO_POLICY_ARC_CONFLICT 38634
#define IDS_POLICY_LABEL_IS_AFFILIATED 38635
#define IDS_POLICY_IS_AFFILIATED_YES 38636
#define IDS_POLICY_IS_AFFILIATED_NO 38637
#define IDS_POLICY_LABEL_IS_OFFHOURS_ACTIVE 38638
#define IDS_POLICY_OFFHOURS_ACTIVE 38639
#define IDS_POLICY_OFFHOURS_NOT_ACTIVE 38640
#define IDS_POLICY_SIGNIN_PROFILE 38641
#define IDS_POLICY_COPY_VALUE 38642
#define IDS_COPY_POLICIES_JSON 38643
#define IDS_COPY_POLICIES_DONE 38644
#define IDS_VIEW_POLICY_LOGS 38645
#define IDS_POLICY_MORE_ACTIONS 38646
#define IDS_POLICY_TABLE_COLUMN_SORT 38647
#define IDS_POLICY_TABLE_COLUMN_SORT_ASCENDING 38648
#define IDS_POLICY_TABLE_COLUMN_SORT_DESCENDING 38649
#define IDS_POLICY_BANNER_PROMOTION_TITLE 38650
#define IDS_POLICY_BANNER_PROMOTION_DESC 38651
#define IDS_POLICY_BANNER_PROMOTION_BTN 38652
#define IDS_DEVTOOLS_BLOCKED_BY_POLICY 38653
#define IDS_DEVTOOLS_NOT_ALLOWED 38654
#define IDS_POLICY_LOGS_TITLE 38655
#define IDS_VERSION_INFO 38656
#define IDS_EXPORT_POLICY_LOGS_JSON 38657
#define IDS_REFRESH_POLICY_LOGS 38658
#define IDS_POLICY_TEST_TITLE 38659
#define IDS_POLICY_TEST_RESTART_AND_APPLY 38660
#define IDS_POLICY_TEST_APPLY 38661
#define IDS_POLICY_TEST_IMPORT 38662
#define IDS_POLICY_TEST_DESC 38663
#define IDS_POLICY_TEST_REVERT 38664
#define IDS_POLICY_TEST_TABLE_SCOPE 38665
#define IDS_POLICY_TEST_ADD 38666
#define IDS_POLICY_SELECT_NAME 38667
#define IDS_POLICY_TEST_TABLE_PRESET 38668
#define IDS_LOCAL_TEST_POLICIES_ENABLED 38669
#define IDS_POLICY_TEST_PRESET_CUSTOM 38670
#define IDS_POLICY_TEST_PRESET_LOCAL_MACHINE 38671
#define IDS_POLICY_TEST_PRESET_CLOUD_ACCOUNT 38672
#define IDS_POLICY_TEST_USER_AFFILIATED 38673
#define IDS_CHROME_URLS_DISABLED_PAGE_HEADER 38674
#define IDS_CHROME_URLS_DISABLED_PAGE_TITLE 38675
#define IDS_CHROME_URLS_DISABLED_PAGE_MESSAGE 38676
#define IDS_POLICY_DLP_CLIPBOARD_BLOCKED_ON_PASTE 38677
#define IDS_POLICY_DLP_CLIPBOARD_BLOCKED_ON_COPY_VM 38678
#define IDS_POLICY_DLP_CLIPBOARD_BLOCK_TOAST_BUTTON 38679
#define IDS_POLICY_DLP_ANDROID_APPS 38680
#define IDS_POLICY_DLP_CLIPBOARD_BLOCK_DISMISS_BUTTON 38681
#define IDS_POLICY_DLP_CLIPBOARD_WARN_ON_PASTE 38682
#define IDS_POLICY_DLP_CLIPBOARD_WARN_PROCEED_BUTTON 38683
#define IDS_POLICY_DLP_CLIPBOARD_WARN_ON_COPY_VM 38684
#define IDS_POLICY_DLP_PRINTING_BLOCKED_TITLE 38685
#define IDS_POLICY_DLP_PRINTING_BLOCKED_MESSAGE 38686
#define IDS_POLICY_DLP_PRINTING_WARN_TITLE 38687
#define IDS_POLICY_DLP_PRINTING_WARN_MESSAGE 38688
#define IDS_POLICY_DLP_PRINTING_WARN_CONTINUE_BUTTON 38689
#define IDS_POLICY_DLP_SCREEN_SHARE_BLOCKED_TITLE 38690
#define IDS_POLICY_DLP_SCREEN_SHARE_BLOCKED_MESSAGE 38691
#define IDS_POLICY_DLP_SCREEN_SHARE_PAUSED_TITLE 38692
#define IDS_POLICY_DLP_SCREEN_SHARE_PAUSED_MESSAGE 38693
#define IDS_POLICY_DLP_SCREEN_SHARE_RESUMED_TITLE 38694
#define IDS_POLICY_DLP_SCREEN_SHARE_RESUMED_MESSAGE 38695
#define IDS_POLICY_DLP_SCREEN_CAPTURE_DISABLED_TITLE 38696
#define IDS_POLICY_DLP_SCREEN_CAPTURE_DISABLED_MESSAGE 38697
#define IDS_POLICY_DLP_VIDEO_CAPTURE_STOPPED_TITLE 38698
#define IDS_POLICY_DLP_VIDEO_CAPTURE_STOPPED_MESSAGE 38699
#define IDS_POLICY_DLP_SCREEN_SHARE_WARN_TITLE 38700
#define IDS_POLICY_DLP_SCREEN_SHARE_WARN_MESSAGE 38701
#define IDS_POLICY_DLP_SCREEN_SHARE_WARN_CONTINUE_BUTTON 38702
#define IDS_POLICY_DLP_SCREEN_CAPTURE_WARN_TITLE 38703
#define IDS_POLICY_DLP_SCREEN_CAPTURE_WARN_MESSAGE 38704
#define IDS_POLICY_DLP_SCREEN_CAPTURE_WARN_CONTINUE_BUTTON 38705
#define IDS_POLICY_DLP_VIDEO_CAPTURE_WARN_TITLE 38706
#define IDS_POLICY_DLP_VIDEO_CAPTURE_WARN_MESSAGE 38707
#define IDS_POLICY_DLP_VIDEO_CAPTURE_WARN_CONTINUE_BUTTON 38708
#define IDS_POLICY_DLP_VIDEO_CAPTURE_WARN_CANCEL_BUTTON 38709
#define IDS_POLICY_DLP_FILES_DOWNLOAD_WARN_TITLE 38710
#define IDS_POLICY_DLP_FILES_TRANSFER_WARN_TITLE 38711
#define IDS_POLICY_DLP_FILES_UPLOAD_WARN_TITLE 38712
#define IDS_POLICY_DLP_FILES_MOVE_WARN_TITLE 38713
#define IDS_POLICY_DLP_FILES_COPY_WARN_TITLE 38714
#define IDS_POLICY_DLP_FILES_OPEN_WARN_TITLE 38715
#define IDS_POLICY_DLP_FILES_DOWNLOAD_REVIEW_TITLE 38716
#define IDS_POLICY_DLP_FILES_TRANSFER_REVIEW_TITLE 38717
#define IDS_POLICY_DLP_FILES_UPLOAD_REVIEW_TITLE 38718
#define IDS_POLICY_DLP_FILES_MOVE_REVIEW_TITLE 38719
#define IDS_POLICY_DLP_FILES_COPY_REVIEW_TITLE 38720
#define IDS_POLICY_DLP_FILES_OPEN_REVIEW_TITLE 38721
#define IDS_POLICY_DLP_FILES_DOWNLOAD_WARN_MESSAGE 38722
#define IDS_POLICY_DLP_FILES_TRANSFER_WARN_MESSAGE 38723
#define IDS_POLICY_DLP_FILES_UPLOAD_WARN_MESSAGE 38724
#define IDS_POLICY_DLP_FILES_MOVE_WARN_MESSAGE 38725
#define IDS_POLICY_DLP_FILES_COPY_WARN_MESSAGE 38726
#define IDS_POLICY_DLP_FILES_OPEN_WARN_MESSAGE 38727
#define IDS_POLICY_DLP_FILES_WARN_MESSAGE 38728
#define IDS_POLICY_DLP_FILES_DOWNLOAD_WARN_CONTINUE_BUTTON 38729
#define IDS_POLICY_DLP_FILES_TRANSFER_WARN_CONTINUE_BUTTON 38730
#define IDS_POLICY_DLP_FILES_UPLOAD_WARN_CONTINUE_BUTTON 38731
#define IDS_POLICY_DLP_FILES_MOVE_WARN_CONTINUE_BUTTON 38732
#define IDS_POLICY_DLP_FILES_COPY_WARN_CONTINUE_BUTTON 38733
#define IDS_POLICY_DLP_FILES_OPEN_WARN_CONTINUE_BUTTON 38734
#define IDS_POLICY_DLP_FILES_DESTINATION_REMOVABLE_STORAGE 38735
#define IDS_POLICY_DLP_FILES_REVIEW_BUTTON 38736
#define IDS_POLICY_DLP_FILES_DISMISS_BUTTON 38737
#define IDS_POLICY_DLP_FILES_OK_BUTTON 38738
#define IDS_POLICY_DLP_WARN_CANCEL_BUTTON 38739
#define IDS_POLICY_DLP_CLIPBOARD_BUBBLE_MESSAGE 38740
#define IDS_POLICY_DLP_FROM_YOUR_ADMIN_MESSAGE 38741
#define IDS_POLICY_DLP_FILES_DOWNLOAD_BLOCK_TITLE 38742
#define IDS_POLICY_DLP_FILES_DOWNLOAD_BLOCK_MESSAGE 38743
#define IDS_POLICY_DLP_FILES_UPLOAD_BLOCK_TITLE 38744
#define IDS_POLICY_DLP_FILES_UPLOAD_BLOCK_MESSAGE 38745
#define IDS_POLICY_DLP_FILES_OPEN_BLOCK_TITLE 38746
#define IDS_POLICY_DLP_FILES_OPEN_BLOCK_MESSAGE 38747
#define IDS_POLICY_DLP_FILES_DOWNLOAD_BLOCKED_TITLE 38748
#define IDS_POLICY_DLP_FILES_TRANSFER_BLOCKED_TITLE 38749
#define IDS_POLICY_DLP_FILES_UPLOAD_BLOCKED_TITLE 38750
#define IDS_POLICY_DLP_FILES_MOVE_BLOCKED_TITLE 38751
#define IDS_POLICY_DLP_FILES_COPY_BLOCKED_TITLE 38752
#define IDS_POLICY_DLP_FILES_OPEN_BLOCKED_TITLE 38753
#define IDS_POLICY_DLP_FILES_POLICY_BLOCK_SINGLE_FILE_MESSAGE 38754
#define IDS_POLICY_DLP_FILES_POLICY_BLOCK_MESSAGE 38755
#define IDS_POLICY_DLP_FILES_CONTENT_BLOCK_SINGLE_FILE_MESSAGE 38756
#define IDS_POLICY_DLP_FILES_CONTENT_BLOCK_MESSAGE 38757
#define IDS_POLICY_DLP_FILES_BLOCK_MESSAGE 38758
#define IDS_POLICY_DLP_FILES_DOWNLOAD_JUSTIFICATION_LABEL 38759
#define IDS_POLICY_DLP_FILES_UPLOAD_JUSTIFICATION_LABEL 38760
#define IDS_POLICY_DLP_FILES_COPY_JUSTIFICATION_LABEL 38761
#define IDS_POLICY_DLP_FILES_MOVE_JUSTIFICATION_LABEL 38762
#define IDS_POLICY_DLP_FILES_OPEN_JUSTIFICATION_LABEL 38763
#define IDS_POLICY_DLP_FILES_TRANSFER_JUSTIFICATION_LABEL 38764
#define IDS_POLICY_DLP_FILES_DOWNLOAD_TIMEOUT_TITLE 38765
#define IDS_POLICY_DLP_FILES_TRANSFER_TIMEOUT_TITLE 38766
#define IDS_POLICY_DLP_FILES_UPLOAD_TIMEOUT_TITLE 38767
#define IDS_POLICY_DLP_FILES_MOVE_TIMEOUT_TITLE 38768
#define IDS_POLICY_DLP_FILES_COPY_TIMEOUT_TITLE 38769
#define IDS_POLICY_DLP_FILES_OPEN_TIMEOUT_TITLE 38770
#define IDS_POLICY_DLP_FILES_DOWNLOAD_TIMEOUT_MESSAGE 38771
#define IDS_POLICY_DLP_FILES_TRANSFER_TIMEOUT_MESSAGE 38772
#define IDS_POLICY_DLP_FILES_UPLOAD_TIMEOUT_MESSAGE 38773
#define IDS_POLICY_DLP_FILES_MOVE_TIMEOUT_MESSAGE 38774
#define IDS_POLICY_DLP_FILES_COPY_TIMEOUT_MESSAGE 38775
#define IDS_POLICY_DLP_FILES_OPEN_TIMEOUT_MESSAGE 38776
#define IDS_POLICY_DLP_FILES_LEARN_MORE_ABOUT_DATA_CONTROLS_ACCESSIBLE_NAME 38777
#define IDS_POLICY_DLP_FILES_LEARN_MORE_ABOUT_MALWARE_PROTECTION_ACCESSIBLE_NAME 38778
#define IDS_POLICY_DLP_FILES_LEARN_MORE_ABOUT_SENSITIVE_DATA_PROTECTION_ACCESSIBLE_NAME 38779
#define IDS_POLICY_DLP_FILES_JUSTIFICATION_TEXTAREA_ACCESSIBLE_DESCRIPTION 38780
#define IDS_POLICY_DEVICE_SCHEDULED_REBOOT_TITLE 38781
#define IDS_POLICY_DEVICE_SCHEDULED_REBOOT_MESSAGE 38782
#define IDS_POLICY_REBOOT_BUTTON 38783
#define IDS_POLICY_DEVICE_SCHEDULED_REBOOT_DIALOG_MESSAGE 38784
#define IDS_REBOOT_SCHEDULED_TITLE_MINUTES 38785
#define IDS_REBOOT_SCHEDULED_TITLE_SECONDS 38786
#define IDS_POLICY_DEVICE_POST_REBOOT_TITLE 38787
#define IDS_POLICY_BROWSING_DATA_DEPENDENCY_APPLIED_INFO 38788
#define IDS_POLICY_BROWSING_DATA_PLATFORM_UNSUPPORTED 38789
#define IDS_POLICY_NOT_SUPPORTED_AS_USER_POLICY_ON_IOS 38790
#define IDS_POLICY_GEN_AI_DEFAULT_SETTINGS_CONTROL_MESSAGE 38791
#define IDS_POLICY_GEN_AI_DEFAULT_SETTINGS_NO_CONTROL_MESSAGE 38792
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_DISPLAY_SOURCE 38793
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_TITLE_PHOTO 38794
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_TITLE_VIDEO 38795
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_TITLE_SCAN 38796
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_MESSAGE_PHOTO 38797
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_MESSAGE_VIDEO 38798
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_MESSAGE_SCAN 38799
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_BUTTON 38800
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_CANCEL_BUTTON 38801
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_DISPLAY_SOURCE 38802
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_CANCEL_BUTTON 38803
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_TITLE 38804
#define IDS_POLICY_SKYVAULT_CAMERA_MULTI_UPLOAD_TITLE 38805
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_ONEDRIVE_MESSAGE 38806
#define IDS_POLICY_SKYVAULT_CAMERA_MULTI_UPLOAD_ONEDRIVE_MESSAGE 38807
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_GOOGLE_DRIVE_MESSAGE 38808
#define IDS_POLICY_SKYVAULT_CAMERA_MULTI_UPLOAD_GOOGLE_DRIVE_MESSAGE 38809
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_TITLE 38810
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_MESSAGE 38811
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_SKIP_CHECKBOX 38812
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_CANCEL_BUTTON 38813
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_CLOSE_BUTTON 38814
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_DONE_TITLE_ONEDRIVE 38815
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_DONE_TITLE_ONEDRIVE 38816
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_DONE_TITLE_ONEDRIVE 38817
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_DONE_TITLE_GOOGLE_DRIVE 38818
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_DONE_TITLE_GOOGLE_DRIVE 38819
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_DONE_TITLE_GOOGLE_DRIVE 38820
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_DONE_MESSAGE 38821
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_DONE_EDIT_BUTTON 38822
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_DONE_DELETE_BUTTON 38823
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_ERROR_TITLE 38824
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_ERROR_MESSAGE 38825
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_ERROR_RETAKE_BUTTON 38826
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_ERROR_TITLE 38827
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_ERROR_MESSAGE 38828
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_ERROR_RETAKE_BUTTON 38829
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_ERROR_TITLE 38830
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_ERROR_MESSAGE 38831
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_ERROR_RETAKE_BUTTON 38832
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_ERROR_DISMISS_BUTTON 38833
#define IDS_POLICY_SKYVAULT_DOWNLOAD_SIGN_IN_TITLE 38834
#define IDS_POLICY_SKYVAULT_DOWNLOAD_SIGN_IN_BUTTON 38835
#define IDS_POLICY_SKYVAULT_DOWNLOAD_SIGN_IN_CANCEL_BUTTON 38836
#define IDS_POLICY_SKYVAULT_DOWNLOAD_SIGN_IN_DISPLAY_SOURCE 38837
#define IDS_POLICY_SKYVAULT_MIGRATION_BANNER 38838
#define IDS_POLICY_SKYVAULT_MISCONFIGURED_POLICY_MESSAGE 38839
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_UPLOAD_TITLE 38840
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_RECORDING_UPLOAD_TITLE 38841
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_UPLOAD_ONEDRIVE_MESSAGE 38842
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_UPLOAD_CANCEL_BUTTON 38843
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_SIGN_IN_TITLE 38844
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_SIGN_IN_BUTTON 38845
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_SIGN_IN_CANCEL_BUTTON 38846
#define IDS_POLICY_SKYVAULT_CLOUD_PROVIDER_GOOGLE_DRIVE 38847
#define IDS_POLICY_SKYVAULT_CLOUD_PROVIDER_ONEDRIVE 38848
#define IDS_POLICY_SKYVAULT_MIGRATION_PROGRESS_TITLE 38849
#define IDS_POLICY_SKYVAULT_MIGRATION_PROGRESS_MESSAGE 38850
#define IDS_POLICY_SKYVAULT_MIGRATION_COMPLETED_TITLE 38851
#define IDS_POLICY_SKYVAULT_MIGRATION_COMPLETED_MESSAGE 38852
#define IDS_POLICY_SKYVAULT_MIGRATION_COMPLETED_BUTTON 38853
#define IDS_POLICY_SKYVAULT_MIGRATION_CONFIG_ERROR_TITLE 38854
#define IDS_POLICY_SKYVAULT_MIGRATION_CONFIG_ERROR_MESSAGE 38855
#define IDS_POLICY_SKYVAULT_MIGRATION_ERROR_TITLE 38856
#define IDS_POLICY_SKYVAULT_MIGRATION_ERROR_MESSAGE 38857
#define IDS_POLICY_SKYVAULT_MIGRATION_ERROR_BUTTON 38858
#define IDS_POLICY_SKYVAULT_MIGRATION_SIGN_IN_TITLE 38859
#define IDS_POLICY_SKYVAULT_MIGRATION_SIGN_IN_MESSAGE 38860
#define IDS_POLICY_SKYVAULT_MIGRATION_SIGN_IN_BUTTON 38861
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_TITLE_HOURS 38862
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_TITLE_HOUR 38863
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_TITLE_MINUTES 38864
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_TITLE_MINUTE 38865
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_START_MESSAGE 38866
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_START_ON_MESSAGE 38867
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_DONE_MESSAGE 38868
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_NOW_BUTTON 38869
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_IN_HOURS_BUTTON 38870
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_IN_MINUTES_BUTTON 38871
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_TITLE_HOURS 38872
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_TITLE_HOUR 38873
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_TITLE_MINUTES 38874
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_TITLE_MINUTE 38875
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_START_MESSAGE 38876
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_STORE_MESSAGE 38877
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_DELETE_NOW_BUTTON 38878
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_DELETE_IN_HOURS_BUTTON 38879
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_DELETE_IN_MINUTES_BUTTON 38880
#define IDS_POLICY_SKYVAULT_DELETION_COMPLETED_TITLE 38881
#define IDS_POLICY_SKYVAULT_DELETION_COMPLETED_MESSAGE 38882
#define IDS_POLICY_SKYVAULT_DELETION_BANNER 38883
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_NO_SPACE 38884
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_FILE_NOT_EXIST 38885
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_ODFS_SIGN_IN 38886
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_NO_INTERNET 38887
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_GENERIC 38888
#define PRINT_PREVIEW_MEDIA_ASME_F_28X40IN 38889
#define PRINT_PREVIEW_MEDIA_ISO_2A0_1189X1682MM 38890
#define PRINT_PREVIEW_MEDIA_ISO_A0_841X1189MM 38891
#define PRINT_PREVIEW_MEDIA_ISO_A0X3_1189X2523MM 38892
#define PRINT_PREVIEW_MEDIA_ISO_A10_26X37MM 38893
#define PRINT_PREVIEW_MEDIA_ISO_A1_594X841MM 38894
#define PRINT_PREVIEW_MEDIA_ISO_A1X3_841X1783MM 38895
#define PRINT_PREVIEW_MEDIA_ISO_A1X4_841X2378MM 38896
#define PRINT_PREVIEW_MEDIA_ISO_A2_420X594MM 38897
#define PRINT_PREVIEW_MEDIA_ISO_A2X3_594X1261MM 38898
#define PRINT_PREVIEW_MEDIA_ISO_A2X4_594X1682MM 38899
#define PRINT_PREVIEW_MEDIA_ISO_A2X5_594X2102MM 38900
#define PRINT_PREVIEW_MEDIA_ISO_A3_297X420MM 38901
#define PRINT_PREVIEW_MEDIA_ISO_A3_EXTRA_322X445MM 38902
#define PRINT_PREVIEW_MEDIA_ISO_A3X3_420X891MM 38903
#define PRINT_PREVIEW_MEDIA_ISO_A3X4_420X1189MM 38904
#define PRINT_PREVIEW_MEDIA_ISO_A3X5_420X1486MM 38905
#define PRINT_PREVIEW_MEDIA_ISO_A3X6_420X1783MM 38906
#define PRINT_PREVIEW_MEDIA_ISO_A3X7_420X2080MM 38907
#define PRINT_PREVIEW_MEDIA_ISO_A4_210X297MM 38908
#define PRINT_PREVIEW_MEDIA_ISO_A4_EXTRA_235_5X322_3MM 38909
#define PRINT_PREVIEW_MEDIA_ISO_A4_TAB_225X297MM 38910
#define PRINT_PREVIEW_MEDIA_ISO_A4X3_297X630MM 38911
#define PRINT_PREVIEW_MEDIA_ISO_A4X4_297X841MM 38912
#define PRINT_PREVIEW_MEDIA_ISO_A4X5_297X1051MM 38913
#define PRINT_PREVIEW_MEDIA_ISO_A4X6_297X1261MM 38914
#define PRINT_PREVIEW_MEDIA_ISO_A4X7_297X1471MM 38915
#define PRINT_PREVIEW_MEDIA_ISO_A4X8_297X1682MM 38916
#define PRINT_PREVIEW_MEDIA_ISO_A4X9_297X1892MM 38917
#define PRINT_PREVIEW_MEDIA_ISO_A5_148X210MM 38918
#define PRINT_PREVIEW_MEDIA_ISO_A5_EXTRA_174X235MM 38919
#define PRINT_PREVIEW_MEDIA_ISO_A6_105X148MM 38920
#define PRINT_PREVIEW_MEDIA_ISO_A7_74X105MM 38921
#define PRINT_PREVIEW_MEDIA_ISO_A8_52X74MM 38922
#define PRINT_PREVIEW_MEDIA_ISO_A9_37X52MM 38923
#define PRINT_PREVIEW_MEDIA_ISO_B0_1000X1414MM 38924
#define PRINT_PREVIEW_MEDIA_ISO_B10_31X44MM 38925
#define PRINT_PREVIEW_MEDIA_ISO_B1_707X1000MM 38926
#define PRINT_PREVIEW_MEDIA_ISO_B2_500X707MM 38927
#define PRINT_PREVIEW_MEDIA_ISO_B3_353X500MM 38928
#define PRINT_PREVIEW_MEDIA_ISO_B4_250X353MM 38929
#define PRINT_PREVIEW_MEDIA_ISO_B5_176X250MM 38930
#define PRINT_PREVIEW_MEDIA_ISO_B5_EXTRA_201X276MM 38931
#define PRINT_PREVIEW_MEDIA_ISO_B6C4_125X324MM 38932
#define PRINT_PREVIEW_MEDIA_ISO_B6_125X176MM 38933
#define PRINT_PREVIEW_MEDIA_ISO_B7_88X125MM 38934
#define PRINT_PREVIEW_MEDIA_ISO_B8_62X88MM 38935
#define PRINT_PREVIEW_MEDIA_ISO_B9_44X62MM 38936
#define PRINT_PREVIEW_MEDIA_ISO_C0_917X1297MM 38937
#define PRINT_PREVIEW_MEDIA_ISO_C10_28X40MM 38938
#define PRINT_PREVIEW_MEDIA_ISO_C1_648X917MM 38939
#define PRINT_PREVIEW_MEDIA_ISO_C2_458X648MM 38940
#define PRINT_PREVIEW_MEDIA_ISO_C3_324X458MM 38941
#define PRINT_PREVIEW_MEDIA_ISO_C4_229X324MM 38942
#define PRINT_PREVIEW_MEDIA_ISO_C5_162X229MM 38943
#define PRINT_PREVIEW_MEDIA_ISO_C6C5_114X229MM 38944
#define PRINT_PREVIEW_MEDIA_ISO_C6_114X162MM 38945
#define PRINT_PREVIEW_MEDIA_ISO_C7C6_81X162MM 38946
#define PRINT_PREVIEW_MEDIA_ISO_C7_81X114MM 38947
#define PRINT_PREVIEW_MEDIA_ISO_C8_57X81MM 38948
#define PRINT_PREVIEW_MEDIA_ISO_C9_40X57MM 38949
#define PRINT_PREVIEW_MEDIA_ISO_DL_110X220MM 38950
#define PRINT_PREVIEW_MEDIA_ISO_ID_1_53_98X85_6MM 38951
#define PRINT_PREVIEW_MEDIA_ISO_RA0_860X1220MM 38952
#define PRINT_PREVIEW_MEDIA_ISO_RA1_610X860MM 38953
#define PRINT_PREVIEW_MEDIA_ISO_RA2_430X610MM 38954
#define PRINT_PREVIEW_MEDIA_ISO_RA3_305X430MM 38955
#define PRINT_PREVIEW_MEDIA_ISO_RA4_215X305MM 38956
#define PRINT_PREVIEW_MEDIA_ISO_SRA0_900X1280MM 38957
#define PRINT_PREVIEW_MEDIA_ISO_SRA1_640X900MM 38958
#define PRINT_PREVIEW_MEDIA_ISO_SRA2_450X640MM 38959
#define PRINT_PREVIEW_MEDIA_ISO_SRA3_320X450MM 38960
#define PRINT_PREVIEW_MEDIA_ISO_SRA4_225X320MM 38961
#define PRINT_PREVIEW_MEDIA_JIS_B0_1030X1456MM 38962
#define PRINT_PREVIEW_MEDIA_JIS_B1_728X1030MM 38963
#define PRINT_PREVIEW_MEDIA_JIS_B2_515X728MM 38964
#define PRINT_PREVIEW_MEDIA_JIS_B3_364X515MM 38965
#define PRINT_PREVIEW_MEDIA_JIS_B4_257X364MM 38966
#define PRINT_PREVIEW_MEDIA_JIS_B5_182X257MM 38967
#define PRINT_PREVIEW_MEDIA_JIS_B6_128X182MM 38968
#define PRINT_PREVIEW_MEDIA_JIS_B7_91X128MM 38969
#define PRINT_PREVIEW_MEDIA_JIS_B8_64X91MM 38970
#define PRINT_PREVIEW_MEDIA_JIS_B9_45X64MM 38971
#define PRINT_PREVIEW_MEDIA_JIS_B10_32X45MM 38972
#define PRINT_PREVIEW_MEDIA_JIS_EXEC_216X330MM 38973
#define PRINT_PREVIEW_MEDIA_JPN_CHOU2_111_1X146MM 38974
#define PRINT_PREVIEW_MEDIA_JPN_CHOU3_120X235MM 38975
#define PRINT_PREVIEW_MEDIA_JPN_CHOU4_90X205MM 38976
#define PRINT_PREVIEW_MEDIA_JPN_CHOU40_90X225MM 38977
#define PRINT_PREVIEW_MEDIA_JPN_HAGAKI_100X148MM 38978
#define PRINT_PREVIEW_MEDIA_JPN_KAHU_240X322_1MM 38979
#define PRINT_PREVIEW_MEDIA_JPN_KAKU1_270X382MM 38980
#define PRINT_PREVIEW_MEDIA_JPN_KAKU2_240X332MM 38981
#define PRINT_PREVIEW_MEDIA_JPN_KAKU3_216X277MM 38982
#define PRINT_PREVIEW_MEDIA_JPN_KAKU4_197X267MM 38983
#define PRINT_PREVIEW_MEDIA_JPN_KAKU5_190X240MM 38984
#define PRINT_PREVIEW_MEDIA_JPN_KAKU7_142X205MM 38985
#define PRINT_PREVIEW_MEDIA_JPN_KAKU8_119X197MM 38986
#define PRINT_PREVIEW_MEDIA_JPN_OUFUKU_148X200MM 38987
#define PRINT_PREVIEW_MEDIA_JPN_YOU4_105X235MM 38988
#define PRINT_PREVIEW_MEDIA_JPN_YOU6_98X190MM 38989
#define PRINT_PREVIEW_MEDIA_NA_10X11_10X11IN 38990
#define PRINT_PREVIEW_MEDIA_NA_10X13_10X13IN 38991
#define PRINT_PREVIEW_MEDIA_NA_10X14_10X14IN 38992
#define PRINT_PREVIEW_MEDIA_NA_10X15_10X15IN 38993
#define PRINT_PREVIEW_MEDIA_NA_11X12_11X12IN 38994
#define PRINT_PREVIEW_MEDIA_NA_11X15_11X15IN 38995
#define PRINT_PREVIEW_MEDIA_NA_12X19_12X19IN 38996
#define PRINT_PREVIEW_MEDIA_NA_5X7_5X7IN 38997
#define PRINT_PREVIEW_MEDIA_NA_6X9_6X9IN 38998
#define PRINT_PREVIEW_MEDIA_NA_7X9_7X9IN 38999
#define PRINT_PREVIEW_MEDIA_NA_9X11_9X11IN 39000
#define PRINT_PREVIEW_MEDIA_NA_A2_4_375X5_75IN 39001
#define PRINT_PREVIEW_MEDIA_NA_ARCH_A_9X12IN 39002
#define PRINT_PREVIEW_MEDIA_NA_ARCH_B_12X18IN 39003
#define PRINT_PREVIEW_MEDIA_NA_ARCH_C_18X24IN 39004
#define PRINT_PREVIEW_MEDIA_NA_ARCH_D_24X36IN 39005
#define PRINT_PREVIEW_MEDIA_NA_ARCH_E_36X48IN 39006
#define PRINT_PREVIEW_MEDIA_NA_ARCH_E2_26X38IN 39007
#define PRINT_PREVIEW_MEDIA_NA_ARCH_E3_27X39IN 39008
#define PRINT_PREVIEW_MEDIA_NA_B_PLUS_12X19_17IN 39009
#define PRINT_PREVIEW_MEDIA_NA_C5_6_5X9_5IN 39010
#define PRINT_PREVIEW_MEDIA_NA_C_17X22IN 39011
#define PRINT_PREVIEW_MEDIA_NA_D_22X34IN 39012
#define PRINT_PREVIEW_MEDIA_NA_EDP_11X14IN 39013
#define PRINT_PREVIEW_MEDIA_NA_EUR_EDP_12X14IN 39014
#define PRINT_PREVIEW_MEDIA_NA_E_34X44IN 39015
#define PRINT_PREVIEW_MEDIA_NA_EXECUTIVE_7_25X10_5IN 39016
#define PRINT_PREVIEW_MEDIA_NA_FANFOLD_EUR_8_5X12IN 39017
#define PRINT_PREVIEW_MEDIA_NA_FANFOLD_US_11X14_875IN 39018
#define PRINT_PREVIEW_MEDIA_NA_FOOLSCAP_8_5X13IN 39019
#define PRINT_PREVIEW_MEDIA_NA_F_44X68IN 39020
#define PRINT_PREVIEW_MEDIA_NA_GOVT_LEGAL_8X13IN 39021
#define PRINT_PREVIEW_MEDIA_NA_GOVT_LETTER_8X10IN 39022
#define PRINT_PREVIEW_MEDIA_NA_INDEX_3X5_3X5IN 39023
#define PRINT_PREVIEW_MEDIA_NA_INDEX_4X6_4X6IN 39024
#define PRINT_PREVIEW_MEDIA_NA_INDEX_4X6_EXT_6X8IN 39025
#define PRINT_PREVIEW_MEDIA_NA_INDEX_5X8_5X8IN 39026
#define PRINT_PREVIEW_MEDIA_NA_INVOICE_5_5X8_5IN 39027
#define PRINT_PREVIEW_MEDIA_NA_LEDGER_11X17IN 39028
#define PRINT_PREVIEW_MEDIA_NA_LEGAL_8_5X14IN 39029
#define PRINT_PREVIEW_MEDIA_NA_LEGAL_EXTRA_9_5X15IN 39030
#define PRINT_PREVIEW_MEDIA_NA_LETTER_8_5X11IN 39031
#define PRINT_PREVIEW_MEDIA_NA_LETTER_EXTRA_9_5X12IN 39032
#define PRINT_PREVIEW_MEDIA_NA_LETTER_PLUS_8_5X12_69IN 39033
#define PRINT_PREVIEW_MEDIA_NA_MONARCH_3_875X7_5IN 39034
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_9_3_875X8_875IN 39035
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_10_4_125X9_5IN 39036
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_11_4_5X10_375IN 39037
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_12_4_75X11IN 39038
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_14_5X11_5IN 39039
#define PRINT_PREVIEW_MEDIA_NA_OFICIO_8_5X13_4IN 39040
#define PRINT_PREVIEW_MEDIA_NA_PERSONAL_3_625X6_5IN 39041
#define PRINT_PREVIEW_MEDIA_NA_QUARTO_8_5X10_83IN 39042
#define PRINT_PREVIEW_MEDIA_NA_SUPER_A_8_94X14IN 39043
#define PRINT_PREVIEW_MEDIA_NA_SUPER_B_13X19IN 39044
#define PRINT_PREVIEW_MEDIA_NA_WIDE_FORMAT_30X42IN 39045
#define PRINT_PREVIEW_MEDIA_OE_12X16_12X16IN 39046
#define PRINT_PREVIEW_MEDIA_OE_14X17_14X17IN 39047
#define PRINT_PREVIEW_MEDIA_OE_18X22_18X22IN 39048
#define PRINT_PREVIEW_MEDIA_OE_A2PLUS_17X24IN 39049
#define PRINT_PREVIEW_MEDIA_OE_BUSINESS_CARD_2X3_5IN 39050
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_10R_10X12IN 39051
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_12R_12X15IN 39052
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_14X18_14X18IN 39053
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_16R_16X20IN 39054
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_20R_20X24IN 39055
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_22R_22X29_5IN 39056
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_22X28_22X28IN 39057
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_24R_24X31_5IN 39058
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_24X30_24X30IN 39059
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_30R_30X40IN 39060
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_L_3_5X5IN 39061
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_S8R_8X12IN 39062
#define PRINT_PREVIEW_MEDIA_OE_SQUARE_PHOTO_4X4IN 39063
#define PRINT_PREVIEW_MEDIA_OE_SQUARE_PHOTO_5X5IN 39064
#define PRINT_PREVIEW_MEDIA_OM_16K_184X260MM 39065
#define PRINT_PREVIEW_MEDIA_OM_16K_195X270MM 39066
#define PRINT_PREVIEW_MEDIA_OM_BUSINESS_CARD_55X85MM 39067
#define PRINT_PREVIEW_MEDIA_OM_BUSINESS_CARD_55X91MM 39068
#define PRINT_PREVIEW_MEDIA_OM_CARD_54X86MM 39069
#define PRINT_PREVIEW_MEDIA_OM_DAI_PA_KAI_275X395MM 39070
#define PRINT_PREVIEW_MEDIA_OM_DSC_PHOTO_89X119MM 39071
#define PRINT_PREVIEW_MEDIA_OM_FOLIO_210X330MM 39072
#define PRINT_PREVIEW_MEDIA_OM_FOLIO_SP_215X315MM 39073
#define PRINT_PREVIEW_MEDIA_OM_INVITE_220X220MM 39074
#define PRINT_PREVIEW_MEDIA_OM_ITALIAN_110X230MM 39075
#define PRINT_PREVIEW_MEDIA_OM_JUURO_KU_KAI_198X275MM 39076
#define PRINT_PREVIEW_MEDIA_OM_LARGE_PHOTO_200X300 39077
#define PRINT_PREVIEW_MEDIA_OM_MEDIUM_PHOTO_130X180MM 39078
#define PRINT_PREVIEW_MEDIA_OM_PA_KAI_267X389MM 39079
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_30X40_300X400MM 39080
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_30X45_300X450MM 39081
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_35X46_350X460MM 39082
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_40X60_400X600MM 39083
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_50X75_500X750MM 39084
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_50X76_500X760MM 39085
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_60X90_600X900MM 39086
#define PRINT_PREVIEW_MEDIA_OM_SQUARE_PHOTO_89X89MM 39087
#define PRINT_PREVIEW_MEDIA_OM_WIDE_PHOTO_100X200MM 39088
#define PRINT_PREVIEW_MEDIA_OM_SMALL_PHOTO_100X150MM 39089
#define PRINT_PREVIEW_MEDIA_PRC_16K_146X215MM 39090
#define PRINT_PREVIEW_MEDIA_PRC_1_102X165MM 39091
#define PRINT_PREVIEW_MEDIA_PRC_2_102X176MM 39092
#define PRINT_PREVIEW_MEDIA_PRC_32K_97X151MM 39093
#define PRINT_PREVIEW_MEDIA_PRC_4_110X208MM 39094
#define PRINT_PREVIEW_MEDIA_PRC_6_120X320MM 39095
#define PRINT_PREVIEW_MEDIA_PRC_7_160X230MM 39096
#define PRINT_PREVIEW_MEDIA_PRC_8_120X309MM 39097
#define PRINT_PREVIEW_MEDIA_ROC_16K_7_75X10_75IN 39098
#define PRINT_PREVIEW_MEDIA_ROC_8K_10_75X15_5IN 39099
#define PRINT_PREVIEW_MEDIA_DIMENSIONS_INCHES 39100
#define PRINT_PREVIEW_MEDIA_DIMENSIONS_MM 39101
#define PRINT_PREVIEW_MEDIA_NAME_WITH_DIMENSIONS_INCHES 39102
#define PRINT_PREVIEW_MEDIA_NAME_WITH_DIMENSIONS_MM 39103
#define IDS_PRINT_COMPOSITOR_SERVICE_DISPLAY_NAME 39105
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_TITLE 39509
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_DESCRIPTION_1 39510
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_DESCRIPTION_2 39511
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_DESCRIPTION_3 39512
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_EXPAND_LABEL 39513
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_DESCRIPTION_4 39514
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_BULLET_1 39515
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_BULLET_2 39516
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_BULLET_3 39517
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_LINK 39518
#define IDS_SETTINGS_TOPICS_PAGE_TITLE 39519
#define IDS_SETTINGS_TOPICS_PAGE_TOGGLE_LABEL 39520
#define IDS_SETTINGS_TOPICS_PAGE_TOGGLE_SUB_LABEL_V2 39521
#define IDS_SETTINGS_TOPICS_PAGE_DISCLAIMER_DESKTOP 39522
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_DESCRIPTION_CANONICAL 39523
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_DESCRIPTION_DISABLED 39524
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_DESCRIPTION_EMPTY_TEXT_V2 39525
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_DESCRIPTION_EMPTY_TEXT_HEADING 39526
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_DESCRIPTION_EMPTY_TEXT_V2 39527
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_DESCRIPTION_EMPTY_TEXT_HEADING 39528
#define IDS_SETTINGS_TOPICS_PAGE_BLOCK_TOPIC 39529
#define IDS_SETTINGS_TOPICS_PAGE_BLOCK_TOPIC_A11Y_LABEL 39530
#define IDS_SETTINGS_TOPICS_PAGE_ALLOW_TOPIC 39531
#define IDS_SETTINGS_TOPICS_PAGE_ALLOW_TOPIC_A11Y_LABEL 39532
#define IDS_SETTINGS_TOPICS_PAGE_UNBLOCK_TOPIC_A11Y_LABEL 39533
#define IDS_SETTINGS_TOPICS_PAGE_FOOTER_CANONICAL 39534
#define IDS_SETTINGS_TOPICS_PAGE_FIRST_LEVEL_TOPIC_DESCRIPTOR 39535
#define IDS_SETTINGS_MANAGE_TOPICS_DIALOG_TITLE 39536
#define IDS_SETTINGS_MANAGE_TOPICS_DIALOG_BODY 39537
#define IDS_SETTINGS_MANAGE_TOPICS_DIALOG_CLANK_TITLE 39538
#define IDS_SETTINGS_MANAGE_TOPICS_DIALOG_CLANK_BODY 39539
#define IDS_SETTINGS_MANAGE_TOPICS_PAGE_DESCRIPTION 39540
#define IDS_SETTINGS_MANAGE_TOPICS_PAGE_LEARN_MORE_LINK 39541
#define IDS_SETTINGS_MANAGE_TOPICS_PAGE_DESCRIPTION_LEARN_MORE_ARIA_LABEL 39542
#define IDS_SETTINGS_UNBLOCK_TOPIC_TOAST_BODY 39543
#define IDS_SETTINGS_UNBLOCK_TOPIC_TOAST_BUTTON_TEXT 39544
#define IDS_SETTINGS_FLEDGE_PAGE_FOOTER_V2 39545
#define IDS_SETTINGS_UNBLOCK_TOPIC_BUTTON_TEXT_V2 39546
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_HEADING_NEW 39547
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_DESCRIPTION_NEW 39548
#define IDS_SETTINGS_TOPICS_PAGE_MANAGE_TOPICS_HEADING 39549
#define IDS_SETTINGS_TOPICS_PAGE_MANAGE_TOPICS_DESCRIPTION 39550
#define IDS_SETTINGS_TOPICS_PAGE_MANAGE_TOPICS_EXPLANATION 39551
#define IDS_SETTINGS_TOPICS_PAGE_ACTIVE_TOPICS_HEADING 39552
#define IDS_SETTINGS_TOPICS_PAGE_ACTIVE_TOPICS_DESCRIPTION 39553
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_STATUS_LABEL 39554
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_LAST_UPDATE_TIME_LABEL 39555
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_LAST_UPDATE_SOURCE_LABEL 39556
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_LAST_UPDATE_TEXT_LABEL 39557
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_UPDATE_SOURCE_SETTINGS 39558
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_UPDATE_SOURCE_DEFAULT 39559
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_UPDATE_SOURCE_CONFIRMATION 39560
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_ACTIVE 39561
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_INACTIVE 39562
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_NOT_REQUIRED 39563
#define IDS_PRIVACY_SANDBOX_TOPICS_INVALID_TOPIC 39564
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_1 39565
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_2 39566
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_3 39567
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_4 39568
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_5 39569
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_6 39570
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_7 39571
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_8 39572
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_9 39573
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_10 39574
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_11 39575
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_12 39576
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_13 39577
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_14 39578
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_15 39579
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_16 39580
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_17 39581
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_18 39582
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_19 39583
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_20 39584
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_21 39585
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_22 39586
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_23 39587
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_24 39588
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_25 39589
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_26 39590
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_27 39591
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_28 39592
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_29 39593
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_30 39594
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_31 39595
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_32 39596
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_33 39597
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_34 39598
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_35 39599
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_36 39600
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_37 39601
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_38 39602
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_39 39603
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_40 39604
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_41 39605
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_42 39606
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_43 39607
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_44 39608
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_45 39609
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_46 39610
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_47 39611
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_48 39612
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_49 39613
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_50 39614
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_51 39615
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_52 39616
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_53 39617
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_54 39618
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_55 39619
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_56 39620
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_57 39621
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_58 39622
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_59 39623
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_60 39624
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_61 39625
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_62 39626
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_63 39627
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_64 39628
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_65 39629
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_66 39630
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_67 39631
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_68 39632
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_69 39633
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_70 39634
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_71 39635
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_72 39636
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_73 39637
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_74 39638
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_75 39639
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_76 39640
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_77 39641
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_78 39642
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_79 39643
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_80 39644
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_81 39645
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_82 39646
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_83 39647
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_84 39648
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_85 39649
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_86 39650
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_87 39651
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_88 39652
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_89 39653
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_90 39654
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_91 39655
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_92 39656
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_93 39657
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_94 39658
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_95 39659
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_96 39660
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_97 39661
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_98 39662
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_99 39663
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_100 39664
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_101 39665
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_102 39666
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_103 39667
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_104 39668
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_105 39669
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_106 39670
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_107 39671
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_108 39672
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_109 39673
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_110 39674
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_111 39675
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_112 39676
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_113 39677
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_114 39678
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_115 39679
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_116 39680
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_117 39681
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_118 39682
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_119 39683
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_120 39684
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_121 39685
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_122 39686
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_123 39687
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_124 39688
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_125 39689
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_126 39690
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_127 39691
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_128 39692
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_129 39693
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_130 39694
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_131 39695
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_132 39696
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_133 39697
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_134 39698
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_135 39699
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_136 39700
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_137 39701
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_138 39702
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_139 39703
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_140 39704
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_141 39705
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_142 39706
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_143 39707
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_144 39708
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_145 39709
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_146 39710
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_147 39711
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_148 39712
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_149 39713
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_150 39714
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_151 39715
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_152 39716
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_153 39717
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_154 39718
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_155 39719
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_156 39720
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_157 39721
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_158 39722
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_159 39723
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_160 39724
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_161 39725
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_162 39726
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_163 39727
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_164 39728
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_165 39729
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_166 39730
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_167 39731
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_168 39732
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_169 39733
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_170 39734
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_171 39735
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_172 39736
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_173 39737
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_174 39738
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_175 39739
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_176 39740
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_177 39741
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_178 39742
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_179 39743
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_180 39744
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_181 39745
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_182 39746
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_183 39747
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_184 39748
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_185 39749
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_186 39750
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_187 39751
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_188 39752
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_189 39753
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_190 39754
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_191 39755
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_192 39756
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_193 39757
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_194 39758
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_195 39759
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_196 39760
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_197 39761
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_198 39762
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_199 39763
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_200 39764
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_201 39765
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_202 39766
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_203 39767
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_204 39768
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_205 39769
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_206 39770
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_207 39771
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_208 39772
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_209 39773
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_210 39774
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_211 39775
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_212 39776
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_213 39777
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_214 39778
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_215 39779
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_216 39780
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_217 39781
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_218 39782
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_219 39783
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_220 39784
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_221 39785
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_222 39786
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_223 39787
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_224 39788
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_225 39789
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_226 39790
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_227 39791
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_228 39792
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_229 39793
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_230 39794
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_231 39795
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_232 39796
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_233 39797
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_234 39798
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_235 39799
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_236 39800
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_237 39801
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_238 39802
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_239 39803
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_240 39804
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_241 39805
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_242 39806
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_243 39807
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_244 39808
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_245 39809
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_246 39810
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_247 39811
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_248 39812
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_249 39813
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_250 39814
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_251 39815
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_252 39816
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_253 39817
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_254 39818
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_255 39819
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_256 39820
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_257 39821
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_258 39822
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_259 39823
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_260 39824
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_261 39825
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_262 39826
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_263 39827
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_264 39828
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_265 39829
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_266 39830
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_267 39831
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_268 39832
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_269 39833
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_270 39834
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_271 39835
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_272 39836
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_273 39837
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_274 39838
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_275 39839
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_276 39840
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_277 39841
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_278 39842
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_279 39843
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_280 39844
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_281 39845
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_282 39846
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_283 39847
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_284 39848
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_285 39849
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_286 39850
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_287 39851
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_288 39852
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_289 39853
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_290 39854
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_291 39855
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_292 39856
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_293 39857
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_294 39858
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_295 39859
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_296 39860
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_297 39861
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_298 39862
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_299 39863
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_300 39864
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_301 39865
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_302 39866
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_303 39867
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_304 39868
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_305 39869
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_306 39870
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_307 39871
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_308 39872
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_309 39873
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_310 39874
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_311 39875
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_312 39876
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_313 39877
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_314 39878
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_315 39879
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_316 39880
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_317 39881
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_318 39882
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_319 39883
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_320 39884
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_321 39885
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_322 39886
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_323 39887
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_324 39888
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_325 39889
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_326 39890
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_327 39891
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_328 39892
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_329 39893
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_330 39894
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_331 39895
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_332 39896
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_333 39897
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_334 39898
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_335 39899
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_336 39900
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_337 39901
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_338 39902
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_339 39903
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_340 39904
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_341 39905
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_342 39906
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_343 39907
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_344 39908
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_345 39909
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_346 39910
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_347 39911
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_348 39912
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_349 39913
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_350 39914
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_351 39915
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_352 39916
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_353 39917
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_354 39918
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_355 39919
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_356 39920
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_357 39921
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_358 39922
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_359 39923
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_360 39924
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_361 39925
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_362 39926
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_363 39927
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_364 39928
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_365 39929
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_366 39930
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_367 39931
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_368 39932
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_369 39933
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_370 39934
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_371 39935
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_372 39936
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_373 39937
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_374 39938
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_375 39939
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_376 39940
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_377 39941
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_378 39942
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_379 39943
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_380 39944
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_381 39945
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_382 39946
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_383 39947
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_384 39948
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_385 39949
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_386 39950
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_387 39951
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_388 39952
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_389 39953
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_390 39954
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_391 39955
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_392 39956
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_393 39957
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_394 39958
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_395 39959
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_396 39960
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_397 39961
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_398 39962
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_399 39963
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_400 39964
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_401 39965
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_402 39966
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_403 39967
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_404 39968
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_405 39969
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_406 39970
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_407 39971
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_408 39972
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_409 39973
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_410 39974
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_411 39975
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_412 39976
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_413 39977
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_414 39978
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_415 39979
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_416 39980
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_417 39981
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_418 39982
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_419 39983
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_420 39984
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_421 39985
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_422 39986
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_423 39987
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_424 39988
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_425 39989
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_426 39990
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_427 39991
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_428 39992
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_429 39993
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_430 39994
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_431 39995
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_432 39996
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_433 39997
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_434 39998
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_435 39999
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_436 40000
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_437 40001
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_438 40002
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_439 40003
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_440 40004
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_441 40005
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_442 40006
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_443 40007
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_444 40008
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_445 40009
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_446 40010
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_447 40011
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_448 40012
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_449 40013
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_450 40014
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_451 40015
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_452 40016
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_453 40017
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_454 40018
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_455 40019
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_456 40020
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_457 40021
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_458 40022
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_459 40023
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_460 40024
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_461 40025
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_462 40026
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_463 40027
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_464 40028
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_465 40029
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_466 40030
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_467 40031
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_468 40032
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_469 40033
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_470 40034
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_471 40035
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_472 40036
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_473 40037
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_474 40038
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_475 40039
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_476 40040
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_477 40041
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_478 40042
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_479 40043
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_480 40044
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_481 40045
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_482 40046
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_483 40047
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_484 40048
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_485 40049
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_486 40050
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_487 40051
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_488 40052
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_489 40053
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_490 40054
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_491 40055
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_492 40056
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_493 40057
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_494 40058
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_495 40059
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_496 40060
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_497 40061
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_498 40062
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_499 40063
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_500 40064
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_501 40065
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_502 40066
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_503 40067
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_504 40068
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_505 40069
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_506 40070
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_507 40071
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_508 40072
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_509 40073
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_510 40074
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_511 40075
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_512 40076
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_513 40077
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_514 40078
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_515 40079
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_516 40080
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_517 40081
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_518 40082
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_519 40083
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_520 40084
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_521 40085
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_522 40086
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_523 40087
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_524 40088
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_525 40089
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_526 40090
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_527 40091
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_528 40092
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_529 40093
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_530 40094
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_531 40095
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_532 40096
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_533 40097
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_534 40098
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_535 40099
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_536 40100
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_537 40101
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_538 40102
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_539 40103
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_540 40104
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_541 40105
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_542 40106
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_543 40107
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_544 40108
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_545 40109
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_546 40110
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_547 40111
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_548 40112
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_549 40113
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_550 40114
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_551 40115
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_552 40116
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_553 40117
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_554 40118
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_555 40119
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_556 40120
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_557 40121
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_558 40122
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_559 40123
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_560 40124
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_561 40125
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_562 40126
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_563 40127
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_564 40128
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_565 40129
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_566 40130
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_567 40131
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_568 40132
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_569 40133
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_570 40134
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_571 40135
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_572 40136
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_573 40137
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_574 40138
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_575 40139
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_576 40140
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_577 40141
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_578 40142
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_579 40143
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_580 40144
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_581 40145
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_582 40146
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_583 40147
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_584 40148
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_585 40149
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_586 40150
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_587 40151
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_588 40152
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_589 40153
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_590 40154
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_591 40155
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_592 40156
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_593 40157
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_594 40158
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_595 40159
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_596 40160
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_597 40161
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_598 40162
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_599 40163
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_600 40164
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_601 40165
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_602 40166
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_603 40167
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_604 40168
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_605 40169
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_606 40170
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_607 40171
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_608 40172
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_609 40173
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_610 40174
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_611 40175
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_612 40176
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_613 40177
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_614 40178
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_615 40179
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_616 40180
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_617 40181
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_618 40182
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_619 40183
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_620 40184
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_621 40185
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_622 40186
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_623 40187
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_624 40188
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_625 40189
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_626 40190
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_627 40191
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_628 40192
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_629 40193
#define IDS_REGISTER_PROTOCOL_HANDLER_TOOLTIP 40194
#define IDS_REGISTER_PROTOCOL_HANDLER_MAILTO_NAME 40195
#define IDS_REGISTER_PROTOCOL_HANDLER_WEBCAL_NAME 40196
#define IDS_REGISTER_PROTOCOL_HANDLER_CONFIRM 40197
#define IDS_REGISTER_PROTOCOL_HANDLER_CONFIRM_REPLACE 40198
#define IDS_REGISTER_PROTOCOL_HANDLER_CONFIRM_FRAGMENT 40199
#define IDS_REGISTER_PROTOCOL_HANDLER_CONFIRM_REPLACE_FRAGMENT 40200
#define IDS_REGISTER_PROTOCOL_HANDLER_ACCEPT 40201
#define IDS_REGISTER_PROTOCOL_HANDLER_DENY 40202
#define IDS_REGISTER_PROTOCOL_HANDLER_IGNORE 40203
#define IDS_CONFIRM_PROTOCOL_HANDLER_TITLE 40204
#define IDS_CONFIRM_PROTOCOL_HANDLER_MESSAGE 40205
#define IDS_CONFIRM_PROTOCOL_HANDLER_MESSAGE_WITH_INITIATING_ORIGIN 40206
#define IDS_CONFIRM_PROTOCOL_HANDLER_REMEMBER 40207
#define IDS_RESET_PASSWORD_TITLE 40208
#define IDS_RESET_PASSWORD_WARNING_HEADING 40209
#define IDS_RESET_PASSWORD_WARNING_HEADING_V2 40210
#define IDS_RESET_PASSWORD_WARNING_HEADING_WITH_ORG_NAME 40211
#define IDS_RESET_PASSWORD_HEADING 40212
#define IDS_RESET_PASSWORD_WARNING_EXPLANATION_PARAGRAPH 40213
#define IDS_RESET_PASSWORD_WARNING_EXPLANATION_PARAGRAPH_V2 40214
#define IDS_RESET_PASSWORD_WARNING_EXPLANATION_PARAGRAPH_WITH_ORG_NAME 40215
#define IDS_RESET_PASSWORD_BUTTON 40216
#define IDS_RESET_PASSWORD_LEARN_MORE 40217
#define IDS_RESET_PASSWORD_EXPLANATION_PARAGRAPH 40218
#define IDS_RESET_PASSWORD_EXPLANATION_PARAGRAPH_WITH_ORG_NAME 40219
#define IDS_SAVED_TAB_GROUPS_CREATION_JUST_NOW 40220
#define IDS_SAVED_TAB_GROUPS_CREATION_MINUTES_AGO_FORMAT 40221
#define IDS_SAVED_TAB_GROUPS_CREATION_HOURS_AGO_FORMAT 40222
#define IDS_SAVED_TAB_GROUPS_CREATION_DAYS_AGO_FORMAT 40223
#define IDS_SAVED_TAB_GROUPS_CREATION_MONTHS_AGO_FORMAT 40224
#define IDS_SAVED_TAB_GROUPS_CREATION_YEARS_AGO_FORMAT 40225
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_SUBTITLE 40226
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_SUBTITLE_NON_EEA 40227
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_CHANGE_DEFAULT_ENGINE 40228
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_CONFIRMATION_TOAST_LABEL 40229
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_ENTRY_POINT_SUBTITLE 40230
#define IDS_SEARCH_ENGINE_CHOICE_BUTTON_TITLE 40231
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_TITLE 40232
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_SUBTITLE 40233
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_SUBTITLE_INFO_LINK 40234
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_SUBTITLE_INFO_LINK_A11Y_LABEL 40235
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_SUBTITLE_WITH_DEFINITION1 40236
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_SUBTITLE_WITH_DEFINITION2 40237
#define IDS_SEARCH_ENGINE_CHOICE_INFO_DIALOG_TITLE 40242
#define IDS_SEARCH_ENGINE_CHOICE_INFO_DIALOG_BODY_FIRST_PARAGRAPH 40243
#define IDS_SEARCH_ENGINE_CHOICE_INFO_DIALOG_BODY_SECOND_PARAGRAPH 40244
#define IDS_SEARCH_ENGINE_CHOICE_INFO_DIALOG_BODY_THIRD_PARAGRAPH 40245
#define IDS_SEARCH_ENGINE_FALLBACK_MARKETING_SNIPPET 40246
#define IDS_SEARCH_ENGINE_CHOICE_MORE_BUTTON 40247
#define IDS_SEARCH_ENGINE_CHOICE_CONTINUE_BUTTON 40248
#define IDS_SEARCH_ENGINE_CHOICE_CHEVRON_A11Y_LABEL 40249
#define IDS_SEARCH_ENGINE_CHOICE_LIST_A11Y_LABEL 40250
#define IDS_SEARCH_ENGINE_CHOICE_GUEST_SESSION_CHECKBOX 40251
#define IDS_SSL_OPEN_DETAILS_BUTTON 40252
#define IDS_SSL_CLOSE_DETAILS_BUTTON 40253
#define IDS_CAPTIVE_PORTAL_AUTHORIZATION_DIALOG_NAME 40254
#define IDS_CAPTIVE_PORTAL_HEADING_WIRED 40255
#define IDS_CAPTIVE_PORTAL_HEADING_WIFI 40256
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_WIRED 40257
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_WIFI 40258
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_WIFI_SSID 40259
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_NO_LOGIN_URL_WIRED 40260
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_NO_LOGIN_URL_WIFI 40261
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_NO_LOGIN_URL_WIFI_SSID 40262
#define IDS_CAPTIVE_PORTAL_BUTTON_OPEN_LOGIN_PAGE 40263
#define IDS_MITM_SOFTWARE_HEADING 40264
#define IDS_MITM_SOFTWARE_PRIMARY_PARAGRAPH_ENTERPRISE 40265
#define IDS_MITM_SOFTWARE_PRIMARY_PARAGRAPH_NONENTERPRISE 40266
#define IDS_MITM_SOFTWARE_EXPLANATION_ENTERPRISE 40267
#define IDS_MITM_SOFTWARE_EXPLANATION_NONENTERPRISE 40268
#define IDS_MITM_SOFTWARE_EXPLANATION 40269
#define IDS_LOOKALIKE_URL_TITLE 40270
#define IDS_LOOKALIKE_URL_HEADING 40271
#define IDS_LOOKALIKE_URL_IGNORE 40272
#define IDS_LOOKALIKE_URL_CONTINUE 40273
#define IDS_LOOKALIKE_URL_PRIMARY_PARAGRAPH 40274
#define IDS_LOOKALIKE_URL_HEADING_NO_SUGGESTED_URL 40275
#define IDS_LOOKALIKE_URL_PRIMARY_PARAGRAPH_NO_SUGGESTED_URL 40276
#define IDS_LOOKALIKE_URL_BACK_TO_SAFETY 40277
#define IDS_LOOKALIKE_URL_CLOSE_PAGE 40278
#define IDS_ENTERPRISE_BLOCK_TITLE 40279
#define IDS_ENTERPRISE_BLOCK_HEADING 40280
#define IDS_ENTERPRISE_BLOCK_PRIMARY_PARAGRAPH 40281
#define IDS_ENTERPRISE_BLOCK_PRIMARY_PARAGRAPH_CUSTOM_MESSAGE 40282
#define IDS_ENTERPRISE_BLOCK_GO_BACK 40283
#define IDS_ENTERPRISE_WARN_TITLE 40284
#define IDS_ENTERPRISE_WARN_HEADING 40285
#define IDS_ENTERPRISE_WARN_PRIMARY_PARAGRAPH 40286
#define IDS_ENTERPRISE_WARN_PRIMARY_PARAGRAPH_CUSTOM_MESSAGE 40287
#define IDS_ENTERPRISE_WARN_GO_BACK 40288
#define IDS_ENTERPRISE_WARN_CONTINUE_TO_SITE 40289
#define IDS_ENTERPRISE_INTERSTITIALS_LEARN_MORE_ACCCESSIBILITY_TEXT 40290
#define IDS_CLOCK_ERROR_TITLE 40291
#define IDS_CLOCK_ERROR_AHEAD_HEADING 40292
#define IDS_CLOCK_ERROR_BEHIND_HEADING 40293
#define IDS_CLOCK_ERROR_UPDATE_DATE_AND_TIME 40294
#define IDS_CLOCK_ERROR_PRIMARY_PARAGRAPH 40295
#define IDS_CLOCK_ERROR_EXPLANATION 40296
#define IDS_SSL_V2_TITLE 40297
#define IDS_SSL_V2_HEADING 40298
#define IDS_SSL_V2_PRIMARY_PARAGRAPH 40299
#define IDS_SSL_OVERRIDABLE_SAFETY_BUTTON 40300
#define IDS_SSL_OVERRIDABLE_CLOSE_PAGE_BUTTON 40301
#define IDS_SSL_OVERRIDABLE_PROCEED_PARAGRAPH 40302
#define IDS_SSL_RELOAD 40303
#define IDS_SSL_NONOVERRIDABLE_PINNED 40304
#define IDS_SSL_NONOVERRIDABLE_HSTS 40305
#define IDS_SSL_NONOVERRIDABLE_REVOKED 40306
#define IDS_SSL_NONOVERRIDABLE_MORE 40307
#define IDS_SSL_NONOVERRIDABLE_INVALID 40308
#define IDS_SAFEBROWSING_V3_TITLE 40309
#define IDS_SAFEBROWSING_V3_OPEN_DETAILS_BUTTON 40310
#define IDS_SAFEBROWSING_V3_CLOSE_DETAILS_BUTTON 40311
#define IDS_SAFEBROWSING_OVERRIDABLE_SAFETY_BUTTON 40312
#define IDS_SAFEBROWSING_HEADING 40313
#define IDS_MALWARE_V3_PRIMARY_PARAGRAPH 40314
#define IDS_MALWARE_V3_EXPLANATION_PARAGRAPH 40315
#define IDS_MALWARE_V3_PROCEED_PARAGRAPH 40316
#define IDS_SAFE_BROWSING_SCOUT_REPORTING_AGREE 40317
#define IDS_SAFE_BROWSING_ENHANCED_PROTECTION_MESSAGE 40318
#define IDS_HARMFUL_V3_PRIMARY_PARAGRAPH 40319
#define IDS_HARMFUL_V3_EXPLANATION_PARAGRAPH 40320
#define IDS_HARMFUL_V3_PROCEED_PARAGRAPH 40321
#define IDS_PHISHING_V4_PRIMARY_PARAGRAPH 40322
#define IDS_PHISHING_V4_EXPLANATION_PARAGRAPH 40323
#define IDS_PHISHING_V4_PROCEED_PARAGRAPH 40324
#define IDS_MALWARE_WEBVIEW_HEADING 40325
#define IDS_MALWARE_WEBVIEW_EXPLANATION_PARAGRAPH 40326
#define IDS_PHISHING_WEBVIEW_HEADING 40327
#define IDS_PHISHING_WEBVIEW_EXPLANATION_PARAGRAPH 40328
#define IDS_HARMFUL_WEBVIEW_HEADING 40329
#define IDS_HARMFUL_WEBVIEW_EXPLANATION_PARAGRAPH 40330
#define IDS_BILLING_WEBVIEW_HEADING 40331
#define IDS_BILLING_WEBVIEW_EXPLANATION_PARAGRAPH 40332
#define IDS_SUPERVISED_USER_URL_BLOCKED_MESSAGE 40333
#define IDS_SUPERVISED_USER_LEARN_MORE 40334
#define IDS_CONNECTION_HELP_SHOW_MORE 40335
#define IDS_CONNECTION_HELP_SHOW_LESS 40336
#define IDS_CONNECTION_HELP_TITLE 40337
#define IDS_CONNECTION_HELP_HEADING 40338
#define IDS_CONNECTION_HELP_GENERAL_HELP 40339
#define IDS_CONNECTION_HELP_SPECIFIC_ERROR_HEADING 40340
#define IDS_CONNECTION_HELP_CONNECTION_NOT_PRIVATE_TITLE 40341
#define IDS_CONNECTION_HELP_CONNECT_TO_NETWORK_TITLE 40342
#define IDS_CONNECTION_HELP_INCORRECT_CLOCK_TITLE 40343
#define IDS_CONNECTION_HELP_CONNECTION_NOT_PRIVATE_DETAILS 40344
#define IDS_CONNECTION_HELP_CONNECT_TO_NETWORK_DETAILS 40345
#define IDS_CONNECTION_HELP_INCORRECT_CLOCK_DETAILS 40346
#define IDS_BILLING_TITLE 40349
#define IDS_BILLING_HEADING 40350
#define IDS_BILLING_PRIMARY_PARAGRAPH 40351
#define IDS_BILLING_PRIMARY_BUTTON 40352
#define IDS_BILLING_PROCEED_BUTTON 40353
#define IDS_BLOCKED_INTERCEPTION_HEADING 40354
#define IDS_KNOWN_INTERCEPTION_TITLE 40355
#define IDS_KNOWN_INTERCEPTION_HEADER 40356
#define IDS_KNOWN_INTERCEPTION_BODY1 40357
#define IDS_KNOWN_INTERCEPTION_BODY2 40358
#define IDS_KNOWN_INTERCEPTION_INFOBAR_HEADING 40359
#define IDS_KNOWN_INTERCEPTION_INFOBAR_BUTTON_TEXT 40360
#define IDS_LEGACY_TLS_HEADING 40361
#define IDS_LEGACY_TLS_PRIMARY_PARAGRAPH 40362
#define IDS_LEGACY_TLS_EXPLANATION 40363
#define IDS_INSECURE_FORM_TITLE 40364
#define IDS_INSECURE_FORM_HEADING 40365
#define IDS_INSECURE_FORM_PRIMARY_PARAGRAPH 40366
#define IDS_INSECURE_FORM_BACK_BUTTON 40367
#define IDS_INSECURE_FORM_SUBMIT_BUTTON 40368
#define IDS_HTTPS_ONLY_MODE_TITLE 40369
#define IDS_HTTPS_ONLY_MODE_HEADING 40370
#define IDS_HTTPS_ONLY_MODE_PRIMARY_PARAGRAPH 40371
#define IDS_HTTPS_ONLY_BALANCED_MODE_HEADING 40372
#define IDS_HTTPS_ONLY_BALANCED_MODE_PRIMARY_PARAGRAPH 40373
#define IDS_HTTPS_ONLY_MODE_WITH_ADVANCED_PROTECTION_PRIMARY_PARAGRAPH 40374
#define IDS_HTTPS_ONLY_MODE_WITH_SITE_ENGAGEMENT_PRIMARY_PARAGRAPH 40376
#define IDS_HTTPS_ONLY_MODE_FOR_TYPICALLY_SECURE_BROWSING_PRIMARY_PARAGRAPH 40377
#define IDS_HTTPS_ONLY_MODE_FOR_INCOGNITO_PRIMARY_PARAGRAPH 40378
#define IDS_HTTPS_ONLY_MODE_BACK_BUTTON 40379
#define IDS_HTTPS_ONLY_MODE_SUBMIT_BUTTON 40380
#define IDS_ABH_PROMPT_TITLE 40381
#define IDS_ABH_PROMPT_BALANCED_MODE_FIRST_ITEM_TEXT 40382
#define IDS_ABH_PROMPT_BALANCED_MODE_SECOND_ITEM_TEXT 40383
#define IDS_ABH_PROMPT_SECONDARY_TEXT 40384
#define IDS_ABH_PROMPT_LEARN_MORE_LINK 40385
#define IDS_ABH_PROMPT_SITE_ENGAGEMENT_PRIMARY_PARAGRAPH 40386
#define IDS_ABH_PROMPT_TYPICALLY_SECURE_BROWSING_PRIMARY_PARAGRAPH 40387
#define IDS_ABH_PROMPT_INCOGNITO_PRIMARY_PARAGRAPH 40388
#define IDS_ABH_PROMPT_ADVANCED_PROTECTION_PRIMARY_PARAGRAPH 40389
#define IDS_SHARING_DEVICE_TYPE_COMPUTER 40390
#define IDS_SHARING_DEVICE_TYPE_DEVICE 40391
#define IDS_SHARING_DEVICE_TYPE_PHONE 40392
#define IDS_SHARING_DEVICE_TYPE_TABLET 40393
#define IDS_SEND_TAB_PUSH_NOTIFICATION_TITLE_DEAULT_DEVICE_NAME 40394
#define IDS_SEND_TAB_PUSH_NOTIFICATION_TITLE_USER_GIVEN_DEVICE_NAME 40395
#define IDS_SEND_TAB_PUSH_NOTIFICATION_BODY 40396
#define IDS_SEND_TAB_PUSH_NOTIFICATION_PLACEHOLDER_TITLE 40397
#define IDS_SEND_TAB_PUSH_NOTIFICATION_PLACEHOLDER_BODY 40398
#define IDS_SITE_SETTINGS_TYPE_ADS 40399
#define IDS_SITE_SETTINGS_TYPE_ADS_MID_SENTENCE 40400
#define IDS_SITE_SETTINGS_TYPE_ANTI_ABUSE 40401
#define IDS_SITE_SETTINGS_TYPE_AR 40402
#define IDS_SITE_SETTINGS_TYPE_AR_MID_SENTENCE 40403
#define IDS_SITE_SETTINGS_TYPE_AUTOMATIC_DOWNLOADS 40404
#define IDS_SITE_SETTINGS_TYPE_AUTOMATIC_DOWNLOADS_MID_SENTENCE 40405
#define IDS_SITE_SETTINGS_TYPE_AUTOMATIC_FULLSCREEN 40406
#define IDS_SITE_SETTINGS_TYPE_AUTOMATIC_FULLSCREEN_MID_SENTENCE 40407
#define IDS_SITE_SETTINGS_TYPE_AUTO_PICTURE_IN_PICTURE 40408
#define IDS_SITE_SETTINGS_TYPE_AUTO_PICTURE_IN_PICTURE_MID_SENTENCE 40409
#define IDS_SITE_SETTINGS_TYPE_BACKGROUND_SYNC 40410
#define IDS_SITE_SETTINGS_TYPE_BACKGROUND_SYNC_MID_SENTENCE 40411
#define IDS_SITE_SETTINGS_TYPE_BLUETOOTH_DEVICES 40412
#define IDS_SITE_SETTINGS_TYPE_BLUETOOTH_DEVICES_MID_SENTENCE 40413
#define IDS_SITE_SETTINGS_TYPE_BLUETOOTH_SCANNING 40414
#define IDS_SITE_SETTINGS_TYPE_BLUETOOTH_SCANNING_MID_SENTENCE 40415
#define IDS_SITE_SETTINGS_TYPE_CAMERA 40416
#define IDS_SITE_SETTINGS_TYPE_CAMERA_MID_SENTENCE 40417
#define IDS_SITE_SETTINGS_TYPE_CAMERA_WITH_COUNT 40418
#define IDS_SITE_SETTINGS_TYPE_CAMERA_PAN_TILT_ZOOM 40419
#define IDS_SITE_SETTINGS_TYPE_CAMERA_PAN_TILT_ZOOM_MID_SENTENCE 40420
#define IDS_SITE_SETTINGS_TYPE_CAMERA_PAN_TILT_ZOOM_WITH_COUNT 40421
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL 40422
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL_MID_SENTENCE 40423
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL_SHARED_TABS 40424
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL_SHARED_TABS_MID_SENTENCE 40425
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL_SUB_MENU 40426
#define IDS_SITE_SETTINGS_TYPE_CLIPBOARD 40427
#define IDS_SITE_SETTINGS_TYPE_CLIPBOARD_MID_SENTENCE 40428
#define IDS_SITE_SETTINGS_TYPE_COOKIES 40429
#define IDS_SITE_SETTINGS_TYPE_COOKIES_MID_SENTENCE 40430
#define IDS_SITE_SETTINGS_TYPE_FEDERATED_IDENTITY_API 40431
#define IDS_SITE_SETTINGS_TYPE_FEDERATED_IDENTITY_API_MID_SENTENCE 40432
#define IDS_SITE_SETTINGS_TYPE_HAND_TRACKING 40433
#define IDS_SITE_SETTINGS_TYPE_HAND_TRACKING_MID_SENTENCE 40434
#define IDS_SITE_SETTINGS_TYPE_IDLE_DETECTION 40435
#define IDS_SITE_SETTINGS_TYPE_IDLE_DETECTION_MID_SENTENCE 40436
#define IDS_SITE_SETTINGS_TYPE_JAVASCRIPT 40437
#define IDS_SITE_SETTINGS_TYPE_JAVASCRIPT_MID_SENTENCE 40438
#define IDS_SITE_SETTINGS_TYPE_JAVASCRIPT_OPTIMIZER 40439
#define IDS_SITE_SETTINGS_TYPE_LOCATION 40440
#define IDS_SITE_SETTINGS_TYPE_LOCATION_MID_SENTENCE 40441
#define IDS_SITE_SETTINGS_TYPE_MIC 40442
#define IDS_SITE_SETTINGS_TYPE_MIC_MID_SENTENCE 40443
#define IDS_SITE_SETTINGS_TYPE_MIC_WITH_COUNT 40444
#define IDS_SITE_SETTINGS_TYPE_MIDI_SYSEX 40445
#define IDS_SITE_SETTINGS_TYPE_MIDI_SYSEX_MID_SENTENCE 40446
#define IDS_SITE_SETTINGS_TYPE_MOTION_AND_LIGHT_SENSORS 40447
#define IDS_SITE_SETTINGS_TYPE_MOTION_AND_LIGHT_SENSORS_MID_SENTENCE 40448
#define IDS_SITE_SETTINGS_TYPE_MOTION_SENSORS 40449
#define IDS_SITE_SETTINGS_TYPE_MOTION_SENSORS_MID_SENTENCE 40450
#define IDS_SITE_SETTINGS_TYPE_NFC 40451
#define IDS_SITE_SETTINGS_TYPE_NFC_MID_SENTENCE 40452
#define IDS_SITE_SETTINGS_TYPE_NOTIFICATIONS 40453
#define IDS_SITE_SETTINGS_TYPE_NOTIFICATIONS_MID_SENTENCE 40454
#define IDS_SITE_SETTINGS_TYPE_POPUPS_REDIRECTS 40455
#define IDS_SITE_SETTINGS_TYPE_POPUPS_REDIRECTS_MID_SENTENCE 40456
#define IDS_SITE_SETTINGS_TYPE_PROTECTED_MEDIA_ID 40457
#define IDS_SITE_SETTINGS_TYPE_PROTECTED_MEDIA_ID_MID_SENTENCE 40458
#define IDS_SITE_SETTINGS_TYPE_SOUND 40459
#define IDS_SITE_SETTINGS_TYPE_SOUND_MID_SENTENCE 40460
#define IDS_SITE_SETTINGS_TYPE_USB_DEVICES 40461
#define IDS_SITE_SETTINGS_TYPE_USB_DEVICES_MID_SENTENCE 40462
#define IDS_SITE_SETTINGS_TYPE_VR 40463
#define IDS_SITE_SETTINGS_TYPE_VR_MID_SENTENCE 40464
#define IDS_SITE_SETTINGS_TYPE_STORAGE_ACCESS 40465
#define IDS_SITE_SETTINGS_TYPE_STORAGE_ACCESS_MID_SENTENCE 40466
#define IDS_SITE_SETTINGS_TYPE_FILE_SYSTEM_ACCESS_WRITE 40467
#define IDS_SITE_SETTINGS_TYPE_FILE_SYSTEM_ACCESS_WRITE_MID_SENTENCE 40468
#define IDS_SITE_SETTINGS_TYPE_LOCAL_NETWORK_ACCESS 40469
#define IDS_SITE_SETTINGS_TYPE_LOCAL_NETWORK_ACCESS_MID_SENTENCE 40470
#define IDS_SITE_SETTINGS_TYPE_LOCAL_NETWORK 40471
#define IDS_SITE_SETTINGS_TYPE_LOCAL_NETWORK_MID_SENTENCE 40472
#define IDS_SITE_SETTINGS_TYPE_LOOPBACK_NETWORK 40473
#define IDS_SITE_SETTINGS_TYPE_LOOPBACK_NETWORK_MID_SENTENCE 40474
#define IDS_SITE_SETTINGS_TYPE_WINDOW_MANAGEMENT 40475
#define IDS_SITE_SETTINGS_TYPE_WINDOW_MANAGEMENT_MID_SENTENCE 40476
#define IDS_SITE_SETTINGS_TYPE_FONT_ACCESS 40477
#define IDS_SITE_SETTINGS_TYPE_FONT_ACCESS_MID_SENTENCE 40478
#define IDS_SITE_SETTINGS_TYPE_HANDLERS 40479
#define IDS_SITE_SETTINGS_TYPE_HANDLERS_MID_SENTENCE 40480
#define IDS_SITE_SETTINGS_TYPE_HID_DEVICES 40481
#define IDS_SITE_SETTINGS_TYPE_HID_DEVICES_MID_SENTENCE 40482
#define IDS_SITE_SETTINGS_TYPE_IMAGES 40483
#define IDS_SITE_SETTINGS_TYPE_IMAGES_MID_SENTENCE 40484
#define IDS_SITE_SETTINGS_TYPE_INSECURE_CONTENT 40485
#define IDS_SITE_SETTINGS_TYPE_INSECURE_CONTENT_MID_SENTENCE 40486
#define IDS_SITE_SETTINGS_TYPE_KEYBOARD_LOCK 40487
#define IDS_SITE_SETTINGS_TYPE_KEYBOARD_LOCK_MID_SENTENCE 40488
#define IDS_SITE_SETTINGS_TYPE_PAYMENT_HANDLER 40489
#define IDS_SITE_SETTINGS_TYPE_PAYMENT_HANDLER_MID_SENTENCE 40490
#define IDS_SITE_SETTINGS_TYPE_PDF_DOCUMENTS 40491
#define IDS_SITE_SETTINGS_TYPE_POINTER_LOCK 40492
#define IDS_SITE_SETTINGS_TYPE_POINTER_LOCK_MID_SENTENCE 40493
#define IDS_SITE_SETTINGS_TYPE_SERIAL_PORTS 40494
#define IDS_SITE_SETTINGS_TYPE_SERIAL_PORTS_MID_SENTENCE 40495
#define IDS_SITE_SETTINGS_TYPE_ZOOM_LEVELS 40497
#define IDS_SITE_SETTINGS_TYPE_ZOOM_LEVELS_MID_SENTENCE 40498
#define IDS_SITE_SETTINGS_TYPE_WEB_APP_INSTALLATION 40499
#define IDS_SITE_SETTINGS_TYPE_WEB_APP_INSTALLATION_MID_SENTENCE 40500
#define IDS_SITE_SETTINGS_TYPE_WEB_PRINTING 40501
#define IDS_SITE_SETTINGS_TYPE_WEB_PRINTING_MID_SENTENCE 40502
#define IDS_SITE_SETTINGS_TYPE_PERFORMANCE 40503
#define IDS_SITE_SETTINGS_TYPE_PERFORMANCE_SUBLABEL 40504
#define IDS_SITE_SETTINGS_TYPE_OFFER_WRITING_HELP 40505
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_HEADER 40506
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_MESSAGE_BODY 40507
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_MESSAGE_BODY_ALT 40508
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_LEARN_MORE 40509
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_TURN_ON 40510
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_HEADER 40511
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_HEADER_ALT 40512
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_MESSAGE_BODY 40513
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_MESSAGE_BODY_ALT 40514
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_LEARN_MORE 40515
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_TURN_ON 40516
#define IDS_STS_CONTEXT_REMINDER_USED_FOLLOWING_TABS 40517
#define IDS_STS_CONTEXT_REMINDER_EXCLUDE_SITES 40518
#define IDS_STS_CONTEXT_REMINDER_MANAGE 40519
#define IDS_STS_CONSIDERING_RELEVANT_OPEN_TABS 40520
#define IDS_STS_CONTEXT_REMINDER_CHANGE_IN_SETTINGS 40521
#define IDS_STS_SETTINGS_OPTION_1_SHARE_OPEN_TABS_FOR_EVERY_THREAD 40522
#define IDS_STS_SETTINGS_OPTION_1_SHARE_OPEN_TABS_BY_DEFAULT 40523
#define IDS_STS_SETTINGS_OPTION_1_LEARN_MORE 40524
#define IDS_STS_SETTINGS_OPTION_1_WHEN_ON 40525
#define IDS_STS_SETTINGS_OPTION_1_RELEVANT_OPEN_TABS_ARE_USED_TO_PERSONALIZE 40526
#define IDS_STS_SETTINGS_OPTION_1_THINGS_TO_CONSIDER 40527
#define IDS_STS_SETTINGS_OPTION_1_SENDS_YOUR_OPEN_TABS 40528
#define IDS_STS_SETTINGS_OPTION_1_SEEN_BY_HUMAN_REVIEWERS 40529
#define IDS_STS_SETTINGS_OPTION_1_SITE_EXCLUSIONS 40530
#define IDS_STS_SETTINGS_OPTION_1_SITES_ADDED_HERE_WONT_BE_REFERENCED 40531
#define IDS_STS_SETTINGS_OPTION_1_MY_GOOGLE_SEARCH_HISTORY 40532
#define IDS_STS_SETTINGS_OPTION_1_REVIEW_AND_MANAGE 40533
#define IDS_STS_OPTION_2_SHARE_OPEN_TABS_FOR_EVERY_THREAD 40534
#define IDS_STS_OPTION_2_CHOOSE_HOW_RELEVANT_OPEN_TABS_CAN_BE_USED 40535
#define IDS_STS_OPTION_2_LEARN_MORE 40536
#define IDS_STS_OPTION_2_DO_NOT_SHARE_AUTOMATICALLY 40537
#define IDS_STS_OPTION_2_DO_NOT_SHARE_AUTOMATICALLY_DETAIL 40538
#define IDS_STS_OPTION_2_SHARE_AUTOMATICALLY 40539
#define IDS_STS_OPTION_2_SHARE_AUTOMATICALLY_DETAIL 40540
#define IDS_STS_OPTION_2_SITE_EXCLUSIONS 40541
#define IDS_STS_OPTION_2_SITES_ADDED_HERE_WONT_BE_REFERENCED 40542
#define IDS_STS_OPTION_2_MY_GOOGLE_SEARCH_HISTORY 40543
#define IDS_STS_OPTION_2_REVIEW_AND_MANAGE 40544
#define IDS_STS_SETTINGS_ENTRYPOINT_AI_MODE_SEARCH 40545
#define IDS_STS_SETTINGS_ENTRYPOINT_GET_RESPONSES_WITH_CONTEXT 40546
#define IDS_STS_SETTINGS_ENTRYPOINT_LEARN_MORE 40547
#define IDS_STS_MEGAPLUS_SHARE_RELEVANT_OPEN_TABS 40548
#define IDS_STS_THREAD_PROMO_CARD_ALWAYS_SHARE_RELEVANT_OPEN_TABS 40549
#define IDS_STS_THREAD_PROMO_CARD_MESSAGE_BODY 40550
#define IDS_SMS_INFOBAR_TITLE 40551
#define IDS_SMS_INFOBAR_STATUS_SMS_RECEIVED 40552
#define IDS_SMS_INFOBAR_STATUS_SMS_RECEIVED_FROM_EMBEDDED_FRAME 40553
#define IDS_SMS_INFOBAR_BUTTON_OK 40554
#define IDS_CERT_ERROR_NO_SUBJECT_ALTERNATIVE_NAMES_DETAILS 40555
#define IDS_CERT_ERROR_COMMON_NAME_INVALID_DETAILS 40556
#define IDS_CERT_ERROR_COMMON_NAME_INVALID_DESCRIPTION 40557
#define IDS_CERT_ERROR_EXPIRED_DETAILS 40558
#define IDS_CERT_ERROR_EXPIRED_DESCRIPTION 40559
#define IDS_CERT_ERROR_NOT_YET_VALID_DETAILS 40560
#define IDS_CERT_ERROR_NOT_YET_VALID_DESCRIPTION 40561
#define IDS_CERT_ERROR_NOT_VALID_AT_THIS_TIME_DETAILS 40562
#define IDS_CERT_ERROR_NOT_VALID_AT_THIS_TIME_DESCRIPTION 40563
#define IDS_CERT_ERROR_AUTHORITY_INVALID_DESCRIPTION 40564
#define IDS_CERT_ERROR_CONTAINS_ERRORS_DETAILS 40565
#define IDS_CERT_ERROR_CONTAINS_ERRORS_DESCRIPTION 40566
#define IDS_CERT_ERROR_UNABLE_TO_CHECK_REVOCATION_DETAILS 40567
#define IDS_CERT_ERROR_UNABLE_TO_CHECK_REVOCATION_DESCRIPTION 40568
#define IDS_CERT_ERROR_NO_REVOCATION_MECHANISM_DETAILS 40569
#define IDS_CERT_ERROR_NO_REVOCATION_MECHANISM_DESCRIPTION 40570
#define IDS_CERT_ERROR_REVOKED_CERT_DETAILS 40571
#define IDS_CERT_ERROR_REVOKED_CERT_DESCRIPTION 40572
#define IDS_CERT_ERROR_INVALID_CERT_DETAILS 40573
#define IDS_CERT_ERROR_INVALID_CERT_DESCRIPTION 40574
#define IDS_CERT_ERROR_WEAK_SIGNATURE_ALGORITHM_DETAILS 40575
#define IDS_CERT_ERROR_WEAK_SIGNATURE_ALGORITHM_DESCRIPTION 40576
#define IDS_CERT_ERROR_WEAK_KEY_DETAILS 40577
#define IDS_CERT_ERROR_WEAK_KEY_DESCRIPTION 40578
#define IDS_CERT_ERROR_NAME_CONSTRAINT_VIOLATION_DETAILS 40579
#define IDS_CERT_ERROR_NAME_CONSTRAINT_VIOLATION_DESCRIPTION 40580
#define IDS_CERT_ERROR_VALIDITY_TOO_LONG_DETAILS 40581
#define IDS_CERT_ERROR_VALIDITY_TOO_LONG_DESCRIPTION 40582
#define IDS_CERT_ERROR_NON_UNIQUE_NAME_DETAILS 40583
#define IDS_CERT_ERROR_NON_UNIQUE_NAME_DESCRIPTION 40584
#define IDS_CERT_ERROR_UNKNOWN_ERROR_DETAILS 40585
#define IDS_CERT_ERROR_UNKNOWN_ERROR_DESCRIPTION 40586
#define IDS_CERT_ERROR_SUMMARY_PINNING_FAILURE_DETAILS 40587
#define IDS_CERT_ERROR_SUMMARY_PINNING_FAILURE_DESCRIPTION 40588
#define IDS_CERT_ERROR_CERTIFICATE_TRANSPARENCY_REQUIRED_DETAILS 40589
#define IDS_CERT_ERROR_CERTIFICATE_TRANSPARENCY_REQUIRED_DESCRIPTION 40590
#define IDS_SSL_ERROR_OBSOLETE_VERSION_DETAILS 40591
#define IDS_SSL_ERROR_OBSOLETE_VERSION_DESCRIPTION 40592
#define IDS_CERT_ERROR_AUTHORITY_INVALID_DETAILS 40593
#define IDS_CERT_ERROR_AUTHORITY_INVALID_DETAILS_V2 40594
#define IDS_ALWAYS_ALLOW_ADS 40595
#define IDS_BLOCKED_ADS_PROMPT_EXPLANATION 40596
#define IDS_BLOCKED_ADS_PROMPT_TITLE 40597
#define IDS_BLOCK_INTERSTITIAL_TITLE 40604
#define IDS_CHILD_BLOCK_INTERSTITIAL_HEADER 40605
#define IDS_BLOCK_INTERSTITIAL_HEADER_ACCESS_REQUESTS_DISABLED 40606
#define IDS_CHILD_BLOCK_INTERSTITIAL_MESSAGE_V2 40607
#define IDS_SUPERVISED_USER_INTERSTITIAL_MESSAGE_BLOCK_ALL 40608
#define IDS_SUPERVISED_USER_INTERSTITIAL_MESSAGE_SAFE_SITES 40609
#define IDS_SUPERVISED_USER_INTERSTITIAL_MESSAGE_MANUAL 40610
#define IDS_CHILD_BLOCK_INTERSTITIAL_MESSAGE_NOT_SIGNED_IN 40611
#define IDS_REQUEST_SENT_OK 40612
#define IDS_BLOCK_INTERSTITIAL_ASK_IN_PERSON_BUTTON 40613
#define IDS_BLOCK_INTERSTITIAL_ASK_IN_PERSON_INSTEAD_BUTTON 40614
#define IDS_BLOCK_INTERSTITIAL_ASK_IN_A_MESSAGE_BUTTON 40615
#define IDS_CHILD_BLOCK_INTERSTITIAL_WAITING_APPROVAL_MESSAGE 40616
#define IDS_CHILD_BLOCK_INTERSTITIAL_WAITING_APPROVAL_DESCRIPTION_SINGLE_PARENT 40617
#define IDS_CHILD_BLOCK_INTERSTITIAL_WAITING_APPROVAL_DESCRIPTION_MULTI_PARENT 40618
#define IDS_CHILD_BLOCK_INTERSTITIAL_REQUEST_FAILED_MESSAGE_SINGLE_PARENT 40619
#define IDS_CHILD_BLOCK_INTERSTITIAL_REQUEST_FAILED_MESSAGE_MULTI_PARENT 40620
#define IDS_BLOCK_INTERSTITIAL_SHOW_DETAILS 40621
#define IDS_BLOCK_INTERSTITIAL_HIDE_DETAILS 40622
#define IDS_GENERIC_SITE_BLOCK_HEADER 40623
#define IDS_SUPERVISED_USER_BLOCK_HEADER 40624
#define IDS_CHILD_BLOCK_MESSAGE_DEFAULT_SINGLE_PARENT 40625
#define IDS_CHILD_BLOCK_MESSAGE_DEFAULT_MULTI_PARENT 40626
#define IDS_SUPERVISED_USER_BLOCK_MESSAGE_SAFE_SITES 40627
#define IDS_CHILD_BLOCK_MESSAGE_MANUAL_SINGLE_PARENT 40628
#define IDS_CHILD_BLOCK_MESSAGE_MANUAL_MULTI_PARENT 40629
#define IDS_SUPERVISED_USER_VERIFY_PAGE_TAB_TITLE 40630
#define IDS_SUPERVISED_USER_VERIFY_PAGE_PRIMARY_HEADING 40631
#define IDS_SUPERVISED_USER_VERIFY_PAGE_PRIMARY_PARAGRAPH 40632
#define IDS_SUPERVISED_USER_VERIFY_PAGE_PRIMARY_BUTTON 40633
#define IDS_SUPERVISED_USER_VERIFY_PAGE_SUBFRAME_YOUTUBE_HEADING 40634
#define IDS_SUPERVISED_USER_VERIFY_PAGE_SUBFRAME_BLOCKED_SITE_HEADING 40635
#define IDS_PARENT_WEBSITE_APPROVAL_BLOCK_ALL_URL 40636
#define IDS_PARENT_WEBSITE_APPROVAL_SAFE_SITES_URL 40637
#define IDS_PARENT_WEBSITE_APPROVAL_MANUAL_URL 40638
#define IDS_PARENT_WEBSITE_APPROVAL_DIALOG_A11Y_NAME 40639
#define IDS_PARENTAL_LOCAL_APPROVAL_DIALOG_GENERIC_ERROR_TITLE 40640
#define IDS_PARENTAL_LOCAL_APPROVAL_DIALOG_GENERIC_ERROR_DESCRIPTION 40641
#define IDS_PARENTAL_LOCAL_APPROVAL_DIALOG_GENERIC_ERROR_BACK_BUTTON 40642
#define IDS_PARENTAL_LOCAL_APPROVAL_SNACKBAR_GENERIC_ERROR_TITLE 40643
#define IDS_PARENTAL_LOCAL_APPROVAL_SNACKBAR_GENERIC_ERROR_BACK_BUTTON 40644
#define IDS_SYNC_BASIC_ENCRYPTION_DATA 40648
#define IDS_SYNC_DATATYPE_AUTOFILL 40649
#define IDS_SYNC_DATATYPE_BOOKMARKS 40650
#define IDS_SYNC_DATATYPE_PASSWORDS 40651
#define IDS_SYNC_DATATYPE_PASSWORDS_AND_PASSKEYS 40652
#define IDS_SYNC_DATATYPE_PREFERENCES 40653
#define IDS_SYNC_DATATYPE_TABS 40654
#define IDS_SYNC_DATATYPE_TYPED_URLS 40655
#define IDS_SYNC_DATATYPE_HISTORY_AND_TABS 40656
#define IDS_SYNC_DATATYPE_READING_LIST 40657
#define IDS_SYNC_EMPTY_PASSPHRASE_ERROR 40658
#define IDS_SYNC_ENCRYPTION_SECTION_TITLE 40659
#define IDS_SYNC_FULL_ENCRYPTION_DATA 40660
#define IDS_SYNC_LOGIN_SETTING_UP 40661
#define IDS_SYNC_PASSPHRASE_LABEL 40662
#define IDS_SYNC_PASSPHRASE_MISMATCH_ERROR 40663
#define IDS_SYNC_ENTER_PASSPHRASE_BODY_WITH_DATE 40664
#define IDS_SYNC_ENTER_PASSPHRASE_BODY 40665
#define IDS_BULK_UPLOAD_SUBTITLE 40666
#define IDS_BULK_UPLOAD_BOOKMARK_FOLDER_SUBTITLE 40667
#define IDS_TAB_GROUP_COLOR_GREY 40668
#define IDS_TAB_GROUP_COLOR_BLUE 40669
#define IDS_TAB_GROUP_COLOR_RED 40670
#define IDS_TAB_GROUP_COLOR_YELLOW 40671
#define IDS_TAB_GROUP_COLOR_GREEN 40672
#define IDS_TAB_GROUP_COLOR_PINK 40673
#define IDS_TAB_GROUP_COLOR_PURPLE 40674
#define IDS_TAB_GROUP_COLOR_CYAN 40675
#define IDS_TAB_GROUP_COLOR_ORANGE 40676
#define IDS_TAB_RESUME_DECORATORS_VISITED_X_AGO 40677
#define IDS_TAB_RESUME_DECORATORS_VISITED_RECENTLY 40678
#define IDS_TAB_RESUME_DECORATORS_FREQUENTLY_VISITED 40679
#define IDS_TAB_RESUME_DECORATORS_CONTINUE_READING 40680
#define IDS_TAB_RESUME_DECORATORS_MOST_RECENT 40681
#define IDS_TAB_RESUME_DECORATORS_TIME_OF_DAY 40682
#define IDS_TAB_RESUME_DECORATORS_VISITED_X_AGO_IOS 40683
#define IDS_TAB_RESUME_DECORATORS_VISITED_RECENTLY_IOS 40684
#define IDS_TAB_RESUME_DECORATORS_FREQUENTLY_VISITED_IOS 40685
#define IDS_TAB_RESUME_DECORATORS_MOST_RECENT_IOS 40686
#define IDS_TAB_RESUME_N_MINUTES_AGO_NARROW 40687
#define IDS_TAB_RESUME_N_HOURS_AGO_NARROW 40688
#define IDS_TRANSLATE_NOTIFICATION_UNDO 40704
#define IDS_TRANSLATE_DETECTED_LANGUAGE 40705
#define IDS_BOOKMARK_BAR_UNDO 40706
#define IDS_BOOKMARK_BAR_REDO 40707
#define IDS_BOOKMARK_BAR_UNDO_ADD 40708
#define IDS_BOOKMARK_BAR_REDO_ADD 40709
#define IDS_BOOKMARK_BAR_UNDO_DELETE 40710
#define IDS_BOOKMARK_BAR_REDO_DELETE 40711
#define IDS_BOOKMARK_BAR_UNDO_EDIT 40712
#define IDS_BOOKMARK_BAR_REDO_EDIT 40713
#define IDS_BOOKMARK_BAR_UNDO_MOVE 40714
#define IDS_BOOKMARK_BAR_REDO_MOVE 40715
#define IDS_BOOKMARK_BAR_UNDO_REORDER 40716
#define IDS_BOOKMARK_BAR_REDO_REORDER 40717
#define IDS_IMPORTED_FROM_SAFARI_FOLDER 40718
#define IDS_IMPORTED_FOLDER 40719
#define IDS_CLOSE_TUTORIAL 40720
#define IDS_CLOSE_PROMO 40721
#define IDS_HELP_BUBBLE 40722
#define IDS_PROMO_DISMISS_BUTTON 40723
#define IDS_PROMO_SNOOZE_BUTTON 40724
#define IDS_PROMO_SHOW_TUTORIAL_BUTTON 40725
#define IDS_TUTORIAL_RESTART_TUTORIAL 40726
#define IDS_PROMO_LEARN_MORE_BUTTON 40727
#define IDS_TUTORIAL_CLOSE_TUTORIAL 40728
#define IDS_TUTORIAL_NEXT_BUTTON 40729
#define IDS_PROMO_MANAGE_BUTTON 40730
#define IDS_VERSION_UI_TITLE 40731
#define IDS_VERSION_UI_OFFICIAL 40732
#define IDS_VERSION_UI_UNOFFICIAL 40733
#define IDS_VERSION_UI_32BIT 40734
#define IDS_VERSION_UI_64BIT 40735
#define IDS_VERSION_UI_REVISION 40740
#define IDS_VERSION_UI_OS 40741
#define IDS_VERSION_UI_USER_AGENT 40743
#define IDS_VERSION_UI_COMMAND_LINE 40744
#define IDS_VERSION_UI_COPY_LABEL 40748
#define IDS_VERSION_UI_COPY_NOTICE 40749
#define IDS_VERSION_UI_EXECUTABLE_PATH 40750
#define IDS_VERSION_UI_PROFILE_PATH 40751
#define IDS_VERSION_UI_MODULE_PATH 40752
#define IDS_VERSION_UI_USER_DATA_PATH 40753
#define IDS_VERSION_UI_PATH_NOTFOUND 40754
#define IDS_VERSION_UI_VARIATIONS 40755
#define IDS_VERSION_UI_VARIATIONS_SEED_NAME 40756
#define IDS_VERSION_UI_VARIATIONS_CMD 40757
#define IDS_VERSION_UI_COPY_VARIATIONS_LABEL 40758
#define IDS_VERSION_UI_COPY_VARIATIONS_NOTICE 40759
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_TITLE 40764
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_NO_THANKS_BUTTON 40765
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_TURN_ON_BUTTON 40766
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_LEARN_MORE 40767
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_SUBTITLE_DESCRIPTION 40768
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_SUBTITLE_ACTION 40769
#define IDS_WALLET_WALLETABLE_PASS_SAVE_LOYALTY_CARD_DIALOG_TITLE 40770
#define IDS_WALLET_WALLETABLE_PASS_SAVE_EVENT_TICKET_DIALOG_TITLE 40771
#define IDS_WALLET_WALLETABLE_PASS_SAVE_TRANSPORT_TICKET_DIALOG_TITLE 40772
#define IDS_WALLET_WALLETABLE_PASS_SAVE_BOARDING_PASS_DIALOG_TITLE 40773
#define IDS_WALLET_WALLETABLE_PASS_GOOGLE_WALLET_TITLE 40774
#define IDS_WALLET_WALLETABLE_PASS_SAVE_DIALOG_SUBTITLE 40775
#define IDS_WALLET_WALLETABLE_PASS_SAVE_DIALOG_NO_THANKS_BUTTON 40776
#define IDS_WALLET_WALLETABLE_PASS_SAVE_DIALOG_SAVE_BUTTON 40777
#define IDS_WALLET_WALLETABLE_PASS_LOYALTY_CARD_ISSUER_ATTRIBUTE_NAME 40778
#define IDS_WALLET_WALLETABLE_PASS_LOYALTY_CARD_MEMBER_ID_ATTRIBUTE_NAME 40779
#define IDS_WALLET_WALLETABLE_PASS_EVENT_PASS_EVENT_NAME_ATTRIBUTE_NAME 40780
#define IDS_WALLET_WALLETABLE_PASS_EVENT_PASS_ISSUER_ATTRIBUTE_NAME 40781
#define IDS_WALLET_WALLETABLE_PASS_EVENT_PASS_VENUE_ATTRIBUTE_NAME 40782
#define IDS_WALLET_WALLETABLE_PASS_EVENT_PASS_DATE_ATTRIBUTE_NAME 40783
#define IDS_WALLET_WALLETABLE_PASS_TRANSPORT_TICKET_OPERATOR_ATTRIBUTE_NAME 40784
#define IDS_WALLET_WALLETABLE_PASS_TRANSPORT_TICKET_TRIP_ATTRIBUTE_NAME 40785
#define IDS_WALLET_WALLETABLE_PASS_TRANSPORT_TICKET_TRIP_VALUE 40786
#define IDS_WALLET_WALLETABLE_PASS_TRANSPORT_TICKET_DATE_ATTRIBUTE_NAME 40787
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_AIRLINE_ATTRIBUTE_NAME 40788
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_FLIGHT_CODE_ATTRIBUTE_NAME 40789
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_TRIP_ATTRIBUTE_NAME 40790
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_TRIP_VALUE 40791
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_DATE_ATTRIBUTE_NAME 40792
#define IDS_COLLABORATION_SIGNIN_TITLE 40793
#define IDS_COLLABORATION_SIGNIN_DESCRIPTION 40794
#define IDS_COLLABORATION_SIGNIN_BOTTOM_SHEET_TITLE 40795
#define IDS_COLLABORATION_SIGNIN_BOTTOM_SHEET_DESCRIPTION 40796
#define IDS_COLLABORATION_SIGNIN_SYNC_DISMISS 40797
#define IDS_COLLABORATION_SYNC_TITLE 40798
#define IDS_COLLABORATION_SYNC_DESCRIPTION 40799
#define IDS_COLLABORATION_ONE_GROUP_REMOVED_NOTIFICATION 40800
#define IDS_COLLABORATION_ONE_UNNAMED_GROUP_REMOVED_NOTIFICATION 40801
#define IDS_COLLABORATION_TWO_GROUPS_REMOVED_NOTIFICATION 40802
#define IDS_COLLABORATION_SEVERAL_GROUPS_REMOVED_NOTIFICATION 40803
#define IDS_COLLABORATION_RECENT_ACTIVITY_MENU_OPTION 40804
#define IDS_COLLABORATION_SOMETHING_WENT_WRONG_HEADER 40805
#define IDS_COLLABORATION_SOMETHING_WENT_WRONG_BODY 40806
#define IDS_COLLABORATION_LINK_FAILED_HEADER 40807
#define IDS_COLLABORATION_LINK_FAILED_BODY 40808
#define IDS_COLLABORATION_CHROME_OUT_OF_DATE_ERROR_DIALOG_HEADER 40809
#define IDS_COLLABORATION_SHARE_BUTTON_CHROME_OUT_OF_DATE_ERROR_DIALOG_BODY 40810
#define IDS_COLLABORATION_JOIN_BUTTON_CHROME_OUT_OF_DATE_ERROR_DIALOG_BODY 40811
#define IDS_COLLABORATION_CHROME_OUT_OF_DATE_ERROR_DIALOG_UPDATE_BUTTON 40812
#define IDS_COLLABORATION_CHROME_OUT_OF_DATE_ERROR_DIALOG_NOT_NOW_BUTTON 40813
#define IDS_COLLABORATION_CHROME_OUT_OF_DATE_ERROR_DIALOG_CONTINUE_BODY 40814
#define IDS_COLLABORATION_SIGNED_OUT_HEADER 40815
#define IDS_COLLABORATION_SIGNED_OUT_BODY 40816
#define IDS_COLLABORATION_SIGNED_OUT_POSITIVE_BUTTON 40817
#define IDS_COLLABORATION_GROUP_IS_FULL_DESCRIPTION 40818
#define IDS_COLLABORATION_GROUP_IS_FULL_ERROR_DIALOG_HEADER 40819
#define IDS_COLLABORATION_GROUP_IS_FULL_ERROR_DIALOG_BODY 40820
#define IDS_COLLABORATION_ENTREPRISE_SIGNIN_DISABLED_HEADER 40821
#define IDS_COLLABORATION_ENTREPRISE_SIGNIN_DISABLED_BODY 40822
#define IDS_COLLABORATION_ENTREPRISE_SIGNIN_DISABLED_SYNC_HISTORY_BODY 40823
#define IDS_COLLABORATION_ENTREPRISE_SYNC_DISABLED_HEADER 40824
#define IDS_COLLABORATION_ENTREPRISE_SYNC_DISABLED_BODY 40825
#define IDS_COLLABORATION_ENTREPRISE_TABS_SYNC_DISABLED_BODY 40826
#define IDS_COLLABORATION_ENTREPRISE_GROUP_CLOSED_HEADER 40827
#define IDS_COLLABORATION_ENTREPRISE_GROUP_CLOSED_BODY 40828
#define IDS_COLLABORATION_ENTREPRISE_SHARING_OFF_HEADER 40829
#define IDS_COLLABORATION_ENTREPRISE_SHARING_OFF_BODY 40830
#define IDS_COLLABORATION_SHARED_TAB_GROUPS_PANEL_OUT_OF_DATE_MESSAGE_CELL_TEXT 40834
#define IDS_COLLABORATION_SHARED_TAB_GROUPS_AVAILABLE_AGAIN_IPH_MESSAGE 40835
#define IDS_DATA_SHARING_RECENT_ACTIVITY_USER_SELF 40836
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_ADDED 40837
#define IDS_DATA_SHARING_RECENT_ACTIVITY_MEMBER_ADDED_THIS_TAB 40838
#define IDS_DATA_SHARING_RECENT_ACTIVITY_MEMBER_CHANGED_THIS_TAB 40839
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_REMOVED 40840
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_UPDATED 40841
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_GROUP_NAME_UPDATED 40842
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_GROUP_COLOR_UPDATED 40843
#define DATA_SHARING_GROUP_LABEL_NEW_ACTIVITY 40844
#define IDS_DATA_SHARING_RECENT_ACTIVITY_USER_JOINED_GROUP 40845
#define IDS_DATA_SHARING_RECENT_ACTIVITY_USER_LEFT_GROUP 40846
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TIME_DELTA 40847
#define IDS_DATA_SHARING_RECENT_ACTIVITY_SEPARATOR 40848
#define IDS_DATA_SHARING_RECENT_ACTIVITY_DESCRIPTION_FULL 40849
#define IDS_DATA_SHARING_RECENT_ACTIVITY_EMPTY 40850
#define IDS_DATA_SHARING_RECENT_ACTIVITY_JUST_NOW 40851
#define IDS_DATA_SHARING_RECENT_ACTIVITY_UNKNOWN_USER 40852
#define IDS_DATA_SHARING_SHARED_TAB_GROUPS_ACTIVITY 40853
#define IDS_DATA_SHARING_TOAST_TAB_REMOVED 40854
#define IDS_DATA_SHARING_TOAST_TAB_UPDATED 40855
#define IDS_DATA_SHARING_TOAST_TAB_REMOVED_ACTION 40856
#define IDS_DATA_SHARING_TOAST_NEW_MEMBER 40857
#define IDS_DATA_SHARING_TOAST_NEW_MEMBER_MULTIPLE_MEMBERS 40858
#define IDS_DATA_SHARING_TOAST_NEW_MEMBER_ACTION 40859
#define IDS_DATA_SHARING_TOAST_BLOCK_LEAVE 40860
#define IDS_DATA_SHARING_TOAST_BLOCK_LEAVE_MULTIPLE_GROUPS 40861
#define IDS_DATA_SHARING_TAB_GROUP_DEFAULT_TITLE_TABS_COUNT 40862
#define IDS_COLLABORATION_SHARED_TAB_GROUPS_COMMENTS_TITLE 40863
#define IDS_COLLABORATION_SHARED_TAB_GROUPS_COMMENTS_TITLE_WITH_NAME 40864
#define IDS_CONTEXTUAL_TASKS_CONTEXTUAL_TASKS_TITLE 40865
#define IDS_CONTEXTUAL_TASKS_ENTRY_POINT_TOOLTIP 40866
#define IDS_CONTEXTUAL_TASKS_AI_MODE_TITLE 40867
#define IDS_CONTEXTUAL_TASKS_MENU_OPEN_IN_NEW_TAB 40868
#define IDS_CONTEXTUAL_TASKS_MENU_MY_ACTIVITY 40869
#define IDS_CONTEXTUAL_TASKS_MENU_HELP 40870
#define IDS_CONTEXTUAL_TASKS_SOURCES_MENU_TITLE 40871
#define IDS_CONTEXTUAL_TASKS_SOURCES_MENU_TABS_HEADER 40872
#define IDS_CONTEXTUAL_TASKS_SOURCES_MENU_IMAGES_HEADER 40873
#define IDS_CONTEXTUAL_TASKS_SOURCES_MENU_FILES_HEADER 40874
#define IDS_CONTEXTUAL_TASKS_FIRST_RUN_EXPERIENCE_TITLE 40875
#define IDS_CONTEXTUAL_TASKS_FIRST_RUN_EXPERIENCE_DESCRIPTION 40876
#define IDS_CONTEXTUAL_TASKS_FIRST_RUN_EXPERIENCE_LEARN_MORE 40877
#define IDS_CONTEXTUAL_TASKS_FIRST_RUN_EXPERIENCE_ACCEPT_BUTTON 40878
#define IDS_CONTEXTUAL_TASKS_CONTINUE_THREAD_MESSAGE 40879
#define IDS_CONTEXTUAL_TASKS_REOPEN_TABS_BUTTON_TEXT 40880
#define IDS_CONTEXTUAL_TASKS_CONTEXT_MENU_RECENT_TABS 40881
#define IDS_CONTEXTUAL_TASKS_CONTEXT_MENU_ADD_IMAGES 40882
#define IDS_CONTEXTUAL_TASKS_CONTEXT_MENU_ADD_FILES 40883
#define IDS_CONTEXTUAL_TASKS_AI_SIDE_PANEL_TOOL_TIP 40884
#define IDS_CONTEXTUAL_TASKS_CONTEXT_MENU_MOST_RECENT_TABS 40885
#define IDS_CONTEXTUAL_TASKS_CONTEXT_MENU_GEMINI_MODELS 40886
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_NEW_THREAD_TOOL_TIP 40887
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_HISTORY_TOOL_TIP 40888
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_CONTEXT_TOOL_TIP 40889
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_MORE_OPTIONS_TOOL_TIP 40890
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_CLOSE_TOOL_TIP 40891
#define IDS_CONTEXTUAL_TASKS_TOOLBAR_CLOSE_TAB_TOOL_TIP 40892
#define IDS_CONTEXTUAL_TASKS_ADD_TAB_CONTEXT_ERROR_TOAST 40893
#define IDS_CONTEXTUAL_TASKS_CANNOT_SHARE_TAB_TOOL_TIP 40894
#define IDS_CONTEXTUAL_TASKS_OAUTH_ERROR_DIALOG_TITLE 40895
#define IDS_CONTEXTUAL_TASKS_OAUTH_ERROR_DIALOG_BODY 40896
#define IDS_CONTEXTUAL_TASKS_OAUTH_ERROR_DIALOG_RELOAD_BUTTON 40897
#define IDS_AI_MODE_FRIENDLY_ZERO_STATE_TITLE 40898
#define IDS_AI_MODE_FRIENDLY_ZERO_STATE_TITLE_WITHOUT_NAME 40899
#define IDS_CONTEXTUAL_TASKS_COMPOSEBOX_PLACEHOLDER_TEXT 40900
#define IDS_CANCEL 40960
#define IDS_CONTINUE 40961
#define IDS_CLOSE 40962
#define IDS_CLEAR 40963
#define IDS_DONE 40964
#define IDS_LEARN_MORE 40965
#define IDS_LEARN_MORE_MAYBE_TITLE_CASE 40966
#define IDS_OK 40967
#define IDS_RELOAD 40968
#define IDS_ADD 40969
#define IDS_MOVE 40970
#define IDS_REMOVE 40971
#define IDS_OPEN 40972
#define IDS_RESTORE 40973
#define IDS_SAVE 40974
#define IDS_MENU 40975
#define IDS_INSTALL 40976
#define IDS_UPDATE 40977
#define IDS_NO_THANKS 40980
#define IDS_NOT_NOW 40981
#define IDS_TURN_OFF 40982
#define IDS_PLUGIN_NOT_SUPPORTED 40983
#define IDS_PRINT 40984
#define IDS_RECENT_TABS 40985
#define IDS_RECENTLY_CLOSED 40986
#define IDS_YOUR_DEVICES 40987
#define IDS_CHOOSE 40988
#define IDS_ACCNAME_BACK 40989
#define IDS_ACCNAME_FORWARD 40990
#define IDS_ACCNAME_OK 40991
#define IDS_ACCNAME_CANCEL 40992
#define IDS_ACCNAME_DONE 40993
#define IDS_ACCNAME_SAVE 40994
#define IDS_ACCNAME_CLOSE 40995
#define IDS_ACCNAME_OPEN 40996
#define IDS_ACCNAME_OPEN_IN_NEW_TAB 40997
#define IDS_ACCNAME_PREVIOUS 40998
#define IDS_ACCNAME_NEXT 40999
#define IDS_ACCNAME_LOCATION 41000
#define IDS_ACCNAME_TAB_LIST 41001
#define IDS_UTILITY_PROCESS_JSON_PARSER_NAME 41002
#define IDS_SESSION_CRASHED_VIEW_RESTORE_BUTTON 41003
#define IDS_SESSION_CRASHED_VIEW_STARTUP_PAGES_BUTTON 41004
#define IDS_OPTIONS_ADVANCED_SECTION_TITLE_PRIVACY 41005
#define IDS_OPTIONS_ADVANCED_SECTION_TITLE_SAFETY_CHECK 41006
#define IDS_CONTENT_BOOKMARK_PARSER_SERVICE_DISPLAY_NAME 41007
#define IDS_PATCH_SERVICE_DISPLAY_NAME 41008
#define IDS_PASSWORD_MANAGER_CSV_PASSWORD_PARSER_SERVICE_DISPLAY_NAME 41009
#define IDS_UNZIP_SERVICE_DISPLAY_NAME 41010
#define IDS_INTERNAL_DEBUG_PAGES_DISABLED_HEADING 41011
#define IDS_SETTINGS_MANAGE_IN_GOOGLE_PASSWORD_MANAGER 41012
#define IDS_SETTINGS_MANAGE_IN_YOUR_GOOGLE_ACCOUNT 41013
#define IDS_SETTINGS_MANAGE_OTHER_DATA_LABEL 41014
#define IDS_SETTINGS_MANAGE_OTHER_GOOGLE_DATA_LABEL 41015
#define IDS_SETTINGS_MY_ACTIVITY 41016
#define IDS_SETTINGS_OTHER_DATA_TITLE 41017
#define IDS_SETTINGS_OTHER_GOOGLE_DATA_TITLE 41018
#define IDS_SETTINGS_PASSWORDS_AND_PASSKEYS 41019
#define IDS_SETTINGS_MANAGE_PASSWORDS_SUB_LABEL 41020
#define IDS_SETTINGS_SEARCH_HISTORY 41021
#define IDS_SETTINGS_MANAGE_OTHER_DATA_SUB_LABEL 41022
#define IDS_SETTINGS_OTHER_DATA_DESCRIPTION 41023
#define IDS_SETTINGS_CLEAR_NON_GOOGLE_SEARCH_HISTORY_NON_PREPOPULATED_DSE 41024
#define IDS_SETTINGS_CLEAR_NON_GOOGLE_SEARCH_HISTORY_PREPOPULATED_DSE 41025

// ---------------------------------------------------------------------------
// From extensions_strings.h:

#define IDS_EXTENSION_BAD_FILE_ENCODING 46140
#define IDS_EXTENSION_CANT_GET_ABSOLUTE_PATH 46141
#define IDS_EXTENSION_CONTAINS_PRIVATE_KEY 46142
#define IDS_EXTENSION_CRX_EXISTS 46143
#define IDS_EXTENSION_CONTENT_SCRIPT_FILE_TOO_LARGE 46144
#define IDS_EXTENSION_CONTENT_SCRIPT_FILE_BAD_JS_MIME_TYPE 46145
#define IDS_EXTENSION_CONTENT_SCRIPT_FILE_BAD_CSS_MIME_TYPE 46146
#define IDS_EXTENSION_DIRECTORY_NO_EXISTS 46147
#define IDS_EXTENSION_ERROR_WHILE_SIGNING 46148
#define IDS_EXTENSION_FAILED_DURING_PACKAGING 46149
#define IDS_EXTENSION_LOAD_ABOUT_PAGE_FAILED 46150
#define IDS_EXTENSION_LOAD_BACKGROUND_SCRIPT_FAILED 46151
#define IDS_EXTENSION_LOAD_BACKGROUND_PAGE_FAILED 46152
#define IDS_EXTENSION_LOAD_CSS_FAILED 46153
#define IDS_EXTENSION_LOAD_JAVASCRIPT_FAILED 46154
#define IDS_EXTENSION_LOAD_OPTIONS_PAGE_FAILED 46155
#define IDS_EXTENSION_LOCALES_NO_DEFAULT_LOCALE_SPECIFIED 46156
#define IDS_EXTENSION_MANIFEST_UNREADABLE 46157
#define IDS_EXTENSION_MANIFEST_INVALID 46158
#define IDS_EXTENSION_PACKAGE_IMAGE_ERROR 46159
#define IDS_EXTENSION_PACKAGE_UNZIP_ERROR 46160
#define IDS_EXTENSION_PRIVATE_KEY_EXISTS 46161
#define IDS_EXTENSION_PRIVATE_KEY_FAILED_TO_READ 46162
#define IDS_EXTENSION_PRIVATE_KEY_FAILED_TO_EXPORT 46163
#define IDS_EXTENSION_PRIVATE_KEY_FAILED_TO_OUTPUT 46164
#define IDS_EXTENSION_PRIVATE_KEY_INVALID 46165
#define IDS_EXTENSION_PRIVATE_KEY_NO_EXISTS 46166
#define IDS_EXTENSION_PRIVATE_KEY_INVALID_PATH 46167
#define IDS_EXTENSION_PRIVATE_KEY_INVALID_FORMAT 46168
#define IDS_EXTENSION_PUBLIC_KEY_FAILED_TO_EXPORT 46169
#define IDS_EXTENSION_SHARING_VIOLATION 46170
#define IDS_EXTENSION_CANT_INSTALL_POLICY_BLOCKED 46171
#define IDS_EXTENSION_CANT_MODIFY_POLICY_REQUIRED 46172
#define IDS_EXTENSION_CANT_UNINSTALL_POLICY_REQUIRED 46173
#define IDS_EXTENSION_MANIFEST_VERSION_NOT_SUPPORTED 46174
#define IDS_EXTENSION_CANT_INSTALL_BLOCKED_BY_RISK_SCORE 46175
#define IDS_DEVICE_NAME_WITH_PRODUCT_SERIAL 46176
#define IDS_DEVICE_NAME_WITH_PRODUCT_UNKNOWN_VENDOR 46177
#define IDS_DEVICE_NAME_WITH_PRODUCT_UNKNOWN_VENDOR_SERIAL 46178
#define IDS_DEVICE_NAME_WITH_PRODUCT_VENDOR 46179
#define IDS_DEVICE_NAME_WITH_PRODUCT_VENDOR_SERIAL 46180
#define IDS_DEVICE_NAME_WITH_UNKNOWN_PRODUCT_UNKNOWN_VENDOR 46181
#define IDS_DEVICE_NAME_WITH_UNKNOWN_PRODUCT_UNKNOWN_VENDOR_SERIAL 46182
#define IDS_DEVICE_NAME_WITH_UNKNOWN_PRODUCT_VENDOR 46183
#define IDS_DEVICE_NAME_WITH_UNKNOWN_PRODUCT_VENDOR_SERIAL 46184
#define IDS_DEVICE_PERMISSIONS_PROMPT_SINGLE_SELECTION 46185
#define IDS_DEVICE_PERMISSIONS_PROMPT_MULTIPLE_SELECTION 46186
#define IDS_CAMERA_FACING_USER 46187
#define IDS_CAMERA_FACING_ENVIRONMENT 46188
#define IDS_EXTENSION_USB_DEVICE_PRODUCT_NAME_AND_VENDOR 46189
#define IDS_EXTENSION_TASK_MANAGER_APPVIEW_TAG_PREFIX 46190
#define IDS_EXTENSION_TASK_MANAGER_EXTENSIONOPTIONS_TAG_PREFIX 46191
#define IDS_EXTENSION_TASK_MANAGER_MIMEHANDLERVIEW_TAG_PREFIX 46192
#define IDS_EXTENSION_TASK_MANAGER_WEBVIEW_TAG_PREFIX 46193
#define IDS_EXTENSION_WARNINGS_NETWORK_DELAY 46194
#define IDS_EXTENSION_WARNINGS_DOWNLOAD_FILENAME_CONFLICT 46195
#define IDS_EXTENSION_WARNING_RELOAD_TOO_FREQUENT 46196
#define IDS_EXTENSION_WARNING_RULESET_FAILED_TO_LOAD 46197
#define IDS_EXTENSION_WARNING_ENABLED_RULE_COUNT_EXCEEDED 46198
#define IDS_EXTENSION_IS_BLOCKLISTED 46199
#define IDS_APP_CANT_DOWNGRADE_VERSION 46200
#define IDS_EXTENSION_CANT_DOWNGRADE_VERSION 46201
#define IDS_EXTENSION_MOVE_DIRECTORY_TO_PROFILE_FAILED 46202
#define IDS_EXTENSION_INSTALL_DEPENDENCY_OLD_VERSION 46203
#define IDS_EXTENSION_INSTALL_DEPENDENCY_NOT_SHARED_MODULE 46204
#define IDS_EXTENSION_INSTALL_DEPENDENCY_NOT_ALLOWLISTED 46205
#define IDS_EXTENSION_INSTALL_DISALLOWED_ON_SITE 46206
#define IDS_EXTENSION_INSTALL_GALLERY_ONLY 46207
#define IDS_EXTENSION_INSTALL_INCORRECT_APP_CONTENT_TYPE 46208
#define IDS_EXTENSION_INSTALL_INCORRECT_INSTALL_HOST 46209
#define IDS_EXTENSION_INSTALL_KIOSK_MODE_ONLY 46210
#define IDS_EXTENSION_INSTALL_NOT_ENABLED 46211
#define IDS_EXTENSION_OVERLAPPING_WEB_EXTENT 46212
#define IDS_EXTENSION_INSTALL_PROCESS_CRASHED 46213
#define IDS_EXTENSION_INSTALL_UNEXPECTED_ID 46214
#define IDS_EXTENSION_INSTALL_UNEXPECTED_VERSION 46215
#define IDS_EXTENSION_PACKAGE_ERROR_CODE 46216
#define IDS_EXTENSION_PACKAGE_ERROR_MESSAGE 46217
#define IDS_EXTENSION_PACKAGE_INSTALL_ERROR 46218
#define IDS_EXTENSION_WEBGL_NOT_SUPPORTED 46219
#define IDS_EXTENSION_WEB_STORE_TITLE 46220
#define IDS_EXTENSIONS_LOAD_ERROR_ALERT_HEADING 46221
#define IDS_EXTENSIONS_LOAD_ERROR_MESSAGE 46222

// ---------------------------------------------------------------------------
// From generated_resources.h:

#define IDS_ACCESS_CODE_CAST_ACCESS_CODE_MESSAGE 1600
#define IDS_ACCESS_CODE_CAST_BACK 1601
#define IDS_ACCESS_CODE_CAST_CAST 1602
#define IDS_ACCESS_CODE_CAST_CONNECT 1603
#define IDS_ACCESS_CODE_CAST_DIALOG_TITLE 1604
#define IDS_ACCESS_CODE_CAST_ENTER_CHARACTER 1605
#define IDS_ACCESS_CODE_CAST_ERROR_ACCESS_CODE 1606
#define IDS_ACCESS_CODE_CAST_ERROR_DIFFERENT_NETWORK 1607
#define IDS_ACCESS_CODE_CAST_ERROR_NETWORK 1608
#define IDS_ACCESS_CODE_CAST_ERROR_PERMISSION 1609
#define IDS_ACCESS_CODE_CAST_ERROR_TOO_MANY_REQUESTS 1610
#define IDS_ACCESS_CODE_CAST_ERROR_UNKNOWN 1611
#define IDS_ACCESS_CODE_CAST_ERROR_PROFILE_SYNC 1612
#define IDS_ACCESS_CODE_CAST_INPUT_ARIA_LABEL 1613
#define IDS_ACCESS_CODE_CAST_MANAGED_FOOTNOTE_DAYS 1614
#define IDS_ACCESS_CODE_CAST_MANAGED_FOOTNOTE_HOURS 1615
#define IDS_ACCESS_CODE_CAST_MANAGED_FOOTNOTE_MONTHS 1616
#define IDS_ACCESS_CODE_CAST_MANAGED_FOOTNOTE_YEARS 1617
#define IDS_ACCESS_CODE_CAST_SUBMIT 1618
#define IDS_ACCESS_CODE_CAST_USE_CAMERA 1619
#define IDS_HANDOFF_TAKE_OVER_TASK_LABEL 1620
#define IDS_HANDOFF_GIVE_TASK_BACK_LABEL 1621
#define IDS_HANDOFF_TAKE_OVER_TASK_A11Y_LABEL 1622
#define IDS_HANDOFF_GIVE_TASK_BACK_A11Y_LABEL 1623
#define IDS_TASK_IN_PROGRESS_TOAST_BODY 1624
#define IDS_ACTOR_TASK_NUDGE_CHECK_TASK_LABEL 1625
#define IDS_ACTOR_TASK_NUDGE_TASK_COMPLETE_LABEL 1626
#define IDR_ACTOR_TASK_LIST_BUBBLE_ROW_TAB_CLOSED_SUBTITLE 1627
#define IDR_ACTOR_TASK_LIST_BUBBLE_ROW_CHECK_TASK_SUBTITLE 1628
#define IDR_ACTOR_TASK_LIST_BUBBLE_ROW_ACTING_TASK_SUBTITLE 1629
#define IDS_ACTOR_TASK_LIST_BUBBLE_A11Y_LABEL 1630
#define IDS_ACTOR_TASK_INDICATOR_TOOLTIP 1631
#define IDR_ACTOR_TASK_LIST_BUBBLE_ROW_PAUSED_TASK_SUBTITLE 1632
#define IDR_ACTOR_TASK_LIST_BUBBLE_ROW_COMPLETED_TASK_SUBTITLE 1633
#define IDR_ACTOR_TASK_LIST_BUBBLE_ROW_FAILED_TASK_SUBTITLE 1634
#define IDS_TOOLTIP_TAB_ALERT_STATE_ACTOR_ACCESSING 1635
#define IDS_TAB_AX_LABEL_ACTOR_ACCESSING 1636
#define IDS_ACTOR_OVERLAY_SNACKBAR_MESSAGE 1637
#define IDS_APP_MANAGEMENT_CAMERA 1638
#define IDS_APP_MANAGEMENT_LOCATION 1639
#define IDS_APP_MANAGEMENT_MICROPHONE 1640
#define IDS_APP_MANAGEMENT_NOTIFICATIONS 1641
#define IDS_APP_MANAGEMENT_PERMISSIONS 1643
#define IDS_APP_MANAGEMENT_PERMISSIONS_WITH_ORIGIN 1644
#define IDS_APP_MANAGEMENT_MORE_SETTINGS 1645
#define IDS_APP_MANAGEMENT_WINDOW 1646
#define IDS_APP_MANAGEMENT_UNINSTALL_APP 1647
#define IDS_APP_MANAGEMENT_RUN_ON_OS_LOGIN 1648
#define IDS_APP_MANAGEMENT_POLICY_APP_POLICY_STRING 1649
#define IDS_APP_MANAGEMENT_INTENT_SETTINGS_TITLE 1650
#define IDS_APP_MANAGEMENT_INTENT_SHARING_APP_OPEN 1651
#define IDS_APP_MANAGEMENT_INTENT_SHARING_BROWSER_OPEN 1652
#define IDS_APP_MANAGEMENT_INTENT_SHARING_TAB_EXPLANATION 1653
#define IDS_APP_MANAGEMENT_INTENT_SETTINGS_DIALOG_TITLE 1654
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_CHANGE_BUTTON 1655
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TITLE 1656
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_1_APP 1657
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_2_APPS 1658
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_3_APPS 1659
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_4_APPS 1660
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_5_OR_MORE_APPS 1661
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_1_APP 1662
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_2_APPS 1663
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_3_APPS 1664
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_4_APPS 1665
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_5_OR_MORE_APPS 1666
#define IDS_APP_MANAGEMENT_APP_VERSION_TITLE 1667
#define IDS_APP_MANAGEMENT_APP_SIZE_TITLE 1668
#define IDS_APP_MANAGEMENT_APP_DATA_SIZE_TITLE 1669
#define IDS_APP_MANAGEMENT_FILE_HANDLING_HEADER 1670
#define IDS_APP_MANAGEMENT_FILE_HANDLING_OVERFLOW_DIALOG_TITLE 1671
#define IDS_APP_MANAGEMENT_FILE_HANDLING_SET_DEFAULTS_LINK 1672
#define IDS_APP_MANAGEMENT_FILE_HANDLING_TYPES 1673
#define IDS_APP_MANAGEMENT_APP_CONTENT_TITLE 1674
#define IDS_APP_MANAGEMENT_APP_CONTENT_SUBTITLE 1675
#define IDS_APP_MANAGEMENT_APP_CONTENT_DIALOG_SUBTITLE 1676
#define IDS_APP_MANAGEMENT_IS_SUB_APP_PERMISSION_EXPLANATION 1677
#define IDS_APP_MANAGEMENT_HAS_SUB_APPS_PERMISSION_EXPLANATION 1678
#define IDS_BOOKMARK_GROUP_FROM_FIREFOX 1681
#define IDS_BOOKMARK_GROUP_FROM_SAFARI 1682
#define IDS_BOOKMARK_GROUP 1683
#define IDS_UNNAMED_BOOKMARK_BUTTON_ACCESSIBLE_NAME 1684
#define IDS_BOOKMARK_BAR_SHOW_APPS_SHORTCUT 1685
#define IDS_BOOKMARK_BAR_SHOW_TAB_GROUPS 1686
#define IDS_BOOKMARK_BAR_SHOW_READING_LIST 1687
#define IDS_BOOKMARK_BAR_SHOW_MANAGED_BOOKMARKS_DEFAULT_NAME 1688
#define IDS_BOOKMARK_BAR_SHOW_MANAGED_BOOKMARKS 1689
#define IDS_BOOKMARK_BAR_APPS_SHORTCUT_NAME 1690
#define IDS_BOOKMARK_BAR_APPS_SHORTCUT_TOOLTIP 1691
#define IDS_BOOKMARK_BAR_OVERFLOW_BUTTON_TOOLTIP 1692
#define IDS_BOOKMARK_BAR_OPEN_ALL 1693
#define IDS_BOOKMARK_BAR_OPEN_ALL_COUNT 1694
#define IDS_BOOKMARK_BAR_OPEN_ALL_COUNT_NEW_WINDOW 1695
#define IDS_BOOKMARK_BAR_OPEN_ALL_COUNT_INCOGNITO 1696
#define IDS_BOOKMARK_BAR_OPEN_ALL_COUNT_NEW_TAB_GROUP 1697
#define IDS_BOOKMARK_BAR_OPEN_IN_NEW_TAB 1698
#define IDS_BOOKMARK_BAR_OPEN_IN_NEW_WINDOW 1699
#define IDS_BOOKMARK_BAR_OPEN_INCOGNITO 1700
#define IDS_BOOKMARK_BAR_OPEN_IN_SPLIT_VIEW 1701
#define IDS_BOOKMARK_BAR_EDIT 1702
#define IDS_BOOKMARK_BAR_RENAME_FOLDER 1703
#define IDS_BOOKMARK_BAR_REMOVE 1704
#define IDS_BOOKMARK_BAR_ADD_NEW_BOOKMARK 1705
#define IDS_BOOKMARK_BAR_NEW_FOLDER 1706
#define IDS_SHOW_BOOKMARK_BAR 1707
#define IDS_HIDE_BOOKMARK_BAR 1708
#define IDS_BOOKMARK_BAR_SHOULD_OPEN_ALL 1709
#define IDS_BOOKMARK_BAR_ALREADY_CREATED_GROUP 1710
#define IDS_BOOKMARK_BAR_REPLACE_OR_CREATE_NEW_GROUP_TITLE 1711
#define IDS_BOOKMARK_BAR_CREATE_NEW_GROUP_BUTTON 1712
#define IDS_BOOKMARK_BAR_REPLACE_OLD_GROUP_BUTTON 1713
#define IDS_BOOKMARK_BUBBLE_PAGE_BOOKMARKED 1714
#define IDS_BOOKMARK_BUBBLE_PAGE_BOOKMARK 1715
#define IDS_BOOKMARK_BUBBLE_EDIT_BOOKMARK 1716
#define IDS_BOOKMARK_BUBBLE_NAME_LABEL 1717
#define IDS_BOOKMARK_BUBBLE_SAVED_TO 1718
#define IDS_BOOKMARK_AX_BUBBLE_NAME_LABEL 1719
#define IDS_BOOKMARK_BUBBLE_FOLDER_LABEL 1720
#define IDS_BOOKMARK_AX_BUBBLE_FOLDER_LABEL 1721
#define IDS_BOOKMARK_BUBBLE_OPTIONS 1722
#define IDS_BOOKMARK_BUBBLE_CHOOSER_ANOTHER_FOLDER 1723
#define IDS_BOOKMARK_DICE_PROMO_SYNC_MESSAGE 1724
#define IDS_BOOKMARK_VERIFY_PROMO_SUBTITLE 1725
#define IDS_BOOKMARK_PROMO_TITLE 1730
#define IDS_BOOKMARK_EDITOR_NAME_LABEL 1731
#define IDS_BOOKMARK_AX_EDITOR_NAME_LABEL 1732
#define IDS_BOOKMARK_AX_EDITOR_URL_LABEL 1734
#define IDS_BOOKMARK_EDITOR_URL_LABEL 1735
#define IDS_BOOKMARK_EDITOR_CONFIRM_DELETE 1736
#define IDS_TAB_GROUP_TO_BOOKMARK_FOLDER_SUBTITLE 1737
#define IDS_BOOKMARK_EDITOR_NEW_FOLDER_BUTTON 1738
#define IDS_BOOKMARK_EDITOR_NEW_FOLDER_MENU_ITEM 1739
#define IDS_BOOKMARK_FOLDER_EDITOR_WINDOW_TITLE 1740
#define IDS_BOOKMARK_FOLDER_EDITOR_WINDOW_TITLE_NEW 1741
#define IDS_UNNAMED_BOOKMARK_FOLDER 1742
#define IDS_BOOKMARK_ALL_TABS_DIALOG_TITLE 1743
#define IDS_TAB_GROUP_TO_BOOKMARK_FOLDER_TITLE 1744
#define IDS_BOOKMARK_MANAGER_TITLE 1745
#define IDS_BOOKMARK_MANAGER_SEARCH_BUTTON 1746
#define IDS_BOOKMARK_MANAGER 1747
#define IDS_BOOKMARK_MANAGER_ORGANIZE_MENU 1748
#define IDS_BOOKMARK_MANAGER_INVALID_URL 1749
#define IDS_EXPORT_BOOKMARKS_DEFAULT_FILENAME 1750
#define IDS_BOOKMARK_MANAGER_ADD_BOOKMARK_TITLE 1751
#define IDS_BOOKMARK_MANAGER_ADD_FOLDER_TITLE 1752
#define IDS_BOOKMARK_MANAGER_CLEAR_SEARCH 1753
#define IDS_BOOKMARK_MANAGER_EMPTY_LIST 1754
#define IDS_BOOKMARK_MANAGER_EMPTY_UNMODIFIABLE_LIST 1755
#define IDS_BOOKMARK_MANAGER_FOLDER_LABEL 1756
#define IDS_BOOKMARK_MANAGER_FOLDER_RENAME_TITLE 1757
#define IDS_BOOKMARK_MANAGER_FOLDER_LIST_CHANGED 1758
#define IDS_BOOKMARK_MANAGER_LIST_AX_LABEL 1759
#define IDS_BOOKMARK_MANAGER_MENU_ADD_BOOKMARK 1760
#define IDS_BOOKMARK_MANAGER_MENU_ADD_FOLDER 1761
#define IDS_BOOKMARK_MANAGER_MENU_CUT 1762
#define IDS_BOOKMARK_MANAGER_MENU_COPY 1763
#define IDS_BOOKMARK_MANAGER_MENU_PASTE 1764
#define IDS_BOOKMARK_MANAGER_MENU_EXPORT 1765
#define IDS_BOOKMARK_MANAGER_MENU_HELP_CENTER 1766
#define IDS_BOOKMARK_MANAGER_MENU_IMPORT 1767
#define IDS_BOOKMARK_MANAGER_MENU_IMPORT_BEGAN 1768
#define IDS_BOOKMARK_MANAGER_MENU_IMPORT_ENDED 1769
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL 1770
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_WITH_COUNT 1771
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_NEW_WINDOW 1772
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_NEW_WINDOW_WITH_COUNT 1773
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_INCOGNITO 1774
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_INCOGNITO_WITH_COUNT 1775
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_NEW_TAB_GROUP 1776
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_NEW_TAB_GROUP_WITH_COUNT 1777
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_IN_NEW_TAB 1778
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_IN_NEW_WINDOW 1779
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_INCOGNITO 1780
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_IN_NEW_TAB_GROUP 1781
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_IN_SPLIT_VIEW 1782
#define IDS_BOOKMARK_MANAGER_MENU_RENAME 1783
#define IDS_BOOKMARK_MANAGER_MENU_SHOW_IN_FOLDER 1784
#define IDS_BOOKMARK_MANAGER_MENU_SORT 1785
#define IDS_BOOKMARK_MANAGER_MORE_ACTIONS 1786
#define IDS_BOOKMARK_MANAGER_MORE_ACTIONS_AX_LABEL 1787
#define IDS_BOOKMARK_MANAGER_MORE_ACTIONS_MULTI_AX_LABEL 1788
#define IDS_BOOKMARK_MANAGER_OPEN_DIALOG_TITLE 1789
#define IDS_BOOKMARK_MANAGER_OPEN_DIALOG_CONFIRM 1790
#define IDS_BOOKMARK_MANAGER_ITEMS_SELECTED 1791
#define IDS_BOOKMARK_MANAGER_ITEMS_UNSELECTED 1792
#define IDS_BOOKMARK_MANAGER_SIDEBAR_AX_LABEL 1793
#define IDS_BOOKMARK_MANAGER_TOAST_FOLDER_SORTED 1794
#define IDS_BOOKMARK_MANAGER_TOAST_ITEM_DELETED 1795
#define IDS_BOOKMARK_MANAGER_TOAST_ITEMS_DELETED 1796
#define IDS_BOOKMARK_MANAGER_TOAST_ITEM_COPIED 1797
#define IDS_BOOKMARK_MANAGER_TOAST_ITEMS_COPIED 1798
#define IDS_BOOKMARKS_MENU 1799
#define IDS_BOOKMARKS_AND_LISTS_MENU 1800
#define IDS_SHOW_BOOKMARK_SIDE_PANEL 1801
#define IDS_BOOKMARK_THIS_TAB 1802
#define IDS_BOOKMARK_ALL_TABS 1803
#define IDS_BOOKMARKS_LIST_TITLE 1804
#define IDS_TOOLTIP_STARRED 1805
#define IDS_BOOKMARK_SCREEN_READER_CREATED 1806
#define IDS_BOOKMARK_SCREEN_READER_FOLDER_CREATED 1807
#define IDS_BOOKMARK_SCREEN_READER_REORDERED 1808
#define IDS_BOOKMARK_SCREEN_READER_MOVED 1809
#define IDS_TOOLTIP_TAB_ALERT_STATE_GLIC_ACCESSING 1810
#define IDS_TOOLTIP_TAB_ALERT_STATE_GLIC_SHARING 1811
#define IDS_TAB_AX_LABEL_GLIC_ACCESSING 1812
#define IDS_TAB_AX_LABEL_GLIC_SHARING 1813
#define IDS_GLIC_PROMO_BODY 1814
#define IDS_GLIC_STATUS_ICON_MENU_CUSTOMIZE_KEYBOARD_SHORTCUT 1815
#define IDS_GLIC_STATUS_ICON_MENU_EXIT 1816
#define IDS_GLIC_STATUS_ICON_MENU_SETTINGS 1817
#define IDS_GLIC_OS_WIDGET_TOGGLE_HELP_BUBBLE 1818
#define IDS_GLIC_OS_WIDGET_KEYBOARD_SHORTCUT_HELP_BUBBLE 1819
#define IDS_GLIC_OFFLINE_NOTICE_HEADER 1820
#define IDS_GLIC_OFFLINE_NOTICE_ACTION 1821
#define IDS_GLIC_OFFLINE_NOTICE_ACTION_BUTTON 1822
#define IDS_GLIC_UNRESPONSIVE_MESSAGE 1823
#define IDS_GLIC_ERROR_NOTICE_HEADER 1824
#define IDS_GLIC_ERROR_NOTICE 1825
#define IDS_GLIC_ERROR_NOTICE_ACTION_BUTTON 1826
#define IDS_GLIC_NOTICE_CLOSE_BUTTON_LABEL 1827
#define IDS_GLIC_SIGN_IN_NOTICE_HEADER 1828
#define IDS_GLIC_SIGN_IN_NOTICE 1829
#define IDS_GLIC_SIGN_IN_NOTICE_ACTION_BUTTON 1830
#define IDS_GLIC_INELIGIBLE_PROFILE_NOTICE_HEADER 1831
#define IDS_GLIC_INELIGIBLE_PROFILE_NOTICE_ACTION_BUTTON 1832
#define IDS_GLIC_DISABLED_BY_ADMIN_NOTICE 1833
#define IDS_GLIC_DISABLED_BY_ADMIN_NOTICE_WITH_LINK 1834
#define IDS_GLIC_DISABLED_BY_ADMIN_NOTICE_CLOSE_BUTTON 1835
#define IDS_GLIC_DISABLED_BY_ADMIN_NOTICE_HEADER 1836
#define IDS_SETTINGS_GLIC_ROW_SUBLABEL 1837
#define IDS_SETTINGS_GLIC_POLICY_DISABLED_MESSAGE 1838
#define IDS_SETTINGS_GLIC_PREFERENCES_SECTION 1839
#define IDS_SETTINGS_GLIC_PERMISSIONS_SECTION 1840
#define IDS_SETTINGS_GLIC_BUTTON_TOGGLE 1841
#define IDS_SETTINGS_GLIC_BUTTON_TOGGLE_SUBLABEL 1842
#define IDS_SETTINGS_GLIC_OS_WIDGET_TOGGLE 1843
#define IDS_SETTINGS_GLIC_OS_WIDGET_TOGGLE_SHORTCUTS_ONLY 1844
#define IDS_SETTINGS_GLIC_OS_WIDGET_TOGGLE_SUBLABEL 1845
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT 1846
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_EDIT_LABEL 1847
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_CLEAR_LABEL 1848
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_SUBLABEL 1849
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_LEARN_MORE_LABEL 1850
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_LEARN_MORE_ARIA_LABEL 1851
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT_LEARN_MORE_ARIA_LABEL 1852
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT_LEARN_MORE_ARIA_LABEL 1853
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT 1854
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT_EDIT_LABEL 1855
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT_CLEAR_LABEL 1856
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT_SUBLABEL 1857
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT 1858
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT_EDIT_LABEL 1859
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT_CLEAR_LABEL 1860
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT_SUBLABEL 1861
#define IDS_SETTINGS_GLIC_CLOSED_CAPTIONING 1862
#define IDS_SETTINGS_GLIC_CLOSED_CAPTIONING_SUBLABEL 1863
#define IDS_SETTINGS_GLIC_KEEP_SIDEPANEL_OPEN_ON_NEW_TABS 1864
#define IDS_SETTINGS_GLIC_PERMISSIONS_LOCATION_TOGGLE 1865
#define IDS_SETTINGS_GLIC_PERMISSIONS_LOCATION_TOGGLE_SUBLABEL 1866
#define IDS_SETTINGS_GLIC_PERMISSIONS_LOCATION_TOGGLE_SUBLABEL_DATA_PROTECTED 1867
#define IDS_SETTINGS_GLIC_PERMISSIONS_MICROPHONE_TOGGLE 1868
#define IDS_SETTINGS_GLIC_PERMISSIONS_MICROPHONE_TOGGLE_SUBLABEL 1869
#define IDS_SETTINGS_GLIC_PERMISSIONS_MICROPHONE_TOGGLE_SUBLABEL_DATA_PROTECTED 1870
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_TOGGLE 1871
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_TOGGLE_SUBLABEL 1872
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_TOGGLE_SUBLABEL_DATA_PROTECTED 1873
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_TOGGLE 1874
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_TOGGLE_SUBLABEL 1875
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_TOGGLE_SUBLABEL_DATA_PROTECTED 1876
#define IDS_SETTINGS_GLIC_PERMISSIONS_ACTIVITY_BUTTON 1877
#define IDS_SETTINGS_GLIC_PERMISSIONS_ACTIVITY_BUTTON_SUBLABEL 1878
#define IDS_SETTINGS_GLIC_PERMISSIONS_ACTIVITY_BUTTON_URL 1879
#define IDS_SETTINGS_GLIC_EXTENSIONS_BUTTON 1880
#define IDS_SETTINGS_GLIC_EXTENSIONS_BUTTON_SUBLABEL 1881
#define IDS_SETTINGS_GLIC_EXTENSIONS_BUTTON_URL 1882
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_WHEN_ON_1 1883
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_CONSIDER_1 1884
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_CONSIDER_1_LEARN_MORE_LABEL 1885
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_WHEN_ON_1 1886
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_WHEN_ON_2 1887
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_WHEN_ON_2_NO_LIVE 1888
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_CONSIDER_1 1889
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_CONSIDER_2 1890
#define IDS_SETTINGS_GLIC_PERSONAL_CONTEXT_LABEL 1891
#define IDS_SETTINGS_GLIC_PERSONAL_CONTEXT 1892
#define IDS_SETTINGS_GLIC_INSTRUCTIONS_BUTTON 1893
#define IDS_SETTINGS_GLIC_INSTRUCTIONS_BUTTON_SUBLABEL 1894
#define IDS_SETTINGS_GLIC_PERMISSIONS_CHROME_WEB_ACTUATION_TOGGLE 1895
#define IDS_SETTINGS_GLIC_PERMISSIONS_CHROME_WEB_ACTUATION_TOGGLE_SUBLABEL 1896
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_WHEN_ON_1 1897
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_WHEN_ON_2 1898
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_CONSIDER_1 1899
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_CONSIDER_2 1900
#define IDS_GLIC_PIN 1901
#define IDS_GLIC_UNPIN 1902
#define IDS_GLIC_SCREEN_PICKER_REQUESTER 1903
#define IDS_GLIC_SCREEN_PICKER_HEADLINE 1904
#define IDS_GLIC_SCREEN_PICKER_DESCRIPTION 1905
#define IDS_GLIC_SCREEN_PICKER_CTA 1906
#define IDS_GLIC_INACTIVE_VIEW_CARD_TEXT 1907
#define IDS_GLIC_WINDOW_TITLE 1908
#define IDS_GLIC_WINDOW_TITLE_FIRST_LOAD 1909
#define IDS_GLIC_WINDOW_FIRST_FOCUS_LOST_ANNOUNCEMENT 1910
#define IDS_TASK_MANAGER_GLIC_RENDERER_PREFIX 1911
#define IDS_TAB_CXMENU_GLIC_START_SHARE 1912
#define IDS_TAB_CXMENU_GLIC_STOP_SHARE 1913
#define IDS_TAB_CXMENU_GLIC_SHARE_LIMIT 1914
#define IDS_TAB_CXMENU_GLIC_CREATE_NEW_CHAT 1915
#define IDS_TAB_CXMENU_GLIC_UNSHARE 1916
#define IDS_GLIC_BUTTON_CXMENU_UNPIN 1917
#define IDS_GLIC_BUTTON_ENTRYPOINT_LABEL 1918
#define IDS_GLIC_BUTTON_ENTRYPOINT_ASK_GEMINI_LABEL 1919
#define IDS_GLIC_BUTTON_ENTRYPOINT_BROWSE_LABEL 1920
#define IDS_GLIC_BUTTON_ENTRYPOINT_ASK_ABOUT_THIS_PAGE_LABEL 1921
#define IDS_CONTENT_CONTEXT_GLICSHAREIMAGE 1922
#define IDS_GLIC_CONTEXT_MENU_SUMMARIZE_PAGE_WITH_GEMINI 1923
#define IDS_GLIC_SUMMARIZE_PAGE_PROMPT 1924
#define IDS_GLIC_PROMO_CONFIRM 1925
#define IDS_GLIC_TRYIT_TITLE 1926
#define IDS_GLIC_TRYIT_BODY 1927
#define IDS_GLIC_SHORTCUT_IPH_TEXT_TEMPLATE 1928
#define IDS_GLIC_SHORTCUT_IPH_TEXT 1929
#define IDS_GLIC_SHORTCUT_IPH_SCREENREADER 1930
#define IDS_GLIC_SELECTION_ASK_ABOUT 1931
#define IDS_GLIC_SELECTION_TELL_ME_ABOUT 1932
#define IDS_GLOBAL_MEDIA_CONTROLS_ICON_TOOLTIP_TEXT 1933
#define IDS_GLOBAL_MEDIA_CONTROLS_DEVICES_LABEL_WITH_COLON 1934
#define IDS_GLOBAL_MEDIA_CONTROLS_DEVICES_LABEL 1935
#define IDS_GLOBAL_MEDIA_CONTROLS_STOP_CASTING_BUTTON_LABEL 1936
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION 1937
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION_SHOW_LANGUAGE 1938
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION_DOWNLOAD_PROGRESS 1939
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION_DOWNLOAD_ERROR 1940
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION_DOWNLOAD_ERROR_REBOOT_REQUIRED 1941
#define IDS_GLOBAL_MEDIA_CONTROLS_CAPTION_SETTINGS 1942
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_TRANSLATE_TARGET_LANGUAGE_ACCNAME 1943
#define IDS_GLOBAL_MEDIA_CONTROLS_DIALOG_NAME 1944
#define IDS_GLOBAL_MEDIA_CONTROLS_CONTROL_CAST_SESSIONS_PROMO 1945
#define IDS_GMC_LOCAL_MEDIA_CAST_SESSIONS_PROMO 1946
#define IDS_GMC_LOCAL_MEDIA_CAST_START_PROMO 1947
#define IDS_MEDIA_TOOLBAR_CONTEXT_REPORT_CAST_ISSUE 1948
#define IDS_MEDIA_TOOLBAR_CONTEXT_SHOW_OTHER_SESSIONS 1949
#define IDS_MEDIA_PREVIEW_CAMERA_ACCESSIBLE_NAME 1950
#define IDS_MEDIA_PREVIEW_VIDEO_STREAM_ACCESSIBLE_NAME 1951
#define IDS_MEDIA_PREVIEW_NO_CAMERAS_FOUND 1952
#define IDS_MEDIA_PREVIEW_NO_CAMERAS_FOUND_COMBOBOX 1953
#define IDS_MEDIA_PREVIEW_VIDEO_STREAM_PREVIEW_BADGE 1954
#define IDS_MEDIA_PREVIEW_MIC_ACCESSIBLE_NAME 1955
#define IDS_MEDIA_PREVIEW_AUDIO_STREAM_ACCESSIBLE_NAME 1956
#define IDS_MEDIA_PREVIEW_NO_MICS_FOUND 1957
#define IDS_MEDIA_PREVIEW_NO_MICS_FOUND_COMBOBOX 1958
#define IDS_MEDIA_PREVIEW_SYSTEM_DEFAULT_MIC 1959
#define IDS_MEDIA_PREVIEW_SYSTEM_DEFAULT_MIC_PARENTHETICAL 1960
#define IDS_MEDIA_PREVIEW_ANNOUNCE_SELECTED_DEVICE_CHANGE 1961
#define IDS_MEDIA_ROUTER_ICON_TOOLTIP_TEXT 1962
#define IDS_MEDIA_ROUTER_MENU_ITEM_TITLE 1963
#define IDS_MEDIA_ROUTER_PRESENTATION_CAST_MODE 1964
#define IDS_MEDIA_ROUTER_DESKTOP_MIRROR_CAST_MODE 1965
#define IDS_MEDIA_ROUTER_TAB_MIRROR_CAST_MODE 1966
#define IDS_MEDIA_ROUTER_ALTERNATIVE_SOURCES_BUTTON 1967
#define IDS_MEDIA_ROUTER_ABOUT 1968
#define IDS_MEDIA_ROUTER_HELP 1969
#define IDS_MEDIA_ROUTER_ALWAYS_SHOW_TOOLBAR_ACTION 1970
#define IDS_MEDIA_ROUTER_SHOWN_BY_POLICY 1971
#define IDS_MEDIA_ROUTER_TOGGLE_MEDIA_REMOTING 1972
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_TIMEOUT_WITH_HOSTNAME 1973
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_TIMEOUT 1974
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_TIMEOUT_FOR_DESKTOP 1975
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_TIMEOUT_FOR_TAB 1976
#define IDS_MEDIA_ROUTER_ISSUE_UNABLE_TO_CAST_DESKTOP 1977
#define IDS_MEDIA_ROUTER_ISSUE_TAB_AUDIO_NOT_SUPPORTED 1978
#define IDS_MEDIA_ROUTER_ISSUE_DESKTOP_AUDIO_NOT_SUPPORTED 1979
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_USER_PENDING_AUTHORIZATION 1981
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_USER_NOT_ALLOWED 1982
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_NOTIFICATION_DISABLED 1983
#define IDS_MEDIA_ROUTER_ISSUE_FAILED_TO_CAST 1984
#define IDS_MEDIA_ROUTER_ISSUE_CANNOT_TERMINATE 1985
#define IDS_MEDIA_ROUTER_STATUS_LOOKING_FOR_DEVICES 1986
#define IDS_MEDIA_ROUTER_STATUS_NO_DEVICES_FOUND 1987
#define IDS_MEDIA_ROUTER_NO_DEVICES_FOUND_BUTTON 1988
#define IDS_MEDIA_ROUTER_DESTINATION_MISSING 1989
#define IDS_MEDIA_ROUTER_LOCAL_DISCOVERY_PERMISSION_REJECTED_BUTTON 1990
#define IDS_MEDIA_ROUTER_LOCAL_DISCOVERY_PERMISSION_REJECTED_LABEL 1991
#define IDS_MEDIA_ROUTER_LOCAL_DISCOVERY_PERMISSION_REJECTED_LINK 1992
#define IDS_MEDIA_ROUTER_SINK_AVAILABLE 1993
#define IDS_MEDIA_ROUTER_SINK_CONNECTING 1994
#define IDS_MEDIA_ROUTER_SINK_DISCONNECTING 1995
#define IDS_MEDIA_ROUTER_SINK_PAUSED 1996
#define IDS_MEDIA_ROUTER_STOP_CASTING 1997
#define IDS_MEDIA_ROUTER_SOURCE_NOT_SUPPORTED 1998
#define IDS_MEDIA_ROUTER_AVAILABLE_SPECIFIC_SITES 1999
#define IDS_MEDIA_ROUTER_CASTING_DESKTOP 2000
#define IDS_MEDIA_ROUTER_CASTING_TAB 2001
#define IDS_MEDIA_ROUTER_PRESENTATION_ROUTE_DESCRIPTION 2002
#define IDS_MEDIA_ROUTER_SINK_VIEW_PAUSE 2003
#define IDS_MEDIA_ROUTER_SINK_VIEW_PAUSE_GENERIC_ACCESSIBLE_NAME 2004
#define IDS_MEDIA_ROUTER_SINK_VIEW_PAUSE_SCREEN_ACCESSIBLE_NAME 2005
#define IDS_MEDIA_ROUTER_SINK_VIEW_PAUSE_TAB_ACCESSIBLE_NAME 2006
#define IDS_MEDIA_ROUTER_SINK_VIEW_RESUME 2007
#define IDS_MEDIA_ROUTER_SINK_VIEW_RESUME_GENERIC_ACCESSIBLE_NAME 2008
#define IDS_MEDIA_ROUTER_SINK_VIEW_RESUME_SCREEN_ACCESSIBLE_NAME 2009
#define IDS_MEDIA_ROUTER_SINK_VIEW_RESUME_TAB_ACCESSIBLE_NAME 2010
#define IDS_MEDIA_ROUTER_SINK_VIEW_STOP 2011
#define IDS_MEDIA_ROUTER_SINK_VIEW_STOP_GENERIC_ACCESSIBLE_NAME 2012
#define IDS_MEDIA_ROUTER_SINK_VIEW_STOP_SCREEN_ACCESSIBLE_NAME 2013
#define IDS_MEDIA_ROUTER_SINK_VIEW_STOP_TAB_ACCESSIBLE_NAME 2014
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_TITLE 2015
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_BODY_TEXT 2016
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_CHECKBOX 2017
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_OPTIMIZE_BUTTON 2018
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_CANCEL_BUTTON 2019
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_CANCEL_BUTTON_MACOS 2020
#define IDS_MEDIA_ROUTER_CAST_TO_MEETING_DEPRECATED 2021
#define IDS_MEDIA_ROUTER_CAST_TO_MEETING_REMOVED 2022
#define IDS_MEDIA_ROUTER_WIRED_DISPLAY_SINK_NAME 2023
#define IDS_MEDIA_ROUTER_FEEDBACK_TITLE 2024
#define IDS_MEDIA_ROUTER_FEEDBACK_NA 2025
#define IDS_MEDIA_ROUTER_FEEDBACK_FORM_DESCRIPTION 2026
#define IDS_MEDIA_ROUTER_FEEDBACK_HEADER 2027
#define IDS_MEDIA_ROUTER_FEEDBACK_YOUR_ANSWER 2028
#define IDS_MEDIA_ROUTER_FEEDBACK_REQUIRED 2029
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_QUESTION 2030
#define IDS_MEDIA_ROUTER_FEEDBACK_PROMPT 2031
#define IDS_MEDIA_ROUTER_FEEDBACK_MIRRORING_QUALITY_SUBHEADING 2032
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_SMOOTHNESS 2033
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_QUALITY 2034
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_QUALITY 2035
#define IDS_MEDIA_ROUTER_FEEDBACK_CONTENT_QUESTION 2036
#define IDS_MEDIA_ROUTER_FEEDBACK_ADDITIONAL_COMMENTS 2037
#define IDS_MEDIA_ROUTER_FEEDBACK_ALLOW_CONTACT_BY_EMAIL 2038
#define IDS_MEDIA_ROUTER_FEEDBACK_YOUR_EMAIL_ADDRESS 2039
#define IDS_MEDIA_ROUTER_FEEDBACK_EMAIL_FIELD 2040
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_BUTTON 2041
#define IDS_MEDIA_ROUTER_FEEDBACK_DISCARD_CONFIRMATION 2042
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_BUG_OR_ERROR 2043
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_FEATURE_REQUEST 2044
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_PROJECTION_QUALITY 2045
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_DISCOVERY 2046
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_OTHER 2047
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_FREEZES 2048
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_JERKY 2049
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_STUTTER 2050
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_SMOOTH 2051
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_PERFECT 2052
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_UNWATCHABLE 2053
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_POOR 2054
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_ACCEPTABLE 2055
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_GOOD 2056
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_GREAT 2057
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_UNINTELLIGIBLE 2058
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_POOR 2059
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_ACCEPTABLE 2060
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_GOOD 2061
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_PERFECT 2062
#define IDS_MEDIA_ROUTER_FEEDBACK_SENDING 2063
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_FAIL 2064
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_SUCCESS 2065
#define IDS_MEDIA_ROUTER_FEEDBACK_RESENDING 2066
#define IDS_MEDIA_ROUTER_FEEDBACK_LOGS_HEADER 2067
#define IDS_MEDIA_ROUTER_FEEDBACK_FINE_LOGS_WARNING 2068
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_LOGS_HTML 2069
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_LOGS 2070
#define IDS_MEDIA_ROUTER_FEEDBACK_PRIVACY_DATA_USAGE 2071
#define IDS_MEDIA_ROUTER_FEEDBACK_SETUP_VISIBILITY_QUESTION 2072
#define IDS_MEDIA_ROUTER_FEEDBACK_YES 2073
#define IDS_MEDIA_ROUTER_FEEDBACK_NO 2074
#define IDS_MEDIA_ROUTER_FEEDBACK_DID_NOT_TRY 2075
#define IDS_MEDIA_ROUTER_FEEDBACK_SOFTWARE_QUESTION 2076
#define IDS_MEDIA_ROUTER_FEEDBACK_UNKNOWN 2077
#define IDS_MEDIA_ROUTER_FEEDBACK_NETWORK_QUESTION 2078
#define IDS_MEDIA_ROUTER_FEEDBACK_NETWORK_SAME_WIFI 2079
#define IDS_MEDIA_ROUTER_FEEDBACK_NETWORK_DIFFERENT_WIFI 2080
#define IDS_MEDIA_ROUTER_FEEDBACK_NETWORK_WIRED_PC 2081
#define IDS_MEDIA_ROUTER_NOTIFICATION_MESSAGE_CAST_SCREEN 2082
#define IDS_MEDIA_ROUTER_NOTIFICATION_MESSAGE_PAUSED 2083
#define IDS_MEDIA_ROUTER_NOTIFICATION_MESSAGE_SCREEN_CAN_PAUSE 2084
#define IDS_MEDIA_ROUTER_NOTIFICATION_MESSAGE_SCREEN_PAUSED 2085
#define IDS_MEDIA_ROUTER_NOTIFICATION_MESSAGE_TAB_CAN_PAUSE 2086
#define IDS_MEDIA_ROUTER_NOTIFICATION_TITLE 2087
#define IDS_MEDIA_ROUTER_NOTIFICATION_TITLE_UNKNOWN 2088
#define IDS_AVATAR_BUTTON_GUEST 2089
#define IDS_AVATAR_BUTTON_GUEST_TOOLTIP 2090
#define IDS_GUEST_BUBBLE_ACCESSIBLE_TITLE 2091
#define IDS_INCOGNITO_BUBBLE_ACCESSIBLE_TITLE 2092
#define IDS_AVATAR_BUTTON_INCOGNITO 2093
#define IDS_AVATAR_BUTTON_INCOGNITO_TOOLTIP 2094
#define IDS_AVATAR_BUTTON_SYNC_ERROR 2095
#define IDS_AVATAR_BUTTON_SYNC_ERROR_TOOLTIP 2096
#define IDS_AVATAR_BUTTON_SYNC_PAUSED 2097
#define IDS_AVATAR_BUTTON_SYNC_ERROR_BOOKMARKS_LIMIT_EXCEEDED 2098
#define IDS_AVATAR_BUTTON_SIGNIN_PAUSED 2099
#define IDS_AVATAR_BUTTON_WORK 2100
#define IDS_AVATAR_BUTTON_SCHOOL 2101
#define IDS_AVATAR_BUTTON_GREETING 2102
#define IDS_AVATAR_BUTTON_PASSKEYS_ERROR_UNLOCK 2103
#define IDS_AVATAR_BUTTON_PASSKEYS_ERROR_GET 2104
#define IDS_AVATAR_BUTTON_PASSKEYS_ERROR_VERIFY 2105
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_DESCRIPTION_UNLOCK 2106
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_DESCRIPTION_GET 2107
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_DESCRIPTION_VERIFY 2108
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_BUTTON_UNLOCK 2109
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_BUTTON_GET 2110
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_BUTTON_VERIFY 2111
#define IDS_PROFILES_MENU_NAME 2112
#define IDS_PROFILES_ADD_PROFILE_LABEL 2114
#define IDS_PROFILES_PROFILE_BUBBLE_ACCESSIBLE_TITLE 2115
#define IDS_PROFILES_EXIT_PROFILE_BUTTON 2116
#define IDS_PROFILES_ACCOUNT_REMOVAL_TITLE 2117
#define IDS_PROFILES_SYNC_COMPLETE_TITLE 2118
#define IDS_PROFILES_DICE_SIGNIN_BUTTON 2119
#define IDS_EXTENSIONS_EXPLICIT_SIGNIN_BUTTON 2120
#define IDS_PROFILES_DICE_WEB_ONLY_SIGNIN_BUTTON 2121
#define IDS_PROFILES_DICE_SIGNIN_FIRST_ACCOUNT_BUTTON 2122
#define IDS_PROFILES_DICE_SIGNIN_FIRST_ACCOUNT_BUTTON_NO_NAME 2123
#define IDS_PROFILES_DICE_SYNC_DISABLED_TITLE 2124
#define IDS_PROFILES_DASHER_FEATURE_DISABLED_TITLE 2125
#define IDS_PROFILES_DICE_SYNC_PAUSED_TITLE 2126
#define IDS_PROFILES_SIGNIN_PROMO 2127
#define IDS_AI_SIGNIN_PROMO_TITLE 2128
#define IDS_PROFILES_VERIFY_ACCOUNT_BUTTON 2129
#define IDS_PROFILE_MENU_SIGNIN_PROMO_DESCRIPTION 2130
#define IDS_PROFILE_MENU_SIGNIN_PROMO_DESCRIPTION_WITH_BOOKMARKS 2131
#define IDS_PROFILE_MENU_PROFILE_IDENTIFIER_WITH_SEPARATOR 2132
#define IDS_PROFILE_MENU_PROFILE_MANAGED_HEADER 2133
#define IDS_GUEST_PROFILE_MENU_CLOSE_X_WINDOWS_BUTTON 2134
#define IDS_INCOGNITO_PROFILE_MENU_CLOSE_X_WINDOWS_BUTTON 2135
#define IDS_PROFILES_PROFILE_MANAGE_ACCOUNTS_BUTTON 2136
#define IDS_PROFILES_PROFILE_HIDE_MANAGE_ACCOUNTS_BUTTON 2137
#define IDS_PROFILE_MENU_OPEN_GUEST_PROFILE 2138
#define IDS_PROFILE_MENU_CLOSE_PROFILE_X_WINDOWS_BUTTON 2139
#define IDS_PROFILES_OPEN_SYNC_SETTINGS_BUTTON 2140
#define IDS_PROFILE_MENU_CUSTOMIZE_PROFILE_BUTTON 2141
#define IDS_PROFILE_MENU_OPEN_ACCOUNT_SETTINGS 2142
#define IDS_PROFILE_MENU_AUTOFILL_SETTINGS_BUTTON 2143
#define IDS_PROFILE_MENU_BATCH_UPLOAD_BUTTON 2144
#define IDS_PROFILES_MANAGED_BY 2145
#define IDS_PROFILES_MANAGE_PROFILES_BUTTON_TOOLTIP 2146
#define IDS_PROFILES_CUSTOMIZE_PROFILE_BUTTON_TOOLTIP 2147
#define IDS_PROFILES_GUEST_PROFILE_NAME 2148
#define IDS_DEFAULT_PROFILE_NAME 2149
#define IDS_LEGACY_DEFAULT_PROFILE_NAME 2150
#define IDS_NEW_NUMBERED_PROFILE_NAME 2151
#define IDS_SINGLE_PROFILE_DISPLAY_NAME 2152
#define IDS_GUEST_PROFILE_NAME 2153
#define IDS_DEFAULT_AVATAR_NAME_8 2154
#define IDS_DEFAULT_AVATAR_NAME_9 2155
#define IDS_DEFAULT_AVATAR_NAME_10 2156
#define IDS_DEFAULT_AVATAR_NAME_11 2157
#define IDS_DEFAULT_AVATAR_NAME_12 2158
#define IDS_DEFAULT_AVATAR_NAME_13 2159
#define IDS_DEFAULT_AVATAR_NAME_14 2160
#define IDS_DEFAULT_AVATAR_NAME_15 2161
#define IDS_DEFAULT_AVATAR_NAME_16 2162
#define IDS_DEFAULT_AVATAR_NAME_17 2163
#define IDS_DEFAULT_AVATAR_NAME_18 2164
#define IDS_DEFAULT_AVATAR_NAME_19 2165
#define IDS_DEFAULT_AVATAR_NAME_20 2166
#define IDS_DEFAULT_AVATAR_NAME_21 2167
#define IDS_DEFAULT_AVATAR_NAME_22 2168
#define IDS_DEFAULT_AVATAR_NAME_23 2169
#define IDS_DEFAULT_AVATAR_NAME_24 2170
#define IDS_DEFAULT_AVATAR_NAME_25 2171
#define IDS_DEFAULT_AVATAR_NAME_26 2172
#define IDS_DEFAULT_AVATAR_LABEL_0 2173
#define IDS_DEFAULT_AVATAR_LABEL_1 2174
#define IDS_DEFAULT_AVATAR_LABEL_2 2175
#define IDS_DEFAULT_AVATAR_LABEL_3 2176
#define IDS_DEFAULT_AVATAR_LABEL_4 2177
#define IDS_DEFAULT_AVATAR_LABEL_5 2178
#define IDS_DEFAULT_AVATAR_LABEL_6 2179
#define IDS_DEFAULT_AVATAR_LABEL_7 2180
#define IDS_DEFAULT_AVATAR_LABEL_8 2181
#define IDS_DEFAULT_AVATAR_LABEL_9 2182
#define IDS_DEFAULT_AVATAR_LABEL_10 2183
#define IDS_DEFAULT_AVATAR_LABEL_11 2184
#define IDS_DEFAULT_AVATAR_LABEL_12 2185
#define IDS_DEFAULT_AVATAR_LABEL_13 2186
#define IDS_DEFAULT_AVATAR_LABEL_14 2187
#define IDS_DEFAULT_AVATAR_LABEL_15 2188
#define IDS_DEFAULT_AVATAR_LABEL_16 2189
#define IDS_DEFAULT_AVATAR_LABEL_17 2190
#define IDS_DEFAULT_AVATAR_LABEL_18 2191
#define IDS_DEFAULT_AVATAR_LABEL_19 2192
#define IDS_DEFAULT_AVATAR_LABEL_20 2193
#define IDS_DEFAULT_AVATAR_LABEL_21 2194
#define IDS_DEFAULT_AVATAR_LABEL_22 2195
#define IDS_DEFAULT_AVATAR_LABEL_23 2196
#define IDS_DEFAULT_AVATAR_LABEL_24 2197
#define IDS_DEFAULT_AVATAR_LABEL_25 2198
#define IDS_DEFAULT_AVATAR_LABEL_26 2199
#define IDS_DEFAULT_AVATAR_LABEL_27 2200
#define IDS_DEFAULT_AVATAR_LABEL_28 2201
#define IDS_DEFAULT_AVATAR_LABEL_29 2202
#define IDS_DEFAULT_AVATAR_LABEL_30 2203
#define IDS_DEFAULT_AVATAR_LABEL_31 2204
#define IDS_DEFAULT_AVATAR_LABEL_32 2205
#define IDS_DEFAULT_AVATAR_LABEL_33 2206
#define IDS_DEFAULT_AVATAR_LABEL_34 2207
#define IDS_DEFAULT_AVATAR_LABEL_35 2208
#define IDS_DEFAULT_AVATAR_LABEL_36 2209
#define IDS_DEFAULT_AVATAR_LABEL_37 2210
#define IDS_DEFAULT_AVATAR_LABEL_38 2211
#define IDS_DEFAULT_AVATAR_LABEL_39 2212
#define IDS_DEFAULT_AVATAR_LABEL_40 2213
#define IDS_DEFAULT_AVATAR_LABEL_41 2214
#define IDS_DEFAULT_AVATAR_LABEL_42 2215
#define IDS_DEFAULT_AVATAR_LABEL_43 2216
#define IDS_DEFAULT_AVATAR_LABEL_44 2217
#define IDS_DEFAULT_AVATAR_LABEL_45 2218
#define IDS_DEFAULT_AVATAR_LABEL_46 2219
#define IDS_DEFAULT_AVATAR_LABEL_47 2220
#define IDS_DEFAULT_AVATAR_LABEL_48 2221
#define IDS_DEFAULT_AVATAR_LABEL_49 2222
#define IDS_DEFAULT_AVATAR_LABEL_50 2223
#define IDS_DEFAULT_AVATAR_LABEL_51 2224
#define IDS_DEFAULT_AVATAR_LABEL_52 2225
#define IDS_DEFAULT_AVATAR_LABEL_53 2226
#define IDS_DEFAULT_AVATAR_LABEL_54 2227
#define IDS_DEFAULT_AVATAR_LABEL_55 2228
#define IDS_PROFILES_LOCAL_PROFILE_STATE 2229
#define IDS_PROFILES_CREATE_BUTTON_LABEL 2230
#define IDS_PROFILES_MANAGE_BUTTON_LABEL 2231
#define IDS_PROFILES_DEFAULT_NAME 2232
#define IDS_SYNC_LOGIN_NAME_PROHIBITED 2233
#define IDS_SIGN_IN_LOGIN_NAME_PROHIBITED 2234
#define IDS_SUPERVISED_USER_NOT_ALLOWED_BY_POLICY 2235
#define IDS_SYNC_USER_NAME_IN_USE_ERROR 2236
#define IDS_SYNC_USER_NAME_IN_USE_BY_ERROR 2237
#define IDS_SCREEN_LOCK_SIGN_OUT 2238
#define IDS_PROFILE_CUSTOMIZATION_DONE_BUTTON_LABEL 2244
#define IDS_PROFILE_CUSTOMIZATION_THEME_PICKER_LABEL 2245
#define IDS_PROFILE_CUSTOMIZATION_WELCOME 2246
#define IDS_PROFILE_CUSTOMIZATION_INPUT_LABEL 2247
#define IDS_PROFILE_CUSTOMIZATION_INPUT_TITLE 2248
#define IDS_PROFILE_CUSTOMIZATION_INPUT_PLACEHOLDER 2249
#define IDS_PROFILE_CUSTOMIZATION_INPUT_ERROR_MESSAGE 2250
#define IDS_PROFILE_CUSTOMIZATION_SKIP_BUTTON_LABEL 2251
#define IDS_PROFILE_CUSTOMIZATION_DELETE_PROFILE_BUTTON_LABEL 2252
#define IDS_PROFILE_CUSTOMIZATION_LOCAL_PROFILE_CREATION_TITLE 2253
#define IDS_PROFILE_CUSTOMIZATION_AVATAR_SELECTION_BACK_BUTTON_LABEL 2254
#define IDS_ENTERPRISE_PROFILE_WELCOME_TITLE 2255
#define IDS_ENTERPRISE_PROFILE_WELCOME_ACCOUNT_MANAGED_BY 2256
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_MANAGED_STRICT_SEPARATION 2257
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_MANAGED_SEPARATION 2258
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_SEPARATION_DEVICE_MANAGED 2259
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_SEPARATION_ACCOUNT_MANAGED 2260
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_SEPARATION_DEVICE_MANAGED_BY 2261
#define IDS_ENTERPRISE_PROFILE_WELCOME_ACCOUNT_EMAIL_MANAGED_BY 2262
#define IDS_ENTERPRISE_PROFILE_WELCOME_DEVICE_MANAGED_BY 2263
#define IDS_ENTERPRISE_PROFILE_WELCOME_DEVICE_MANAGED 2264
#define IDS_ENTERPRISE_WELCOME_PROFILE_REQUIRED_TITLE 2265
#define IDS_ENTERPRISE_WELCOME_PROFILE_SETUP_TITLE 2266
#define IDS_ENTERPRISE_WELCOME_PROFILE_WILL_BE_MANAGED_TITLE 2267
#define IDS_ENTERPRISE_PROFILE_WELCOME_CREATE_PROFILE_BUTTON 2268
#define IDS_ENTERPRISE_PROFILE_WELCOME_LINK_DATA_CHECKBOX 2269
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_SCHOOL_TITLE 2270
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_WORK_TITLE 2271
#define IDS_ENTERPRISE_WELCOME_PROFILE_OIDC_DISCLOSURE_TITLE 2272
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_ALREADY_SIGNED_IN_TITLE 2273
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_ALREADY_SIGNED_IN_ENFORCED_SUBTITLE 2274
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_ALREADY_SIGNED_IN_SUBTITLE 2275
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_SUBTITLE 2276
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_KNOWN_DOMAIN_SUBTITLE 2277
#define IDS_ENTERPRISE_WELCOME_PROFILE_INFORMATION_TITLE 2278
#define IDS_ENTERPRISE_WELCOME_DEVICE_INFORMATION_TITLE 2279
#define IDS_ENTERPRISE_WELCOME_DEVICE_INFORMATION_DETAILS 2280
#define IDS_ENTERPRISE_PROFILE_WELCOME_BACK 2281
#define IDS_ENTERPRISE_OIDC_WELCOME_PROCESSING_SUBTITLE 2282
#define IDS_ENTERPRISE_OIDC_WELCOME_LONG_PROCESSING_SUBTITLE 2283
#define IDS_ENTERPRISE_OIDC_WELCOME_SUCCESS_TITLE 2284
#define IDS_ENTERPRISE_OIDC_WELCOME_SUCCESS_SUBTITLE 2285
#define IDS_ENTERPRISE_OIDC_WELCOME_TIMEOUT_TITLE 2286
#define IDS_ENTERPRISE_OIDC_WELCOME_TIMEOUT_SUBTITLE 2287
#define IDS_ENTERPRISE_OIDC_WELCOME_TIMEOUT_RETRY_LABEL 2288
#define IDS_ENTERPRISE_OIDC_WELCOME_ERROR_TITLE 2289
#define IDS_ENTERPRISE_OIDC_WELCOME_ERROR_SUBTITLE 2290
#define IDS_ENTERPRISE_OIDC_WELCOME_ERROR_NO_SIGNIN_TITLE 2291
#define IDS_ENTERPRISE_OIDC_WELCOME_ERROR_NO_SIGNIN_SUBTITLE 2292
#define IDS_ENTERPRISE_VALUE_PROPOSITION_CONSUMER_SUBTITLE 2293
#define IDS_ENTERPRISE_VALUE_PROPOSITION_CONSUMER_SUBTITLE_WITH_BOOKMARKS 2294
#define IDS_ENTERPRISE_VALUE_PROPOSITION_SCHOOL_SUBTITLE 2295
#define IDS_ENTERPRISE_VALUE_PROPOSITION_WORK_SUBTITLE 2296
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_WORK_TITLE 2297
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_SCHOOL_TITLE 2298
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_ALREADY_SIGNED_IN_TITLE 2299
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_CONSUMER_TITLE 2300
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_SCHOOL_CHOICE 2301
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_WORK_CHOICE 2302
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_ALREADY_SIGNED_IN_CHOICE 2303
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_SCHOOL_NOT_RECOMMENDED 2304
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_WORK_NOT_RECOMMENDED 2305
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_DETAILS 2306
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_ALREADY_SIGNED_IN_DETAILS 2307
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WORK_CHOICE 2308
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_SCHOOL_CHOICE 2309
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_ALREADY_SIGNED_IN_CHOICE 2310
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_CHOICE_DETAILS 2311
#define IDS_BROWSING_HISTORY_COUNT 2312
#define IDS_BOOKMARKS_COUNT 2313
#define IDS_EXTENSIONS_COUNT 2314
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WITH_THREE_COUNTS_CHOICE_DETAILS 2315
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WITH_TWO_COUNTS_CHOICE_DETAILS 2316
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WITH_ONE_COUNT_CHOICE_DETAILS 2317
#define IDS_SUPERVISED_USER_PROFILE_SIGNIN_IPH_TITLE 2318
#define IDS_SUPERVISED_USER_PROFILE_SIGNIN_IPH_TEXT 2319
#define IDS_MANAGED_BY_PARENT_A11Y 2320
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_KIDS_BODY 2321
#define IDS_PROFILE_PICKER_ADD_SPACE_BUTTON 2322
#define IDS_PROFILE_PICKER_BROWSE_AS_GUEST_BUTTON 2323
#define IDS_PROFILE_PICKER_BACK_BUTTON_ARIA_LABEL 2324
#define IDS_PROFILE_PICKER_BACK_BUTTON_SIGN_IN_LABEL 2325
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_KEEP_WORK_AND_LIFE_SEPARATE 2326
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_GOT_ANOTHER_GOOGLE_ACCOUNT 2327
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_KEEP_TASKS_SEPARATE 2328
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_SHARING_A_COMPUTER 2329
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_SHARING_A_COMPUTER 2330
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_KEEP_EVERYTHING_IN_CHROME 2331
#define IDS_PROFILE_PICKER_PROFILE_CARD_NEEDS_SIGNIN_PROMPT 2332
#define IDS_PROFILE_PICKER_PROFILE_CARD_LABEL_SUPERVISED 2333
#define IDS_PROFILE_PICKER_PROFILE_CARD_LABEL 2334
#define IDS_PROFILE_PICKER_PROFILE_CARD_INPUT_LABEL 2335
#define IDS_PROFILE_PICKER_PROFILE_MORE_ACTIONS_ARIA_LABEL 2336
#define IDS_PROFILE_PICKER_PROFILE_MENU_REMOVE_TEXT 2337
#define IDS_PROFILE_PICKER_PROFILE_MENU_REMOVE_CONFIRM 2338
#define IDS_PROFILE_PICKER_PROFILE_MENU_CUSTOMIZE_TEXT 2339
#define IDS_PROFILE_PICKER_PROFILE_MENU_INCOGNITO_TEXT 2340
#define IDS_PROFILE_PICKER_ASK_ON_STARTUP 2341
#define IDS_PROFILE_PICKER_OPEN_ALL_PROFILES_BUTTON 2342
#define IDS_PROFILE_PICKER_REMOVE_WARNING_LOCAL_PROFILE_TITLE 2343
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_NOT_ALLOWED_TITLE 2344
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_NOT_ALLOWED_BODY 2345
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_WRONG_ACCOUNT_TITLE 2346
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_WRONG_ACCOUNT_BODY 2347
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_TIMEOUT_TITLE 2348
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_TIMEOUT_BODY 2349
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_NOT_SUPPORTED_BY_GLIC_FLOW_TITLE 2350
#define IDS_PROFILE_PICKER_REMOVE_WARNING_HISTORY 2351
#define IDS_PROFILE_PICKER_REMOVE_WARNING_PASSWORDS 2352
#define IDS_PROFILE_PICKER_REMOVE_WARNING_BOOKMARKS 2353
#define IDS_PROFILE_PICKER_REMOVE_WARNING_AUTOFILL 2354
#define IDS_PROFILE_PICKER_REMOVE_WARNING_CALCULATING 2355
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_SIGNIN_BUTTON_LABEL 2356
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_NOT_NOW_BUTTON_LABEL 2357
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_DONT_SIGN_IN_BUTTON_LABEL 2358
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_STAY_SIGNED_OUT_BUTTON_LABEL 2359
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_LOCAL_PROFILE_CREATION_CUSTOMIZE_AVATAR_BUTTON_LABEL 2360
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_LOCAL_PROFILE_CREATION_AVATAR_TEXT 2361
#define IDS_PROFILE_PICKER_TAKE_A_TOUR_BUTTON_LABEL 2362
#define IDS_PROFILE_PICKER_IPH_NEXT_BUTTON_LABEL 2363
#define IDS_PROFILE_PICKER_IPH_DONE_BUTTON_LABEL 2364
#define IDS_PROFILE_PICKER_IPH_FOR_PROFILES_TITLE 2365
#define IDS_PROFILE_PICKER_IPH_FOR_ADD_PROFILE_TITLE 2366
#define IDS_PROFILE_PICKER_IPH_FOR_CUSTOMIZE_PROFILE_TITLE 2367
#define IDS_PROFILE_PICKER_IPH_FOR_CUSTOMIZE_PROFILE_TEXT 2368
#define IDS_PROFILE_PICKER_PROFILE_SWITCH_SWITCH_BUTTON_LABEL 2369
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_DEVICE_MANAGED_BY_DESCRIPTION 2370
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_DEVICE_MANAGED_DESCRIPTION 2371
#define IDS_PROFILE_PICKER_REMOVE_WARNING_LOCAL_PROFILE 2372
#define IDS_PROFILE_PICKER_REMOVE_WARNING_SIGNED_IN_PROFILE_TITLE 2373
#define IDS_PROFILE_PICKER_REMOVE_WARNING_SIGNED_IN_PROFILE 2374
#define IDS_PROFILE_PICKER_REMOVE_WARNING_SIGNED_IN_PROFILE_SIGN_IN_AS 2375
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_PROFILE_TYPE_CHOICE_SUBTITLE_UNO 2376
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_PROFILE_TYPE_CHOICE_SUBTITLE_UNO_BOOKMARKS 2377
#define IDS_FRE_SIGN_IN_SUBTITLE_0 2378
#define IDS_FRE_SIGN_IN_SUBTITLE_1 2379
#define IDS_FRE_DEVICES_CARD_TITLE 2380
#define IDS_FRE_DEVICES_CARD_DESCRIPTION 2381
#define IDS_FRE_SECURITY_CARD_TITLE 2382
#define IDS_FRE_SECURITY_CARD_DESCRIPTION 2383
#define IDS_FRE_BACKUP_CARD_TITLE 2384
#define IDS_UNO_FRE_BACKUP_CARD_DESCRIPTION 2385
#define IDS_UNO_FRE_BACKUP_CARD_DESCRIPTION_WITH_PASSWORDS 2386
#define IDS_FRE_DECLINE_SIGN_IN_BUTTON_TITLE 2387
#define IDS_FRE_STAY_SIGNED_OUT_BUTTON_TITLE 2388
#define IDS_FRE_ACCEPT_SIGN_IN_BUTTON_TITLE 2389
#define IDS_FRE_MANAGED_DESCRIPTION 2390
#define IDS_FRE_MANAGED_BY_DESCRIPTION 2391
#define IDS_FRE_DEFAULT_BROWSER_TITLE_NEW 2392
#define IDS_FRE_DEFAULT_BROWSER_SUBTITLE 2393
#define IDS_FRE_DEFAULT_BROWSER_SET_AS_DEFAULT 2394
#define IDS_FRE_DEFAULT_BROWSER_SKIP 2395
#define IDS_FRE_REFRESH_DEFAULT_BROWSER_SET_AS_DEFAULT 2396
#define IDS_FRE_REFRESH_DEFAULT_BROWSER_NO_THANKS 2397
#define IDS_BATCH_UPLOAD_TITLE 2398
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_ITEMS_WITH_DEDUPLICATION 2399
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_PASSWORDS_WITH_DEDUPLICATION 2400
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_PASSWORDS_COMBO_WITH_DEDUPLICATION 2401
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_BOOKMARKS_WITH_DEDUPLICATION 2402
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_BOOKMARKS_COMBO_WITH_DEDUPLICATION 2403
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_ITEMS 2404
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_PASSWORDS 2405
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_PASSWORDS_COMBO 2406
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_BOOKMARKS 2407
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_BOOKMARKS_COMBO 2408
#define IDS_BATCH_UPLOAD_SECTION_TITLE_PASSWORDS 2409
#define IDS_BATCH_UPLOAD_SECTION_TITLE_BOOKMARKS 2410
#define IDS_BATCH_UPLOAD_SECTION_TITLE_READING_LIST 2411
#define IDS_BATCH_UPLOAD_SECTION_TITLE_ADDRESSES 2412
#define IDS_BATCH_UPLOAD_SECTION_TITLE_EXTENSIONS 2413
#define IDS_BATCH_UPLOAD_SECTION_TITLE_THEMES_WITH_DESCRIPTION 2414
#define IDS_BATCH_UPLOAD_SAVE_TO_ACCOUNT_OK_BUTTON_LABEL 2415
#define IDS_BATCH_UPLOAD_AVATAR_BUTTON_SAVING_TO_ACCOUNT 2416
#define IDS_BATCH_UPLOAD_LAST_ITEM_SELECTED_SCREEN_READER 2417
#define IDS_BATCH_UPLOAD_SCREEN_READER_ITEM_COUNT_SELECTED 2418
#define IDS_BATCH_UPLOAD_SCREEN_READER_SELECT_ALL 2419
#define IDS_BATCH_UPLOAD_SCREEN_READER_SELECT_NONE 2420
#define IDS_BATCH_UPLOAD_PROMO_TITLE 2421
#define IDS_BATCH_UPLOAD_PROMO_TITLE_OK_BUTTON_LABEL 2422
#define IDS_BATCH_UPLOAD_PROMO_SUBTITLE_BOOKMARKS 2423
#define IDS_BATCH_UPLOAD_PROMO_SUBTITLE_BOOKMARKS_COMBO 2424
#define IDS_BATCH_UPLOAD_PROMO_SUBTITLE_ITEMS_WITH_LINK 2425
#define IDS_SIGNOUT_CONFIRMATION_EXTENSIONS_SECTION_TITLE 2426
#define IDS_SIGNOUT_CONFIRMATION_EXTENSIONS_SECTION_TOOLTIP 2427
#define IDS_SIGNOUT_CONFIRMATION_UNSYNCED_DATA_WITH_ACCOUNT_EXTENSIONS 2428
#define IDS_HISTORY_SYNC_OPT_IN_TITLE 2429
#define IDS_HISTORY_SYNC_OPT_IN_SUBTITLE 2430
#define IDS_HISTORY_SYNC_OPT_IN_SUBTITLE_WITH_EMAIL 2431
#define IDS_HISTORY_SYNC_OPT_IN_DESCRIPTION 2432
#define IDS_HISTORY_SYNC_OPT_IN_ACCEPT_BUTTON 2433
#define IDS_HISTORY_SYNC_OPT_IN_REJECT_BUTTON 2434
#define IDS_TABS_DISABLED_ERROR_DESCRIPTION 2435
#define IDS_AVATAR_BUTTON_SYNC_HISTORY 2436
#define IDS_AVATAR_BUTTON_SYNC_PROMO 2437
#define IDS_AVATAR_BUTTON_BATCH_UPLOAD_PROMO 2438
#define IDS_AVATAR_BUTTON_BATCH_UPLOAD_PROMO_WITH_BOOKMARK_CLEANUP_PROMO 2439
#define IDS_PROFILE_MENU_SYNC_PROMO_SYNC_HISTORY_DESCRIPTION 2440
#define IDS_PROFILE_MENU_SYNC_PROMO_BUTTON_LABEL 2441
#define IDS_PROFILE_MENU_DESCRIPTION_WITH_SYNC_PROMO 2442
#define IDS_PROFILE_MENU_BUTTON_LABEL_WITH_SYNC_PROMO 2443
#define IDS_PROFILE_MENU_PROMO_DESCRIPTION_WITH_BATCH_UPLOAD 2444
#define IDS_PROFILE_MENU_PROMO_BUTTON_WITH_BATCH_UPLOAD 2445
#define IDS_PROFILE_MENU_PROMO_DESCRIPTION_WITH_BATCH_UPLOAD_BOOKMARK_CLEANUP 2446
#define IDS_SIGN_IN_BENEFITS_IPH_TEXT 2447
#define IDS_SIGN_IN_BENEFITS_WITHOUT_BOOKMARKS_AND_EXTENSIONS_IPH_TEXT 2448
#define IDS_TYPE_A_SHORTCUT 2449
#define IDS_SHORTCUT_SET 2450
#define IDS_SHORTCUT_NOT_SET 2451
#define IDS_SHORTCUT_INCLUDE_START_MODIFIER 2452
#define IDS_SHORTCUT_TOO_MANY_MODIFIERS 2453
#define IDS_SHORTCUT_NEED_CHARACTER 2454
#define IDS_SHORTCUT_CLEAR 2455
#define IDS_SETTINGS_EMPTY_STRING 7594
#define IDS_SETTINGS_CONTINUE 7595
#define IDS_SETTINGS_GOT_IT 7596
#define IDS_SETTINGS_MORE_ACTIONS 7597
#define IDS_SETTINGS_MORE_ACTIONS_BUTTON_ARIA_LABEL 7598
#define IDS_SETTINGS_OPENS_IN_NEW_TAB 7599
#define IDS_SETTINGS_SEND_FEEDBACK_ROLE_DESCRIPTION 7600
#define IDS_SETTINGS_COLUMN_HEADING_WHEN_ON 7601
#define IDS_SETTINGS_COLUMN_HEADING_CONSIDER 7602
#define IDS_SETTINGS_COLUMN_HEADING_WHEN_USED 7603
#define IDS_RELAUNCH_CONFIRMATION_DIALOG_BODY 7604
#define IDS_SETTINGS_ABOUT_PAGE_BROWSER_VERSION 7605
#define IDS_SETTINGS_ABOUT_PAGE_LEARN_MORE_UPDATE_ERRORS 7606
#define IDS_SETTINGS_ABOUT_PAGE_LEARN_MORE_SYSTEM_REQUIREMENTS 7607
#define IDS_SETTINGS_ABOUT_PAGE_RELAUNCH 4651
#define IDS_SETTINGS_ACCESSIBILITY 7614
#define IDS_SETTINGS_ACCESSIBILITY_WEB_STORE 7615
#define IDS_SETTINGS_MORE_FEATURES_LINK 7616
#define IDS_SETTINGS_MORE_FEATURES_LINK_DESCRIPTION 7617
#define IDS_SETTINGS_ACCESSIBLE_IMAGE_LABELS_TITLE 7618
#define IDS_SETTINGS_ACCESSIBLE_IMAGE_LABELS_SUBTITLE 7619
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_DOWNLOAD_COMPLETE 7620
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_DOWNLOAD_ERROR 7621
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_DOWNLOAD_PROGRESS 7622
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_DOWNLOADING 7623
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_TITLE 7624
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_SUBTITLE 7625
#define IDS_SETTINGS_AX_TREE_FIXING_TITLE 7626
#define IDS_SETTINGS_AX_TREE_FIXING_SUBTITLE 7627
#define IDS_SETTINGS_CAPTIONS_ENABLE_LIVE_CAPTION_TITLE 7628
#define IDS_SETTINGS_CAPTIONS_ENABLE_LIVE_TRANSLATE_TITLE 7629
#define IDS_SETTINGS_CAPTIONS_ENABLE_LIVE_TRANSLATE_SUBTITLE 7630
#define IDS_SETTINGS_CAPTIONS_ENABLE_LIVE_CAPTION_SUBTITLE 7631
#define IDS_SETTINGS_CAPTIONS_LIVE_CAPTION_DOWNLOAD_PROGRESS 7632
#define IDS_SETTINGS_CAPTIONS_LIVE_CAPTION_DOWNLOAD_COMPLETE 7633
#define IDS_SETTINGS_CAPTIONS_LIVE_CAPTION_DOWNLOAD_ERROR 7634
#define IDS_SETTINGS_CAPTIONS_LIVE_CAPTION_DOWNLOAD_ERROR_REBOOT_REQUIRED 7635
#define IDS_SETTINGS_CAPTIONS_MASK_OFFENSIVE_WORDS_TITLE 7636
#define IDS_SETTINGS_ENABLE_CARET_BROWSING_TITLE 7637
#define IDS_SETTINGS_ENABLE_CARET_BROWSING_SUBTITLE 7638
#define IDS_SETTINGS_ACCESSIBILITY_FOCUS_HIGHLIGHT_DESCRIPTION 5374
#define IDS_SETTINGS_OVERSCROLL_HISTORY_NAVIGATION_TITLE 5306
#define IDS_SETTINGS_OVERSCROLL_HISTORY_NAVIGATION_SUBTITLE 7639
#define IDS_SETTINGS_ACCESSIBILITY_TOAST_FREQUENCY_TITLE 7640
#define IDS_SETTINGS_ACCESSIBILITY_TOAST_FREQUENCY_DESCRIPTION 7641
#define IDS_SETTINGS_APPEARANCE 7642
#define IDS_SETTINGS_CUSTOM_WEB_ADDRESS 7643
#define IDS_SETTINGS_ENTER_CUSTOM_WEB_ADDRESS 7644
#define IDS_SETTINGS_HOME_BUTTON_DISABLED 7645
#define IDS_SETTINGS_THEMES 7646
#define IDS_SETTINGS_GTK_THEME 7647
#define IDS_SETTINGS_USE_GTK_THEME 7648
#define IDS_SETTINGS_QT_THEME 7649
#define IDS_SETTINGS_USE_QT_THEME 7650
#define IDS_SETTINGS_CLASSIC_THEME 7651
#define IDS_SETTINGS_USE_CLASSIC_THEME 7652
#define IDS_SETTINGS_RESET_TO_DEFAULT 7653
#define IDS_SETTINGS_CUSTOMIZE_TOOLBAR 7655
#define IDS_SETTINGS_RESET_TOOLBAR_TO_DEFAULT 7656
#define IDS_SETTINGS_CHROME_COLORS 7657
#define IDS_SETTINGS_COLOR_SCHEME_MODE 7658
#define IDS_SETTINGS_SHOW_HOME_BUTTON 7659
#define IDS_SETTINGS_SHOW_BOOKMARKS_BAR 7660
#define IDS_SETTINGS_SHOW_TAB_SEARCH_BUTTON 7661
#define IDS_SETTINGS_SHOW_PROJECTS_PANEL_BUTTON 7662
#define IDS_SETTINGS_SHOW_EVERYTHING_MENU_BUTTON 7663
#define IDS_SETTINGS_TAB_STRIP_POSITION 7664
#define IDS_SETTINGS_ALLOW_SPLIT_VIEW_DRAG_AND_DROP 7665
#define IDS_SETTINGS_SHOW_TAB_GROUPS_IN_BOOKMARKS_BAR 7666
#define IDS_SETTINGS_AUTO_PIN_NEW_TAB_GROUPS 7667
#define IDS_SETTINGS_HOVER_CARD_TITLE 7668
#define IDS_SETTINGS_SHOW_HOVER_CARD_IMAGES 7669
#define IDS_SETTINGS_SHOW_HOVER_CARD_MEMORY_USAGE 7670
#define IDS_SETTINGS_SHOW_HOVER_CARD_MEMORY_USAGE_STANDALONE 7671
#define IDS_SETTINGS_SIDE_PANEL_POSITION 7672
#define IDS_SETTINGS_TAB_SEARCH_POSITION 7673
#define IDS_SETTINGS_UI_FEATURE_ALIGN_LEFT 7674
#define IDS_SETTINGS_UI_FEATURE_ALIGN_RIGHT 7675
#define IDS_SETTINGS_UI_FEATURE_ALIGN_SIDE 7676
#define IDS_SETTINGS_UI_FEATURE_ALIGN_TOP 7677
#define IDS_SETTINGS_HOME_PAGE_NTP 7678
#define IDS_SETTINGS_CHANGE_HOME_PAGE 7679
#define IDS_SETTINGS_ADVANCED 7682
#define IDS_SETTINGS_BASIC 7683
#define IDS_SETTINGS_MENU_BUTTON_LABEL 7684
#define IDS_SETTINGS_MENU_EXTENSIONS_LINK_TOOLTIP 7685
#define IDS_SETTINGS_SEARCH_PROMPT 7686
#define IDS_SETTINGS_SEARCH_NO_RESULTS_HELP 7687
#define IDS_SETTINGS_SETTINGS 7688
#define IDS_SETTINGS_ALT_PAGE_TITLE 7689
#define IDS_SETTINGS_SUBPAGE_BUTTON 7690
#define IDS_SETTINGS_RESTART 7691
#define IDS_SETTINGS_CONTROLLED_BY_EXTENSION 7692
#define IDS_SETTINGS_CONTROLLED_BY_EXTENSION_TITLE 7693
#define IDS_SETTINGS_CONTROLLED_BY_EXTENSION_WITH_DISABLE_AND_MANAGE_OPTION 7694
#define IDS_SETTINGS_CLEAR 7695
#define IDS_SETTINGS_CUSTOM 7696
#define IDS_SETTINGS_DELETE 7697
#define IDS_SETTINGS_EDIT 7698
#define IDS_SETTINGS_END_TIME 7699
#define IDS_SETTINGS_NOT_VALID 7700
#define IDS_SETTINGS_NOT_VALID_WEB_ADDRESS 7701
#define IDS_SETTINGS_NOT_VALID_WEB_ADDRESS_FOR_CONTENT_TYPE 7702
#define IDS_SETTINGS_INPUT_MAX_LENGTH_DESCRIPTION 7703
#define IDS_SETTINGS_RETRY 7704
#define IDS_SETTINGS_SLIDER_MIN_MAX_ARIA_ROLE_DESCRIPTION 7705
#define IDS_SETTINGS_START_TIME 7706
#define IDS_PASSWORDS_PAGE_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 7707
#define IDS_PASSWORDS_PAGE_COPY_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 7708
#define IDS_PASSWORDS_PAGE_EDIT_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 7709
#define IDS_PASSWORDS_PAGE_EXPORT_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 7710
#define IDS_PASSWORDS_PAGE_DELETE_ALL_DATA_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 7711
#define IDS_SETTINGS_AUTOFILL_AND_PASSWORDS 7712
#define IDS_SETTINGS_YOUR_SAVED_INFO 7713
#define IDS_IDENTITY_DOCS_SUBMENU_OPTION 7714
#define IDS_TRAVEL_SUBMENU_OPTION 7715
#define IDS_SETTINGS_YOUR_SAVED_INFO_DESCRIPTION 7716
#define IDS_SETTINGS_YOUR_SAVED_INFO_AUTOFILL_SETTINGS_LABEL 7717
#define IDS_SETTINGS_YOUR_SAVED_INFO_AUTOFILL_SETTINGS_DESCRIPTION 7718
#define IDS_SETTINGS_RELATED_SERVICES_TITLE 7719
#define IDS_PASSWORDS_PAGE_IMPORT_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 7720
#define IDS_SETTINGS_GOOGLE_PAYMENTS 7721
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_ADD_TITLE 7722
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_EDIT_TITLE 7723
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_COUNTRY 7724
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_PHONE 7725
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_EMAIL 7726
#define IDS_SETTINGS_AUTOFILL_DETAIL 7727
#define IDS_SETTINGS_AUTOFILL_DROPDOWN_NO_OPTION_SELECTED 7728
#define IDS_SETTINGS_AUTOFILL_CARD_DESCRIPTION 7729
#define IDS_SETTINGS_AUTOFILL_CARD_A11Y_LABELED 7730
#define IDS_SETTINGS_AUTOFILL_CARD_EXP_DATE_A11Y_LABELED 7731
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_ADDRESS 7732
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_CREDIT_CARD 7733
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_CREDIT_CARD_WITH_CVC 7734
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_HOME_ADDRESS 7735
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_WORK_ADDRESS 7736
#define IDS_AUTOFILL_ADD_VIRTUAL_CARD 7737
#define IDS_AUTOFILL_REMOVE_VIRTUAL_CARD 7738
#define IDS_AUTOFILL_EDIT_SERVER_CREDIT_CARD 7739
#define IDS_AUTOFILL_EDIT_SERVER_CREDIT_CARD_IN_WALLET 7740
#define IDS_AUTOFILL_VIRTUAL_CARD_TURNED_ON_LABEL 7741
#define IDS_AUTOFILL_VIRTUAL_CARD_UNENROLL_DIALOG_TITLE 7742
#define IDS_AUTOFILL_VIRTUAL_CARD_UNENROLL_DIALOG_LABEL 7743
#define IDS_AUTOFILL_VIRTUAL_CARD_UNENROLL_DIALOG_CONFIRM_BUTTON_LABEL 7744
#define IDS_SETTINGS_ADDRESS_REMOVE 7745
#define IDS_SETTINGS_ADDRESS_REMOVE_CONFIRMATION_TITLE 7746
#define IDS_SETTINGS_ADDRESS_REMOVED_MESSAGE 7747
#define IDS_SETTINGS_EDIT_CREDIT_CARD_TITLE 7748
#define IDS_SETTINGS_LOCAL_CARD_REMOVE_CONFIRMATION_TITLE 7749
#define IDS_SETTINGS_LOCAL_PAYMENT_METHOD_REMOVE_CONFIRMATION_DESCRIPTION 7750
#define IDS_SETTINGS_PAYMENTS_MANAGE_CREDIT_CARDS 7751
#define IDS_SETTINGS_GOOGLE_WALLET 7752
#define IDS_SETTINGS_PAYMENTS_MANAGE_LOYALTY_CARDS_AND_PAYMENT_METHODS 7753
#define IDS_SETTINGS_REMOTE_WALLET_PASSES_LINK_LABEL 7754
#define IDS_SETTINGS_PAYMENTS_SAVED_TO_THIS_DEVICE_ONLY 7755
#define IDS_SETTINGS_CREDIT_AND_DEBIT_CARD_TITLE 7756
#define IDS_SETTINGS_ADD_CREDIT_CARD_TITLE 7757
#define IDS_SETTINGS_REMOTE_PAYMENT_METHODS_LINK_LABEL 7758
#define IDS_SETTINGS_REMOTE_PAYMENT_METHODS_WALLET_LINK_LABEL 7759
#define IDS_SETTINGS_NAME_ON_CREDIT_CARD 7760
#define IDS_SETTINGS_CREDIT_CARD_NUMBER 7761
#define IDS_SETTINGS_CREDIT_CARD_EXPIRATION_DATE 7762
#define IDS_SETTINGS_CREDIT_CARD_EXPIRATION_MONTH 7763
#define IDS_SETTINGS_CREDIT_CARD_EXPIRATION_YEAR 7764
#define IDS_SETTINGS_CREDIT_CARD_EXPIRED 7765
#define IDS_SETTINGS_CREDIT_CARD_NICKNAME 7766
#define IDS_SETTINGS_CREDIT_CARD_NICKNAME_INVALID 7767
#define IDS_SETTINGS_CREDIT_CARD_CVC_TITLE 7768
#define IDS_SETTINGS_CREDIT_CARD_CVC_IMAGE_TITLE 7769
#define IDS_SETTINGS_CREDIT_CARD_CVC_IMAGE_TITLE_AMEX 7770
#define IDS_SETTINGS_CREDIT_CARD_CVC_PLACEHOLDER 7771
#define IDS_SETTINGS_ADD_PAYMENT_METHODS 7772
#define IDS_SETTINGS_ADD_PAYMENT_METHOD_CREDIT_OR_DEBIT_CARD 7773
#define IDS_SETTINGS_ADD_PAYMENT_METHOD_IBAN 7774
#define IDS_SETTINGS_IBAN_SAVED_TO_THIS_DEVICE_ONLY 7775
#define IDS_SETTINGS_IBAN_INVALID_VALIDATION_MESSAGE 7776
#define IDS_IBAN_NICKNAME 7777
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_IBAN 7778
#define IDS_SETTINGS_AUTOFILL_A11Y_IBAN_DESCRIPTION 7779
#define IDS_SETTINGS_ADD_IBAN_TITLE 7780
#define IDS_SETTINGS_EDIT_IBAN_TITLE 7781
#define IDS_SETTINGS_IBAN_EDIT 7782
#define IDS_SETTINGS_LOCAL_IBAN_REMOVE_CONFIRMATION_TITLE 7783
#define IDS_SETTINGS_PASSWORD_MANAGER 7784
#define IDS_SETTINGS_PASSWORD_MANAGER_DESCRIPTION 7785
#define IDS_SETTINGS_PAYMENT_METHODS_NONE 7786
#define IDS_AUTOFILL_PASSKEYS_TITLE 7787
#define IDS_SETTINGS_PASSKEYS_LENGTH_ERROR 7788
#define IDS_SETTINGS_PASSKEYS_SITE_LABEL 7789
#define IDS_SETTINGS_PASSKEYS_DIALOG_TITLE 7790
#define IDS_SETTINGS_PASSKEYS_EDIT_DIALOG_FOOTNOTE 7791
#define IDS_SETTINGS_ADDRESS_NONE 7792
#define IDS_SETTINGS_PASSWORDS_LEAK_DETECTION_LABEL 7793
#define IDS_SETTINGS_PASSWORDS_LEAK_DETECTION_SIGNED_OUT_ENABLED_DESC 7794
#define IDS_SETTINGS_CHECK_PASSWORDS_PROGRESS 7795
#define IDS_SETTINGS_COMPROMISED_PASSWORDS_COUNT 7796
#define IDS_SETTINGS_COMPROMISED_PASSWORDS_COUNT_SHORT 7797
#define IDS_SETTINGS_WEAK_PASSWORDS_COUNT_SHORT 7798
#define IDS_SETTINGS_REUSED_PASSWORDS_COUNT_SHORT 7799
#define IDS_SETTINGS_AUTOFILL_AI_WHEN_ON_SAVED_INFO 7800
#define IDS_SETTINGS_AUTOFILL_AI_ENTERPRISE_LOGGING_MANAGED_DISABLED 7801
#define IDS_SETTINGS_AUTOFILL_AI_ENTITY_INSTANCES_HEADER 7802
#define IDS_SETTINGS_AUTOFILL_AI_ENTITY_INSTANCES_NONE 7803
#define IDS_SETTINGS_AUTOFILL_AI_MORE_ACTIONS_FOR_ENTITY_INSTANCE 7804
#define IDS_SETTINGS_AUTOFILL_AI_DELETE_ENTITY_INSTANCE_DIALOG_TEXT 7805
#define IDS_SETTINGS_AUTOFILL_AI_ACCESSIBILITY_LABEL_MONTH_DROPDOWN 7806
#define IDS_SETTINGS_AUTOFILL_AI_ACCESSIBILITY_LABEL_DAY_DROPDOWN 7807
#define IDS_SETTINGS_AUTOFILL_AI_ACCESSIBILITY_LABEL_YEAR_DROPDOWN 7808
#define IDS_SETTINGS_AUTOFILL_AI_MONTH_DROPDOWN_NO_OPTION_SELECTED 7809
#define IDS_SETTINGS_AUTOFILL_AI_DAY_DROPDOWN_NO_OPTION_SELECTED 7810
#define IDS_SETTINGS_AUTOFILL_AI_YEAR_DROPDOWN_NO_OPTION_SELECTED 7811
#define IDS_SETTINGS_AUTOFILL_AI_ADD_OR_EDIT_DIALOG_DATE_VALIDATION_ERROR 7812
#define IDS_SETTINGS_AUTOFILL_AI_ADD_OR_EDIT_DIALOG_VALIDATION_ERROR 7813
#define IDS_AUTOFILL_AI_ADD_OR_EDIT_DIALOG_REQUIRED_FIELD_ERROR 7814
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_TOGGLE_LABEL 7815
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_TOGGLE_SUB_LABEL 7816
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_WHEN_ON_SAVED_INFO 7817
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_WHEN_ON_NOTIFICATIONS 7818
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_TO_CONSIDER_DATA_USAGE 7819
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_TO_CONSIDER_DATA_STORAGE 7820
#define IDS_SETTINGS_PASSWORD_SHOW_PASSWORD_A11Y 7832
#define IDS_SETTINGS_PASSWORD_HIDE_PASSWORD_A11Y 7833
#define IDS_SETTINGS_HOME_AND_WORK_ADDRESS_EDIT 7834
#define IDS_SETTINGS_HOME_AND_WORK_ADDRESS_REMOVE 7835
#define IDS_SETTINGS_HOME_ADDRESS_REMOVE_CONFIRMATION_DIALOG_TITLE 7836
#define IDS_SETTINGS_WORK_ADDRESS_REMOVE_CONFIRMATION_DIALOG_TITLE 7837
#define IDS_SETTINGS_NAME_EMAIL_ADDRESS_REMOVE_CONFIRMATION_DIALOG_TITLE 7838
#define IDS_SETTINGS_HOME_ADDRESS_REMOVE_CONFIRMATION_DIALOG_NOTICE 7839
#define IDS_SETTINGS_WORK_ADDRESS_REMOVE_CONFIRMATION_DIALOG_NOTICE 7840
#define IDS_SETTINGS_NAME_EMAIL_ADDRESS_REMOVE_CONFIRMATION_DIALOG_NOTICE 7841
#define IDS_SETTINGS_HOME_AND_WORK_ADDRESS_REMOVE_CONFIRMATION_DIALOG_ACTION_OK 7842
#define IDS_SETTINGS_HOME_AND_WORK_ADDRESS_REMOVED_MESSAGE 7843
#define IDS_SETTINGS_NAME_EMAIL_ADDRESS_REMOVED_MESSAGE 7844
#define IDS_SETTINGS_DEFAULT_BROWSER 7845
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT_BUTTON 7846
#define IDS_SETTINGS_CLEAR_PERIOD_TITLE 7847
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_WITH_SYNC 7848
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_WITH_SYNC_ERROR 7849
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_WITH_SYNC_PASSPHRASE_ERROR 7850
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_WITH_SYNC_PAUSED 7851
#define IDS_SETTINGS_CLEAR_BROWSING_HISTORY 7852
#define IDS_SETTINGS_CLEAR_COOKIES_AND_SITE_DATA_SUMMARY_BASIC 7853
#define IDS_SETTINGS_CLEAR_COOKIES_AND_SITE_DATA_SUMMARY_BASIC_WITH_EXCEPTION 7854
#define IDS_SETTINGS_CLEAR_COOKIES_AND_SITE_DATA_SUMMARY_BASIC_SUPERVISED_PROFILE 7855
#define IDS_SETTINGS_CLEAR_COOKIES_AND_SITE_DATA_SUMMARY_BASIC_SIGNED_IN_PROFILE 7856
#define IDS_SETTINGS_CLEAR_BROWSING_HISTORY_SUMMARY 7857
#define IDS_SETTINGS_CLEAR_BROWSING_HISTORY_SUMMARY_SIGNED_IN_NO_LINK 7858
#define IDS_SETTINGS_CLEAR_GOOGLE_SEARCH_HISTORY_GOOGLE_DSE 7859
#define IDS_SETTINGS_CLEAR_GOOGLE_SEARCH_HISTORY_NON_GOOGLE_DSE 7860
#define IDS_SETTINGS_CLEAR_DOWNLOAD_HISTORY 7861
#define IDS_SETTINGS_CLEAR_CACHE 7862
#define IDS_SETTINGS_CLEAR_COOKIES 7863
#define IDS_SETTINGS_CLEAR_PASSWORDS 7864
#define IDS_SETTINGS_CLEAR_FORM_DATA 7865
#define IDS_SETTINGS_CLEAR_HOSTED_APP_DATA 7866
#define IDS_SETTINGS_CLEAR_PERIOD_15_MIN 7867
#define IDS_SETTINGS_CLEAR_PERIOD_15_MINUTES 7868
#define IDS_SETTINGS_CLEAR_PERIOD_HOUR 7869
#define IDS_SETTINGS_CLEAR_PERIOD_24_HOURS 7870
#define IDS_SETTINGS_CLEAR_PERIOD_7_DAYS 7871
#define IDS_SETTINGS_CLEAR_PERIOD_FOUR_WEEKS 7872
#define IDS_SETTINGS_CLEAR_PERIOD_EVERYTHING 7873
#define IDS_SETTINGS_NOTIFICATION_WARNING 7874
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_SHOW_MORE 7875
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_MORE 7876
#define IDS_SETTINGS_MANAGE_IN_YOUR_GEMINI_APPS_ACTIVITY 7877
#define IDS_SETTINGS_GEMINI_APPS_ACTIVITY 7878
#define IDS_SETTINGS_DELETE_DATA_FROM_DEVICE 7879
#define IDS_SETTINGS_DELETION_CONFIRMATION_TOAST_LABEL 7880
#define IDS_SETTINGS_DELETION_CONFIRMATION_ALL_TIME_TOAST_LABEL 7881
#define IDS_SETTINGS_SEARCH_GEMINI_PASSWORDS_OTHER_DATA_SUB_LABEL 7882
#define IDS_SETTINGS_DOWNLOADS 7883
#define IDS_SETTINGS_DOWNLOAD_LOCATION 7884
#define IDS_SETTINGS_CHANGE_DOWNLOAD_LOCATION 7885
#define IDS_SETTINGS_PROMPT_FOR_DOWNLOAD 7886
#define IDS_SETTINGS_OPEN_FILE_TYPES_AUTOMATICALLY 7887
#define IDS_SETTINGS_DOWNLOADS_SHOW_WHEN_FINISHED 7888
#define IDS_SETTINGS_ON_STARTUP 7889
#define IDS_SETTINGS_ON_STARTUP_OPEN_NEW_TAB 7890
#define IDS_SETTINGS_ON_STARTUP_CONTINUE 7891
#define IDS_SETTINGS_ON_STARTUP_OPEN_SPECIFIC 7892
#define IDS_SETTINGS_ON_STARTUP_CONTINUE_AND_OPEN_SPECIFIC 7893
#define IDS_SETTINGS_ON_STARTUP_USE_CURRENT 7894
#define IDS_SETTINGS_ON_STARTUP_ADD_NEW_PAGE 7895
#define IDS_SETTINGS_ON_STARTUP_EDIT_PAGE 7896
#define IDS_SETTINGS_ON_STARTUP_SITE_URL 7897
#define IDS_SETTINGS_ON_STARTUP_REMOVE 7898
#define IDS_SETTINGS_ON_STARTUP_PAGE_TOOLTIP 7899
#define IDS_SETTINGS_INVALID_URL 7900
#define IDS_SETTINGS_URL_TOOL_LONG 7901
#define IDS_SETTINGS_PERFORMANCE_PAGE_TITLE 7902
#define IDS_SETTINGS_PERFORMANCE_GENERAL_PAGE_TITLE 7903
#define IDS_SETTINGS_PERFORMANCE_MEMORY_PAGE_TITLE 7904
#define IDS_SETTINGS_PERFORMANCE_SPEED_PAGE_TITLE 7905
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_SETTING 7906
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_HEURISTICS_LABEL 7907
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_RECOMMENDED_BADGE 7908
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_ON_TIMER_LABEL 7909
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_RADIO_GROUP_ARIA_LABEL 7910
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_CHOOSE_DISCARD_TIME_ARIA_LABEL 7911
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_CONSERVATIVE_LABEL 7912
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_MEDIUM_LABEL 7913
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_AGGRESSIVE_LABEL 7914
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_CONSERVATIVE_DESCRIPTION 7915
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_MEDIUM_DESCRIPTION 7916
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_AGGRESSIVE_DESCRIPTION 7917
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_BUTTON_ARIA_LABEL 7918
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_SAVE_BUTTON_ARIA_LABEL 7919
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_HEADER 7920
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_DESCRIPTION 7921
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADDITIONAL_SITES 7922
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_DIALOG_CURRENT_TABS 7923
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_DIALOG_CURRENT_TABS_EMPTY 7924
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_DIALOG_MANUAL 7925
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ACTIVE_SITE_ARIA_DESCRIPTION 7926
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_DIALOG_HELP 7927
#define IDS_SETTINGS_PERFORMANCE_BATTERY_PAGE_TITLE 7928
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_SETTING 7929
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_ON_BATTERY_LABEL 7930
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_BELOW_THRESHOLD_LABEL 7931
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_RADIO_GROUP_ARIA_LABEL 7932
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_LINK_OS_SETTING_DESCRIPTION 7933
#define IDS_SETTINGS_PERFORMANCE_DISCARD_RING_TREATMENT_ENABLED_LABEL 7934
#define IDS_SETTINGS_PERFORMANCE_DISCARD_RING_TREATMENT_ENABLED_DESCRIPTION_WITH_LEARN_LINK 7935
#define IDS_SETTINGS_PERFORMANCE_TAB_HOVER_PREVIEW_CARD_LINK_TITLE 7936
#define IDS_SETTINGS_PERFORMANCE_TAB_HOVER_PREVIEW_CARD_LINK_SUBTITLE 7937
#define IDS_SETTINGS_PERFORMANCE_INTERVENTION_NOTIFICATION_ENABLED_LABEL 7938
#define IDS_SETTINGS_PERFORMANCE_INTERVENTION_NOTIFICATION_ENABLED_DESCRIPTION 7939
#define IDS_SETTINGS_LANGUAGES_PAGE_TITLE 7940
#define IDS_SETTINGS_LANGUAGES_CARD_TITLE 7941
#define IDS_SETTINGS_LANGUAGE_SEARCH 7942
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_LIST_MOVE_TO_TOP 7943
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_LIST_MOVE_UP 7944
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_LIST_MOVE_DOWN 7945
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_LIST_REMOVE 7946
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_ADD 7947
#define IDS_SETTINGS_LANGUAGES_MANAGE_LANGUAGES_TITLE 7948
#define IDS_SETTINGS_LANGUAGES_NO_LANGUAGES_ADDED 7949
#define IDS_SETTINGS_LANGUAGES_EXPAND_ACCESSIBILITY_LABEL 7950
#define IDS_SETTINGS_LANGUAGES_PREFERRED_LANGUAGES_HEADER 7951
#define IDS_SETTINGS_LANGUAGES_PREFERRED_LANGUAGES_DESC 7952
#define IDS_SETTINGS_LANGUAGES_OFFER_TO_ENABLE_TRANSLATE 7953
#define IDS_SETTINGS_LANGUAGES_OFFER_TO_ENABLE_TRANSLATE_SUBLABEL 7954
#define IDS_SETTINGS_LANGUAGES_TRANSLATE_TARGET 7955
#define IDS_SETTINGS_LANGUAGES_MANAGED_DIALOG_TITLE 7956
#define IDS_SETTINGS_LANGUAGES_MANAGED_DIALOG_BODY 7957
#define IDS_SETTINGS_LANGUAGES_ADD_ARIA_LABEL 7958
#define IDS_SETTINGS_LANGUAGES_REMOVE_AUTOMATIC_ARIA_LABEL 7959
#define IDS_SETTINGS_LANGUAGES_REMOVE_NEVER_ARIA_LABEL 7960
#define IDS_SETTINGS_TRANSLATE_PAGE_TITLE 7961
#define IDS_SETTINGS_TARGET_TRANSLATE_LABEL 7962
#define IDS_SETTINGS_LANGUAGES_AUTOMATIC_TRANSLATE 7963
#define IDS_SETTINGS_LANGUAGES_AUTOMATIC_TRANSLATE_ADD_ARIA_LABEL 7964
#define IDS_SETTINGS_LANGUAGES_NEVER_LANGUAGES 7965
#define IDS_SETTINGS_LANGUAGES_NEVER_TRANSLATE_ADD_ARIA_LABEL 7966
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_TITLE 7967
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_BASIC_LABEL 7968
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_ENHANCED_LABEL 7969
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_ENHANCED_DESCRIPTION 7970
#define IDS_SETTINGS_LANGUAGES_OFFER_TO_ENABLE_SPELL_CHECK 7971
#define IDS_SETTING_LANGUAGES_SPELL_CHECK_DISABLED_REASON 7972
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_LANGUAGES_LIST_TITLE 7973
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_MANAGE 7974
#define IDS_SETTINGS_LANGUAGES_EDIT_DICTIONARY_TITLE 7975
#define IDS_SETTINGS_LANGUAGES_ADD_DICTIONARY_WORD 7976
#define IDS_SETTINGS_LANGUAGES_ADD_DICTIONARY_WORD_BUTTON 7977
#define IDS_SETTINGS_LANGUAGES_ADD_DICTIONARY_WORD_DUPLICATE_ERROR 7978
#define IDS_SETTINGS_LANGUAGES_ADD_DICTIONARY_WORD_LENGTH_ERROR 7979
#define IDS_SETTINGS_LANGUAGES_DELETE_DICTIONARY_WORD_BUTTON 7980
#define IDS_SETTINGS_LANGUAGES_DICTIONARY_WORDS 7981
#define IDS_SETTINGS_LANGUAGES_DICTIONARY_WORDS_NONE 7982
#define IDS_SETTINGS_LANGUAGES_DICTIONARY_DOWNLOAD_FAILED 7983
#define IDS_SETTINGS_LANGUAGES_DICTIONARY_DOWNLOAD_FAILED_HELP 7984
#define IDS_SETTINGS_PRELOAD_PAGES_TITLE 7987
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_TITLE 7988
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_EXPAND_A11Y_LABEL 7989
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_SUMMARY 7990
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_WHEN_ON_BULLET_ONE 7991
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_TITLE 7992
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_SUMMARY 7993
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_EXPAND_A11Y_LABEL 7994
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_WHEN_ON_BULLET_ONE 7995
#define IDS_SETTINGS_PRIVACY 7996
#define IDS_SETTINGS_PRIVACY_V2 7997
#define IDS_SETTINGS_PRIVACY_MORE 7998
#define IDS_SETTINGS_AI_COMPOSE_SUBLABEL_V2 8000
#define IDS_SETTINGS_OFFER_WRITING_HELP_TOGGLE_LABEL 8001
#define IDS_SETTINGS_OFFER_WRITING_HELP_TOGGLE_SUB_LABEL 8002
#define IDS_SETTINGS_OFFER_WRITING_HELP_ENABLED_SUB_LABEL 8003
#define IDS_SETTINGS_OFFER_WRITING_HELP_DISABLED_SUB_LABEL 8004
#define IDS_SETTINGS_OFFER_WRITING_HELP_DISABLED_SITES_LABEL_V2 8005
#define IDS_SETTINGS_OFFER_WRITING_HELP_NO_DISABLED_SITES 8006
#define IDS_SETTINGS_OFFER_WRITING_HELP_REMOVE_SITE_ARIA_LABEL 8007
#define IDS_SETTINGS_COMPOSE_SETTING_LINK_A11Y 8008
#define IDS_SETTINGS_COMPOSE_WHEN_ON_WRITING_HELP 8009
#define IDS_SETTINGS_COMPOSE_WHEN_ON_WRITING_EXAMPLES 8010
#define IDS_SETTINGS_COMPOSE_WHEN_ON_WRITING_REFERENCES 8011
#define IDS_SETTINGS_COMPOSE_CONSIDER_DATA 8012
#define IDS_SETTINGS_ANTI_ABUSE_ENABLED_SUB_LABEL 8013
#define IDS_SETTINGS_ANTI_ABUSE_DISABLED_SUB_LABEL 8014
#define IDS_SETTINGS_ANTI_ABUSE_DESCRIPTION 8015
#define IDS_SETTINGS_ANTI_ABUSE_WHEN_ON_SECTION_ONE 8016
#define IDS_SETTINGS_ANTI_ABUSE_WHEN_ON_SECTION_TWO 8017
#define IDS_SETTINGS_ANTI_ABUSE_WHEN_ON_SECTION_THREE 8018
#define IDS_SETTINGS_ANTI_ABUSE_THINGS_TO_CONSIDER_SECTION_ONE 8019
#define IDS_SETTINGS_PRIVACY_SANDBOX_TITLE 8020
#define IDS_SETTINGS_PRIVACY_SANDBOX_COOKIES_DIALOG 8021
#define IDS_SETTINGS_PRIVACY_SANDBOX_COOKIES_DIALOG_MORE 8022
#define IDS_SETTINGS_AD_PRIVACY_LINK_ROW_LABEL 8023
#define IDS_SETTINGS_AD_PRIVACY_LINK_ROW_SUB_LABEL 8024
#define IDS_SETTINGS_AD_PRIVACY_RESTRICTED_LINK_ROW_SUB_LABEL 8025
#define IDS_SETTINGS_AD_PRIVACY_PAGE_TITLE 8026
#define IDS_SETTINGS_AD_PRIVACY_PAGE_TOPICS_LINK_ROW_LABEL 8027
#define IDS_SETTINGS_AD_PRIVACY_PAGE_TOPICS_LINK_ROW_SUB_LABEL_ENABLED 8028
#define IDS_SETTINGS_AD_PRIVACY_PAGE_TOPICS_LINK_ROW_SUB_LABEL_DISABLED 8029
#define IDS_SETTINGS_AD_PRIVACY_PAGE_FLEDGE_LINK_ROW_LABEL 8030
#define IDS_SETTINGS_AD_PRIVACY_PAGE_FLEDGE_LINK_ROW_SUB_LABEL_ENABLED 8031
#define IDS_SETTINGS_AD_PRIVACY_PAGE_FLEDGE_LINK_ROW_SUB_LABEL_DISABLED 8032
#define IDS_SETTINGS_AD_PRIVACY_PAGE_AD_MEASUREMENT_LINK_ROW_LABEL 8033
#define IDS_SETTINGS_AD_PRIVACY_PAGE_AD_MEASUREMENT_LINK_ROW_SUB_LABEL_ENABLED 8034
#define IDS_SETTINGS_AD_PRIVACY_PAGE_AD_MEASUREMENT_LINK_ROW_SUB_LABEL_DISABLED 8035
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_REGION_A11Y_DESCRIPTION 8036
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_REGION_A11Y_DESCRIPTION 8037
#define IDS_SETTINGS_TOPICS_PAGE_FOOTER_V2 8038
#define IDS_SETTINGS_FLEDGE_PAGE_TITLE 8039
#define IDS_SETTINGS_FLEDGE_PAGE_TOGGLE_LABEL 8040
#define IDS_SETTINGS_FLEDGE_PAGE_TOGGLE_SUB_LABEL 8041
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_HEADING 8042
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION 8043
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION_LEARN_MORE 8044
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION_DISABLED 8045
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION_EMPTY 8046
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_REGION_A11Y_DESCRIPTION 8047
#define IDS_SETTINGS_FLEDGE_PAGE_SEE_ALL_SITES_LABEL 8048
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCK_SITE 8049
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCK_SITE_A11Y_LABEL 8050
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCKED_SITES_HEADING 8051
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCKED_SITES_DESCRIPTION 8052
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCKED_SITES_DESCRIPTION_EMPTY 8053
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCKED_SITES_REGION_A11Y_DESCRIPTION 8054
#define IDS_SETTINGS_FLEDGE_PAGE_ALLOW_SITE 8055
#define IDS_SETTINGS_FLEDGE_PAGE_ALLOW_SITE_A11Y_LABEL 8056
#define IDS_SETTINGS_FLEDGE_PAGE_LEARN_MORE_HEADING 8057
#define IDS_SETTINGS_FLEDGE_PAGE_LEARN_MORE_BULLET_1 8058
#define IDS_SETTINGS_FLEDGE_PAGE_LEARN_MORE_BULLET_2 8059
#define IDS_SETTINGS_FLEDGE_PAGE_LEARN_MORE_BULLET_3 8060
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION_LEARN_MORE_A11Y_LABEL 8061
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_TITLE 8062
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_TOGGLE_LABEL 8063
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_TOGGLE_SUB_LABEL 8064
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_ENABLED_BULLET_1 8065
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_ENABLED_BULLET_2 8066
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_ENABLED_BULLET_3 8067
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_CONSIDER_BULLET_1 8068
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_CONSIDER_BULLET_2 8069
#define IDS_SETTINGS_PRIVACY_GUIDE_LABEL 8070
#define IDS_SETTINGS_PRIVACY_GUIDE_SUBLABEL 8071
#define IDS_SETTINGS_PRIVACY_GUIDE_PROMO_HEADER 8072
#define IDS_SETTINGS_PRIVACY_GUIDE_PROMO_START_BUTTON 8073
#define IDS_SETTINGS_PRIVACY_GUIDE_BACK_TO_SETTINGS_ARIA_LABEL 8074
#define IDS_SETTINGS_PRIVACY_GUIDE_BACK_TO_SETTINGS_ARIA_ROLE_DESC 8075
#define IDS_SETTINGS_PRIVACY_GUIDE_BACK_BUTTON 8076
#define IDS_SETTINGS_PRIVACY_GUIDE_STEPS 8077
#define IDS_SETTINGS_PRIVACY_GUIDE_NEXT_BUTTON 8078
#define IDS_SETTINGS_PRIVACY_GUIDE_WELCOME_CARD_HEADER 8079
#define IDS_SETTINGS_PRIVACY_GUIDE_WELCOME_CARD_SUB_HEADER 8080
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_HEADER 8081
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_SUB_HEADER 8082
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_SUB_HEADER_NO_LINKS 8083
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_LEAVE_BUTTON 8084
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_PRIVACY_SANDBOX_LABEL 8085
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_PRIVACY_SANDBOX_SUB_LABEL_AD_TOPICS 8086
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_WAA_LABEL 8087
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_AI_SETTINGS_LABEL 8088
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_CARD_HEADER 8089
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_FEATURE_DESCRIPTION1 8090
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_FEATURE_DESCRIPTION2 8091
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_PRIVACY_DESCRIPTION1 8092
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_CARD_HEADER 8093
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_AND_TABS_SYNC_CARD_HEADER 8094
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_SETTING_LABEL 8095
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_AND_TABS_SYNC_SETTING_LABEL 8096
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_FEATURE_DESCRIPTION1 8097
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_AND_TABS_SYNC_FEATURE_DESCRIPTION1 8098
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_FEATURE_DESCRIPTION2 8099
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_PRIVACY_DESCRIPTION1 8100
#define IDS_SETTINGS_PRIVACY_GUIDE_COOKIES_CARD_HEADER 8101
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_HEADER 8102
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_ENHANCED_PROTECTION_PRIVACY_DESCRIPTION1 8103
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_ENHANCED_PROTECTION_PRIVACY_DESCRIPTION2 8104
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_ENHANCED_PROTECTION_PRIVACY_DESCRIPTION3 8105
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_STANDARD_PROTECTION_FEATURE_DESCRIPTION1 8106
#define IDS_SETTINGS_SAFETY_CHECK_ICON_INFO_ARIA_LABEL 8109
#define IDS_SETTINGS_SAFETY_CHECK_ICON_WARNING_ARIA_LABEL 8110
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW 8111
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_ALLOW_AGAIN_ARIA_LABEL 8112
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_ALLOW_AGAIN_LABEL 8113
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_PRIMARY_LABEL 8114
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_SECONDARY_LABEL 8115
#define IDS_SETTINGS_SAFETY_HUB_REVOKED_PERMISSIONS_SECONDARY_LABEL 8116
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_TOAST_BULK_LABEL 8117
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_TOAST_LABEL 8118
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_SETTING_LABEL 8119
#define IDS_SETTINGS_SAFETY_CHECK_UPDATES_DISABLED_BY_ADMIN 8120
#define IDS_SETTINGS_SAFETY_CHECK_PASSWORDS_PRIMARY_LABEL 8121
#define IDS_SETTINGS_SAFETY_CHECK_PASSWORDS_FEATURE_UNAVAILABLE 8122
#define IDS_SETTINGS_SAFETY_CHECK_SAFE_BROWSING_ENABLED 8123
#define IDS_SETTINGS_SAFETY_CHECK_SAFE_BROWSING_ENABLED_STANDARD 8124
#define IDS_SETTINGS_SAFETY_CHECK_SAFE_BROWSING_ENABLED_STANDARD_AVAILABLE_ENHANCED 8125
#define IDS_SETTINGS_SAFETY_CHECK_SAFE_BROWSING_ENABLED_ENHANCED 8126
#define IDS_SETTINGS_SAFETY_CHECK_EXTENSIONS_SAFE 8127
#define IDS_SETTINGS_SAFETY_CHECK_EXTENSIONS_BLOCKLISTED_OFF 8128
#define IDS_SETTINGS_SAFETY_CHECK_EXTENSIONS_BLOCKLISTED_ON_USER 8129
#define IDS_SETTINGS_SAFETY_CHECK_EXTENSIONS_BLOCKLISTED_ON_ADMIN 8130
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_EXTENSIONS 8131
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_IGNORED_TOAST_LABEL 8132
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_BLOCKED_TOAST_LABEL 8133
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_RESET_TOAST_LABEL 8134
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_COUNT_LABEL 8135
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_DONT_ALLOW_LABEL 8136
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_DONT_ALLOW_ARIA_LABEL 8137
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_IGNORE_LABEL 8138
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_IGNORE_ARIA_LABEL 8139
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_RESET_LABEL 8140
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_RESET_ARIA_LABEL 8141
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_MORE_ACTIONS_ARIA_LABEL 8142
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_BLOCK_ALL_LABEL 8143
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_BLOCK_ALL_TOAST_LABEL 8144
#define IDS_SETTINGS_SAFETY_CHECK_TOAST_UNDO_BUTTON_LABEL 8145
#define IDS_SETTINGS_NETWORK_PREDICTION_ENABLED_DESC 8146
#define IDS_SETTINGS_SAFEBROWSING_ENABLEPROTECTION 8147
#define IDS_SETTINGS_SAFEBROWSING_ENABLEPROTECTION_DESC 8148
#define IDS_SETTINGS_SAFEBROWSING_ENABLE_REPORTING_DESC 8149
#define IDS_SETTINGS_SAFEBROWSING_SECTION_LABEL 8150
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED 8151
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_DESC_UPDATED 8152
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_EXPAND_ACCESSIBILITY_LABEL 8153
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_ONE 8154
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_THREE 8155
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_FOUR 8156
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_FIVE 8157
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_WHEN_ON_BULLET_TWO 8158
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_WHEN_ON_BULLET_THREE 8159
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_WHEN_ON_BULLET_FOUR 8160
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_THINGS_TO_CONSIDER_BULLET_ONE 8161
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_THINGS_TO_CONSIDER_BULLET_TWO 8162
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_THINGS_TO_CONSIDER_BULLET_THREE 8163
#define IDS_SETTINGS_SAFEBROWSING_STANDARD 8164
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_DESC 8165
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_EXPAND_ACCESSIBILITY_LABEL 8168
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_BULLET_ONE 8169
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_HELP_IMPROVE 8170
#define IDS_SETTINGS_SAFEBROWSING_NONE 8171
#define IDS_SETTINGS_SAFEBROWSING_NONE_DESC 8172
#define IDS_SETTINGS_SAFEBROWSING_DISABLE_DIALOG_TITLE 8173
#define IDS_SETTINGS_SAFEBROWSING_DISABLE_DIALOG_DESC 8174
#define IDS_SETTINGS_SAFEBROWSING_DISABLE_DIALOG_CONFIRM 8175
#define IDS_SETTINGS_ENABLE_DO_NOT_TRACK 8176
#define IDS_SETTINGS_ENABLE_DO_NOT_TRACK_DIALOG_TITLE 8177
#define IDS_SETTINGS_ENABLE_DO_NOT_TRACK_DIALOG_TEXT 8178
#define IDS_SETTINGS_ENABLE_DO_NOT_TRACK_DIALOG_LEARN_MORE_ACCESSIBILITY_LABEL 8179
#define IDS_SETTINGS_PERMISSIONS 8180
#define IDS_SETTINGS_PERMISSIONS_DESCRIPTION 8181
#define IDS_SETTINGS_SECURITY 8182
#define IDS_SETTINGS_SECURITY_DESCRIPTION 8183
#define IDS_SETTINGS_ADVANCED_PROTECTION_PROGRAM 8184
#define IDS_SETTINGS_ADVANCED_PROTECTION_PROGRAM_DESC 8185
#define IDS_SETTINGS_SECURITY_BUNDLE_TOAST_FOR_USER_OPTED_INTO_ENHANCED_BUNDLE 8186
#define IDS_SETTINGS_SECURITY_BUNDLE_RESET_TO_DEFAULTS_BUTTON_LABEL 8187
#define IDS_SETTINGS_SECURITY_TITLE 8188
#define IDS_SETTINGS_SECURITY_STANDARD_BUNDLE_TITLE 8189
#define IDS_SETTINGS_SECURITY_ENHANCED_BUNDLE_TITLE 8190
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_TITLE 8191
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_DESCRIPTION 8192
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_TITLE 8193
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_SUBTITLE 8194
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_WHAT_IT_DOES_HEADING 8195
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_WHAT_IT_DOES_CONTENT 8196
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_HOW_IT_WORKS_HEADING 8197
#define IDS_SETTINGS_SECURITY_BUNDLE_STANDARD_BULLET_ONE 8198
#define IDS_SETTINGS_SECURITY_BUNDLE_STANDARD_BULLET_TWO 8199
#define IDS_SETTINGS_SECURITY_BUNDLE_STANDARD_BULLET_THREE 8200
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_ENHANCED_TITLE 8201
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_ENHANCED_SUBTITLE 8202
#define IDS_SETTINGS_SECURITY_BUNDLE_ENHANCED_BULLET_TWO 8203
#define IDS_SETTINGS_SECURITY_BUNDLE_ENHANCED_BULLET_THREE 8204
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_ENHANCED 8205
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_ENHANCED_CUSTOM 8206
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_ENHANCED_STRICT 8207
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_STANDARD 8208
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_OFF 8209
#define IDS_SETTINGS_SECURITY_ACCOUNT_AND_NETWORK_SECTION_TITLE 8210
#define IDS_SETTINGS_SECURITY_ADVANCED_PROTECTION_PROGRAM_LABEL 8211
#define IDS_SETTINGS_SECURITY_PASSWORDS_LEAK_DETECTION_TITLE 8212
#define IDS_SETTINGS_SECURITY_SECURE_DNS_TITLE 8213
#define IDS_SETTINGS_SECURITY_SECURE_DNS_DESCRIPTION 8214
#define IDS_SETTINGS_SECURITY_SECURE_DNS_DEFAULT 8215
#define IDS_SETTINGS_SECURITY_SECURE_DNS_FALLBACK 8216
#define IDS_SETTINGS_SECURITY_SECURE_DNS_CUSTOM 8217
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_TITLE 8218
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_DESCRIPTION 8219
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_UNRECOGNIZED_SITES 8220
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_STRICT_FOR_ALL_SITES 8221
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_STRICT_FOR_ALL_SITES_DESCRIPTION 8222
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_MANAGE_SITE_EXCEPTIONS 8223
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_MANAGE_SITE_EXCEPTIONS_DESCRIPTION 8224
#define IDS_SETTINGS_SECURE_CONNECTIONS_SECTION_TITLE 8225
#define IDS_SETTINGS_HTTPS_ONLY_MODE 8226
#define IDS_SETTINGS_HTTPS_ONLY_MODE_DESCRIPTION 8227
#define IDS_SETTINGS_HTTPS_ONLY_MODE_DESCRIPTION_ADVANCED_PROTECTION 8228
#define IDS_SETTINGS_HTTPS_FIRST_MODE_TITLE 8229
#define IDS_SETTINGS_HTTPS_FIRST_MODE_DESCRIPTION 8230
#define IDS_SETTINGS_HTTPS_FIRST_MODE_DESCRIPTION_ADVANCED_PROTECTION 8231
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_FULL_LABEL 8232
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_INCOGNITO_LABEL 8233
#define IDS_SETTINGS_HTTPS_FIRST_MODE_DISABLED_LABEL 8234
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_STRICT_LABEL 8235
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_STRICT_SUBLABEL 8236
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_BALANCED_LABEL 8237
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_BALANCED_SUBLABEL 8238
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_TOGGLE_LABEL 8239
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_TOGGLE_SUBLABEL 8240
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_BALANCED_LABEL 8241
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_BALANCED_SUBLABEL 8242
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_STRICT_LABEL 8243
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_STRICT_SUBLABEL 8244
#define IDS_SETTINGS_MANAGE_CERTIFICATES 8245
#define IDS_SETTINGS_MANAGE_CERTIFICATES_DESCRIPTION 8246
#define IDS_SETTINGS_MANAGE_DEVICE_CERTIFICATES 8247
#define IDS_SETTINGS_MANAGE_DEVICE_CERTIFICATES_DESCRIPTION 8248
#define IDS_SETTINGS_MANAGE 8249
#define IDS_SETTINGS_SECURE_DNS 8250
#define IDS_SETTINGS_AUTOMATIC_MODE_DESCRIPTION 8252
#define IDS_SETTINGS_SECURE_DNS_DROPDOWN_ACCESSIBILITY_LABEL 8253
#define IDS_SETTINGS_SECURE_DROPDOWN_MODE_DESCRIPTION 8254
#define IDS_SETTINGS_SECURE_DROPDOWN_MODE_PRIVACY_POLICY 8255
#define IDS_SETTINGS_SECURE_DNS_DISABLED_FOR_MANAGED_ENVIRONMENT 8256
#define IDS_SETTINGS_SECURE_DNS_DISABLED_FOR_PARENTAL_CONTROL 8257
#define IDS_SETTINGS_SECURE_DNS_CUSTOM_DESCRIPTION 8258
#define IDS_SETTINGS_SECURE_DNS_CUSTOM_PLACEHOLDER 8259
#define IDS_SETTINGS_SECURE_DNS_CUSTOM_FORMAT_ERROR 8260
#define IDS_SETTINGS_SECURE_DNS_CUSTOM_CONNECTION_ERROR 8261
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_OPTIMIZATION_LINK_TITLE 8262
#define IDS_SETTINGS_CONTENT_SETTINGS 8263
#define IDS_SETTINGS_SITE_SETTINGS 8264
#define IDS_SETTINGS_SITE_SETTINGS_DESCRIPTION 8265
#define IDS_SETTINGS_CLEAR_DATA 8266
#define IDS_SETTINGS_CLEARING_DATA 8267
#define IDS_SETTINGS_CLEARED_DATA 8268
#define IDS_SETTINGS_CLEAR_BROWSING_DATA 8269
#define IDS_SETTINGS_CLEAR_DATA_DESCRIPTION 8270
#define IDS_SETTINGS_TITLE_AND_COUNT 8271
#define IDS_SETTINGS_SYNC_AND_GOOGLE_SERVICES_PRIVACY_DESC_UNIFIED_CONSENT 8272
#define IDS_SETTINGS_SEARCH_AGGREGATOR_PREF 8273
#define IDS_SETTINGS_RECENT_PERMISSIONS_NO_CHANGES 8274
#define IDS_SETTINGS_RECENT_PERMISSIONS_ALLOWED_ONE_ITEM 8275
#define IDS_SETTINGS_RECENT_PERMISSIONS_ALLOWED_TWO_ITEMS 8276
#define IDS_SETTINGS_RECENT_PERMISSIONS_ALLOWED_MORE_THAN_TWO_ITEMS 8277
#define IDS_SETTINGS_RECENT_PERMISSIONS_AUTOMATICALLY_BLOCKED_ONE_ITEM 8278
#define IDS_SETTINGS_RECENT_PERMISSIONS_AUTOMATICALLY_BLOCKED_TWO_ITEMS 8279
#define IDS_SETTINGS_RECENT_PERMISSIONS_AUTOMATICALLY_BLOCKED_MORE_THAN_TWO_ITEMS 8280
#define IDS_SETTINGS_RECENT_PERMISSIONS_BLOCKED_ONE_ITEM 8281
#define IDS_SETTINGS_RECENT_PERMISSIONS_BLOCKED_TWO_ITEMS 8282
#define IDS_SETTINGS_RECENT_PERMISSIONS_BLOCKED_MORE_THAN_TWO_ITEMS 8283
#define IDS_SETTINGS_RESET_PROMPT_TITLE 8284
#define IDS_SETTINGS_RESET 8285
#define IDS_SETTINGS_RESET_SETTINGS_TRIGGER 8286
#define IDS_SETTINGS_RESET_AUTOMATED_DIALOG_TITLE 8287
#define IDS_SETTINGS_RESET_BANNER_TEXT 8288
#define IDS_SETTINGS_RESET_BANNER_RESET_BUTTON_TEXT 8289
#define IDS_SETTINGS_RESET_LEARN_MORE_ACCESSIBILITY_TEXT 8290
#define IDS_SETTINGS_RESET_AUTOMATED_DIALOG_V2_TITLE 8291
#define IDS_SETTINGS_RESET_AUTOMATED_DIALOG_V2_BODY 8292
#define IDS_SETTINGS_RESET_PINNED_TABS 8293
#define IDS_SETTINGS_RESET_EXTENSIONS 8294
#define IDS_SETTINGS_RESET_HOMEPAGE 8295
#define IDS_SETTINGS_RESET_DSE 8296
#define IDS_SETTINGS_SEARCH 8299
#define IDS_SETTINGS_DEFAULT_SEARCH 8300
#define IDS_SETTINGS_SEARCH_EXPLANATION_ACCESSIBILITY_LABEL 8301
#define IDS_SETTINGS_SEARCH_MANAGE_SEARCH_ENGINES 8302
#define IDS_SETTINGS_SEARCH_MANAGE_SEARCH_ENGINES_AND_SITE_SEARCH 8303
#define IDS_SETTINGS_SEARCH_MANAGE_SEARCH_ENGINES_EXPLANATION 8304
#define IDS_SETTINGS_SEARCH_SITE_SEARCH 8305
#define IDS_SETTINGS_SEARCH_ACTIVE_SHORTCUTS 8306
#define IDS_SETTINGS_SEARCH_ACTIVE_SHORTCUTS_EXPLANATION 8307
#define IDS_SETTINGS_SEARCH_INACTIVE_SHORTCUTS 8308
#define IDS_SETTINGS_SEARCH_INACTIVE_SHORTCUTS_EXPLANATION 8309
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES 8310
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES_ACTIVE_SHORTCUTS 8311
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES_INACTIVE_SHORTCUTS 8312
#define IDS_SETTINGS_SEARCH_KEYBOARD_KEY_TITLE 8313
#define IDS_SETTINGS_SEARCH_KEYBOARD_KEY_DESCRIPTION 8314
#define IDS_SETTINGS_SEARCH_ACTIVATE 8315
#define IDS_SETTINGS_SEARCH_DEACTIVATE 8316
#define IDS_SETTINGS_SEARCH_ACTIVATE_SHORTCUT 8317
#define IDS_SETTINGS_SEARCH_DEACTIVATE_SHORTCUT 8318
#define IDS_SETTINGS_SEARCH_DISABLE_EXTENSION 8319
#define IDS_SETTINGS_SEARCH_MANAGE_EXTENSION 8320
#define IDS_SETTINGS_SEARCH_ENGINES 8321
#define IDS_SETTINGS_SEARCH_ENGINES_PAGE_EXPLANATION 8322
#define IDS_SETTINGS_SEARCH_ENGINES_SEARCH 8323
#define IDS_SETTINGS_SEARCH_ENGINES_SUBTITLE_FOR_POLICY 8324
#define IDS_SETTINGS_SEARCH_ENGINES_ADD_SITE_SEARCH 8325
#define IDS_SETTINGS_SEARCH_ENGINES_EDIT_SEARCH_ENGINE 8326
#define IDS_SETTINGS_SEARCH_ENGINES_VIEW_SEARCH_ENGINE 8327
#define IDS_SETTINGS_SEARCH_ENGINES_EDIT_SITE_SEARCH 8328
#define IDS_SETTINGS_SEARCH_ENGINES_VIEW_SITE_SEARCH 8329
#define IDS_SETTINGS_SEARCH_ENGINES_DELETE_CONFIRMATION_TITLE 8330
#define IDS_SETTINGS_SEARCH_ENGINES_DELETE_CONFIRMATION_DESCRIPTION 8331
#define IDS_SETTINGS_SEARCH_ENGINES_DELETE_CONFIRMATION_DESCRIPTION_FOR_POLICY 8332
#define IDS_SETTINGS_SEARCH_ENGINES_SEARCH_ENGINES 8333
#define IDS_SETTINGS_SEARCH_ENGINES_SEARCH_ENGINES_EXPLANATION 8334
#define IDS_SETTINGS_SEARCH_ENGINES_SITE_SEARCH 8335
#define IDS_SETTINGS_SEARCH_ENGINES_SITE_SEARCH_EXPLANATION 8336
#define IDS_SETTINGS_SEARCH_ENGINES_SITE_SEARCH_EXPLANATION_STARTER_PACK 8337
#define IDS_SETTINGS_SEARCH_ENGINES_NO_SITES_ADDED 8338
#define IDS_SETTINGS_SEARCH_ENGINES_INACTIVE_SHORTCUTS 8339
#define IDS_SETTINGS_SEARCH_ENGINES_NO_OTHER_ENGINES 8340
#define IDS_SETTINGS_SEARCH_ENGINES_EXTENSION_ENGINES 8341
#define IDS_SETTINGS_SEARCH_ENGINES_EXTENSION_ENGINES_EXPLANATION 8342
#define IDS_SETTINGS_SEARCH_ENGINES_NAME 8343
#define IDS_SETTINGS_SEARCH_ENGINES_SHORTCUT 8344
#define IDS_SETTINGS_SEARCH_ENGINES_QUERY_URL 8345
#define IDS_SETTINGS_SEARCH_ENGINES_QUERY_URL_EXPLANATION 8346
#define IDS_SETTINGS_SEARCH_ENGINES_MAKE_DEFAULT 8347
#define IDS_SETTINGS_SEARCH_ENGINES_ACTIVATE 8348
#define IDS_SETTINGS_SEARCH_ENGINES_DEACTIVATE 8349
#define IDS_SETTINGS_SEARCH_ENGINES_VIEW_DETAILS 8350
#define IDS_SETTINGS_SEARCH_ENGINES_MANAGE_EXTENSION 8351
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_TITLE 8352
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_DESCRIPTION 8353
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_DESCRIPTION_STARTER_PACK 8354
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_SPACE_OR_TAB 8355
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_TAB 8356
#define IDS_SETTINGS_SEARCH_ENGINES_ADDITIONAL_SITES 8357
#define IDS_SETTINGS_SEARCH_ENGINES_ADDITIONAL_INACTIVE_SITES 8358
#define IDS_SETTINGS_SEARCH_ENGINES_MORE_ACTIONS_ARIA_LABEL 8359
#define IDS_SETTINGS_SEARCH_ENGINES_ACTIVATE_BUTTON_ARIA_LABEL 8360
#define IDS_SETTINGS_SEARCH_ENGINES_ADD_SITE_SEARCH_BUTTON_ARIA_LABEL 8361
#define IDS_SETTINGS_SEARCH_ENGINES_EDIT_SEARCH_ENGINE_BUTTON_ARIA_LABEL 8362
#define IDS_SETTINGS_EXCEPTIONS_EMBEDDED_ON_HOST 8363
#define IDS_SETTINGS_EXCEPTIONS_EMBEDDED_ON_ANY_HOST 8364
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES 8365
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_DESCRIPTION 8366
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_FILTER 8367
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SEARCH 8368
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SORT 8369
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SORT_METHOD_MOST_VISITED 8370
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SORT_METHOD_STORAGE 8371
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SORT_METHOD_NAME 8372
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_HEADER 8373
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_EDIT_HEADER 8374
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_REMOVE_GRANT_LABEL 8375
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_REMOVE_GRANTS 8376
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_VIEW_HEADER 8377
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_VIEW_SITE_DETAILS 8378
#define IDS_SETTINGS_SITE_SETTINGS_SITE_ENTRY_PARTITIONED_LABEL 8379
#define IDS_SETTINGS_SITE_SETTINGS_SITE_REPRESENTATION_SEPARATOR 8380
#define IDS_SETTINGS_SITE_SETTINGS_DEFAULT_BEHAVIOR 8381
#define IDS_SETTINGS_SITE_SETTINGS_DEFAULT_BEHAVIOR_DESCRIPTION 8382
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_DEFAULT_BEHAVIOR_DESC 8383
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_DESC 8384
#define IDS_SETTINGS_SITE_SETTINGS_CUSTOMIZED_BEHAVIORS 8385
#define IDS_SETTINGS_SITE_SETTINGS_CUSTOMIZED_BEHAVIORS_DESCRIPTION 8386
#define IDS_SETTINGS_SITE_SETTINGS_CUSTOMIZED_BEHAVIORS_DESCRIPTION_SHORT 8387
#define IDS_SETTINGS_SITE_SETTINGS_ADS_DESCRIPTION 8388
#define IDS_SETTINGS_SITE_SETTINGS_ADS_ALLOWED 8389
#define IDS_SETTINGS_SITE_SETTINGS_ADS_BLOCKED 8390
#define IDS_SETTINGS_SITE_SETTINGS_ADS_ALLOWED_EXCEPTIONS 8391
#define IDS_SETTINGS_SITE_SETTINGS_ADS_BLOCKED_EXCEPTIONS 8392
#define IDS_SETTINGS_SITE_SETTINGS_AR_DESCRIPTION 8393
#define IDS_SETTINGS_SITE_SETTINGS_AR_ALLOWED 8394
#define IDS_SETTINGS_SITE_SETTINGS_AR_BLOCKED 8395
#define IDS_SETTINGS_SITE_SETTINGS_AR_ALLOWED_EXCEPTIONS 8396
#define IDS_SETTINGS_SITE_SETTINGS_AR_BLOCKED_EXCEPTIONS 8397
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_DESCRIPTION 8398
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_ASK 8399
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_BLOCKED 8400
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_ALLOWED_EXCEPTIONS 8401
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_BLOCKED_EXCEPTIONS 8402
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_DESCRIPTION 8403
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_ALLOWED 8404
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_BLOCKED 8405
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_ALLOWED_EXCEPTIONS 8406
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_BLOCKED_EXCEPTIONS 8407
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_DESCRIPTION 8408
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_ALLOWED 8409
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_BLOCKED 8410
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_BLOCKED_SUB_LABEL 8411
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_ALLOWED_EXCEPTIONS 8412
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_BLOCKED_EXCEPTIONS 8413
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_DEVICES_DESCRIPTION 8414
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_DEVICES_ASK 8415
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_DEVICES_BLOCKED 8416
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_DESCRIPTION 8417
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_ASK 8418
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_BLOCKED 8419
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_ALLOWED_EXCEPTIONS 8420
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_BLOCKED_EXCEPTIONS 8421
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_DESCRIPTION 8422
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_ASK 8423
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_BLOCKED 8424
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_BLOCKED_SUB_LABEL 8425
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_ALLOWED_EXCEPTIONS 8426
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_BLOCKED_EXCEPTIONS 8427
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_DESCRIPTION 8428
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_ASK 8429
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_BLOCKED 8430
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_ALLOWED_EXCEPTIONS 8431
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_BLOCKED_EXCEPTIONS 8432
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_DESCRIPTION 8433
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_ASK 8434
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_BLOCKED 8435
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_ALLOWED_EXCEPTIONS 8436
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_BLOCKED_EXCEPTIONS 8437
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_DESCRIPTION 8438
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_ALLOWED 8439
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_BLOCKED 8440
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_ALLOWED_EXCEPTIONS 8441
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_BLOCKED_EXCEPTIONS 8442
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_WRITE_DESCRIPTION 8443
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_WRITE_ASK 8444
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_WRITE_BLOCKED 8445
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_WRITE_BLOCKED_EXCEPTIONS 8446
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_DESCRIPTION 8447
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_ASK 8448
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_BLOCKED 8449
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_ALLOWED_EXCEPTIONS 8450
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_BLOCKED_EXCEPTIONS 8451
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_FULLSCREEN_DESCRIPTION 8452
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_FULLSCREEN_ALLOWED_EXCEPTIONS 8453
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_FULLSCREEN_BLOCKED_EXCEPTIONS 8454
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_DESCRIPTION 8455
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_ALLOWED_EXCEPTIONS 8456
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_BLOCKED_EXCEPTIONS 8457
#define IDS_SETTINGS_SITE_SETTINGS_HID_DEVICES_DESCRIPTION 8458
#define IDS_SETTINGS_SITE_SETTINGS_HID_DEVICES_ASK 8459
#define IDS_SETTINGS_SITE_SETTINGS_HID_DEVICES_BLOCKED 8460
#define IDS_SITE_SETTINGS_SMART_CARD_READERS 8461
#define IDS_SITE_SETTINGS_SMART_CARD_READERS_DESCRIPTION 8462
#define IDS_SITE_SETTINGS_SMART_CARDS_DEFAULT_DESCRIPTION 8463
#define IDS_SITE_SETTINGS_SMART_CARDS_ASK 8464
#define IDS_SITE_SETTINGS_SMART_CARDS_BLOCKED 8465
#define IDS_SITE_SETTINGS_NO_SMART_CARD_READERS_FOUND 8466
#define IDS_SITE_SETTINGS_RESET_SMART_CARD_CONFIRMATION 8467
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_DESCRIPTION 8468
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_ALLOWED 8469
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_BLOCKED 8470
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_BLOCKED_SUB_LABEL 8471
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_ALLOWED_EXCEPTIONS 8472
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_BLOCKED_EXCEPTIONS 8473
#define IDS_SETTINGS_SITE_SETTINGS_INSECURE_CONTENT_DESCRIPTION 8474
#define IDS_SETTINGS_SITE_SETTINGS_INSECURE_CONTENT_ALLOWED_EXCEPTIONS 8475
#define IDS_SETTINGS_SITE_SETTINGS_INSECURE_CONTENT_BLOCKED_EXCEPTIONS 8476
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_DESCRIPTION 8477
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_ALLOWED 8478
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_BLOCKED 8479
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_ALLOWED_EXCEPTIONS 8480
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_BLOCKED_EXCEPTIONS 8481
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_ALLOWED 8482
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED 8483
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_UNFAMILIAR_SITES 8484
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_UNFAMILIAR_SITES_SUB_LABEL 8485
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_UNFAMILIAR_SITES_SAFE_BROWSING_OFF_SUB_LABEL 8486
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_ALLOWED_EXCEPTIONS 8487
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_EXCEPTIONS 8488
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_DESCRIPTION 8489
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_ASK 8490
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_BLOCKED 8491
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_ALLOWED_EXCEPTIONS 8492
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_BLOCKED_EXCEPTIONS 8493
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_DESCRIPTION 8494
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_ASK 8495
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_BLOCKED 8496
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_BLOCKED_SUB_LABEL 8497
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_ALLOWED_EXCEPTIONS 8498
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_BLOCKED_EXCEPTIONS 8499
#define IDS_SETTINGS_SITE_SETTINGS_MIC_DESCRIPTION 8500
#define IDS_SETTINGS_SITE_SETTINGS_MIC_ASK 8501
#define IDS_SETTINGS_SITE_SETTINGS_MIC_BLOCKED 8502
#define IDS_SETTINGS_SITE_SETTINGS_MIC_BLOCKED_SUB_LABEL 8503
#define IDS_SETTINGS_SITE_SETTINGS_MIC_ALLOWED_EXCEPTIONS 8504
#define IDS_SETTINGS_SITE_SETTINGS_MIC_BLOCKED_EXCEPTIONS 8505
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_DESCRIPTION 8506
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_ASK 8507
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_BLOCKED 8508
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_ALLOWED_EXCEPTIONS 8509
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_BLOCKED_EXCEPTIONS 8510
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_DESCRIPTION 8511
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_ALLOWED 8512
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_ASK 8513
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_BLOCKED 8514
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_BLOCKED_SUB_LABEL 8515
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_ALLOWED_EXCEPTIONS 8516
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_BLOCKED_EXCEPTIONS 8517
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_DESCRIPTION 8518
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_ALLOWED 8519
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_ASK 8520
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_BLOCKED 8521
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_BLOCKED_SUB_LABEL 8522
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_ALLOWED_EXCEPTIONS 8523
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_BLOCKED_EXCEPTIONS 8524
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_DESCRIPTION 8525
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_ALLOWED 8526
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_PARTIAL 8527
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_PARTIAL_SUB_LABEL 8528
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_ASK_STATE 8529
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSION_QUIET 8530
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSION_CPSS 8531
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSION_LOUD 8532
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSION_TITLE 8533
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_BLOCKED 8534
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_BLOCKED_SUB_LABEL 8535
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_ALLOWED_EXCEPTIONS 8536
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_BLOCKED_EXCEPTIONS 8537
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_DESCRIPTION 8538
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_ALLOWED 8539
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_BLOCKED 8540
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_ALLOWED_EXCEPTIONS 8541
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_BLOCKED_EXCEPTIONS 8542
#define IDS_SETTINGS_SITE_SETTINGS_PDFS_DESCRIPTION 8543
#define IDS_SETTINGS_SITE_SETTINGS_PDFS_ALLOWED 8544
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_DESCRIPTION 8545
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_ALLOWED 8546
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_BLOCKED 8547
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_ALLOWED_EXCEPTIONS 8548
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_BLOCKED_EXCEPTIONS 8549
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_DESCRIPTION 8550
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_ALLOWED 8551
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_BLOCKED 8552
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_ALLOWED_EXCEPTIONS 8553
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_BLOCKED_EXCEPTIONS 8554
#define IDS_SETTINGS_SITE_SETTINGS_PROTECTED_CONTENT_DESCRIPTION 8555
#define IDS_SETTINGS_SITE_SETTINGS_PROTECTED_CONTENT_ALLOWED 8556
#define IDS_SETTINGS_SITE_SETTINGS_PROTECTED_CONTENT_BLOCKED 8557
#define IDS_SETTINGS_SITE_SETTINGS_PROTECTED_CONTENT_BLOCKED_SUB_LABEL 8558
#define IDS_SETTINGS_SITE_SETTINGS_PROTOCOL_HANDLERS_DESCRIPTION 8566
#define IDS_SETTINGS_SITE_SETTINGS_PROTOCOL_HANDLERS_ALLOWED 8567
#define IDS_SETTINGS_SITE_SETTINGS_PROTOCOL_HANDLERS_BLOCKED 8568
#define IDS_SETTINGS_SITE_SETTINGS_PROTOCOL_HANDLERS_BLOCKED_EXCEPTIONS 8569
#define IDS_SETTINGS_SITE_SETTINGS_SERIAL_PORTS_DESCRIPTION 8570
#define IDS_SETTINGS_SITE_SETTINGS_SERIAL_PORTS_ASK 8571
#define IDS_SETTINGS_SITE_SETTINGS_SERIAL_PORTS_BLOCKED 8572
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_DESCRIPTION 8573
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_ALLOWED 8574
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_BLOCKED 8575
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_BLOCKED_SUB_LABEL 8576
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_ALLOWED_EXCEPTIONS 8577
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_BLOCKED_EXCEPTIONS 8578
#define IDS_SETTINGS_SITE_SETTINGS_USB_DESCRIPTION 8579
#define IDS_SETTINGS_SITE_SETTINGS_USB_ASK 8580
#define IDS_SETTINGS_SITE_SETTINGS_USB_BLOCKED 8581
#define IDS_SETTINGS_SITE_SETTINGS_VR_DESCRIPTION 8582
#define IDS_SETTINGS_SITE_SETTINGS_VR_ASK 8583
#define IDS_SETTINGS_SITE_SETTINGS_VR_BLOCKED 8584
#define IDS_SETTINGS_SITE_SETTINGS_VR_ALLOWED_EXCEPTIONS 8585
#define IDS_SETTINGS_SITE_SETTINGS_VR_BLOCKED_EXCEPTIONS 8586
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_DESCRIPTION 8587
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_ASK 8588
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_BLOCK 8589
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_ALLOWED_EXCEPTIONS 8590
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_BLOCKED_EXCEPTIONS 8591
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_DESCRIPTION 8592
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_ASK 8593
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_BLOCK 8594
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_ALLOWED_EXCEPTIONS 8595
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_BLOCKED_EXCEPTIONS 8596
#define IDS_SETTINGS_SITE_SETTINGS_ZOOM_LEVELS_DESCRIPTION 8597
#define IDS_SETTINGS_SITE_SETTINGS_AR_ASK 8598
#define IDS_SETTINGS_SITE_SETTINGS_AR_BLOCK 8599
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_ASK 8600
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_BLOCK 8601
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ACCESS_DESCRIPTION 8602
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ACCESS_ASK 8603
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ACCESS_BLOCK 8604
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ACCESS_ALLOWED_EXCEPTIONS 8605
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ACCESS_BLOCKED_EXCEPTIONS 8606
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_DESCRIPTION 8607
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ASK 8608
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_BLOCK 8609
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ALLOWED_EXCEPTIONS 8610
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_BLOCKED_EXCEPTIONS 8611
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_DESCRIPTION 8612
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_ASK 8613
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_BLOCK 8614
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_ALLOWED_EXCEPTIONS 8615
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_BLOCKED_EXCEPTIONS 8616
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_PAGE_DESCRIPTION 8617
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_PAGE_TITLE 8618
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_LINK_ROW_LABEL 8619
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_LINK_ROW_SUB_LABEL_ENABLED 8620
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_LINK_ROW_SUB_LABEL_DISABLED 8621
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_PAGE_ALLOW_RADIO_LABEL 8622
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_PAGE_BLOCK_RADIO_LABEL 8623
#define IDS_SETTINGS_COOKIES_RELATED_WEBSITE_SETS_TOGGLE_LABEL 8624
#define IDS_SETTINGS_COOKIES_RELATED_WEBSITE_SETS_TOGGLE_SUB_LABEL 8625
#define IDS_SETTINGS_COOKIES_ALL_SITES_LINK 8626
#define IDS_SETTINGS_TRACKING_PROTECTION_ADVANCED_LABEL 8627
#define IDS_SETTINGS_TRACKING_PROTECTION_DO_NOT_TRACK_TOGGLE_SUB_LABEL 8628
#define IDS_SETTINGS_TRACKING_PROTECTION_SITES_ALLOWED_COOKIES_TITLE 8629
#define IDS_SETTINGS_TRACKING_PROTECTION_SITES_ALLOWED_COOKIES_DESCRIPTION 8630
#define IDS_SETTINGS_SITE_SETTINGS_APP_PROTOCOL_HANDLERS 8631
#define IDS_SETTINGS_SITE_SETTINGS_APP_ALLOWED_PROTOCOL_HANDLERS_DESCRIPTION 8632
#define IDS_SETTINGS_SITE_SETTINGS_APP_DISALLOWED_PROTOCOL_HANDLERS_DESCRIPTION 8633
#define IDS_SETTINGS_SITE_SETTINGS_INSECURE_CONTENT_BLOCK 8634
#define IDS_SETTINGS_SITE_SETTINGS_PDF_DOWNLOAD_PDFS 8635
#define IDS_SETTINGS_SITE_SETTINGS_RECENT_ACTIVITY 8636
#define IDS_SETTINGS_SITE_SETTINGS_SERIAL_PORTS_ASK_RECOMMENDED 8637
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_ZOOM_LEVEL 8638
#define IDS_SETTINGS_SITE_SETTINGS_ASK_BEFORE_SENDING 8639
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATICALLY_BLOCKED_NOTIFICATIONS 8640
#define IDS_SETTINGS_SITE_SETTINGS_SHOW_BLOCKED_NOTIFICATIONS_INDICATOR 8641
#define IDS_SETTINGS_SITE_SETTINGS_HANDLERS_ASK_RECOMMENDED 8642
#define IDS_SETTINGS_SITE_SETTINGS_HANDLERS_BLOCKED 8643
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_DESCRIPTION 8644
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_ASK 8645
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_BLOCKED 8646
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_ASK_EXCEPTIONS 8647
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_BLOCKED_EXCEPTIONS 8648
#define IDS_SETTINGS_SITE_SETTINGS_BLOCKED 8649
#define IDS_SETTINGS_SITE_SETTINGS_ALLOW 8650
#define IDS_SETTINGS_SITE_SETTINGS_BLOCK 8651
#define IDS_SETTINGS_SITE_SETTINGS_SESSION_ONLY 8652
#define IDS_SETTINGS_SITE_SETTINGS_ASK_DEFAULT_MENU 8653
#define IDS_SETTINGS_SITE_SETTINGS_ALLOW_DEFAULT_MENU 8654
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DEFAULT_MENU 8655
#define IDS_SETTINGS_SITE_SETTINGS_BLOCK_DEFAULT_MENU 8656
#define IDS_SETTINGS_SITE_SETTINGS_ACTION_BLOCK_ON_UNFAMILIAR_SITES_DEFAULT_MENU 8657
#define IDS_SETTINGS_SITE_SETTINGS_MUTE_DEFAULT_MENU 8658
#define IDS_SETTINGS_SITE_SETTINGS_ALLOW_MENU 8659
#define IDS_SETTINGS_SITE_SETTINGS_BLOCK_MENU 8660
#define IDS_SETTINGS_SITE_SETTINGS_ASK_MENU 8661
#define IDS_SETTINGS_SITE_SETTINGS_MUTE_MENU 8662
#define IDS_SETTINGS_SITE_SETTINGS_RESET_MENU 8663
#define IDS_SETTINGS_SITE_SETTINGS_RESET_FROM_LIST_A11Y 8664
#define IDS_SETTINGS_SITE_SETTINGS_VIEW_FROM_LIST_A11Y 8665
#define IDS_SETTINGS_SITE_SETTINGS_SESSION_ONLY_MENU 8666
#define IDS_SETTINGS_SITE_SETTINGS_USAGE 8667
#define IDS_SETTINGS_SITE_SETTINGS_USAGE_NONE 8668
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSIONS 8669
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSIONS_MORE 8670
#define IDS_SETTINGS_SITE_SETTINGS_CONTENT 8671
#define IDS_SETTINGS_SITE_SETTINGS_CONTENT_MORE 8672
#define IDS_SETTINGS_SITE_SETTINGS_ALLOWLISTED 8673
#define IDS_SETTINGS_SITE_SETTINGS_ADS_BLOCK_BLOCKLISTED_SINGULAR 8674
#define IDS_SETTINGS_SITE_SETTINGS_ADS_BLOCK_NOT_BLOCKLISTED_SINGULAR 8675
#define IDS_SETTINGS_SITE_SETTINGS_SOURCE_KILL_SWITCH 8676
#define IDS_SETTINGS_SITE_SETTINGS_SOURCE_INSECURE_ORIGIN 8677
#define IDS_SETTINGS_SITE_SETTINGS_RESET_BUTTON 8678
#define IDS_SETTINGS_SITE_SETTINGS_DELETE 8679
#define IDS_SETTINGS_SITE_SETTINGS_THIRD_PARTY_COOKIES_EXCEPTION_LABEL 8680
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_ALL_STORAGE_DIALOG_TITLE 8681
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_DISPLAYED_STORAGE_DIALOG_TITLE 8682
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_LEARN_MORE 8683
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_LEARN_MORE_ACCESSIBILITY 8684
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_ALL_STORAGE_DESCRIPTION 8685
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_DISPLAYED_STORAGE_DESCRIPTION 8686
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_ALL_STORAGE_LABEL 8687
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_DISPLAYED_STORAGE_LABEL 8688
#define IDS_SETTINGS_SITE_SETTINGS_SITE_DETAILS_SUBPAGE_ACCESSIBILITY_LABEL 8689
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_MEMBERSHIP_LABEL 8690
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_MORE_ACTIONS_TITLE 8691
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_SHOW_RELATED_SITES_BUTTON 8692
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_SITE_DELETE_STORAGE_BUTTON 8693
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_ALL_STORAGE_CONFIRMATION 8694
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_DISPLAYED_STORAGE_CONFIRMATION 8695
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_RWS_STORAGE_CONFIRMATION 8696
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_ALL_STORAGE_CONFIRMATION_INSTALLED 8697
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_DISPLAYED_STORAGE_CONFIRMATION_INSTALLED 8698
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_RWS_STORAGE_CONFIRMATION_INSTALLED 8699
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_ALL_STORAGE_SIGN_OUT 8700
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_DISPLAYED_STORAGE_SIGN_OUT 8701
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_RWS_STORAGE_SIGN_OUT 8702
#define IDS_SETTINGS_SITE_SETTINGS_SITE_RESET_DIALOG_TITLE 8703
#define IDS_SETTINGS_SITE_SETTINGS_SITE_RESET_CONFIRMATION 8704
#define IDS_SETTINGS_SITE_SETTINGS_SITE_DELETE_STORAGE_DIALOG_TITLE 8705
#define IDS_SETTINGS_SITE_SETTINGS_SITE_CLEAR_STORAGE_CONFIRMATION 8706
#define IDS_SETTINGS_SITE_SETTINGS_SITE_CLEAR_STORAGE_CONFIRMATION_NEW 8707
#define IDS_SETTINGS_SITE_SETTINGS_SITE_CLEAR_STORAGE_SIGN_OUT 8708
#define IDS_SETTINGS_SITE_SETTINGS_SITE_DELETE_STORAGE_OFFLINE_DATA 8709
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_AD_PERSONALIZATION 8710
#define IDS_SETTINGS_SITE_SETTINGS_SITE_GROUP_DELETE_OFFLINE_DATA 8711
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_ORIGIN_DIALOG_TITLE 8712
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_ORIGIN_APP_DIALOG_TITLE 8713
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_ORIGIN_PARTITIONED_DIALOG_TITLE 8714
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_GROUP_DIALOG_TITLE 8715
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_GROUP_APP_DIALOG_TITLE 8716
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_GROUP_APP_PLURAL_DIALOG_TITLE 8717
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_ORIGIN_LOGOUT 8718
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_GROUP_LOGOUT 8719
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_OFFLINE_DATA 8720
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_PERMISSIONS 8721
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_CONFIRM 8722
#define IDS_SETTINGS_SITE_SETTINGS_COOKIE_REMOVE_SITE 8723
#define IDS_SETTINGS_SITE_SETTINGS_SITE_RESET_ALL 8724
#define IDS_SETTINGS_SITE_SETTINGS_SITE_CLEAR_STORAGE 8725
#define IDS_SETTINGS_SITE_SETTINGS_HANDLER_IS_DEFAULT 8726
#define IDS_SETTINGS_SITE_SETTINGS_HANDLER_SET_DEFAULT 8727
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE 8728
#define IDS_SETTINGS_SITE_SETTINGS_INCOGNITO_ONLY 8729
#define IDS_SETTINGS_SITE_SETTINGS_INCOGNITO_SITE_EXCEPTION_DESC 8730
#define IDS_SETTINGS_SITE_SETTINGS_NO_ZOOMED_SITES 8731
#define IDS_SETTINGS_SITE_NO_SITES_ADDED 8732
#define IDS_SETTINGS_SITE_SETTINGS_BLOCK_AUTOPLAY 8733
#define IDS_SETTINGS_SITE_SETTINGS_EMPTY_ALL_SITES_PAGE 8734
#define IDS_SETTINGS_SITE_SETTINGS_NO_SITES_FOUND 8735
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_DESCRIPTION 8736
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_ASK 8737
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_BLOCK 8738
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_ALLOWED_EXCEPTIONS 8739
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_BLOCKED_EXCEPTIONS 8740
#define IDS_SETTINGS_SITE_SETTINGS_EXTENSION_ID_DESCRIPTION 8741
#define IDS_SETTINGS_SITE_SETTINGS_PAGE_SITE_DATA_ALLOWED_SUB_LABEL 8742
#define IDS_SETTINGS_SITE_SETTINGS_PAGE_SITE_DATA_BLOCKED_SUB_LABEL 8743
#define IDS_SETTINGS_SITE_SETTINGS_PAGE_SITE_DATA_DELETE_ON_EXIT_SUB_LABEL 8744
#define IDS_SETTINGS_EXPIRES_AFTER_TIME_LABEL 8745
#define IDS_SETTINGS_SITE_DATA_PAGE_TITLE 8746
#define IDS_SETTINGS_SITE_DATA_PAGE_DESCRIPTION 8747
#define IDS_SETTINGS_SITE_DATA_PAGE_DEFAULT_BEHAVIOR_HEADING 8748
#define IDS_SETTINGS_SITE_DATA_PAGE_DEFAULT_BEHAVIOR_DESCRIPTION 8749
#define IDS_SETTINGS_SITE_DATA_PAGE_ALLOW_RADIO_LABEL 8750
#define IDS_SETTINGS_SITE_DATA_PAGE_ALLOW_RADIO_SUB_LABEL 8751
#define IDS_SETTINGS_SITE_DATA_PAGE_CLEAR_ON_EXIT_RADIO_LABEL 8752
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_RADIO_LABEL 8753
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_RADIO_SUB_LABEL 8754
#define IDS_SETTINGS_SITE_DATA_PAGE_CUSTOMIZED_BEHAVIOR_HEADING 8755
#define IDS_SETTINGS_SITE_DATA_PAGE_CUSTOMIZED_BEHAVIOR_DESCRIPTION 8756
#define IDS_SETTINGS_SITE_DATA_PAGE_ALLOW_EXCEPTIONS_SUB_HEADING 8757
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_EXCEPTIONS_SUB_HEADING 8758
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_CONFIRM_DIALOG_TITLE 8759
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_CONFIRM_DIALOG_DESCRIPTION 8760
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_CONFIRM_DIALOG_CONFIRM_BUTTON 8761
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_CONFIRM_DIALOG_CANCEL_BUTTON 8762
#define IDS_SETTINGS_ADD_SITE_TO_ALLOW_LIST_LABEL 8763
#define IDS_SETTINGS_ADD_SITE_TO_BLOCK_LIST_LABEL 8764
#define IDS_SETTINGS_ADD_SITE_CONTEXT_MENU_LABEL 8765
#define IDS_SETTINGS_STORAGE_ACCESS_DESCRIPTION 8766
#define IDS_SETTINGS_STORAGE_ACCESS_ASK 8767
#define IDS_SETTINGS_STORAGE_ACCESS_BLOCKED 8768
#define IDS_SETTINGS_STORAGE_ACCESS_ALLOWED_EXCEPTIONS 8769
#define IDS_SETTINGS_STORAGE_ACCESS_BLOCKED_EXCEPTIONS 8770
#define IDS_SETTINGS_STORAGE_ACCESS_RESET_ALL 8771
#define IDS_SETTINGS_STORAGE_ACCESS_RESET_SITE 8772
#define IDS_SETTINGS_STORAGE_ACCESS_OPEN_EXPAND 8773
#define IDS_SETTINGS_STORAGE_ACCESS_CLOSE_EXPAND 8774
#define IDS_SETTINGS_STORAGE_ACCESS_ALLOWED_SITE_LABEL 8775
#define IDS_SETTINGS_STORAGE_ACCESS_BLOCKED_SITE_LABEL 8776
#define IDS_SETTINGS_NO_BLUETOOTH_DEVICES_FOUND 8777
#define IDS_SETTINGS_NO_USB_DEVICES_FOUND 8778
#define IDS_SETTINGS_NO_SERIAL_PORTS_FOUND 8779
#define IDS_SETTINGS_NO_HID_DEVICES_FOUND 8780
#define IDS_SETTINGS_RESET_BLUETOOTH_CONFIRMATION 8781
#define IDS_SETTINGS_RESET_HID_CONFIRMATION 8782
#define IDS_SETTINGS_RESET_SERIAL_PORTS_CONFIRMATION 8783
#define IDS_SETTINGS_RESET_USB_CONFIRMATION 8784
#define IDS_SETTINGS_ADD_SITE_TITLE 8785
#define IDS_SETTINGS_ADD_SITES_TITLE 8786
#define IDS_SETTINGS_EDIT_SITE_TITLE 8787
#define IDS_SETTINGS_ADD_SITE 8788
#define IDS_SETTINGS_SITE_SETTINGS_NUM_COOKIES 8789
#define IDS_SETTINGS_PEOPLE 8790
#define IDS_SETTINGS_CHANGE_PICTURE_PROFILE_PHOTO 8791
#define IDS_SETTINGS_PEOPLE_SIGN_IN 8792
#define IDS_SETTINGS_PEOPLE_VERIFY_ACCOUNT_BUTTON 8793
#define IDS_SETTINGS_TURN_OFF_SYNC_MANAGED_PROFILE_EXPLANATION 8794
#define IDS_SETTINGS_TURN_OFF_SYNC_AND_SIGN_OUT_DIALOG_TITLE 8795
#define IDS_SETTINGS_TURN_OFF_SYNC_AND_SIGN_OUT_DIALOG_TITLE_SUPERVISED_PROFILE 8796
#define IDS_SETTINGS_TURN_OFF_SYNC_DIALOG_MANAGED_CONFIRM 8797
#define IDS_SETTINGS_TURN_OFF_SYNC_DIALOG_CHECKBOX 8798
#define IDS_SETTINGS_SYNC_SETTINGS_SAVED_TOAST_LABEL 8799
#define IDS_SETTINGS_CHROME_SIGNIN_OPTION_SAVED_TOAST_LABEL 8800
#define IDS_SETTINGS_PROFILE_NAME_INPUT_LABEL 8801
#define IDS_SETTINGS_PROFILE_SHORTCUT_TOGGLE_LABEL 8802
#define IDS_SETTINGS_CUSTOMIZE_PROFILE 8803
#define IDS_SETTINGS_PICK_A_THEME_COLOR 8804
#define IDS_SETTINGS_PICK_AN_AVATAR 8805
#define IDS_SETTINGS_CREATE_SHORTCUT 8806
#define IDS_SETTINGS_CREATE_SHORTCUT_SUBTITLE 8807
#define IDS_SETTINGS_ACCOUNT_PAGE_TITLE 8808
#define IDS_SETTINGS_ACCOUNT_DATATYPES_HEADING 8809
#define IDS_SETTINGS_ACCOUNT_BODY 8810
#define IDS_SETTINGS_ACCOUNT_SYNC_DISABLED 8811
#define IDS_SETTINGS_ACCOUNT_HISTORY_TOGGLE 8812
#define IDS_SETTINGS_ACCOUNT_HISTORY_TOGGLE_SUB_LABEL_OFF 8813
#define IDS_SETTINGS_GOOGLE_SERVICES_PAGE_TITLE 8814
#define IDS_SETTINGS_SYNC_DISCONNECT_EXPLANATION 8815
#define IDS_SETTINGS_SYNC_DISCONNECT_AND_SIGN_OUT_EXPLANATION 8816
#define IDS_SETTINGS_SYNC_DISCONNECT_AND_SIGN_OUT_EXPLANATION_SUPERVISED_PROFILE 8817
#define IDS_SETTINGS_SYNC_DISCONNECT_EXPAND_ACCESSIBILITY_LABEL 8818
#define IDS_SETTINGS_SYNC_WILL_START 8819
#define IDS_SETTINGS_USER_EVENTS_CHECKBOX_LABEL 8820
#define IDS_SETTINGS_USER_EVENTS_CHECKBOX_TEXT 8821
#define IDS_SETTINGS_ENCRYPT_WITH_SYNC_PASSPHRASE_LABEL 8822
#define IDS_SETTINGS_PASSPHRASE_EXPLANATION_TEXT 8823
#define IDS_SETTINGS_PASSPHRASE_RESET_HINT_ENCRYPTION 8824
#define IDS_SETTINGS_PASSPHRASE_RESET_HINT_TOGGLE 8825
#define IDS_SETTINGS_PASSPHRASE_RECOVER 8826
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_TITLE 8827
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_TITLE_V2 8828
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_WAA_TITLE 8829
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_LINKED_SERVICES_TITLE 8830
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTION_PLACEHOLDER 8831
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTION_SIGNIN 8832
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTION_DO_NOT_SIGNIN 8833
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTION_ALWAYS_ASK 8834
#define IDS_SETTINGS_GOOGLE_ACCOUNT 8835
#define IDS_SETTINGS_MANAGE_GOOGLE_ACCOUNT 8836
#define IDS_SETTINGS_IMPORT_SETTINGS_TITLE 8837
#define IDS_SETTINGS_IMPORT_FROM_LABEL 8838
#define IDS_SETTINGS_IMPORT_ITEMS_LABEL 8839
#define IDS_SETTINGS_IMPORT_LOADING_PROFILES 8840
#define IDS_SETTINGS_IMPORT_HISTORY_CHECKBOX 8841
#define IDS_SETTINGS_IMPORT_FAVORITES_CHECKBOX 8842
#define IDS_SETTINGS_IMPORT_PASSWORDS_CHECKBOX 8843
#define IDS_SETTINGS_IMPORT_SEARCH_ENGINES_CHECKBOX 8844
#define IDS_SETTINGS_IMPORT_AUTOFILL_FORM_DATA_CHECKBOX 8845
#define IDS_SETTINGS_IMPORT_CHOOSE_FILE 8846
#define IDS_SETTINGS_IMPORT_COMMIT 8847
#define IDS_SETTINGS_IMPORT_SUCCESS 8848
#define IDS_SETTINGS_IMPORT_NO_PROFILE_FOUND 8849
#define IDS_SETTINGS_HISTORY_SEARCH_SETTING_LABEL 8850
#define IDS_SETTINGS_HISTORY_SEARCH_SETTING_SUBLABEL_V2 8851
#define IDS_SETTINGS_HISTORY_SEARCH_LEARN_MORE_A11Y_LABEL 8852
#define IDS_SETTINGS_HISTORY_SEARCH_WHEN_ON_PAGE_CONTENT 8853
#define IDS_SETTINGS_HISTORY_SEARCH_WHEN_ON_SEARCH_FROM 8854
#define IDS_SETTINGS_HISTORY_SEARCH_WHEN_ON_LOG_START 8855
#define IDS_SETTINGS_HISTORY_SEARCH_CONSIDER_DATA 8856
#define IDS_SETTINGS_HISTORY_SEARCH_CONSIDER_DATA_ENCRYPTED 8857
#define IDS_SETTINGS_HISTORY_SEARCH_SUBLABEL_ON 8858
#define IDS_SETTINGS_HISTORY_SEARCH_SUBLABEL_OFF 8859
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_SETTING_SUBLABEL_V2 8860
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_WHEN_ON_PAGE_CONTENT 8861
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_WHEN_ON_RECALL_INFO 8862
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_CONSIDER_DATA_ENCRYPTED 8863
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_CONSIDER_OUTDATED 8864
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_SUBLABEL_ON 8865
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_SUBLABEL_OFF 8866
#define IDS_SETTINGS_PAGE_ZOOM_LABEL 8867
#define IDS_SETTINGS_FONT_SIZE_LABEL 8868
#define IDS_SETTINGS_VERY_SMALL_FONT 8869
#define IDS_SETTINGS_SMALL_FONT 8870
#define IDS_SETTINGS_MEDIUM_FONT 8871
#define IDS_SETTINGS_LARGE_FONT 8872
#define IDS_SETTINGS_VERY_LARGE_FONT 8873
#define IDS_SETTINGS_CUSTOMIZE_FONTS 8874
#define IDS_SETTINGS_FONTS 8875
#define IDS_SETTINGS_STANDARD_FONT_LABEL 8876
#define IDS_SETTINGS_SERIF_FONT_LABEL 8877
#define IDS_SETTINGS_SANS_SERIF_FONT_LABEL 8878
#define IDS_SETTINGS_FIXED_WIDTH_FONT_LABEL 8879
#define IDS_SETTINGS_MATH_FONT_LABEL 8880
#define IDS_SETTINGS_MINIMUM_FONT_SIZE_LABEL 8881
#define IDS_SETTINGS_TINY_FONT_SIZE 8882
#define IDS_SETTINGS_HUGE_FONT_SIZE 8883
#define IDS_SETTINGS_QUICK_BROWN_FOX 8884
#define IDS_SETTINGS_SYSTEM 8885
#define IDS_SETTINGS_SYSTEM_HARDWARE_ACCELERATION_LABEL 8886
#define IDS_SETTINGS_SYSTEM_FEATURE_NOTIFICATIONS_LABEL 8887
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_LABEL 8888
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_EXTENSION_LABEL 8889
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_POLICY_LABEL 8890
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_YOUR_ORGANIZATION_LABEL 8891
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_YOUR_DEVICE_LABEL 8892
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_MULTIPLE_SOURCES_LABEL 8893
#define IDS_PAGE_NOT_AVAILABLE_FOR_GUEST_HEADING 8896
#define IDS_SETTINGS_SECURITY_KEYS_TITLE 8897
#define IDS_SETTINGS_SECURITY_KEYS_DESC 8898
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN 8899
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_BUTTON 8900
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_DESC 8901
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_INITIAL_TITLE 8902
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_CREATE_TITLE 8903
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_CHANGE_TITLE 8904
#define IDS_SETTINGS_SECURITY_KEYS_RESET 8905
#define IDS_SETTINGS_SECURITY_KEYS_RESET_DESC 8906
#define IDS_SETTINGS_SECURITY_KEYS_RESET_TITLE 8907
#define IDS_SETTINGS_SECURITY_KEYS_RESET_CONFIRM_TITLE 8908
#define IDS_SETTINGS_SECURITY_KEYS_RESET_STEP1 8909
#define IDS_SETTINGS_SECURITY_KEYS_RESET_STEP2 8910
#define IDS_SETTINGS_SECURITY_KEYS_NO_RESET 8911
#define IDS_SETTINGS_SECURITY_KEYS_RESET_ERROR 8912
#define IDS_SETTINGS_SECURITY_KEYS_RESET_SUCCESS 8913
#define IDS_SETTINGS_SECURITY_KEYS_RESET_NOTALLOWED 8914
#define IDS_SETTINGS_SECURITY_KEYS_NO_PIN 8915
#define IDS_SETTINGS_SECURITY_KEYS_CURRENT_PIN_INTRO 8916
#define IDS_SETTINGS_SECURITY_KEYS_PIN_INCORRECT 8917
#define IDS_SETTINGS_SECURITY_KEYS_PIN_INCORRECT_RETRIES_SIN 8918
#define IDS_SETTINGS_SECURITY_KEYS_PIN_INCORRECT_RETRIES_PL 8919
#define IDS_SETTINGS_SECURITY_KEYS_SAME_PIN_AS_CURRENT 8920
#define IDS_SETTINGS_SECURITY_KEYS_NEW_PIN 8921
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_CONFIRM 8922
#define IDS_SETTINGS_SECURITY_KEYS_CURRENT_PIN 8923
#define IDS_SETTINGS_SECURITY_KEYS_PIN 8924
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR_TOO_SHORT_SMALL 8925
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR_TOO_LONG 8926
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR_INVALID 8927
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR_MISMATCH 8928
#define IDS_SETTINGS_SECURITY_KEYS_CONFIRM_PIN 8929
#define IDS_SETTINGS_SECURITY_KEYS_PIN_SUCCESS 8930
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR 8931
#define IDS_SETTINGS_SECURITY_KEYS_PIN_HARD_LOCK 8932
#define IDS_SETTINGS_SECURITY_KEYS_PIN_SOFT_LOCK 8933
#define IDS_SETTINGS_SECURITY_KEYS_SHOW_PINS 8934
#define IDS_SETTINGS_SECURITY_KEYS_HIDE_PINS 8935
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_LABEL 8936
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_USERNAME_LABEL 8937
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_DISPLAYNAME_LABEL 8938
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_WEBSITE_LABEL 8939
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_DESC 8940
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_DIALOG_TITLE 8941
#define IDS_SETTINGS_SECURITY_KEYS_UPDATE_CREDENTIAL_DIALOG_TITLE 8942
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_CONFIRM_DELETE_TITLE 8943
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_CONFIRM_DELETE_CREDENTIAL 8944
#define IDS_SETTINGS_SECURITY_KEYS_INPUT_ERROR_TOO_LONG 8945
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_NO_CREDENTIALS 8946
#define IDS_SETTINGS_SECURITY_KEYS_NO_CREDENTIAL_MANAGEMENT 8947
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_REMOVED 8948
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_NO_PIN 8949
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_ERROR 8950
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_DELETE_SUCCESS 8951
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_DELETE_FAILED 8952
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_UPDATE_SUCCESS 8953
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_UPDATE_FAILED 8954
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_SUBPAGE_LABEL 8955
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_SUBPAGE_DESCRIPTION 8956
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_DIALOG_TITLE 8957
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_ADD_TITLE 8958
#define IDS_SETTINGS_SECURITY_KEYS_BIO_CHOOSE_NAME 8959
#define IDS_SETTINGS_SECURITY_KEYS_BIO_NAME_LABEL 8960
#define IDS_SETTINGS_SECURITY_KEYS_BIO_NAME_LABEL_TOO_LONG 8961
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_NO_ENROLLMENTS_LABEL 8962
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_ENROLLMENTS_LABEL 8963
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_ENROLLING_LABEL 8964
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_TRY_AGAIN_LABEL 8965
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_FAILED_LABEL 8966
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_ENROLLING_COMPLETE_LABEL 8967
#define IDS_SETTINGS_SECURITY_KEYS_NO_BIOMETRIC_ENROLLMENT 8968
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_DELETE 8969
#define IDS_SETTINGS_SECURITY_KEYS_BIO_NO_PIN 8970
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_STORAGE_FULL 8971
#define IDS_SETTINGS_SECURITY_KEYS_TOUCH_TO_CONTINUE 8972
#define IDS_SETTINGS_SECURITY_KEYS_PIN_PROMPT 8973
#define IDS_SETTINGS_SECURITY_KEYS_FORCE_PIN_CHANGE 8974
#define IDS_SETTINGS_EXTENSION_OR_APP_DISPLAY_NAME 8975
#define IDS_SETTINGS_SAFETY_HUB 8976
#define IDS_SETTINGS_SAFETY_HUB_ENTRY_POINT_BUTTON_LABEL 8977
#define IDS_SETTINGS_SAFETY_HUB_PAGE_CARD_SECTION_HEADER 8978
#define IDS_SETTINGS_SAFETY_HUB_PAGE_MODULE_SECTION_HEADER 8979
#define IDS_SETTINGS_SAFETY_HUB_EMPTY_STATE_MODULE_HEADER 8980
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_RECENTLY 8981
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_SOME_TIME_AGO 8982
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_HEADER_NO_WEAK_OR_REUSED 8983
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_SIGN_IN 8984
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_GO_TO_PASSWORD_MANAGER 8985
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_HEADER_NO_PASSWORDS 8986
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_NO_PASSWORDS_POLICY 8987
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_NAVIGATION_ARIA_LABEL 8988
#define IDS_SETTINGS_SAFETY_HUB_SB_ON_ENHANCED_HEADER 8989
#define IDS_SETTINGS_SAFETY_HUB_SB_ON_ENHANCED_SUBHEADER 8990
#define IDS_SETTINGS_SAFETY_HUB_SB_ON_STANDARD_HEADER 8991
#define IDS_SETTINGS_SAFETY_HUB_SB_ON_STANDARD_SUBHEADER 8992
#define IDS_SETTINGS_SAFETY_HUB_SB_OFF_HEADER 8993
#define IDS_SETTINGS_SAFETY_HUB_SB_OFF_MANAGED_SUBHEADER 8994
#define IDS_SETTINGS_SAFETY_HUB_SB_OFF_EXTENSION_SUBHEADER 8995
#define IDS_SETTINGS_SAFETY_HUB_SB_OFF_USER_SUBHEADER 8996
#define IDS_SETTINGS_SAFETY_HUB_SB_NAVIGATION_ARIA_LABEL 8997
#define IDS_SETTINGS_SAFETY_HUB_GO_SITE_SETTINGS_ITEM 8998
#define IDS_SETTINGS_SAFETY_HUB_GO_NOTIFICATION_SETTINGS_ITEM 8999
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_INCOGNITO_SUBHEADER 9000
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_SAFE_BROWSING_HEADER 9001
#define IDS_SETTINGS_SAFETY_HUB_VERSION_CARD_SUBHEADER_RESTART 9002
#define IDS_SETTINGS_SAFETY_HUB_NOTIFICATION_PERMISSIONS_PRIMARY_LABEL 9003
#define IDS_SETTINGS_SAFETY_HUB_NOTIFICATION_PERMISSIONS_SECONDARY_LABEL 9004
#define IDS_SETTINGS_SAFETY_HUB_REVOKED_PERMISSIONS_MENU_NOTIFICATION 9005
#define IDS_SETTINGS_SAFETY_HUB_REVIEW_NOTIFICATION_PERMISSIONS_MENU_NOTIFICATION 9006
#define IDS_SETTINGS_SAFETY_HUB_COMPROMISED_PASSWORDS_MENU_NOTIFICATION 9007
#define IDS_SETTINGS_SAFETY_HUB_EXTENSIONS_MENU_NOTIFICATION 9008
#define IDS_SETTINGS_SAFETY_HUB_SAFE_BROWSING_MENU_NOTIFICATION 9009
#define IDS_SETTINGS_SAFETY_HUB_PASSWORDS_MODULE_NAME 9010
#define IDS_SETTINGS_SAFETY_HUB_SAFE_BROWSING_MODULE_NAME 9011
#define IDS_SETTINGS_SAFETY_HUB_EXTENSIONS_MODULE_UPPERCASE_NAME 9012
#define IDS_SETTINGS_SAFETY_HUB_EXTENSIONS_MODULE_LOWERCASE_NAME 9013
#define IDS_SETTINGS_SAFETY_HUB_NOTIFICATIONS_MODULE_UPPERCASE_NAME 9014
#define IDS_SETTINGS_SAFETY_HUB_NOTIFICATIONS_MODULE_LOWERCASE_NAME 9015
#define IDS_SETTINGS_SAFETY_HUB_PERMISSIONS_MODULE_UPPERCASE_NAME 9016
#define IDS_SETTINGS_SAFETY_HUB_PERMISSIONS_MODULE_LOWERCASE_NAME 9017
#define IDS_SETTINGS_SAFETY_HUB_MODULE_NAME_SEPARATOR 9018
#define IDS_SETTINGS_AI_INNOVATIONS_PAGE_TITLE 9019
#define IDS_SETTINGS_AI_PAGE_MAIN_TITLE 9020
#define IDS_SETTINGS_AI_PAGE_MAIN_SUBLABEL_1 9021
#define IDS_SETTINGS_AI_PAGE_MAIN_SUBLABEL_2 9022
#define IDS_SETTINGS_AI_PAGE_MAIN_SUBLABEL_3 9023
#define IDS_SETTINGS_AI_PAGE_MAIN_MANAGED_SUBLABEL_3 9024
#define IDS_SETTINGS_AI_PAGE_MAIN_MANAGED_LEARN_MORE_ACCESSIBILITY_LABEL 9025
#define IDS_SETTINGS_AI_SUBPAGE_SUBLABEL_AI 9026
#define IDS_SETTINGS_AI_SUBPAGE_SUBLABEL_REVIEWERS 9027
#define IDS_SETTINGS_AI_SUBPAGE_SUBLABEL_LOGGING_MANAGED_DISABLED 9028
#define IDS_SETTINGS_AI_SUBPAGE_FEATURE_MANAGED_DISABLED_LABEL 9029
#define IDS_SETTINGS_EXPERIMENTAL_ADVANCED_FEATURE2_LABEL 9030
#define IDS_SETTINGS_TAB_ORGANIZER_SUB_LABEL 9031
#define IDS_SETTINGS_AUTOTABS_SETTING_LINK_A11Y 9032
#define IDS_SETTINGS_TAB_ORGANIZER_WHEN_ON_AUTO_GROUPS 9033
#define IDS_SETTINGS_TAB_ORGANIZER_WHEN_ON_IMPROVE_FOCUS 9034
#define IDS_SETTINGS_TAB_ORGANIZER_CONSIDER_DATA 9035
#define IDS_SETTINGS_COMPARE_SETTING_SUBLABEL 9036
#define IDS_SETTINGS_COMPARE_SETTING_LINK_A11Y 9037
#define IDS_SETTINGS_COMPARE_WHEN_ON_PRODUCT_DETAILS 9038
#define IDS_SETTINGS_COMPARE_WHEN_ON_PRODUCT_SUGGEST 9039
#define IDS_SETTINGS_COMPARE_WHEN_ON_PRODUCT_FILTER 9040
#define IDS_SETTINGS_COMPARE_WHEN_ON_PRODUCT_REVIEWS 9041
#define IDS_SETTINGS_COMPARE_CONSIDER_DATA 9042
#define IDS_SETTINGS_COMPARE_CONSIDER_TABLES_IN_ACCOUNT 9043
#define IDS_SETTINGS_PASSWORD_CHANGE_LABEL 9044
#define IDS_SETTINGS_PASSWORD_CHANGE_SUBLABEL 9045
#define IDS_SETTINGS_PASSWORD_CHANGE_DATA_BREACH 9046
#define IDS_SETTINGS_PASSWORD_CHANGE_WHERE_SAVED 9047
#define IDS_SETTINGS_PASSWORD_CHANGE_EXPERIMENTAL 9048
#define IDS_SETTINGS_PASSWORD_CHANGE_CONTENT 9049
#define IDS_SETTINGS_PASSWORD_CHANGE_ENCRYPTION 9050
#define IDS_SETTINGS_SAFEBROWSING_TURN_ON_ENHANCED_TOAST_BUTTON 9051
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_ON_TOAST_MESSAGE 9052
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_OFF_TOAST_MESSAGE 9053
#define IDS_SYNC_ERROR_BOOKMARKS_LIMIT_EXCEEDED_DESCRIPTION 9054
#define IDS_SETTINGS_SUBPAGE_BACK_BUTTON_ARIA_LABEL 9055
#define IDS_SETTINGS_SUBPAGE_BACK_BUTTON_ARIA_ROLE_DESCRIPTION 9056
#define IDS_SETTINGS_SUBPAGE_LEARN_MORE_ARIA_LABEL 9057
#define IDS_SETTINGS_CAPTIONS 9058
#define IDS_SETTINGS_CAPTIONS_PREFERENCES_TITLE 9059
#define IDS_SETTINGS_CAPTIONS_PREFERENCES_SUBTITLE 9060
#define IDS_SETTINGS_CAPTIONS_TEXT_SIZE 9061
#define IDS_SETTINGS_CAPTIONS_TEXT_FONT 9062
#define IDS_SETTINGS_CAPTIONS_TEXT_COLOR 9063
#define IDS_SETTINGS_CAPTIONS_TEXT_OPACITY 9064
#define IDS_SETTINGS_CAPTIONS_BACKGROUND_OPACITY 9065
#define IDS_SETTINGS_CAPTIONS_OPACITY_OPAQUE 9066
#define IDS_SETTINGS_CAPTIONS_OPACITY_SEMI_TRANSPARENT 9067
#define IDS_SETTINGS_CAPTIONS_OPACITY_TRANSPARENT 9068
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW 9069
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_NONE 9070
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_RAISED 9071
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_DEPRESSED 9072
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_UNIFORM 9073
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_DROP_SHADOW 9074
#define IDS_SETTINGS_CAPTIONS_BACKGROUND_COLOR 9075
#define IDS_SETTINGS_CAPTIONS_COLOR_BLACK 9076
#define IDS_SETTINGS_CAPTIONS_COLOR_WHITE 9077
#define IDS_SETTINGS_CAPTIONS_COLOR_RED 9078
#define IDS_SETTINGS_CAPTIONS_COLOR_GREEN 9079
#define IDS_SETTINGS_CAPTIONS_COLOR_BLUE 9080
#define IDS_SETTINGS_CAPTIONS_COLOR_YELLOW 9081
#define IDS_SETTINGS_CAPTIONS_COLOR_CYAN 9082
#define IDS_SETTINGS_CAPTIONS_COLOR_MAGENTA 9083
#define IDS_SETTINGS_CAPTIONS_DEFAULT_SETTING 9084
#define IDS_SETTINGS_CAPTIONS_LANGUAGE 9085
#define IDS_SETTINGS_CAPTIONS_MANAGE_LANGUAGES_TITLE 9086
#define IDS_SETTINGS_CAPTIONS_MANAGE_LANGUAGES_SUBTITLE 9087
#define IDS_SETTINGS_CAPTIONS_MANAGE_LANGUAGES_SUBTITLE_LIVE_CAPTION_ONLY 9088
#define IDS_SETTINGS_CAPTIONS_LIVE_TRANSLATE_TARGET_LANGUAGE 9089
#define IDS_SETTINGS_CAPTIONS_LIVE_TRANSLATE_TARGET_LANGUAGE_SUBTITLE 9090
#define IDS_SETTINGS_CAPTIONS_REMOVE_LANGUAGE_LABEL 9091
#define IDS_SETTINGS_CAPTIONS_MAKE_DEFAULT_LANGUAGE_LABEL 9092
#define IDS_SETTINGS_CAPTIONS_DEFAULT_LANGUAGE_LABEL 9093
#define IDS_SETTINGS_NEARBY_SHARE_TITLE 9094
#define IDS_SETTINGS_NEARBY_SHARE_TITLE_PH 9095
#define IDS_SETTINGS_NEARBY_SHARE_SET_UP_BUTTON_TITLE 9096
#define IDS_SETTINGS_NEARBY_SHARE_DEVICE_NAME_ROW_TITLE 9097
#define IDS_SETTINGS_NEARBY_SHARE_DEVICE_NAME_DIALOG_TITLE 9098
#define IDS_SETTINGS_NEARBY_SHARE_DEVICE_NAME_FIELD_LABEL 9099
#define IDS_SETTINGS_NEARBY_SHARE_EDIT_DEVICE_NAME 9100
#define IDS_SETTINGS_NEARBY_SHARE_FAST_INITIATION_NOTIFICATION_TOGGLE_TITLE 9101
#define IDS_SETTINGS_NEARBY_SHARE_FAST_INITIATION_NOTIFICATION_TOGGLE_DESCRIPTION 9102
#define IDS_SETTINGS_NEARBY_SHARE_FAST_INITIATION_NOTIFICATION_TOGGLE_ARIA_LABEL 9103
#define IDS_SETTINGS_NEARBY_SHARE_DEVICE_NAME_ARIA_DESCRIPTION 9104
#define IDS_SETTINGS_NEARBY_SHARE_CONFIRM_DEVICE_NAME 9105
#define IDS_SETTINGS_NEARBY_SHARE_MANAGE_CONTACTS_LABEL 9106
#define IDS_SETTINGS_NEARBY_SHARE_MANAGE_CONTACTS_ROW_TITLE 9107
#define IDS_SETTINGS_NEARBY_SHARE_EDIT_DATA_USAGE 9108
#define IDS_SETTINGS_NEARBY_SHARE_UPDATE_DATA_USAGE 9109
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_DIALOG_TITLE 9110
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_WIFI_ONLY_LABEL 9111
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_WIFI_ONLY_DESCRIPTION 9112
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_MOBILE_DATA_LABEL 9113
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_MOBILE_DATA_DESCRIPTION 9114
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_MOBILE_DATA_TOOLTIP 9115
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_OFFLINE_LABEL 9116
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_OFFLINE_DESCRIPTION 9117
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_EDIT_BUTTON_DATA_DESCRIPTION 9118
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_EDIT_BUTTON_WIFI_ONLY_DESCRIPTION 9119
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_EDIT_BUTTON_OFFLINE_DESCRIPTION 9120
#define IDS_SETTINGS_NEARBY_SHARE_CONTACT_VISIBILITY_ROW_TITLE 9121
#define IDS_SETTINGS_NEARBY_SHARE_EDIT_VISIBILITY 9122
#define IDS_SETTINGS_NEARBY_SHARE_VISIBILITY_DIALOG_TITLE 9123
#define IDS_SETTINGS_NEARBY_SHARE_VISIBILITY_DIALOG_SAVE 9124
#define IDS_SETTINGS_NEARBY_SHARE_DESCRIPTION 9125
#define IDS_SETTINGS_NEARBY_SHARE_HIGH_VISIBILITY_TITLE 9126
#define IDS_SETTINGS_NEARBY_SHARE_HIGH_VISIBILITY_ON 9127
#define IDS_SETTINGS_NEARBY_SHARE_HIGH_VISIBILITY_OFF 9128
#define IDS_SETTINGS_ENABLE_URL_KEYED_ANONYMIZED_DATA_COLLECTION 9129
#define IDS_SETTINGS_ENABLE_URL_KEYED_ANONYMIZED_DATA_COLLECTION_DESC 9130
#define IDS_SETTINGS_SPELLING_PREF 9131
#define IDS_SETTINGS_ENABLE_LOGGING_PREF 9132
#define IDS_SETTINGS_ENABLE_LOGGING_PREF_DESC 9133
#define IDS_SETTINGS_SUGGEST_PREF 9134
#define IDS_SETTINGS_PEOPLE_SIGNED_IN_TO_ACCOUNT 9135
#define IDS_SETTINGS_PEOPLE_SYNCING_TO_ACCOUNT 9136
#define IDS_SETTINGS_PEOPLE_SYNC_PAUSED 9137
#define IDS_SETTINGS_PEOPLE_SIGN_IN_PROMPT 9138
#define IDS_SETTINGS_PEOPLE_SYNC_TURN_OFF 9139
#define IDS_SETTINGS_SETTINGS_CHECKBOX_LABEL 9140
#define IDS_SETTINGS_PEOPLE_SYNC_NOT_WORKING 9141
#define IDS_SETTINGS_PEOPLE_SYNC_PASSWORDS_NOT_WORKING 9142
#define IDS_SETTINGS_SYNC_ADVANCED_PAGE_TITLE 9143
#define IDS_SETTINGS_NEW_SYNC_ADVANCED_PAGE_TITLE 9144
#define IDS_SETTINGS_PEOPLE_SYNC_ANOTHER_ACCOUNT 9145
#define IDS_SETTINGS_TURN_ON_SYNC_BUTTON_UPDATE_SETTINGS_UI_ENABLED 9146
#define IDS_SETTINGS_ACCOUNT_AWARE_SIGNIN_BUTTON_LABEL 9147
#define IDS_SETTINGS_ERROR_PASSWORDS_USER_ERROR_DESCRIPTION 9148
#define IDS_SETTINGS_ERROR_RECOVERABILITY_DEGRADED_FOR_PASSWORDS_USER_ERROR_DESCRIPTION 9149
#define IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_SUBTITLE_WITH_EMAIL 9150
#define IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_SUBTITLE_WITH_EMAIL_WITH_BOOKMARKS 9151
#define IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_SUBTITLE_WITH_EMAIL_SIMPLE 9152
#define IDS_SETTINGS_CHANGE_ACCOUNT 9153
#define IDS_SETTINGS_SYNC_DISCONNECT_CONFIRM 9154
#define IDS_SETTINGS_PEOPLE_SIGN_OUT 9155
#define IDS_SETTINGS_AUTOFILL_CHECKBOX_LABEL 9156
#define IDS_SETTINGS_HISTORY_CHECKBOX_LABEL 9157
#define IDS_SETTINGS_EXTENSIONS_CHECKBOX_LABEL 9158
#define IDS_SETTINGS_OPEN_TABS_CHECKBOX_LABEL 9159
#define IDS_SETTINGS_SAVED_TAB_GROUPS_CHECKBOX_LABEL 9160
#define IDS_SETTINGS_PRODUCT_COMPARISONS_CHECKBOX_LABEL 9161
#define IDS_SETTINGS_WIFI_CONFIGURATIONS_CHECKBOX_LABEL 9162
#define IDS_SETTINGS_SYNC_EVERYTHING_CHECKBOX_LABEL 9163
#define IDS_SETTINGS_APPS_CHECKBOX_LABEL 9164
#define IDS_SETTINGS_APPS_CHECKBOX_SUBLABEL 9165
#define IDS_SETTINGS_NON_PERSONALIZED_SERVICES_SECTION_LABEL 9166
#define IDS_SETTINGS_CUSTOMIZE_SYNC 9167
#define IDS_SETTINGS_SYNC_DATA 9168
#define IDS_SETTINGS_PASSWORDS_AND_PASSKEYS_CHECKBOX_LABEL 9169
#define IDS_SETTINGS_PASSPHRASE_PLACEHOLDER 9170
#define IDS_SETTINGS_EXISTING_PASSPHRASE_TITLE 9171
#define IDS_SETTINGS_SUBMIT_PASSPHRASE 9172
#define IDS_SETTINGS_ENCRYPT_WITH_GOOGLE_CREDENTIALS_LABEL 9173
#define IDS_SETTINGS_ENCRYPT_ACCOUNT_DATA_WITH_GOOGLE_CREDENTIALS_LABEL 9174
#define IDS_SETTINGS_BOOKMARKS_CHECKBOX_LABEL 9175
#define IDS_SETTINGS_READING_LIST_CHECKBOX_LABEL 9176
#define IDS_SETTINGS_ENCRYPTION_OPTIONS 9177
#define IDS_SETTINGS_MISMATCHED_PASSPHRASE_ERROR 9178
#define IDS_SETTINGS_EMPTY_PASSPHRASE_ERROR 9179
#define IDS_SETTINGS_INCORRECT_PASSPHRASE_ERROR 9180
#define IDS_SETTINGS_NEW_MANAGE_SYNCED_DATA_TITLE_UNIFIED_CONSENT 9181
#define IDS_SETTINGS_NEW_SYNC_ADVANCED_BROWSER_PAGE_TITLE 9182
#define IDS_SETTINGS_SYNC_SYNC_AND_NON_PERSONALIZED_SERVICES 9183
#define IDS_SETTINGS_PASSPHRASE_CONFIRMATION_PLACEHOLDER 9184
#define IDS_SETTINGS_SYNC_LOADING 9185
#define IDS_SETTINGS_SYNC_TIMEOUT 9186
#define IDS_SETTINGS_SYNC 9187
#define IDS_SETTINGS_SYNC_SETTINGS_CANCEL_SYNC 9188
#define IDS_SETTINGS_SYNC_SETUP_CANCEL_DIALOG_TITLE 9189
#define IDS_SETTINGS_SYNC_SETUP_CANCEL_DIALOG_BODY 9190
#define IDS_SYNC_UNAVAILABLE_FOR_NON_GOOGLE_ACCOUNT 9191
#define IDS_SETTINGS_ABOUT_UPGRADE_CHECK_STARTED 9194
#define IDS_SETTINGS_UPDATE_TO_ROLLBACK_VERSION_DISALLOWED 9195
#define IDS_SETTINGS_THEME_CHECKBOX_LABEL 9197
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_TITLE 9201
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES 9202
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_LOCAL_CERTIFICATES 9203
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CRS_CERTIFICATES 9204
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_HASH_COPIED_TOAST 9205
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_PLATFORM 9206
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_PLATFORM_CERTS_TITLE 9207
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_PLATFORM_CERTS_VIEW_LINK 9209
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_ADMIN_CERTS_TITLE 9211
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_USER_CERTS_TITLE 9212
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_TRUSTED_CERTS_LIST 9213
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_INTERMEDIATE_CERTS_LIST 9214
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DISTRUSTED_CERTS_LIST 9215
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_NO_CERTIFICATES_ROW 9216
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_EXPORT_BUTTON_LABEL 9217
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_EXPORT_BUTTON_ARIA_LABEL 9218
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_BUTTON_LABEL 9219
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_BUTTON_ARIA_LABEL 9220
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_AND_BIND_BUTTON_LABEL 9221
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_AND_BIND_BUTTON_ARIA_LABEL 9222
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_NUM_CERTS 9223
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES_DESCRIPTION 9224
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_LOCAL_CERTIFICATES_DESCRIPTION 9225
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CRS_CERTIFICATES_DESCRIPTION 9226
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CRS_LEARN_MORE_LINK 9227
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CRS_LEARN_MORE_LINK_ARIA_LABEL 9228
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_PLATFORM_CERTS_TOGGLE_LABEL 9229
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CUSTOM_CERTS_TITLE 9230
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES_FROM_PLATFORM 9231
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES_FROM_ADMIN 9232
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES_FROM_EXTENSION 9233
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_CERT_TITLE 9234
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_CLIENT_CERT_DESCRIPTION 9235
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_SERVER_CERT_DESCRIPTION 9236
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_READ_FILE_ERROR 9237
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_MULTIPLE_CERT_ERROR 9238
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_ERROR_TITLE 9239
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_ERROR 9240
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_ENTER_PASSWORD_TITLE 9241
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_ERROR_TITLE 9242
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_INVALID_FILE 9243
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_FAILED 9244
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_BAD_PASSWORD 9245
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_INVALID_MAC 9246
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_UNSUPPORTED 9247
#define IDS_CERTIFICATE_MANAGER_V2_SUBPAGE_BACK_BUTTON_ARIA_LABEL 9248
#define IDS_CERTIFICATE_MANAGER_V2_SUBPAGE_BACK_BUTTON_ARIA_ROLE_DESCRIPTION 9249
#define IDS_CERTIFICATE_MANAGER_V2_LIST_EXPAND_ARIA_LABEL 9250
#define IDS_CERTIFICATE_MANAGER_V2_CERT_ENTRY_VIEW_ARIA_LABEL 9251
#define IDS_CERTIFICATE_MANAGER_V2_CERT_ENTRY_DELETE_ARIA_LABEL 9252
#define IDS_CERTIFICATE_MANAGER_V2_CERT_HASH_COPY_ARIA_LABEL 9253
#define IDS_SUPPORT_TOOL_ISSUE_DETAILS_PAGE_TITLE 9277
#define IDS_SUPPORT_TOOL_DATA_SELECTION_PAGE_TITLE 9278
#define IDS_SUPPORT_TOOL_REVIEW_PII_PAGE_TITLE 9279
#define IDS_SUPPORT_TOOL_DATA_EXPORT_DONE_PAGE_TITLE 9280
#define IDS_SUPPORT_TOOL_DATA_EXPORTED_TEXT 9281
#define IDS_SUPPORT_TOOL_SUPPORT_CASE_ID 9282
#define IDS_SUPPORT_TOOL_EMAIL 9283
#define IDS_SUPPORT_TOOL_DESCRIBE_ISSUE_TEXT 9284
#define IDS_SUPPORT_TOOL_ISSUE_DESCRIPTION_PLACEHOLDER 9285
#define IDS_SUPPORT_TOOL_PII_WARNING_TEXT 9286
#define IDS_SUPPORT_TOOL_INCLUDE_ALL_PII_RADIO_BUTTON 9287
#define IDS_SUPPORT_TOOL_REMOVE_PII_RADIO_BUTTON 9288
#define IDS_SUPPORT_TOOL_PII_REMOVAL_DISCLAIMER 9289
#define IDS_SUPPORT_TOOL_MANUALLY_SELECT_PII_RADIO_BUTTON 9290
#define IDS_SUPPORT_TOOL_CANCEL_BUTTON_TEXT 9291
#define IDS_SUPPORT_TOOL_EXPORT_BUTTON_TEXT 9292
#define IDS_SUPPORT_TOOL_BACK_BUTTON_TEXT 9293
#define IDS_SUPPORT_TOOL_DISMISS_BUTTON_TEXT 9294
#define IDS_SUPPORT_TOOL_CONTINUE_BUTTON_TEXT 9295
#define IDS_SUPPORT_TOOL_DATA_COLLECTION_SPINNER 9296
#define IDS_SUPPORT_TOOL_DATA_EXPORT_SPINNER 9297
#define IDS_SUPPORT_TOOL_TAB_TITLE 9298
#define IDS_SUPPORT_TOOL_URL_GENERATOR_PAGE_TITLE 9299
#define IDS_SUPPORT_TOOL_DATA_COLLECTOR_LIST_TITLE 9300
#define IDS_SUPPORT_TOOL_GET_LINK_TEXT 9301
#define IDS_SUPPORT_TOOL_COPY_LINK_DESCRIPTION 9302
#define IDS_SUPPORT_TOOL_COPY_LINK_BUTTON_TEXT 9303
#define IDS_SUPPORT_TOOL_COPY_TOKEN_BUTTON_TEXT 9304
#define IDS_SUPPORT_TOOL_DONT_INCLUDE_EMAIL 9305
#define IDS_SUPPORT_TOOL_LINK_COPIED_TEXT 9306
#define IDS_SUPPORT_TOOL_TOKEN_COPIED_TEXT 9307
#define IDS_SUPPORT_TOOL_SELECT_DATA_COLLECTOR_ERROR 9308
#define IDS_SUPPORT_TOOL_SELECT_ALL 9309
#define IDS_SUPPORT_TOOL_CHROME_SYSTEM_INFO 9310
#define IDS_SUPPORT_TOOL_CRASH_IDS 9311
#define IDS_SUPPORT_TOOL_MEMORY_DETAILS 9312
#define IDS_SUPPORT_TOOL_UI_HIEARCHY 9313
#define IDS_SUPPORT_TOOL_ADDITIONAL_CROS_PLATFROM_LOGS 9314
#define IDS_SUPPORT_TOOL_DEVICE_EVENT 9315
#define IDS_SUPPORT_TOOL_INTEL_WIFI_DEBUG_DUMP 9316
#define IDS_SUPPORT_TOOL_TOUCH_EVENTS 9317
#define IDS_SUPPORT_TOOL_CHROMEOS_FLEX_LOGS 9318
#define IDS_SUPPORT_TOOL_DBUS_DETAILS 9319
#define IDS_SUPPORT_TOOL_CHROMEOS_NETWORK_ROUTES 9320
#define IDS_SUPPORT_TOOL_CHROMEOS_SHILL_LOGS 9321
#define IDS_SUPPORT_TOOL_POLICIES 9322
#define IDS_SUPPORT_TOOL_CHROMEOS_SYSTEM_STATE 9323
#define IDS_SUPPORT_TOOL_CHROMEOS_SYSTEM_LOGS 9324
#define IDS_SUPPORT_TOOL_CHROMEOS_CHROME_USER_LOGS 9325
#define IDS_SUPPORT_TOOL_CHROMEOS_BLUETOOTH_FLOSS 9326
#define IDS_SUPPORT_TOOL_CHROMEOS_CONNECTED_INPUT_DEVICES 9327
#define IDS_SUPPORT_TOOL_CHROMEOS_TRAFFIC_COUNTERS 9328
#define IDS_SUPPORT_TOOL_CHROMEOS_VIRTUAL_KEYBOARD 9329
#define IDS_SUPPORT_TOOL_CHROMEOS_NETWORK_HEALTH 9330
#define IDS_SUPPORT_TOOL_PERFORMANCE 9331
#define IDS_SUPPORT_TOOL_SIGN_IN 9332
#define IDS_SUPPORT_TOOL_CHROMEOS_APP_SERVICE 9333
#define IDS_SUPPORT_TOOL_CHROMEOS_KIOSK_APP_LEVEL_LOGS 9334
#define IDS_SUPPORT_TOOL_CHROME_UPDATER 9335
#define IDS_SUPPORT_TOOL_ANDROID_APP_INFO 9336
#define IDS_SUPPORT_TOOL_WIFI_SSID 9337
#define IDS_SUPPORT_TOOL_CELLULAR_LOCATION_INFO 9338
#define IDS_SUPPORT_TOOL_EMAIL_ADDRESS 9339
#define IDS_SUPPORT_TOOL_GAIA_ID 9340
#define IDS_SUPPORT_TOOL_STABLE_IDENTIDIERS 9341
#define IDS_SUPPORT_TOOL_PRINTING_IPP_ADDRESS 9342
#define IDS_SUPPORT_TOOL_IP_ADDRESS 9343
#define IDS_SUPPORT_TOOL_MAC_ADDRESS 9344
#define IDS_SUPPORT_TOOL_WINDOW_TITLES 9345
#define IDS_SUPPORT_TOOL_URLS 9346
#define IDS_SUPPORT_TOOL_SERIAL_NUMBERS 9347
#define IDS_SUPPORT_TOOL_REMOVABLE_STORAGE_NAMES 9348
#define IDS_SUPPORT_TOOL_EAP 9349
#define IDS_SUPPORT_TOOL_CREDIT_CARD 9350
#define IDS_SUPPORT_TOOL_IBAN 9351
#define IDS_SUPPORT_TOOL_CRASH_ID 9352
#define IDS_SUPPORT_TOOL_MEMORY 9353
#define IDS_SUPPORT_TOOL_BLUETOOTH_HID_DEVICE 9354
#define IDS_EXTENSIONS_ALLOW_FILE_ACCESS 9355
#define IDS_EXTENSIONS_ALLOW_ON_ALL_URLS 9356
#define IDS_EXTENSIONS_ALLOW_ON_FOLLOWING_SITES 9357
#define IDS_EXTENSIONS_VIEW_ACTIVITY_LOG 9358
#define IDS_EXTENSIONS_BACKGROUND_PAGE 9359
#define IDS_EXTENSIONS_SERVICE_WORKER_BACKGROUND 9360
#define IDS_EXTENSIONS_CORRUPTED_EXTENSION 9361
#define IDS_EXTENSIONS_ENABLE_ERROR_COLLECTION 9362
#define IDS_EXTENSIONS_ERROR_NO_ERRORS_CODE_MESSAGE 9363
#define IDS_EXTENSIONS_INSTALL_DROP_TARGET 9364
#define IDS_EXTENSIONS_INSTALL_WARNINGS 9365
#define IDS_EXTENSIONS_LOG_LEVEL_ERROR 9366
#define IDS_EXTENSIONS_LOG_LEVEL_INFO 9367
#define IDS_EXTENSIONS_LOG_LEVEL_WARN 9368
#define IDS_EXTENSIONS_PATH 9369
#define IDS_EXTENSIONS_PERMISSIONS_OFF 9370
#define IDS_EXTENSIONS_RELOAD_TERMINATED 9371
#define IDS_EXTENSIONS_REPAIR_CORRUPTED 9372
#define IDS_EXTENSIONS_MOVE_TO_ACCOUNT_ICON_TOOLTIP 9373
#define IDS_EXTENSIONS_VIEW_IFRAME 9374
#define IDS_EXTENSIONS_VIEW_INACTIVE 9375
#define IDS_EXTENSIONS_VIEW_INCOGNITO 9376
#define IDS_EXTENSIONS_DEVELOPER_MODE 9377
#define IDS_EXTENSIONS_DISABLED_UNSUPPORTED_DEVELOPER_MODE 9378
#define IDS_EXTENSIONS_DISABLED_UNSUPPORTED_DEVELOPER_MODE_DETAILS 9379
#define IDS_EXTENSIONS_DISABLED_UNSUPPORTED_DEVELOPER_MODE_TOAST 9380
#define IDS_EXTENSIONS_DISABLED_UPDATE_REQUIRED_BY_POLICY 9381
#define IDS_EXTENSIONS_DISABLED_PUBLISHED_IN_STORE_REQUIRED_BY_POLICY 9382
#define IDS_EXTENSIONS_MATCHING_RESTRICTED_SITES_ALLOW 9383
#define IDS_EXTENSIONS_MATCHING_RESTRICTED_SITES_TITLE 9384
#define IDS_EXTENSIONS_MATCHING_RESTRICTED_SITES_WARNING 9385
#define IDS_EXTENSIONS_MENU_BUTTON_LABEL 9386
#define IDS_EXTENSIONS_ERROR_PAGE_HEADING 9387
#define IDS_EXTENSIONS_EDIT_SITE_PERMISSIONS_ALLOW_ALL_EXTENSIONS 9388
#define IDS_EXTENSIONS_EDIT_SITE_PERMISSIONS_CUSTOMIZE_PER_EXTENSION 9389
#define IDS_EXTENSIONS_EDIT_SITE_PERMISSIONS_RESTRICT_EXTENSIONS 9390
#define IDS_EXTENSIONS_ERROR_ANONYMOUS_FUNCTION 9391
#define IDS_EXTENSIONS_ERROR_CONTEXT 9392
#define IDS_EXTENSIONS_ERROR_CONTEXT_UNKNOWN 9393
#define IDS_EXTENSIONS_CLEAR_ACTIVITIES 9394
#define IDS_EXTENSIONS_ERROR_CLEAR_ALL 9395
#define IDS_EXTENSIONS_A11Y_CLEAR_ENTRY 9396
#define IDS_EXTENSIONS_ERROR_STACK_TRACE 9397
#define IDS_EXTENSIONS_ERROR_LINES_NOT_SHOWN 9398
#define IDS_EXTENSIONS_HOST_PERMISSIONS_DESCRIPTION 9399
#define IDS_EXTENSIONS_PERMISSIONS_LEARN_MORE_A11Y_LABEL 9400
#define IDS_EXTENSIONS_HOST_PERMISSIONS_EDIT 9401
#define IDS_EXTENSIONS_ITEM_ERRORS 9402
#define IDS_EXTENSIONS_ITEM_WARNINGS 9403
#define IDS_EXTENSIONS_ITEM_HOST_PERMISSIONS_HEADING 9404
#define IDS_EXTENSIONS_NEW_HOST_PERMISSIONS_HEADING 9405
#define IDS_EXTENSIONS_HOST_PERMISSIONS_SUB_HEADING 9406
#define IDS_EXTENSIONS_HOST_ACCESS_ON_CLICK 9407
#define IDS_EXTENSIONS_HOST_ACCESS_ASK_ON_EVERY_VISIT 9408
#define IDS_EXTENSIONS_HOST_ACCESS_ON_SPECIFIC_SITES 9409
#define IDS_EXTENSIONS_HOST_ACCESS_ALLOW_ON_SPECIFIC_SITES 9410
#define IDS_EXTENSIONS_HOST_ACCESS_ON_ALL_SITES 9411
#define IDS_EXTENSIONS_HOST_ACCESS_ALLOW_ON_ALL_SITES 9412
#define IDS_EXTENSIONS_ITEM_ALLOWED_HOSTS 9413
#define IDS_EXTENSIONS_ACCESSIBILITY_ERROR_LINE 9414
#define IDS_EXTENSIONS_ACCESSIBILITY_ERROR_MULTI_LINE 9415
#define IDS_EXTENSIONS_ACTIVITY_LOG_PAGE_HEADING 9416
#define IDS_EXTENSIONS_ACTIVITY_LOG_SEARCH_LABEL 9417
#define IDS_EXTENSIONS_ACTIVITY_LOG_TYPE_COLUMN 9418
#define IDS_EXTENSIONS_ACTIVITY_LOG_NAME_COLUMN 9419
#define IDS_EXTENSIONS_ACTIVITY_LOG_COUNT_COLUMN 9420
#define IDS_EXTENSIONS_ACTIVITY_LOG_TIME_COLUMN 9421
#define IDS_EXTENSIONS_ACTIVITY_LOG_HISTORY_TAB_HEADING 9422
#define IDS_EXTENSIONS_ACTIVITY_LOG_STREAM_TAB_HEADING 9423
#define IDS_EXTENSIONS_START_ACTIVITY_STREAM 9424
#define IDS_EXTENSIONS_STOP_ACTIVITY_STREAM 9425
#define IDS_EXTENSIONS_EMPTY_STREAM_STARTED 9426
#define IDS_EXTENSIONS_EMPTY_STREAM_STOPPED 9427
#define IDS_EXTENSIONS_ACTIVITY_ARGUMENTS_HEADING 9428
#define IDS_EXTENSIONS_WEB_REQUEST_INFO_HEADING 9429
#define IDS_EXTENSIONS_ACTIVITY_LOG_MORE_ACTIONS_LABEL 9430
#define IDS_EXTENSIONS_ACTIVITY_LOG_EXPAND_ALL 9431
#define IDS_EXTENSIONS_ACTIVITY_LOG_COLLAPSE_ALL 9432
#define IDS_EXTENSIONS_ACTIVITY_LOG_EXPORT_HISTORY 9433
#define IDS_EXTENSIONS_ITEM_ID 9434
#define IDS_EXTENSIONS_ITEM_INSPECT_VIEWS 9435
#define IDS_EXTENSIONS_ITEM_INSPECT_VIEWS_EXTRA 9436
#define IDS_EXTENSIONS_ITEM_NO_ACTIVE_VIEWS 9437
#define IDS_EXTENSIONS_ITEM_ALLOW_INCOGNITO 9438
#define IDS_EXTENSIONS_ITEM_ALLOW_USER_SCRIPTS 9439
#define IDS_EXTENSIONS_ALLOW_USER_SCRIPTS_WARNING 9440
#define IDS_EXTENSIONS_ITEM_DEPENDENCIES 9441
#define IDS_EXTENSIONS_DEPENDENT_ENTRY 9442
#define IDS_EXTENSIONS_ITEM_DESCRIPTION 9443
#define IDS_EXTENSIONS_ITEM_DETAILS 9444
#define IDS_EXTENSIONS_DETAILS_BACK_BUTTON_ARIA_LABEL 9445
#define IDS_EXTENSIONS_DETAILS_BACK_BUTTON_ARIA_ROLE_DESCRIPTION 9446
#define IDS_EXTENSIONS_EXTENSION_A11Y_ASSOCIATION 9447
#define IDS_EXTENSIONS_APP_ICON 9448
#define IDS_EXTENSIONS_EXTENSION_ICON 9449
#define IDS_EXTENSIONS_ITEM_ID_HEADING 9450
#define IDS_EXTENSIONS_EXTENSION_ENABLED 9451
#define IDS_EXTENSIONS_APP_ENABLED 9452
#define IDS_EXTENSIONS_ITEM_OFF 9453
#define IDS_EXTENSIONS_ITEM_ON 9454
#define IDS_EXTENSIONS_ITEM_EXTENSION_WEBSITE 9455
#define IDS_EXTENSIONS_ITEM_CHROME_WEB_STORE 9456
#define IDS_EXTENSIONS_VIEW_IN_DEVTOOLS 9457
#define IDS_EXTENSIONS_ITEM_OPTIONS 9458
#define IDS_EXTENSIONS_ITEM_PERMISSIONS 9459
#define IDS_EXTENSIONS_ITEM_PERMISSIONS_EMPTY 9460
#define IDS_EXTENSIONS_ITEM_PERMISSIONS_AND_SITE_ACCESS_EMPTY 9461
#define IDS_EXTENSIONS_ITEM_PIN_TO_TOOLBAR 9462
#define IDS_EXTENSIONS_ITEM_REMOVE_EXTENSION 9463
#define IDS_EXTENSIONS_ITEM_SITE_ACCESS 9464
#define IDS_EXTENSIONS_ITEM_SITE_ACCESS_ADD_HOST 9465
#define IDS_EXTENSIONS_ITEM_SITE_ACCESS_EMPTY 9466
#define IDS_EXTENSIONS_REMOVE_SITES_DIALOG_TITLE 9467
#define IDS_EXTENSIONS_ITEM_SOURCE 9468
#define IDS_EXTENSIONS_ITEM_SOURCE_INSTALLED_BY_DEFAULT 9469
#define IDS_EXTENSIONS_ITEM_SOURCE_POLICY 9470
#define IDS_EXTENSIONS_ITEM_SOURCE_SIDELOADED 9471
#define IDS_EXTENSIONS_ITEM_SOURCE_UNPACKED 9472
#define IDS_EXTENSIONS_ITEM_SOURCE_WEBSTORE 9473
#define IDS_EXTENSIONS_ITEM_VERSION 9474
#define IDS_EXTENSIONS_ITEM_RELOADED 9475
#define IDS_EXTENSIONS_ITEM_RELOADING 9476
#define IDS_EXTENSIONS_LOAD_ERROR_HEADING 9477
#define IDS_EXTENSIONS_LOAD_ERROR_ERROR_LABEL 9478
#define IDS_EXTENSIONS_LOAD_ERROR_FILE_LABEL 9479
#define IDS_EXTENSIONS_LOAD_ERROR_COULD_NOT_LOAD_MANIFEST 9480
#define IDS_EXTENSIONS_LOAD_ERROR_RETRY 9481
#define IDS_EXTENSIONS_LOADING_ACTIVITIES 9482
#define IDS_MISSING_OR_UNINSTALLED_EXTENSION 9483
#define IDS_EXTENSIONS_NO_ACTIVITIES 9484
#define IDS_EXTENSIONS_NO_INSTALLED_ITEMS 9485
#define IDS_EXTENSIONS_NO_DESCRIPTION 9486
#define IDS_EXTENSIONS_OPENS_IN_NEW_TAB 9487
#define IDS_EXTENSIONS_PACK_DIALOG_TITLE 9488
#define IDS_EXTENSIONS_PACK_DIALOG_WARNING_TITLE 9489
#define IDS_EXTENSIONS_PACK_DIALOG_ERROR_TITLE 9490
#define IDS_EXTENSIONS_PACK_DIALOG_PROCEED_ANYWAY 9491
#define IDS_EXTENSIONS_PACK_DIALOG_BROWSE_BUTTON 9492
#define IDS_EXTENSIONS_PACK_DIALOG_EXTENSION_ROOT_LABEL 9493
#define IDS_EXTENSIONS_PACK_DIALOG_KEY_FILE_LABEL 9494
#define IDS_EXTENSIONS_PACK_DIALOG_CONFIRM_BUTTON 9495
#define IDS_EXTENSIONS_TOOLBAR_TITLE 9496
#define IDS_EXTENSIONS_SEARCH 9497
#define IDS_EXTENSIONS_SITE_PERMISSIONS 9498
#define IDS_EXTENSIONS_SITE_PERMISSIONS_PAGE_TITLE 9499
#define IDS_EXTENSIONS_SITE_PERMISSIONS_VIEW_ALL_SITES 9500
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALL_SITES_PAGE_TITLE 9501
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALL_SITES_ONE_EXTENSION 9502
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALL_SITES_EXTENSION_COUNT 9503
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALWAYS_ON_ALL_SITES 9504
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALWAYS_ON_THIS_SITE 9505
#define IDS_EXTENSIONS_SITE_SETTINGS 9506
#define IDS_EXTENSIONS_PERMITTED_SITES 9507
#define IDS_EXTENSIONS_RESTRICTED_SITES 9508
#define IDS_EXTENSIONS_NO_SITES_ADDED 9509
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ADD_SITE_DIALOG_TITLE 9510
#define IDS_EXTENSIONS_SITE_PERMISSIONS_EDIT_SITE_DIALOG_TITLE 9511
#define IDS_EXTENSIONS_SITE_PERMISSIONS_EDIT_URL 9512
#define IDS_EXTENSIONS_SITE_PERMISSIONS_EDIT_PERMISSIONS_DIALOG_TITLE 9513
#define IDS_EXTENSIONS_SITE_PERMISSIONS_EDIT_PERMISSIONS 9514
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ASK_ON_EVERY_VISIT 9515
#define IDS_EXTENSIONS_SITE_PERMISSIONS_DIALOG_INPUT_ERROR 9516
#define IDS_EXTENSIONS_SITE_PERMISSIONS_DIALOG_INPUT_LABEL 9517
#define IDS_EXTENSIONS_SITE_PERMISSIONS_INCLUDES_SUBDOMAINS 9518
#define IDS_EXTENSIONS_EDIT_SHORTCUT_INPUT_LABEL 9519
#define IDS_EXTENSIONS_EDIT_SHORTCUT_BUTTON_LABEL 9520
#define IDS_EXTENSIONS_SET_SHORTCUT_IN_SYSTEM_SETTINGS 9521
#define IDS_EXTENSIONS_SHORTCUT_SCOPE_LABEL 9522
#define IDS_EXTENSIONS_SHORTCUT_SCOPE_GLOBAL 9523
#define IDS_EXTENSIONS_APPS_TITLE 9524
#define IDS_EXTENSIONS_REMOVE 9525
#define IDS_EXTENSIONS_MORE_OPTIONS 9526
#define IDS_EXTENSIONS_RUNTIME_HOSTS_DIALOG_TITLE 9527
#define IDS_EXTENSIONS_RUNTIME_HOSTS_DIALOG_INPUT_ERROR 9528
#define IDS_EXTENSIONS_RUNTIME_HOSTS_DIALOG_INPUT_LABEL 9529
#define IDS_EXTENSIONS_SIDEBAR_EXTENSIONS 9530
#define IDS_EXTENSIONS_SIDEBAR_DISCOVER_MORE 9531
#define IDS_EXTENSIONS_WHATS_NEW_SIDEBAR_PROMO 9532
#define IDS_EXTENSIONS_SIDEBAR_KEYBOARD_SHORTCUTS 9533
#define IDS_EXTENSIONS_TOOLBAR_LOAD_UNPACKED 9534
#define IDS_EXTENSIONS_TOOLBAR_LOAD_UNPACKED_DONE 9535
#define IDS_EXTENSIONS_TOOLBAR_PACK 9536
#define IDS_EXTENSIONS_TOOLBAR_UPDATE_NOW 9537
#define IDS_EXTENSIONS_TOOLBAR_UPDATE_NOW_TOOLTIP 9538
#define IDS_EXTENSIONS_TOOLBAR_UPDATE_DONE 9539
#define IDS_EXTENSIONS_TOOLBAR_UPDATING_TOAST 9540
#define IDS_EXTENSIONS_SUBPAGE_BUTTON 9541
#define IDS_EXTENSIONS_SECTION_HEADER 9542
#define IDS_EXTENSIONS_SAFETY_HUB_HEADER 9543
#define IDS_EXTENSIONS_SC_MALWARE 9544
#define IDS_EXTENSIONS_SC_POLICY_VIOLATION_OFF 9545
#define IDS_EXTENSIONS_SC_POLICY_VIOLATION_ON 9546
#define IDS_EXTENSIONS_SC_UNPUBLISHED_OFF 9547
#define IDS_EXTENSIONS_SC_UNPUBLISHED_ON 9548
#define IDS_EXTENSIONS_SAFETY_CHECK_NO_PRIVACY_PRACTICES_ON 9549
#define IDS_EXTENSIONS_SAFETY_CHECK_NO_PRIVACY_PRACTICES_OFF 9550
#define IDS_EXTENSIONS_SC_TITLE 9551
#define IDS_EXTENSIONS_SC_KEEP_EXT 9552
#define IDS_EXTENSIONS_SC_THREEDOT_DETAILS 9553
#define IDS_EXTENSIONS_SC_REMOVE_ALL 9554
#define IDS_EXTENSIONS_SC_ALL_DONE_FOR_NOW 9555
#define IDS_EXTENSIONS_SC_REMOVE_BUTTON_A11Y_LABEL 9556
#define IDS_EXTENSIONS_SC_OPTION_MENU_A11Y_LABEL 9557
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_TITLE 9558
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_WARNING_HEADER 9559
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_WARNING_SUBTITLE 9560
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_DISABLED_HEADER 9561
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_WARNING_HEADER 9562
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_WARNING_SUBTITLE 9563
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_DISABLED_HEADER 9564
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_REMOVE_BUTTON 9565
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_DISMISS_BUTTON 9566
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_FIND_ALTERNATIVE_BUTTON 9567
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_KEEP_FOR_NOW_BUTTON 9568
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_ACTION_MENU_BUTTON_LABEL 9569
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_FIND_ALTERNATIVE_BUTTON_ACC_LABEL 9570
#define IDS_EXTENSIONS_MV2_DEPRECATION_UNSUPPORTED_EXTENSION_OFF_TEXT 9571
#define IDS_EXTENSIONS_CANT_INSTALL_MV2_EXTENSION 9572
#define IDS_EXTENSIONS_ZERO_STATE_IPH_HEADER 9584
#define IDS_EXTENSIONS_ZERO_STATE_IPH_HEADER_V2 9585
#define IDS_EXTENSIONS_ZERO_STATE_CHIPS_IPH_DESCRIPTION 9586
#define IDS_EXTENSIONS_ZERO_STATE_CHIPS_WITH_LINK_IPH_LINK_LABEL 9587
#define IDS_EXTENSIONS_ZERO_STATE_CHIPS_WITH_LINK_IPH_DESCRIPTION 9588
#define IDS_EXTENSIONS_ZERO_STATE_PLAIN_LINK_IPH_DESCRIPTION 9589
#define IDS_EXTENSIONS_ZERO_STATE_IPH_SHOPPING_CATEGORY_LABEL 9590
#define IDS_EXTENSIONS_ZERO_STATE_IPH_WRITING_HELP_COLLECTION_LABEL 9591
#define IDS_EXTENSIONS_ZERO_STATE_IPH_PRODUCTIVITY_CATEGORY_LABEL 9592
#define IDS_EXTENSIONS_ZERO_STATE_IPH_AI_PRODUCTIVITY_COLLECTION_LABEL 9593
#define IDS_EXTENSIONS_ZERO_STATE_IPH_DISMISS_BUTTON_TITLE 9594
#define IDS_EXTENSIONS_ZERO_STATE_IPH_SHOPPING_CATEGORY_LINK 9595
#define IDS_EXTENSIONS_ZERO_STATE_IPH_WRITING_HELP_COLLECTION_LINK 9596
#define IDS_EXTENSIONS_ZERO_STATE_IPH_PRODUCTIVITY_CATEGORY_LINK 9597
#define IDS_EXTENSIONS_ZERO_STATE_IPH_AI_PRODUCTIVITY_COLLECTION_LINK 9598
#define IDS_EXTENSIONS_ZERO_STATE_IPH_WEB_STORE_LINK 9599
#define IDS_EXTENSIONS_ZERO_STATE_IPH_DISMISS_BUTTON_TEXT 9600
#define IDS_NEARBY_CONFIRMATION_PAGE_ADD_CONTACT_SUBTITLE 9601
#define IDS_NEARBY_CONFIRMATION_PAGE_ADD_CONTACT_TITLE 9602
#define IDS_NEARBY_CONFIRMATION_PAGE_TITLE 9603
#define IDS_QUICK_SHARE_V2_VISIBILITY_SECTION_TITLE 9604
#define IDS_QUICK_SHARE_V2_VISIBILITY_SECTION_SUBTITLE_ON_DISABLED 9605
#define IDS_QUICK_SHARE_V2_VISIBILITY_YOUR_DEVICES_SUBLABEL 9606
#define IDS_QUICK_SHARE_V2_VISIBILITY_CONTACTS_SUBLABEL 9607
#define IDS_QUICK_SHARE_V2_VISIBILITY_EVERYONE_LABEL 9608
#define IDS_QUICK_SHARE_V2_VISIBILITY_EVERYONE_SUBLABEL 9609
#define IDS_QUICK_SHARE_V2_VISIBILITY_ONLY_FOR_TEN_MINUTES_LABEL 9610
#define IDS_NEARBY_CONTACT_VISIBILITY_DOWNLOAD_FAILED 9611
#define IDS_NEARBY_CONTACT_VISIBILITY_DOWNLOADING 9612
#define IDS_NEARBY_CONTACT_VISIBILITY_NO_CONTACTS_SUBTITLE 9613
#define IDS_NEARBY_CONTACT_VISIBILITY_NO_CONTACTS_SUBTITLE_PH 9614
#define IDS_NEARBY_CONTACT_VISIBILITY_NO_CONTACTS_TITLE 9615
#define IDS_NEARBY_CONTACT_VISIBILITY_NUM_UNREACHABLE 9616
#define IDS_NEARBY_CONTACT_VISIBILITY_NUM_UNREACHABLE_PH 9617
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_ALL 9618
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_ALL_SELF_SHARE 9619
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_NONE 9620
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_SOME 9621
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_SOME_SELF_SHARE 9622
#define IDS_NEARBY_CONTACT_VISIBILITY_ZERO_STATE_TEXT 9623
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_YOUR_DEVICES 9624
#define IDS_NEARBY_DEVICE_NAME_EMPTY_ERROR 9625
#define IDS_NEARBY_DEVICE_NAME_TOO_LONG_ERROR 9626
#define IDS_NEARBY_DEVICE_NAME_INVALID_CHARACTERS_ERROR 9627
#define IDS_NEARBY_DISCOVERY_PAGE_INFO 9628
#define IDS_NEARBY_DISCOVERY_PAGE_SUBTITLE 9629
#define IDS_NEARBY_DISCOVERY_PAGE_TITLE 9630
#define IDS_NEARBY_DISCOVERY_PAGE_TITLE_PH 9631
#define IDS_NEARBY_DISCOVERY_PAGE_PLACEHOLDER 9632
#define IDS_NEARBY_ONBOARDING_PAGE_DEVICE_NAME 9633
#define IDS_NEARBY_ONBOARDING_PAGE_DEVICE_NAME_HELP 9634
#define IDS_NEARBY_ONBOARDING_PAGE_SUBTITLE 9635
#define IDS_NEARBY_ONBOARDING_PAGE_TITLE 9636
#define IDS_NEARBY_ONBOARDING_PAGE_TITLE_PH 9637
#define IDS_NEARBY_ONBOARDING_PAGE_DEVICE_VISIBILITY 9638
#define IDS_NEARBY_ONBOARDING_PAGE_DEVICE_VISIBILITY_HELP_ALL_CONTACTS 9639
#define IDS_NEARBY_VISIBILITY_PAGE_MANAGE_CONTACTS 9640
#define IDS_NEARBY_VISIBILITY_PAGE_SUBTITLE 9641
#define IDS_NEARBY_VISIBILITY_PAGE_TITLE 9642
#define IDS_NEARBY_SHARE_FEATURE_NAME 9643
#define IDS_NEARBY_SHARE_FEATURE_NAME_PH 9644
#define IDS_NEARBY_ACTIONS_ACCEPT 9645
#define IDS_NEARBY_ACTIONS_CANCEL 9646
#define IDS_NEARBY_ACTIONS_CLOSE 9647
#define IDS_NEARBY_ACTIONS_CONFIRM 9648
#define IDS_NEARBY_ACTIONS_DECLINE 9649
#define IDS_NEARBY_ACTIONS_NEXT 9650
#define IDS_NEARBY_ACTIONS_REJECT 9651
#define IDS_NEARBY_DEFAULT_DEVICE_NAME 9652
#define IDS_NEARBY_ERROR_CANCELLED 9653
#define IDS_NEARBY_ERROR_CANT_RECEIVE 9654
#define IDS_NEARBY_ERROR_CANT_SHARE 9655
#define IDS_NEARBY_ERROR_NO_RESPONSE 9656
#define IDS_NEARBY_ERROR_TRANSFER_IN_PROGRESS 9657
#define IDS_NEARBY_ERROR_NOT_ENOUGH_SPACE 9658
#define IDS_NEARBY_ERROR_REJECTED 9659
#define IDS_NEARBY_ERROR_SOMETHING_WRONG 9660
#define IDS_NEARBY_ERROR_TIME_OUT 9661
#define IDS_NEARBY_ERROR_TRY_AGAIN 9662
#define IDS_NEARBY_ERROR_UNSUPPORTED_FILE_TYPE 9663
#define IDS_NEARBY_FILE_ATTACHMENTS_CAPITALIZED_APPS 9664
#define IDS_NEARBY_FILE_ATTACHMENTS_NOT_CAPITALIZED_APPS 9665
#define IDS_NEARBY_FILE_ATTACHMENTS_CAPITALIZED_IMAGES 9666
#define IDS_NEARBY_FILE_ATTACHMENTS_NOT_CAPITALIZED_IMAGES 9667
#define IDS_NEARBY_FILE_ATTACHMENTS_CAPITALIZED_UNKNOWN 9668
#define IDS_NEARBY_FILE_ATTACHMENTS_NOT_CAPITALIZED_UNKNOWN 9669
#define IDS_NEARBY_FILE_ATTACHMENTS_CAPITALIZED_VIDEOS 9670
#define IDS_NEARBY_FILE_ATTACHMENTS_NOT_CAPITALIZED_VIDEOS 9671
#define IDS_NEARBY_SECURE_CONNECTION_ID 9672
#define IDS_NEARBY_TEXT_ATTACHMENTS_CAPITALIZED_ADDRESSES 9673
#define IDS_NEARBY_TEXT_ATTACHMENTS_NOT_CAPITALIZED_ADDRESSES 9674
#define IDS_NEARBY_TEXT_ATTACHMENTS_CAPITALIZED_LINKS 9675
#define IDS_NEARBY_TEXT_ATTACHMENTS_NOT_CAPITALIZED_LINKS 9676
#define IDS_NEARBY_TEXT_ATTACHMENTS_CAPITALIZED_PHONE_NUMBERS 9677
#define IDS_NEARBY_TEXT_ATTACHMENTS_NOT_CAPITALIZED_PHONE_NUMBERS 9678
#define IDS_NEARBY_TEXT_ATTACHMENTS_CAPITALIZED_UNKNOWN 9679
#define IDS_NEARBY_TEXT_ATTACHMENTS_NOT_CAPITALIZED_UNKNOWN 9680
#define IDS_NEARBY_CAPITALIZED_UNKNOWN_ATTACHMENTS 9681
#define IDS_NEARBY_NOT_CAPITALIZED_UNKNOWN_ATTACHMENTS 9682
#define IDS_NEARBY_HIGH_VISIBILITY_SUB_TITLE 9683
#define IDS_NEARBY_HIGH_VISIBILITY_SUB_TITLE_MINUTES 9684
#define IDS_NEARBY_HIGH_VISIBILITY_SUB_TITLE_SECONDS 9685
#define IDS_NEARBY_HIGH_VISIBILITY_HELP_TEXT 9686
#define IDS_NEARBY_HIGH_VISIBILITY_TIMEOUT_TEXT 9687
#define IDS_NEARBY_HIGH_VISIBILITY_TRANSFER_IN_PROGRESS_ERROR 9688
#define IDS_NEARBY_HIGH_VISIBILITY_TRANSFER_IN_PROGRESS_DESCRIPTION 9689
#define IDS_NEARBY_HIGH_VISIBILITY_CONNECTION_MEDIUM_ERROR 9690
#define IDS_NEARBY_HIGH_VISIBILITY_CONNECTION_MEDIUM_DESCRIPTION 9691
#define IDS_NEARBY_HIGH_VISIBILITY_CONNECTION_MEDIUM_DESCRIPTION_PH 9692
#define IDS_NEARBY_RECEIVE_CONFIRM_PAGE_TITLE 9693
#define IDS_NEARBY_RECEIVE_CONFIRM_PAGE_CONNECTION_ID 9694
#define IDS_NEARBY_PREVIEW_TITLE_MULTIPLE_FILE 9695
#define IDS_NEARBY_ACCOUNT_ROW_LABEL 9696
#define IDS_NEARBY_ACCOUNT_ROW_LABEL_PH 9697
#define IDS_NEARBY_SETTINGS_HELP_CAPTION_TOP 9698
#define IDS_NEARBY_SETTINGS_HELP_CAPTION_TOP_PH 9699
#define IDS_NEARBY_SETTINGS_HELP_CAPTION_BOTTOM 9700
#define IDS_NEARBY_VISIBLITY_ALL_CONTACTS 9701
#define IDS_NEARBY_VISIBLITY_ALL_CONTACTS_DESCRIPTION 9702
#define IDS_NEARBY_VISIBILITY_CONTACTS_BUTTON 9703
#define IDS_NEARBY_VISIBLITY_SOME_CONTACTS 9704
#define IDS_NEARBY_VISIBLITY_SOME_CONTACTS_DESCRIPTION 9705
#define IDS_NEARBY_VISIBILITY_YOUR_DEVICES 9706
#define IDS_NEARBY_VISIBILITY_YOUR_DEVICES_DESCRIPTION 9707
#define IDS_NEARBY_VISIBILITY_ALL_CONTACTS_TOGGLE 9708
#define IDS_NEARBY_VISIBLITY_HIDDEN 9709
#define IDS_NEARBY_VISIBLITY_HIDDEN_DESCRIPTION 9710
#define IDS_NEARBY_VISIBLITY_UNKNOWN 9711
#define IDS_NEARBY_VISIBLITY_UNKNOWN_DESCRIPTION 9712
#define IDS_NEARBY_NOTIFICATION_ACTION_COPY_TO_CLIPBOARD 9713
#define IDS_NEARBY_NOTIFICATION_ACTION_OPEN_FOLDER 9714
#define IDS_NEARBY_NOTIFICATION_ACTION_OPEN_NETWORK_LIST 9715
#define IDS_NEARBY_NOTIFICATION_ACTION_OPEN_URL 9716
#define IDS_NEARBY_NOTIFICATION_ACCEPT_ACTION 9717
#define IDS_NEARBY_NOTIFICATION_CONNECTION_REQUEST_MESSAGE 9718
#define IDS_NEARBY_NOTIFICATION_CONNECTION_REQUEST_MESSAGE_WIFI_CREDENTIALS 9719
#define IDS_NEARBY_NOTIFICATION_CONNECTION_REQUEST_TITLE 9720
#define IDS_NEARBY_NOTIFICATION_CONNECTION_REQUEST_TITLE_PH 9721
#define IDS_NEARBY_NOTIFICATION_DECLINE_ACTION 9722
#define IDS_NEARBY_NOTIFICATION_ONBOARDING_MESSAGE 9723
#define IDS_NEARBY_NOTIFICATION_ONBOARDING_MESSAGE_PH 9724
#define IDS_NEARBY_NOTIFICATION_GO_VISIBLE_MESSAGE 9725
#define IDS_NEARBY_NOTIFICATION_ONBOARDING_TITLE 9726
#define IDS_NEARBY_NOTIFICATION_SET_UP_ACTION 9727
#define IDS_NEARBY_NOTIFICATION_GO_VISIBLE_ACTION 9728
#define IDS_NEARBY_NOTIFICATION_VISIBILITY_REMINDER_TITLE 9729
#define IDS_NEARBY_NOTIFICATION_VISIBILITY_REMINDER_MESSAGE 9730
#define IDS_NEARBY_NOTIFICATION_GO_TO_SETTINGS_ACTION 9731
#define IDS_NEARBY_NOTIFICATION_DISMISS_ACTION 9732
#define IDS_NEARBY_NOTIFICATION_RECEIVE_FAILURE_TITLE 9733
#define IDS_NEARBY_NOTIFICATION_RECEIVE_FAILURE_TITLE_WIFI_CREDENTIALS 9734
#define IDS_NEARBY_NOTIFICATION_RECEIVE_PROGRESS_TITLE 9735
#define IDS_NEARBY_NOTIFICATION_RECEIVE_PROGRESS_TITLE_WIFI_CREDENTIALS 9736
#define IDS_NEARBY_NOTIFICATION_RECEIVE_SUCCESS_TITLE 9737
#define IDS_NEARBY_NOTIFICATION_RECEIVE_SUCCESS_TITLE_WIFI_CREDENTIALS 9738
#define IDS_NEARBY_NOTIFICATION_SEND_FAILURE_TITLE 9739
#define IDS_NEARBY_NOTIFICATION_SEND_PROGRESS_TITLE 9740
#define IDS_NEARBY_NOTIFICATION_SEND_SUCCESS_TITLE 9741
#define IDS_NEARBY_NOTIFICATION_SOURCE 9742
#define IDS_NEARBY_NOTIFICATION_SOURCE_PH 9743
#define IDS_NEARBY_NOTIFICATION_SENDER_CANCELLED 9744
#define IDS_WHATS_NEW_TITLE 9745
#define IDS_PASSWORD_MANAGER_UI_TITLE 9746
#define IDS_PASSWORD_MANAGER_UI_DESCRIPTION 9747
#define IDS_PASSWORD_MANAGER_UI_SEARCH_PROMPT 9748
#define IDS_PASSWORD_MANAGER_UI_CHECKUP 9749
#define IDS_PASSWORD_MANAGER_UI_PASSWORDS 9750
#define IDS_PASSWORD_MANAGER_UI_SETTINGS 9751
#define IDS_PASSWORD_MANAGER_UI_SAVE_PASSWORDS_TOGGLE_LABEL 9752
#define IDS_PASSWORD_MANAGER_UI_AUTOSIGNIN_TOGGLE_LABEL 9753
#define IDS_PASSWORD_MANAGER_UI_AUTOSIGNIN_TOGGLE_DESC 9754
#define IDS_PASSWORD_MANAGER_UI_PASSWORDS_DESCRIPTION 9755
#define IDS_PASSWORD_MANAGER_UI_ADD_PASSWORD_BUTTON 9756
#define IDS_PASSWORD_MANAGER_UI_ADD_SHORTCUT_TITLE 9757
#define IDS_PASSWORD_MANAGER_UI_ADD_SHORTCUT_DESCRIPTION 9758
#define IDS_PASSWORD_MANAGER_UI_TRUSTED_VAULT_OPT_IN_TITLE 9759
#define IDS_PASSWORD_MANAGER_UI_TRUSTED_VAULT_OPT_IN_DESCRIPTION 9760
#define IDS_PASSWORD_MANAGER_UI_TRUSTED_VAULT_OPTED_IN_TITLE 9761
#define IDS_PASSWORD_MANAGER_UI_TRUSTED_VAULT_OPTED_IN_DESCRIPTION 9762
#define IDS_PASSWORD_MANAGER_UI_SHARE 9763
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_ERROR_DESCRIPTION 9764
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_ERROR_TITLE 9765
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_LOADING_TITLE 9766
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_SUCCESS_TITLE 9767
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CANCELED_TITLE 9768
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_NOT_FAMILY_MEMBER 9769
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_NO_OTHER_FAMILY_MEMBERS 9770
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_FAMILY_PICKER_DESCRIPTION 9771
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CONFIRMATION_DESCRIPTION_SINGLE 9772
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CONFIRMATION_DESCRIPTION_MULTIPLE 9773
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CONFIRMATION_FOOTER_WEBSITE 9774
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CONFIRMATION_FOOTER_ANDROID_APP 9775
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_VIEW_FAMILY 9776
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_MEMBER_UNAVAILABLE 9777
#define IDS_PASSWORD_MANAGER_UI_SHARING_IS_MANAGED_BY_ADMIN 9778
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_NOT_AVAILABLE 9779
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_TRY_AGAIN 9780
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_GOT_IT 9781
#define IDS_PASSWORD_MANAGER_UI_SHARE_DIALOG_TITLE 9782
#define IDS_PASSWORD_MANAGER_UI_IMPORT_BANNER_TITLE 9783
#define IDS_PASSWORD_MANAGER_UI_IMPORT_DESCRIPTION_ACCOUNT_STORE_USERS 9784
#define IDS_PASSWORD_MANAGER_UI_IMPORT_DESCRIPTION_SYNCING_USERS 9785
#define IDS_PASSWORD_MANAGER_UI_IMPORT_DESCRIPTION_SIGNEDOUT_USERS 9786
#define IDS_PASSWORD_MANAGER_UI_STORE_PICKER_OPTION_DEVICE 9787
#define IDS_PASSWORD_MANAGER_UI_STORE_PICKER_OPTION_ACCOUNT 9788
#define IDS_PASSWORD_MANAGER_UI_IMPORT_STORE_PICKER_ACCESSIBLE_NAME 9789
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SELECT_FILE_DESCRIPTION 9790
#define IDS_PASSWORD_MANAGER_UI_SELECT_FILE 9791
#define IDS_PASSWORD_MANAGER_UI_IMPORT_MISSING_PASSWORD 9792
#define IDS_PASSWORD_MANAGER_UI_IMPORT_MISSING_URL 9793
#define IDS_PASSWORD_MANAGER_UI_IMPORT_INVALID_URL 9794
#define IDS_PASSWORD_MANAGER_UI_IMPORT_LONG_URL 9795
#define IDS_PASSWORD_MANAGER_UI_IMPORT_LONG_USERNAME 9796
#define IDS_PASSWORD_MANAGER_UI_IMPORT_LONG_PASSWORD 9797
#define IDS_PASSWORD_MANAGER_UI_IMPORT_LONG_NOTE 9798
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CONFLICT_ACCOUNT 9799
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CONFLICT_DEVICE 9800
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ERROR_UNKNOWN 9801
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ERROR_BAD_FORMAT 9802
#define IDS_PASSWORD_MANAGER_UI_IMPORT_FILE_SIZE_EXCEEDED 9803
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ERROR_LIMIT_EXCEEDED 9804
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ERROR_TITLE 9805
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SUCCESS_TITLE 9806
#define IDS_PASSWORD_MANAGER_UI_IMPORT_COMPLETE_TITLE 9807
#define IDS_PASSWORD_MANAGER_UI_IMPORT_DELETE_FILE_OPTION 9808
#define IDS_PASSWORD_MANAGER_UI_IMPORT_VIEW_PASSWORDS 9809
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ALREADY_ACTIVE 9810
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SUCCESS_TIP 9811
#define IDS_PASSWORD_MANAGER_UI_IMPORT_FAILURES_SUMMARY 9812
#define IDS_PASSWORD_MANAGER_UI_IMPORT_BAD_ROWS_FORMAT 9813
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SUCCESS_SUMMARY_ACCOUNT 9814
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SUCCESS_SUMMARY_DEVICE 9815
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CONFLICTS_TITLE 9816
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CONFLICTS_DESCRIPTION 9817
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CANCEL 9818
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SKIP 9819
#define IDS_PASSWORD_MANAGER_UI_IMPORT_REPLACE 9820
#define IDS_PASSWORD_MANAGER_UI_EXPORT_TITLE 9821
#define IDS_PASSWORD_MANAGER_UI_DOWNLOAD_FILE 9822
#define IDS_PASSWORD_MANAGER_UI_EXPORT_BANNER_DESCRIPTION 9823
#define IDS_PASSWORD_MANAGER_UI_EXPORT_SUCCESSFUL 9824
#define IDS_PASSWORD_MANAGER_UI_EXPORT_TRY_AGAIN 9825
#define IDS_PASSWORD_MANAGER_UI_EXPORTING_FAILURE_TITLE 9826
#define IDS_PASSWORD_MANAGER_UI_EXPORTING_FAILURE_TIPS 9827
#define IDS_PASSWORD_MANAGER_UI_EXPORTING_FAILURE_TIP_ENOUGH_SPACE 9828
#define IDS_PASSWORD_MANAGER_UI_EXPORTING_FAILURE_TIP_ANOTHER_FOLDER 9829
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_TITLE 9830
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_RESULT 9831
#define IDS_PASSWORD_MANAGER_UI_JUST_NOW 9832
#define IDS_PASSWORD_MANAGER_UI_COMPROMISED_PASSWORDS_COUNT 9833
#define IDS_PASSWORD_MANAGER_UI_NO_COMPROMISED_PASSWORDS 9834
#define IDS_PASSWORD_MANAGER_UI_HAS_COMPROMISED_PASSWORDS 9835
#define IDS_PASSWORD_MANAGER_UI_REUSED_PASSWORDS_COUNT 9836
#define IDS_PASSWORD_MANAGER_UI_NO_REUSED_PASSWORDS 9837
#define IDS_PASSWORD_MANAGER_UI_HAS_REUSED_PASSWORDS 9838
#define IDS_PASSWORD_MANAGER_UI_WEAK_PASSWORDS_COUNT 9839
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_GREEN_STATE_A11Y 9840
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_YELLOW_STATE_A11Y 9841
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_RED_STATE_A11Y 9842
#define IDS_PASSWORD_MANAGER_UI_NO_WEAK_PASSWORDS 9843
#define IDS_PASSWORD_MANAGER_UI_HAS_WEAK_PASSWORDS 9844
#define IDS_PASSWORD_MANAGER_UI_CHECK_PASSWORDS_AFTER_ERROR 9845
#define IDS_PASSWORD_MANAGER_UI_BLOCKED_SITES_TITLE 9846
#define IDS_PASSWORD_MANAGER_UI_BLOCKED_SITES_DESCRIPTION 9847
#define IDS_PASSWORD_MANAGER_UI_ALLOWED_ACTOR_LOGIN_SITES_TITLE 9848
#define IDS_PASSWORD_MANAGER_UI_ALLOWED_ACTOR_LOGIN_SITES_DESCRIPTION 9849
#define IDS_PASSWORD_MANAGER_UI_REMOVE_ACTOR_LOGIN_PERMISSION_DIALOG_TITLE 9850
#define IDS_PASSWORD_MANAGER_UI_REMOVE_ACTOR_LOGIN_PERMISSION_DIALOG_DESCRIPTION 9851
#define IDS_PASSWORD_MANAGER_UI_REMOVE_ACTOR_LOGIN_PERMISSION_DIALOG_CONFIRMATION 9852
#define IDS_PASSWORD_MANAGER_UI_NUMBER_OF_ACCOUNTS 9853
#define IDS_PASSWORD_MANAGER_UI_USERNAME_LABEL 9854
#define IDS_PASSWORD_MANAGER_UI_SITES_LABEL 9855
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_LABEL 9856
#define IDS_PASSWORD_MANAGER_UI_NOTE_LABEL 9857
#define IDS_PASSWORD_MANAGER_UI_NO_NOTE_ADDED 9858
#define IDS_PASSWORD_MANAGER_UI_COPY_PASSWORD 9859
#define IDS_PASSWORD_MANAGER_UI_COPY_USERNAME 9860
#define IDS_PASSWORD_MANAGER_UI_SHOW_PASSWORD 9861
#define IDS_PASSWORD_MANAGER_UI_HIDE_PASSWORD 9862
#define IDS_PASSWORD_MANAGER_UI_SHOW_PASSWORD_A11Y 9863
#define IDS_PASSWORD_MANAGER_UI_HIDE_PASSWORD_A11Y 9864
#define IDS_PASSWORD_MANAGER_UI_FEDERATION_LABEL 9865
#define IDS_PASSWORD_MANAGER_UI_USERNAME_COPIED_TO_CLIPBOARD 9866
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_COPIED_TO_CLIPBOARD 9867
#define IDS_PASSWORD_MANAGER_UI_ADD_PASSWORD 9868
#define IDS_PASSWORD_MANAGER_UI_WEBSITE_LABEL 9869
#define IDS_PASSWORD_MANAGER_UI_ADD_PASSWORD_FOOTNOTE 9870
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_LEAKED 9871
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_PHISHED 9872
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_PHISHED_AND_LEAKED 9873
#define IDS_PASSWORD_MANAGER_UI_CHANGE_PASSWORD_BUTTON 9874
#define IDS_PASSWORD_MANAGER_UI_CHANGE_PASSWORD_BUTTON_ARIA_DESCRIPTION 9875
#define IDS_PASSWORD_MANAGER_UI_MORE_ACTIONS 9876
#define IDS_PASSWORD_MANAGER_UI_MORE_ACTIONS_ARIA_DESCRIPTION 9877
#define IDS_PASSWORD_MANAGER_UI_COMPROMISED_PASSWORDS_DESCRIPTION 9878
#define IDS_PASSWORD_MANAGER_UI_REUSED_PASSWORDS_DESCRIPTION 9879
#define IDS_PASSWORD_MANAGER_UI_WEAK_PASSWORDS_DESCRIPTION 9880
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_SIGNED_OUT 9881
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_OFFLINE 9882
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_COMPROMISED_SECTION 9883
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_NO_PASSWORDS 9884
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_QUOTA_LIMIT 9885
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_OTHER_ERROR 9886
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_RUNNING_LABEL 9887
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_PROGRESS 9888
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_CANCELED 9889
#define IDS_PASSWORD_MANAGER_UI_MUTED_COMPROMISED_PASSWORDS 9890
#define IDS_PASSWORD_MANAGER_UI_MUTE_ISSUE 9891
#define IDS_PASSWORD_MANAGER_UI_UNMUTE_ISSUE 9892
#define IDS_PASSWORD_MANAGER_UI_NUMBER_OF_CREDENTIALS_WITH_REUSED_PASSWORD 9893
#define IDS_PASSWORD_MANAGER_UI_HELP 9894
#define IDS_PASSWORD_MANAGER_UI_EDIT_PASSWORD 9901
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_EDIT_FOOTNOTE 9902
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DELETED 9903
#define IDS_PASSWORD_MANAGER_UI_UNDO 9904
#define IDS_PASSWORD_MANAGER_UI_SEARCH_RESULT 9905
#define IDS_PASSWORD_MANAGER_UI_CHANGE_PASSWORD_IN_APP 9906
#define IDS_PASSWORD_MANAGER_UI_CHANGE_PASSWORD_MANAGER_PIN 9907
#define IDS_PASSWORD_MANAGER_UI_ALREADY_CHANGED_PASSWORD 9908
#define IDS_PASSWORD_MANAGER_UI_EDIT_DISCLAIMER_DESCRIPTION 9909
#define IDS_PASSWORD_MANAGER_UI_EDIT_DISCLAIMER_TITLE 9910
#define IDS_PASSWORD_MANAGER_UI_DELETE_PASSWORD_CONFIRMATION_TITLE 9911
#define IDS_PASSWORD_MANAGER_UI_DELETE_PASSWORD_CONFIRMATION_DESCRIPTION 9912
#define IDS_PASSWORD_MANAGER_UI_SHOW_MORE 9913
#define IDS_PASSWORD_MANAGER_UI_NOT_VALID_WEB_ADDRESS 9914
#define IDS_PASSWORD_MANAGER_UI_MISSING_TLD 9915
#define IDS_PASSWORD_MANAGER_UI_USERNAME_ALREADY_USED 9916
#define IDS_PASSWORD_MANAGER_UI_NOTE_CHARACTER_COUNT 9917
#define IDS_PASSWORD_MANAGER_UI_NOTE_CHARACTER_COUNT_WARNING 9918
#define IDS_PASSWORD_MANAGER_UI_AUTH_TIMED_OUT 9919
#define IDS_PASSWORD_MANAGER_UI_AUTH_TIMED_OUT_DESCRIPTION 9920
#define IDS_PASSWORD_MANAGER_UI_VIEW_EXISTING_PASSWORD 9921
#define IDS_PASSWORD_MANAGER_UI_VIEW_EXISTING_PASSWORD_ARIA_DESCRIPTION 9922
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_TO_ACCOUNT 9923
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_TO_ACCOUNT_DIALOG_DESCRIPTION 9924
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_TO_ACCOUNT_DIALOG_DESCRIPTION 9925
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_TO_ACCOUNT_DIALOG_PASSWORDS_TITLE 9926
#define IDS_PASSWORD_MANAGER_UI_OPENS_IN_NEW_TAB 9927
#define IDS_PASSWORD_MANAGER_UI_VIEW_PASSWORD_ARIA_DESCRIPTION 9928
#define IDS_PASSWORD_MANAGER_UI_RUN_CHECKUP_ARIA_DESCRIPTION 9929
#define IDS_PASSWORD_MANAGER_UI_REMOVE_BLOCKED_SITE_ARIA_DESCRIPTION 9930
#define IDS_PASSWORD_MANAGER_UI_EMPTY_STATE_ACCOUNT_STORE_USERS 9931
#define IDS_PASSWORD_MANAGER_UI_EMPTY_STATE_SYNCING_USERS 9932
#define IDS_PASSWORD_MANAGER_UI_EMPTY_STATE_SIGNEDOUT_USERS 9933
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_PROMO_CARD_TITLE 9934
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_PROMO_CARD_DESCRIPTION 9935
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_PROMO_CARD_ACTION 9936
#define IDS_PASSWORD_MANAGER_UI_WEB_PROMO_CARD_TITLE 9937
#define IDS_PASSWORD_MANAGER_UI_WEB_PROMO_CARD_DESCRIPTION 9938
#define IDS_PASSWORD_MANAGER_UI_SHORTCUT_PROMO_CARD_TITLE 9939
#define IDS_PASSWORD_MANAGER_UI_SHORTCUT_PROMO_CARD_DESCRIPTION 9940
#define IDS_PASSWORD_MANAGER_UI_ANY_DEVICE_PROMO_CARD_TITLE 9941
#define IDS_PASSWORD_MANAGER_UI_ANY_DEVICE_PROMO_CARD_DESCRIPTION 9942
#define IDS_PASSWORD_MANAGER_UI_ACCOUNT_STORAGE_TOGGLE_SUB_LABEL 9943
#define IDS_PASSWORD_MANAGER_UI_ACCOUNT_STORAGE_WITH_PASSKEYS_TOGGLE_LABEL 9944
#define IDS_PASSWORD_MANAGER_UI_DELETE_DIALOG_TITLE 9945
#define IDS_PASSWORD_MANAGER_UI_DELETE_DIALOG_BODY 9946
#define IDS_PASSWORD_MANAGER_UI_DELETE_DIALOG_FROM_ACCOUNT_CHECKBOX_LABEL 9947
#define IDS_PASSWORD_MANAGER_UI_DELETE_DIALOG_FROM_DEVICE_CHECKBOX_LABEL 9948
#define IDS_PASSWORD_MANAGER_UI_APPS_LABEL 9949
#define IDS_PASSWORD_MANAGER_UI_SITES_AND_APPS_LABEL 9950
#define IDS_PASSWORD_MANAGER_UI_BACK_TO_CHECKUP_ARIA_DESCRIPTION 9951
#define IDS_PASSWORD_MANAGER_UI_BACK_TO_PASSWORDS_ARIA_DESCRIPTION 9952
#define IDS_PASSWORD_MANAGER_UI_BACK_TO_PASSWORD_SETTINGS_ARIA_DESCRIPTION 9953
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_TITLE 9954
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_DESCRIPTION 9955
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_BUTTON 9956
#define IDS_PASSWORD_MANAGER_UI_NO_PASSWORDS_FOUND 9959
#define IDS_PASSWORD_MANAGER_UI_EDIT_PASSKEY 9960
#define IDS_PASSWORD_MANAGER_UI_DISPLAY_NAME_LABEL 9961
#define IDS_PASSWORD_MANAGER_UI_DISPLAY_NAME_PLACEHOLDER 9962
#define IDS_PASSWORD_MANAGER_UI_USERNAME_PLACEHOLDER 9963
#define IDS_PASSWORD_MANAGER_UI_DELETE_PASSKEY_CONFIRMATION_TITLE 9964
#define IDS_PASSWORD_MANAGER_UI_DELETE_PASSKEY_CONFIRMATION_DESCRIPTION 9965
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_HIDDEN_INFO_LABEL 9966
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_MANAGEMENT_INFO_LABEL 9967
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_UPGRADE_TOGGLE_LABEL 9968
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_UPGRADE_TOGGLE_SUBLABEL 9969
#define IDS_PASSKEYS_MANAGER_UI_UNENROLL_TITLE 9970
#define IDS_PASSKEYS_MANAGER_UI_UNENROLL_DESCRIPTION 9971
#define IDS_PASSKEYS_MANAGER_UI_UNENROLL_BUTTON 9972
#define IDS_PASSKEYS_MANAGER_UI_UNENROLL_TOAST_MESSAGE 9973
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_TITLE 9974
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DESCRIPTION 9975
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DELETE_ALL 9976
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_CONFIRM 9977
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_SUCCESS_TOAST 9978
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_CONFIRMATION_TITLE 9979
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_CONFIRMATION_TITLE_LOCAL 9980
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_CONFIRMATION_DESCIPTION 9981
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DOMAINS_DISPLAY_ONE 9982
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DOMAINS_DISPLAY_TWO 9983
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DOMAINS_DISPLAY_TWO_AND_X_MORE 9984
#define IDS_PASSWORD_MANAGER_PASSWORDS_COUNTER 9985
#define IDS_PASSWORD_MANAGER_PASSKEYS_COUNTER 9986
#define IDS_PASSWORD_MANAGER_UI_COPY_DISPLAY_NAME_LABEL 9987
#define IDS_PASSWORD_MANAGER_UI_DISPLAY_NAME_COPIED_TO_CLIPBOARD 9988
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DELETED 9989
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_LIST_ARIA_LABEL 9990
#define IDS_PASSWORD_MANAGER_UI_DEVICE_ONLY_PASSWORDS_ICON_TOOLTIP 9991
#define IDS_PASSWORD_MANAGER_UI_MOVE_TO_ACCOUNT_ICON_TOOLTIP 9992
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_ARIA_LABEL 9993
#define IDS_PASSWORD_MANAGER_UI_BACKUP_PASSWORD_DETAILS_CARD_ARIA_LABEL 9994
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_EDIT_BUTTON_ARIA_LABEL 9995
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_EDIT_BUTTON_NO_USERNAME_ARIA_LABEL 9996
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_DELETE_BUTTON_ARIA_LABEL 9997
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_DELETE_BUTTON_NO_USERNAME_ARIA_LABEL 9998
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_NO_USERNAME_ARIA_LABEL 9999
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_ARIA_LABEL 10000
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_EDIT_BUTTON_ARIA_LABEL 10001
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_EDIT_BUTTON_NO_USERNAME_ARIA_LABEL 10002
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_DELETE_BUTTON_ARIA_LABEL 10003
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_DELETE_BUTTON_NO_USERNAME_ARIA_LABEL 10004
#define IDS_PASSWORD_MANAGER_UI_FEDERATED_CREDENTIAL_ARIA_LABEL 10005
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_TO_ACCOUNT 10006
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_TITLE 10007
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_DESCRIPTION 10008
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_ACTION_BUTTON 10009
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_IN_SETTINGS_SUB_LABEL 10010
#define IDS_PASSWORD_MANAGER_UI_RELAUNCH_CHROME_PROMO_CARD_TITLE_LINUX 10013
#define IDS_PASSWORD_MANAGER_UI_RELAUNCH_CHROME_PROMO_CARD_DESCRIPTION_LINUX 10014
#define IDS_PASSWORD_MANAGER_UI_RELAUNCH_CHROME_PROMO_CARD_ACTION 10015
#define IDS_PASSWORD_MANAGER_UI_NO_USERNAME 10016
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_MOVED_TOAST_MESSAGE 10017
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_PROMO_CARD_TITLE 10018
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_PROMO_CARD_DESCRIPTION 10019
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_PROMO_CARD_ACTION_BUTTON 10020
#define IDS_PASSWORD_MANAGER_UI_BATCH_UPLOAD_PROMO_CARD_TITLE 10021
#define IDS_PASSWORD_MANAGER_UI_BATCH_UPLOAD_PROMO_CARD_ACTION_BUTTON 10022
#define IDS_PASSWORD_MANAGER_SAVE_IN_ACCOUNT_BUBBLE_DESCRIPTION 10023
#define IDS_PASSWORD_MANAGER_SAVE_IN_ACCOUNT_BUBBLE_TITLE 10024
#define IDS_PASSWORD_MANAGER_SAVE_IN_ACCOUNT_BUBBLE_SAVE_BUTTON 10025
#define IDS_PASSWORD_MANAGER_MANAGEMENT_BUBBLE_LIST_ITEM_DEVICE_ONLY_ACCESSIBLE_TEXT 10026
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_LIST_ITEM_ARIA_LABEL 10027
#define IDS_PASSWORD_MANAGER_UI_PROMO_CARD_ARIA_LABEL 10028
#define IDS_PASSWORD_MANAGER_UI_CLOSE_PROMO_CARD_BUTTON_ARIA_LABEL 10029
#define IDS_PASSWORD_MANAGER_PIN_CHANGED 10030
#define IDS_PASSWORD_MANAGER_UI_CONFIRM 10031
#define IDS_PASSWORD_MANAGER_UI_DISCONNECT_CLOUD_AUTHENTICATOR_DIALOG_TITLE 10032
#define IDS_PASSWORD_MANAGER_UI_DISCONNECT_CLOUD_AUTHENTICATOR_DIALOG_DESCRIPTION 10033
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_CANCEL 10034
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_CONTINUE 10035
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGED_TITLE 10036
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_FAILED_TITLE 10037
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_FAILED_BODY 10038
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_FAILED_ACCEPT_BUTTON 10039
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_OMNIBOX_SIGN_IN_CHECK 10040
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_OMNIBOX_CHANGING_PASSWORD 10041
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_TOAST_SIGN_IN_TO_CONTINUE 10042
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_CHANGE_PASSWORD 10043
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_TITLE 10044
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_DETAILS_WITHOUT_PRIVACY_NOTICE 10045
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_DETAILS_WITH_PRIVACY_NOTICE 10046
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_LINK_WITHOUT_PRIVACY_NOTICE 10047
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_LINK_WITH_PRIVACY_NOTICE 10048
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_PRIVACY_NOTICE 10049
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_SETTINGS_DESCRIPTION 10050
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_SETTINGS_TITLE 10051
#define IDS_SETTINGS_PASSWORD_CHANGE_SUBLABEL_WITH_LEARN_MORE 10052
#define IDS_PASSWORD_MANAGER_UI_OTP_DURING_PASSWORD_CHANGE_TITLE 10053
#define IDS_PASSWORD_MANAGER_UI_OTP_DURING_PASSWORD_CHANGE_BODY 10054
#define IDS_PASSWORD_MANAGER_UI_OTP_DURING_PASSWORD_CHANGE_ACTION 10055
#define IDS_PASSWORD_MANAGER_UI_BACKUP_PASSWORD_SETTINGS_DESCRIPTION 10056
#define IDS_PASSWORD_MANAGER_UI_BACKUP_PASSWORD_SETTINGS_DESCRIPTION_DETAILS 10057
#define IDS_PASSWORD_MANAGER_UI_OTP_DIALOG_TITLE 10058
#define IDS_PASSWORD_MANAGER_UI_OTP_DIALOG_DETAILS 10059
#define IDS_PASSWORD_MANAGER_UI_VIEW_DETAILS_BUTTON 10060
#define IDS_PASSWORD_MANAGER_UI_USER_INTERVENTION_NEEDED_TITLE 10061
#define IDS_PASSWORD_MANAGER_UI_USER_INTERVENTION_NEEDED_DIALOG_DETAILS 10062
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_TAKE_OVER_TASK_BUTTON 10063
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_UNCHANGED 10064
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_TOAST_RETRY_BUTTON 10065
#define IDS_UTILITY_PROCESS_PRINTING_SERVICE_NAME 10066
#define IDS_UTILITY_PROCESS_PRINT_BACKEND_SERVICE_NAME 10067
#define IDS_PRINT_INVALID_PRINTER_SETTINGS 10068
#define IDS_PRINT_PREVIEW_TITLE 10069
#define IDS_PRINT_PREVIEW_DESCRIPTION 10070
#define IDS_PRINT_PREVIEW_LOADING 10071
#define IDS_PRINT_PREVIEW_FAILED 10072
#define IDS_PRINT_PREVIEW_INVALID_PRINTER_SETTINGS 10073
#define IDS_PRINT_PREVIEW_PRINT_BUTTON 10074
#define IDS_PRINT_PREVIEW_SAVE_BUTTON 10075
#define IDS_PRINT_PREVIEW_PRINTING 10076
#define IDS_PRINT_PREVIEW_SAVING 10077
#define IDS_PRINT_PREVIEW_OPTION_ALL_PAGES 10078
#define IDS_PRINT_PREVIEW_OPTION_ODD_PAGES 10079
#define IDS_PRINT_PREVIEW_OPTION_EVEN_PAGES 10080
#define IDS_PRINT_PREVIEW_OPTION_CUSTOM_PAGES 10081
#define IDS_PRINT_PREVIEW_DESTINATION_LABEL 10082
#define IDS_PRINT_PREVIEW_OPTION_BW 10083
#define IDS_PRINT_PREVIEW_OPTION_COLLATE 10084
#define IDS_PRINT_PREVIEW_OPTION_COLOR 10085
#define IDS_PRINT_PREVIEW_OPTION_LANDSCAPE 10086
#define IDS_PRINT_PREVIEW_OPTION_PORTRAIT 10087
#define IDS_PRINT_PREVIEW_OPTION_TWO_SIDED 10088
#define IDS_PRINT_PREVIEW_PRINT_ON_BOTH_SIDES_LABEL 10089
#define IDS_PRINT_PREVIEW_OPTION_LONG_EDGE 10090
#define IDS_PRINT_PREVIEW_OPTION_SHORT_EDGE 10091
#define IDS_PRINT_PREVIEW_PAGES_LABEL 10092
#define IDS_PRINT_PREVIEW_LAYOUT_LABEL 10093
#define IDS_PRINT_PREVIEW_COPIES_LABEL 10094
#define IDS_PRINT_PREVIEW_SCALING_LABEL 10095
#define IDS_PRINT_PREVIEW_OPTION_DEFAULT_SCALING 10096
#define IDS_PRINT_PREVIEW_OPTION_CUSTOM_SCALING 10097
#define IDS_PRINT_PREVIEW_PAGES_PER_SHEET_LABEL 10098
#define IDS_PRINT_PREVIEW_EXAMPLE_PAGE_RANGE_TEXT 10099
#define IDS_PRINT_PREVIEW_PRINT_TO_PDF 10100
#define IDS_PRINT_PREVIEW_SHEET_SUMMARY_LABEL 10101
#define IDS_PRINT_PREVIEW_PAGE_SUMMARY_LABEL 10102
#define IDS_PRINT_PREVIEW_PAGE_RANGE_SYNTAX_INSTRUCTION 10103
#define IDS_PRINT_PREVIEW_PAGE_RANGE_LIMIT_INSTRUCTION_WITH_VALUE 10104
#define IDS_PRINT_PREVIEW_COPIES_INSTRUCTION 10105
#define IDS_PRINT_PREVIEW_SCALING_INSTRUCTION 10106
#define IDS_PRINT_PREVIEW_PRINT_PAGES_LABEL 10107
#define IDS_PRINT_PREVIEW_OPTIONS_LABEL 10108
#define IDS_PRINT_PREVIEW_OPTION_HEADER_FOOTER 10109
#define IDS_PRINT_PREVIEW_OPTION_FIT_TO_PAGE 10110
#define IDS_PRINT_PREVIEW_OPTION_FIT_TO_PAPER 10111
#define IDS_PRINT_PREVIEW_OPTION_ACTUAL_SIZE 10112
#define IDS_PRINT_PREVIEW_OPTION_BACKGROUND_COLORS_AND_IMAGES 10113
#define IDS_PRINT_PREVIEW_OPTION_SELECTION_ONLY 10114
#define IDS_PRINT_PREVIEW_OPTION_RASTERIZE 10115
#define IDS_PRINT_PREVIEW_MARGINS_LABEL 10116
#define IDS_PRINT_PREVIEW_DEFAULT_MARGINS 10117
#define IDS_PRINT_PREVIEW_NO_MARGINS 10118
#define IDS_PRINT_PREVIEW_CUSTOM_MARGINS 10119
#define IDS_PRINT_PREVIEW_MINIMUM_MARGINS 10120
#define IDS_PRINT_PREVIEW_TOP_MARGIN_LABEL 10121
#define IDS_PRINT_PREVIEW_BOTTOM_MARGIN_LABEL 10122
#define IDS_PRINT_PREVIEW_LEFT_MARGIN_LABEL 10123
#define IDS_PRINT_PREVIEW_RIGHT_MARGIN_LABEL 10124
#define IDS_PRINT_PREVIEW_MEDIA_SIZE_LABEL 10125
#define IDS_PRINT_PREVIEW_DPI_LABEL 10126
#define IDS_PRINT_PREVIEW_NON_ISOTROPIC_DPI_ITEM_LABEL 10127
#define IDS_PRINT_PREVIEW_DPI_ITEM_LABEL 10128
#define IDS_PRINT_PREVIEW_DESTINATION_SEARCH_TITLE 10129
#define IDS_PRINT_PREVIEW_SEARCH_BOX_PLACEHOLDER 10130
#define IDS_PRINT_PREVIEW_NO_DESTINATIONS_MESSAGE 10131
#define IDS_PRINT_PREVIEW_PRINT_DESTINATIONS_TITLE 10132
#define IDS_PRINT_PREVIEW_MANAGE 10133
#define IDS_PRINT_PREVIEW_SEE_MORE 10134
#define IDS_PRINT_PREVIEW_SEE_MORE_DESTINATIONS_LABEL 10135
#define IDS_PRINT_PREVIEW_EXTENSION_DESTINATION_ICON_TOOLTIP 10136
#define IDS_MORE_OPTIONS_LABEL 10137
#define IDS_PRINT_PREVIEW_COULD_NOT_PRINT 10138
#define IDS_PRINT_PREVIEW_ADVANCED_SETTINGS_SEARCH_BOX_PLACEHOLDER 10139
#define IDS_PRINT_PREVIEW_ADVANCED_SETTINGS_DIALOG_TITLE 10140
#define IDS_PRINT_PREVIEW_NO_ADVANCED_SETTINGS_MATCH_SEARCH_HINT 10141
#define IDS_PRINT_PREVIEW_ADVANCED_SETTINGS_DIALOG_CONFIRM 10142
#define IDS_PRINT_PREVIEW_NEW_SHOW_ADVANCED_OPTIONS 10143
#define IDS_PRINT_PREVIEW_BUTTON_SELECT 10144
#define IDS_PRINT_PREVIEW_BUTTON_GO_BACK 10145
#define IDS_PRINT_PREVIEW_RESOLVE_EXTENSION_USB_DIALOG_TITLE 10146
#define IDS_PRINT_PREVIEW_RESOLVE_EXTENSION_USB_PERMISSION_MESSAGE 10147
#define IDS_PRINT_PREVIEW_RESOLVE_EXTENSION_USB_ERROR_MESSAGE 10148
#define IDS_PRINT_PREVIEW_MANAGED_SETTINGS_TEXT 10149
#define IDS_PRINT_PREVIEW_SYSTEM_DIALOG_OPTION 10180
#define IDS_DEFAULT_PRINT_DOCUMENT_TITLE 10183
#define IDS_PRINT_SPOOL_FAILED_TITLE_TEXT 10184
#define IDS_PRINT_SPOOL_FAILED_ERROR_TEXT 10185
#define IDS_SKILL_SAVED_TOAST_BODY 10186
#define IDS_SKILL_DELETED_TOAST_BODY 10187
#define IDS_SKILL_UNDO_TOAST_BUTTON 10188
#define IDS_SKILL_CARD_ACTION_MENU_LABEL 10189
#define IDS_ADD_NEW_SKILL_LABEL 10190
#define IDS_SKILL_PAGE_TITLE 10191
#define IDS_SKILL_PAGE_SEARCH_BAR_PLACEHOLDER_TEXT 10192
#define IDS_SKILL_PAGE_MAIN_MENU 10193
#define IDS_SKILLS_SIDEBAR_FOOTER_TEXT 10194
#define IDS_SKILLS_SIDEBAR_FOOTER_BRANDING 10195
#define IDS_SKILLS_ERROR_PAGE_TITLE 10196
#define IDS_SKILLS_ERROR_PAGE_DESCRIPTION 10197
#define IDS_SKILLS_NO_SEARCH_RESULT_TITLE 10198
#define IDS_SKILLS_NO_SEARCH_RESULT_DESCRIPTION 10199
#define IDS_SKILL_PAGE_BROWSE_SKILLS_TITLE 10200
#define IDS_SKILL_PAGE_BROWSE_SKILLS_TOP_PICKS_TITLE 10201
#define IDS_SKILL_PAGE_FIRST_PARTY_ADD_SKILL_ERROR_TOAST 10202
#define IDS_SKILL_PAGE_EMPTY_STATE_TITLE 10203
#define IDS_SKILL_PAGE_EMPTY_STATE_DESCRIPTION 10204
#define IDS_SKILL_PAGE_USER_SKILLS_TITLE 10205
#define IDS_SKILL_PAGE_USER_SKILLS_DESCRIPTION 10206
#define IDS_SKILL_PAGE_USER_SKILLS_DELETE 10207
#define IDS_SKILL_PAGE_USER_SKILLS_COPY_INSTRUCTIONS 10208
#define IDS_SKILL_PAGE_INVALID_SKILL_TOAST 10209
#define IDS_SKILLS_DIALOG_ADD_SKILL_HEADER 10210
#define IDS_SKILLS_DIALOG_EDIT_SKILL_HEADER 10211
#define IDS_SKILLS_DIALOG_DESCRIPTION 10212
#define IDS_SKILLS_DIALOG_NAME_LABEL 10213
#define IDS_SKILLS_DIALOG_NAME_PLACEHOLDER 10214
#define IDS_SKILLS_DIALOG_CHOOSE_ICON_TOOLTIP 10215
#define IDS_SKILLS_DIALOG_INSTRUCTIONS_LABEL 10216
#define IDS_SKILLS_DIALOG_INSTRUCTIONS_PLACEHOLDER 10217
#define IDS_SKILLS_DIALOG_UNDO_TOOLTIP 10218
#define IDS_SKILLS_DIALOG_REDO_TOOLTIP 10219
#define IDS_SKILLS_DIALOG_REFINE_TOOLTIP 10220
#define IDS_SKILLS_DIALOG_REFINE_ERROR 10221
#define IDS_SKILLS_DIALOG_CHAR_LIMIT_ERROR 10222
#define IDS_SKILLS_DIALOG_ACCOUNT_INFO 10223
#define IDS_SKILLS_DIALOG_SAVE_ERROR 10224
#define IDS_SKILLS_EMOJI_PICKER_SEARCH_PLACEHOLDER 10225
#define IDS_SKILLS_EMOJI_PICKER_ARIA_LABEL 10226
#define IDS_VR_SHELL_SITE_IS_TRACKING_LOCATION 10227
#define IDS_VR_SHELL_SITE_IS_USING_MICROPHONE 10228
#define IDS_VR_SHELL_SITE_IS_USING_CAMERA 10229
#define IDS_VR_SHELL_SITE_IS_SHARING_SCREEN 10230
#define IDS_VR_SHELL_BG_IS_USING_MICROPHONE 10231
#define IDS_VR_SHELL_BG_IS_USING_CAMERA 10232
#define IDS_VR_SHELL_BG_IS_SHARING_SCREEN 10233
#define IDS_VR_SHELL_SITE_CAN_TRACK_LOCATION 10234
#define IDS_VR_SHELL_SITE_CAN_USE_MICROPHONE 10235
#define IDS_VR_SHELL_SITE_CAN_USE_CAMERA 10236
#define IDS_VR_SHELL_SITE_CAN_SHARE_SCREEN 10237
#define IDS_VR_SHELL_SITE_IS_USING_BLUETOOTH 10238
#define IDS_VR_SHELL_SITE_CAN_USE_BLUETOOTH 10240
#define IDS_DESKTOP_PROMPT_DOFF_HEADSET 10241
#define IDS_VR_DESKTOP_GENERIC_PERMISSION_PROMPT 10242
#define IDS_VR_SHELL_SITE_IS_USING_USB 10243
#define IDS_VR_SHELL_SITE_IS_USING_MIDI 10244
#define IDS_VR_SHELL_SITE_CAN_USE_MIDI 10245
#define IDS_VR_WEB_VR_TIMEOUT_MESSAGE 10246
#define IDS_WILDCARD 10247
#define IDS_BACKGROUND_CRASHED_APP_BALLOON_MESSAGE 10250
#define IDS_BACKGROUND_CRASHED_EXTENSION_BALLOON_MESSAGE 10251
#define IDS_BACKGROUND_APP_NOT_INSTALLED 10252
#define IDS_PERMISSIONS_REQUESTED_SCREENREADER_ANNOUNCEMENT 10253
#define IDS_PERMISSIONS_EXPIRED_SCREENREADER_ANNOUNCEMENT 10254
#define IDS_PERMISSIONS_BUBBLE_PROMPT 10255
#define IDS_PERMISSIONS_BUBBLE_PROMPT_ACCESSIBLE_TITLE_ONE_PERM 10256
#define IDS_PERMISSIONS_BUBBLE_PROMPT_ACCESSIBLE_TITLE_TWO_PERMS 10257
#define IDS_PERMISSIONS_BUBBLE_PROMPT_ACCESSIBLE_TITLE_TWO_PERMS_MORE 10258
#define IDS_PERMISSIONS_BUBBLE_PROMPT_THIS_FILE 10259
#define IDS_PERMISSION_CUSTOMIZE 10260
#define IDS_ALTERNATE_NAV_URL_VIEW_LABEL 10261
#define IDS_DOWNLOAD_HISTORY_TITLE 10262
#define IDS_TAB_LOADING_TITLE 10263
#define IDS_HOVER_CARD_FILE_URL_SOURCE 10264
#define IDS_HOVER_CARD_BLOB_URL_SOURCE 10265
#define IDS_HOVER_CARD_VIEW_SOURCE_URL_SOURCE 10266
#define IDS_HOVER_CARD_CRASHED_TITLE 10267
#define IDS_HISTORY_SEARCH_PROMPT 10268
#define IDS_HISTORY_DELETE 10269
#define IDS_HISTORY_OPEN 10270
#define IDS_HISTORY_ITEMS_SELECTED 10271
#define IDS_HISTORY_ITEMS_UNSELECTED 10272
#define IDS_HISTORY_HISTORY_MENU_DESCRIPTION 10273
#define IDS_HISTORY_NO_SYNCED_RESULTS 10274
#define IDS_HISTORY_OPEN_TABS_MENU_ITEM 10275
#define IDS_HISTORY_TURN_ON_SYNC_BUTTON 10276
#define IDS_HISTORY_TURN_ON_SYNC_PROMO 10277
#define IDS_HISTORY_TURN_ON_SYNC_PROMO_DESC 10278
#define IDS_HISTORY_SYNC_HISTORY_PROMO 10279
#define IDS_RECENT_TABS_SYNC_HISTORY_PROMO_BODY_SIGNED_OUT 10280
#define IDS_RECENT_TABS_SYNC_HISTORY_PROMO_BODY_PENDING_SIGN_IN 10281
#define IDS_RECENT_TABS_SYNC_HISTORY_PROMO_BODY_PENDING_SIGN_IN_SYNC_HISTORY_ON 10282
#define IDS_RECENT_TABS_SYNC_HISTORY_PROMO_BODY_SIGNED_IN_SYNC_OFF 10283
#define IDS_HISTORY_SYNC_HISTORY_BUTTON 10284
#define IDS_EDIT 10285
#define IDS_CLEAR_SEARCH 10286
#define IDS_CONFIRM 10287
#define IDS_DISABLE 10288
#define IDS_SEARCH_CLEARED 10289
#define IDS_SEARCH_RESULTS 10290
#define IDS_SEARCH_RESULTS_SINGULAR 10291
#define IDS_SEARCH_RESULTS_PLURAL 10292
#define IDS_SEARCH_RESULT_BUBBLE_TEXT 10293
#define IDS_SEARCH_RESULTS_BUBBLE_TEXT 10294
#define IDS_SEARCH_NO_RESULTS 10295
#define IDS_SHOW_BUBBLE_INACTIVE_DESCRIPTION 10296
#define IDS_FOCUS_HELP_BUBBLE_DESCRIPTION 10297
#define IDS_FOCUS_HELP_BUBBLE_TOGGLE_DESCRIPTION 10298
#define IDS_FOCUS_HELP_BUBBLE_TUTORIAL_DESCRIPTION 10299
#define IDS_CONTENT_CONTEXT_INSPECTELEMENT 10300
#define IDS_CONTENT_CONTEXT_INSPECTELEMENT_WITH_GEMINI 10301
#define IDS_CONTENT_CONTEXT_INSPECTELEMENT_WITH_DEVTOOLS 10302
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_DIALOG_TITLE 10303
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_BUBBLE_ENABLE 10304
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_BUBBLE_DISABLE 10305
#define IDS_CONTENT_CONTEXT_LIVE_CAPTION_ENABLE 10306
#define IDS_CONTENT_CONTEXT_LIVE_CAPTION_DISABLE 10307
#define IDS_CONTENT_CONTEXT_BACK 10308
#define IDS_CONTENT_CONTEXT_FORWARD 10309
#define IDS_CONTENT_CONTEXT_SAVEPAGEAS 10310
#define IDS_CONTENT_CONTEXT_PRINT 10311
#define IDS_CONTENT_CONTEXT_VIEWPAGESOURCE 10312
#define IDS_CONTENT_CONTEXT_OPENLINKWITH 10313
#define IDS_CONTENT_CONTEXT_OPENLINKWITH_CONFIGURE 10314
#define IDS_CONTENT_CONTEXT_INSPECTBACKGROUNDPAGE 10315
#define IDS_CONTENT_CONTEXT_READING_MODE 10316
#define IDS_CONTENT_CONTEXT_CLOSE_GLIC 10317
#define IDS_CONTENT_CONTEXT_ARCHIVE_GLIC 10318
#define IDS_CONTENT_CONTEXT_RELOAD 10319
#define IDS_CONTENT_CONTEXT_RESTART_APP 10320
#define IDS_CONTENT_CONTEXT_RELOAD_PACKAGED_APP 10321
#define IDS_CONTENT_CONTEXT_TRANSLATE 10322
#define IDS_CONTENT_CONTEXT_EXIT_FULLSCREEN 10323
#define IDS_CONTENT_CONTEXT_RELOADFRAME 10324
#define IDS_CONTENT_CONTEXT_VIEWFRAMESOURCE 10325
#define IDS_CONTENT_CONTEXT_OPENLINKNEWTAB 10326
#define IDS_CONTENT_CONTEXT_OPENLINKNEWWINDOW 10327
#define IDS_CONTENT_CONTEXT_OPENLINKOFFTHERECORD 10328
#define IDS_CONTENT_CONTEXT_OPENLINKSPLITVIEW 10329
#define IDS_CONTENT_CONTEXT_OPENLINKLEFTVIEW 10330
#define IDS_CONTENT_CONTEXT_OPENLINKRIGHTVIEW 10331
#define IDS_CONTENT_CONTEXT_OPENLINKINPROFILES 10332
#define IDS_CONTENT_CONTEXT_OPENLINKINPROFILE 10333
#define IDS_CONTENT_CONTEXT_OPENLINKBOOKMARKAPP 10334
#define IDS_CONTENT_CONTEXT_OPENLINKBOOKMARKAPP_SAMEAPP 10335
#define IDS_CONTENT_CONTEXT_OPENLINKWEBAPP_NEWTAB 10336
#define IDS_CONTENT_CONTEXT_OPENLINKPREVIEW 10337
#define IDS_CONTENT_CONTEXT_OPENLINKPREVIEW_TRIGGER_ALTCLICK 10338
#define IDS_CONTENT_CONTEXT_OPENLINKPREVIEW_TRIGGER_ALTHOVER 10339
#define IDS_CONTENT_CONTEXT_OPENLINKPREVIEW_TRIGGER_LONGPRESS 10340
#define IDS_CONTENT_CONTEXT_SAVELINKAS 10341
#define IDS_CONTENT_CONTEXT_COPYLINKLOCATION 10342
#define IDS_CONTENT_CONTEXT_COPYEMAILADDRESS 10343
#define IDS_CONTENT_CONTEXT_COPYLINKTEXT 10344
#define IDS_CONTENT_CONTEXT_COPYLINKTOTEXT 10345
#define IDS_CONTENT_CONTEXT_ADD_A_NOTE 10346
#define IDS_CONTENT_CONTEXT_REMOVELINKTOTEXT 10347
#define IDS_CONTENT_CONTEXT_RESHARELINKTOTEXT 10348
#define IDS_CONTENT_CONTEXT_SAVEIMAGEAS 10349
#define IDS_CONTENT_CONTEXT_COPYIMAGELOCATION 10350
#define IDS_CONTENT_CONTEXT_COPYIMAGE 10351
#define IDS_CONTENT_CONTEXT_OPENIMAGENEWTAB 10352
#define IDS_CONTENT_CONTEXT_OPEN_ORIGINAL_IMAGE_NEW_TAB 10353
#define IDS_CONTENT_CONTEXT_LOAD_IMAGE 10354
#define IDS_CONTENT_CONTEXT_LOOP 10355
#define IDS_CONTENT_CONTEXT_CONTROLS 10356
#define IDS_CONTENT_CONTEXT_ROTATECW 10357
#define IDS_CONTENT_CONTEXT_ROTATECCW 10358
#define IDS_CONTENT_CONTEXT_SAVEVIDEOFRAMEAS 10359
#define IDS_CONTENT_CONTEXT_SAVEVIDEOAS 10360
#define IDS_CONTENT_CONTEXT_COPYVIDEOLOCATION 10361
#define IDS_CONTENT_CONTEXT_COPYVIDEOFRAME 10362
#define IDS_CONTENT_CONTEXT_SEARCHFORVIDEOFRAME 10363
#define IDS_CONTENT_CONTEXT_OPENVIDEONEWTAB 10364
#define IDS_CONTENT_CONTEXT_SAVEAUDIOAS 10365
#define IDS_CONTENT_CONTEXT_COPYAUDIOLOCATION 10366
#define IDS_CONTENT_CONTEXT_OPENAUDIONEWTAB 10367
#define IDS_CONTENT_CONTEXT_PICTUREINPICTURE 10368
#define IDS_CONTENT_CONTEXT_UNDO 10369
#define IDS_CONTENT_CONTEXT_REDO 10370
#define IDS_CONTENT_CONTEXT_CUT 10371
#define IDS_CONTENT_CONTEXT_COPY 10372
#define IDS_CONTENT_CONTEXT_PASTE 10373
#define IDS_CONTENT_CONTEXT_PASTE_AND_MATCH_STYLE 10374
#define IDS_CONTENT_CONTEXT_ADD_TO_DICTIONARY 10375
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_MENU_OPTION 10376
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_SEND 10377
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_SEND_ONCE 10378
#define IDS_CONTENT_CONTEXT_RUN_LAYOUT_EXTRACTION 10379
#define IDS_CONTENT_CONTEXT_SPELLING_ASK_GOOGLE 10380
#define IDS_CONTENT_CONTEXT_SPELLING_BUBBLE_TITLE 10381
#define IDS_CONTENT_CONTEXT_SPELLING_BUBBLE_ENABLE 10382
#define IDS_CONTENT_CONTEXT_SPELLING_BUBBLE_DISABLE 10383
#define IDS_CONTENT_CONTEXT_SPELLING_CHECKING 10384
#define IDS_CONTENT_CONTEXT_SPELLING_NO_SUGGESTIONS_FROM_GOOGLE 10385
#define IDS_CONTENT_CONTEXT_SELECTALL 10386
#define IDS_CONTENT_CONTEXT_PARTIAL_TRANSLATE 10387
#define IDS_CONTENT_CONTEXT_SEARCHWEBFOR 10388
#define IDS_CONTENT_CONTEXT_SEARCHWEBFORNEWTAB 10389
#define IDS_CONTENT_CONTEXT_SEARCHWEBFORIMAGE 10390
#define IDS_CONTENT_CONTEXT_SEARCHLENSFORIMAGE 10391
#define IDS_CONTENT_CONTEXT_LENS_REGION_SEARCH_ALT1 10392
#define IDS_CONTENT_CONTEXT_LENS_REGION_SEARCH 10393
#define IDS_CONTENT_CONTEXT_GOTOURL 10394
#define IDS_CONTENT_CONTEXT_GENERATEPASSWORD 10395
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_USE_PASSKEY_FROM_ANOTHER_DEVICE 10396
#define IDS_CONTENT_CONTEXT_MORE_APPS 10397
#define IDS_CONTENT_CONTEXT_OPEN_WITH_APP 10398
#define IDS_CONTENT_CONTEXT_AUTOFILL_FEEDBACK 10399
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_AT_MEMORY 10400
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_SELECT_PASSWORD 10401
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_IMPORT_PASSWORDS 10402
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_SUGGEST_PASSWORD 10403
#define IDS_SHARE_MENU_TITLE 10406
#define IDS_CONTENT_CONTEXT_PLUGIN_RUN 10407
#define IDS_CONTENT_CONTEXT_PLUGIN_HIDE 10408
#define IDS_CONTENT_CONTEXT_ENABLE_FLASH 10409
#define IDS_CONTENT_CONTEXT_SPELLCHECK_MENU 10411
#define IDS_CONTENT_CONTEXT_LANGUAGE_SETTINGS 10410
#define IDS_CONTENT_CONTEXT_SPELLCHECK_MULTI_LINGUAL 10412
#define IDS_CONTENT_CONTEXT_CHECK_SPELLING_WHILE_TYPING 10413
#define IDS_PROFILE_ROW_VERIFY_MESSAGE 10414
#define IDS_ADDRESSES_AND_MORE_SUBMENU_OPTION 10415
#define IDS_YOUR_SAVED_INFO_CONTACT_INFO_SUBMENU_OPTION 10416
#define IDS_PASSWORDS_AND_AUTOFILL_MENU 10417
#define IDS_RELAUNCH_TO_UPDATE_ALT 10418
#define IDS_RELAUNCH_TO_UPDATE_ALT_MINOR_TEXT 10419
#define IDS_NEW_TAB 10420
#define IDS_NEW_INCOGNITO_TAB 10421
#define IDS_SHOW_AS_TAB 10422
#define IDS_NEW_WINDOW 10423
#define IDS_NEW_INCOGNITO_WINDOW 10424
#define IDS_PROFILE_ROW_SIGNED_IN_MESSAGE_WITH_EMAIL 10425
#define IDS_PROFILE_ROW_SIGNED_IN_MESSAGE 10426
#define IDS_PROFILE_ROW_SYNC_IS_ON 10427
#define IDS_PROFILE_ROW_TURN_ON_SYNC 10428
#define IDS_PROFILE_ROW_SYNC_ERROR_MESSAGE 10429
#define IDS_EDIT2 10430
#define IDS_CUT 10431
#define IDS_COPY 10432
#define IDS_PASTE 10433
#define IDS_DELETE 10434
#define IDS_FIND 10435
#define IDS_FIND_AND_EDIT_MENU 10436
#define IDS_PAYMENT_METHOD_SUBMENU_OPTION 10437
#define IDS_YOUR_SAVED_INFO_PAYMENTS_SUBMENU_OPTION 10438
#define IDS_SAVE_AND_SHARE_MENU 10439
#define IDS_CAST_SAVE_AND_SHARE_MENU 10440
#define IDS_SAVE_AND_SHARE_MENU_CAST 10441
#define IDS_SAVE_AND_SHARE_MENU_SAVE 10442
#define IDS_SAVE_AND_SHARE_MENU_SHARE 10443
#define IDS_SAVE_PAGE 10444
#define IDS_MORE_TOOLS_MENU 10445
#define IDS_ZOOM_MENU 10446
#define IDS_ZOOM_MENU2 10447
#define IDS_ZOOM_PLUS 10448
#define IDS_ZOOM_PLUS2 10449
#define IDS_ZOOM_NORMAL 10450
#define IDS_ZOOM_MINUS 10451
#define IDS_ZOOM_MINUS2 10452
#define IDS_COPY_URL 10453
#define IDS_OPEN_IN_APP_WINDOW 10454
#define IDS_MOVE_TAB_TO_NEW_WINDOW 10455
#define IDS_SEARCH_TABS 10456
#define IDS_CLOSE_PROFILE 10457
#define IDS_MANAGE_GOOGLE_ACCOUNT 10458
#define IDS_OPEN_GUEST_PROFILE 10459
#define IDS_ADD_NEW_PROFILE 10460
#define IDS_ACCNAME_ZOOM_PLUS2 10464
#define IDS_ACCNAME_ZOOM_MINUS2 10465
#define IDS_VIEW_SOURCE 10466
#define IDS_FEEDBACK 10467
#define IDS_DEV_TOOLS 10468
#define IDS_DEV_TOOLS_ELEMENTS 10469
#define IDS_DEV_TOOLS_CONSOLE 10470
#define IDS_DEV_TOOLS_DEVICES 10471
#define IDS_TASK_MANAGER 10472
#define IDS_TAKE_SCREENSHOT 10473
#define IDS_REPORT_UNSAFE_SITE 10474
#define IDS_RESTORE_ALL_TABS 10475
#define IDS_RESTORE_TAB 10476
#define IDS_REOPEN_WINDOW 10477
#define IDS_REOPEN_GROUP 10478
#define IDS_RESTORE_WINDOW 10479
#define IDS_RESTORE_GROUP 10480
#define IDS_NAME_WINDOW 10481
#define IDS_CHROMELABS 10482
#define IDS_PREFERENCES 10483
#define IDS_TOS_NOTIFICATION_TITLE 10485
#define IDS_TOS_NOTIFICATION_BODY_TEXT 10486
#define IDS_TOS_NOTIFICATION_ACK_BUTTON_TEXT 10487
#define IDS_TOS_NOTIFICATION_REVIEW_BUTTON_TEXT 10488
#define IDS_TOS_NOTIFICATION_LINK 10489
#define IDS_HELP_MENU 10490
#define IDS_MANAGED 10491
#define IDS_MANAGED_BY 10492
#define IDS_MANAGED_BY_PARENT 10493
#define IDS_PROFILE_MANAGED_BY 10494
#define IDS_BROWSER_PROFILE_MANAGED 10495
#define IDS_CHROME_WHATS_NEW 10496
#define IDS_IMPORT_SETTINGS_MENU_LABEL 10497
#define IDS_PROFILING_ENABLED 10498
#define IDS_FULLSCREEN 10499
#define IDS_CLEAR_BROWSING_DATA 10500
#define IDS_SHOW_DOWNLOADS 10501
#define IDS_FIND_EXTENSIONS 10502
#define IDS_SHOW_EXTENSIONS 10503
#define IDS_EXTENSIONS_SUBMENU 10504
#define IDS_EXTENSIONS_SUBMENU_MANAGE_EXTENSIONS_ITEM 10505
#define IDS_EXTENSIONS_SUBMENU_CHROME_WEBSTORE_ITEM 10506
#define IDS_SHOW_PERFORMANCE 10507
#define IDS_SHOW_SEARCH_COMPANION 10508
#define IDS_SHOW_TRANSLATE 10509
#define IDS_SETTINGS 10510
#define IDS_OPTIONS 10511
#define IDS_HELP_PAGE 10512
#define IDS_BETA_FORUM 10513
#define IDS_GET_HELP 10514
#define IDS_EXIT 10515
#define IDS_AUTOCOMPLETE_MATCH_DESCRIPTION_SEPARATOR 10516
#define IDS_MANAGE_SEARCH_ENGINES 10517
#define IDS_MANAGE_SEARCH_ENGINES_AND_SITE_SEARCH 10518
#define IDS_MANAGE_SEARCH_ENGINES_AND_SHORTCUTS 10519
#define IDS_SEARCH_ENGINES_EDITOR_KEYWORD_COLUMN 10520
#define IDS_SEARCH_ENGINES_EDITOR_DESCRIPTION_COLUMN 10521
#define IDS_SEARCH_ENGINES_EDITOR_DEFAULT_ENGINE 10522
#define IDS_DOWNLOAD_INTERRUPTED_STATUS 10523
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_ACCESS_DENIED 10524
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_ACCESS_DENIED 10525
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_PATH_TOO_LONG 10526
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_PATH_TOO_LONG 10527
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_DISK_FULL 10528
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_DISK_FULL 10529
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_FILE_TOO_LARGE 10530
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_FILE_TOO_LARGE 10531
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_TEMPORARY_PROBLEM 10532
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_TEMPORARY_PROBLEM 10533
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_VIRUS 10534
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_VIRUS 10535
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_BLOCKED 10536
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_LOCAL_DOWNLOAD_BLOCKED 10537
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_LOCAL_DOWNLOAD_BLOCKED_DOWNLOAD_UI 10538
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_BLOCKED 10539
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_CONTENT_LENGTH_MISMATCH 10540
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_CONTENT_LENGTH_MISMATCH 10541
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SECURITY_CHECK_FAILED 10542
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SECURITY_CHECK_FAILED 10543
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_FILE_TOO_SHORT 10544
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_FILE_TOO_SHORT 10545
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_FILE_SAME_AS_SOURCE 10546
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_FILE_SAME_AS_SOURCE 10547
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_NETWORK_TIMEOUT 10548
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_NETWORK_TIMEOUT 10549
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_NETWORK_DISCONNECTED 10550
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_NETWORK_DISCONNECTED 10551
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SERVER_DOWN 10552
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SERVER_DOWN 10553
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_NETWORK_ERROR 10554
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_NETWORK_ERROR 10555
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_NO_FILE 10556
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_NO_FILE 10557
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SERVER_PROBLEM 10558
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SERVER_PROBLEM 10559
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_WEB_DRIVE_ERROR 10560
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SHUTDOWN 10561
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SHUTDOWN 10562
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_CRASH 10563
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_CRASH 10564
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_UNAUTHORIZED 10565
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_UNAUTHORIZED 10566
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SERVER_CERT_PROBLEM 10567
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SERVER_CERT_PROBLEM 10568
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_FORBIDDEN 10569
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_FORBIDDEN 10570
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_UNREACHABLE 10571
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_UNREACHABLE 10572
#define IDS_DOWNLOAD_NOTIFICATION_LABEL_OPEN_WHEN_COMPLETE 10573
#define IDS_DOWNLOAD_NOTIFICATION_LABEL_OPEN 10574
#define IDS_DOWNLOAD_STATUS_STARTING 10575
#define IDS_DOWNLOAD_STATUS_IN_PROGRESS 10586
#define IDS_DOWNLOAD_STATUS_SIZES 10587
#define IDS_DOWNLOAD_STATUS_OPEN_IN 10588
#define IDS_DOWNLOAD_STATUS_OPEN_WHEN_COMPLETE 10589
#define IDS_DOWNLOAD_STATUS_IN_PROGRESS_SHORT 10590
#define IDS_DOWNLOAD_STATUS_CANCELLED 10591
#define IDS_DOWNLOAD_STATUS_REMOVED 10592
#define IDS_DOWNLOAD_STATUS_UPLOADING 10593
#define IDS_DOWNLOAD_STATUS_UPLOADED 10594
#define IDS_DOWNLOAD_STATUS_UPLOAD_INTERRUPTED 10595
#define IDS_DOWNLOAD_STATUS_INTERRUPTED 10596
#define IDS_DOWNLOAD_UNCONFIRMED_PREFIX 10597
#define IDS_PROMPT_DANGEROUS_DOWNLOAD 10598
#define IDS_PROMPT_DANGEROUS_DOWNLOAD_EXTENSION 10599
#define IDS_PROMPT_UNCOMMON_DOWNLOAD_CONTENT 10600
#define IDS_PROMPT_UNCOMMON_DOWNLOAD_CONTENT_IN_ADVANCED_PROTECTION 10601
#define IDS_PROMPT_DEEP_SCANNING_APP_DOWNLOAD 10602
#define IDS_PROMPT_CONFIRM_INSECURE_DOWNLOAD 10603
#define IDS_PROMPT_DOWNLOAD_BLOCKED_TOO_LARGE 10604
#define IDS_PROMPT_DOWNLOAD_BLOCKED_PASSWORD_PROTECTED 10605
#define IDS_PROMPT_DOWNLOAD_SENSITIVE_CONTENT_WARNING 10606
#define IDS_PROMPT_DOWNLOAD_SENSITIVE_CONTENT_BLOCKED 10607
#define IDS_PROMPT_DOWNLOAD_FORCED_SAVE_TO_CLOUD 10608
#define IDS_PROMPT_DOWNLOAD_BLOCKED_SCAN_FAILED 10609
#define IDS_PROMPT_DOWNLOAD_DEEP_SCANNED_OPENED_DANGEROUS 10610
#define IDS_PROMPT_DOWNLOAD_INSECURE_WARNING 10611
#define IDS_PROMPT_DOWNLOAD_INSECURE_BLOCKED 10612
#define IDS_PROMPT_APP_DEEP_SCANNING 10613
#define IDS_PROMPT_DEEP_SCANNING 10614
#define IDS_BLOCK_REASON_UNCOMMON_DOWNLOAD_IN_ADVANCED_PROTECTION 10615
#define IDS_BLOCK_REASON_DEEP_SCANNING_UPDATED 10616
#define IDS_BLOCK_REASON_DEEP_SCANNING_SECOND_UPDATED 10617
#define IDS_BLOCK_REASON_PROMPT_FOR_SCANNING_UPDATED 10618
#define IDS_BLOCK_REASON_PROMPT_FOR_LOCAL_PASSWORD_SCANNING 10619
#define IDS_DEEP_SCANNED_OPENED_DANGEROUS_DESCRIPTION 10620
#define IDS_BLOCK_REASON_SENSITIVE_CONTENT_WARNING 10621
#define IDS_SENSITIVE_CONTENT_BLOCKED_DESCRIPTION 10622
#define IDS_FORCED_SAVE_TO_CLOUD_DESCRIPTION 10623
#define IDS_BLOCKED_TOO_LARGE_DESCRIPTION 10624
#define IDS_BLOCKED_PASSWORD_PROTECTED_DESCRIPTION 10625
#define IDS_DEEP_SCANNED_FAILED_DESCRIPTION 10626
#define IDS_DOWNLOADS_TOAST_DELETED_FROM_HISTORY_STILL_ON_DEVICE 10627
#define IDS_DOWNLOADS_TOAST_DELETED_FROM_HISTORY 10628
#define IDS_DOWNLOADS_TOAST_COPIED_DOWNLOAD_LINK 10629
#define IDS_DOWNLOADS_TOAST_COPY_DOWNLOAD_LINK_FAILED 10630
#define IDS_DOWNLOADS_TOAST_COPIED_LINK 10631
#define IDS_EMAIL_VERIFIED 10632
#define IDS_CONFIRM_KEEP_DANGEROUS_DOWNLOAD_TITLE 10636
#define IDS_CONFIRM_DOWNLOAD 10637
#define IDS_CONTINUE_EXTENSION_DOWNLOAD 10638
#define IDS_DISCARD_DOWNLOAD 10639
#define IDS_OPEN_DOWNLOAD_NOW 10640
#define IDS_SCAN_DOWNLOAD 10641
#define IDS_REVIEW_DOWNLOAD 10642
#define IDS_OPEN_DOWNLOAD_ANYWAY 10643
#define IDS_DOWNLOAD_LINK_PAUSE 10644
#define IDS_DOWNLOAD_HISTORY_SEARCH 10645
#define IDS_DOWNLOAD_NO_DOWNLOADS 10646
#define IDS_DOWNLOAD_LINK_RESUME 10647
#define IDS_DOWNLOAD_LINK_CANCEL 10648
#define IDS_DOWNLOAD_LINK_RETRY 10649
#define IDS_DOWNLOAD_LINK_SHOW_IN_WEB_DRIVE 10650
#define IDS_DOWNLOAD_LINK_SHOW 10651
#define IDS_DOWNLOAD_TAB_CANCELLED 10652
#define IDS_DOWNLOAD_FILE_REMOVED 10653
#define IDS_DOWNLOAD_TAB_PROGRESS_STATUS_TIME_UNKNOWN 10654
#define IDS_DOWNLOAD_TAB_PROGRESS_STATUS 10655
#define IDS_DOWNLOAD_TAB_PROGRESS_SIZE 10656
#define IDS_DOWNLOAD_PROGRESS_PAUSED 10657
#define IDS_DOWNLOAD_LINK_CLEAR_ALL 10658
#define IDS_DOWNLOAD_LINK_OPEN_DOWNLOADS_FOLDER 10659
#define IDS_DOWNLOAD_MORE_ACTIONS 10660
#define IDS_DOWNLOAD_ACTION_MENU_DESCRIPTION 10661
#define IDS_DOWNLOAD_BY_EXTENSION_URL 10662
#define IDS_DOWNLOADS_PAGE_INITIATOR_LINE 10663
#define IDS_DOWNLOAD_IN_INCOGNITO 10664
#define IDS_UNDO_DESCRIPTION 10665
#define IDS_DOWNLOAD_UNDO 10666
#define IDS_DOWNLOAD_TOAST_CLEARED_ALL 10667
#define IDS_DOWNLOAD_DEEP_SCAN 10668
#define IDS_DOWNLOAD_DEEP_SCAN_UPDATED 10669
#define IDS_DOWNLOAD_BYPASS_DEEP_SCAN 10670
#define IDS_DOWNLOAD_LOCAL_PASSWORD_SCAN 10671
#define IDS_DOWNLOAD_KEEP_DANGEROUS_FILE 10672
#define IDS_DOWNLOAD_KEEP_SUSPICIOUS_FILE 10673
#define IDS_DOWNLOAD_KEEP_UNVERIFIED_FILE 10674
#define IDS_DOWNLOAD_KEEP_INSECURE_FILE 10675
#define IDS_DOWNLOAD_DELETE_FROM_HISTORY 10676
#define IDS_DOWNLOAD_COPY_DOWNLOAD_LINK 10677
#define IDS_DOWNLOAD_DANGEROUS_ICON_ACCESSIBLE_LABEL 10678
#define IDS_DOWNLOAD_SUSPICIOUS_ICON_ACCESSIBLE_LABEL 10679
#define IDS_DOWNLOAD_INSECURE_ICON_ACCESSIBLE_LABEL 10680
#define IDS_DOWNLOAD_UNVERIFIED_ICON_ACCESSIBLE_LABEL 10681
#define IDS_DOWNLOAD_SCREENREADER_SAVED_DANGEROUS 10682
#define IDS_DOWNLOAD_SCREENREADER_SAVED_SUSPICIOUS 10683
#define IDS_DOWNLOAD_SCREENREADER_SAVED_INSECURE 10684
#define IDS_DOWNLOAD_SCREENREADER_SAVED_UNVERIFIED 10685
#define IDS_DOWNLOAD_SCREENREADER_PAUSED 10686
#define IDS_DOWNLOAD_SCREENREADER_RESUMED 10687
#define IDS_DOWNLOAD_SCREENREADER_CANCELED 10688
#define IDS_DOWNLOAD_WARNING_BYPASS_DIALOG_TITLE 10689
#define IDS_DOWNLOAD_WARNING_BYPASS_PROMPT_DESCRIPTION 10690
#define IDS_DOWNLOAD_STATUS_IN_PROGRESS_ACCESSIBLE_ALERT 10691
#define IDS_DOWNLOAD_STATUS_PERCENT_COMPLETE_ACCESSIBLE_ALERT 10692
#define IDS_DOWNLOAD_STATUS_TIME_REMAINING_ACCESSIBLE_ALERT 10693
#define IDS_DOWNLOAD_FAILED_ACCESSIBLE_ALERT 10694
#define IDS_DOWNLOAD_CANCELLED_ACCESSIBLE_ALERT 10695
#define IDS_DOWNLOAD_COMPLETE_ACCESSIBLE_ALERT 10696
#define IDS_DOWNLOAD_PAUSED_ACCESSIBLE_ALERT 10697
#define IDS_PROMPT_DEEP_SCANNING_ACCESSIBLE_ALERT 10698
#define IDS_DEEP_SCANNING_ACCESSIBLE_ALERT 10699
#define IDS_PROMPT_DOWNLOAD_INSECURE_BLOCKED_ACCESSIBLE_ALERT 10700
#define IDS_DOWNLOAD_NOTIFICATION_COPY_TO_CLIPBOARD 10701
#define IDS_DOWNLOAD_MENU_SHOW 10702
#define IDS_DOWNLOAD_MENU_OPEN_WHEN_COMPLETE 10703
#define IDS_DOWNLOAD_MENU_OPEN 10704
#define IDS_DOWNLOAD_MENU_ALWAYS_OPEN_TYPE 10705
#define IDS_DOWNLOAD_MENU_PLATFORM_OPEN 10706
#define IDS_DOWNLOAD_MENU_PLATFORM_OPEN_ALWAYS 10707
#define IDS_DOWNLOAD_MENU_CANCEL 10708
#define IDS_DOWNLOAD_MENU_PAUSE_ITEM 10709
#define IDS_DOWNLOAD_MENU_RESUME_ITEM 10710
#define IDS_DOWNLOAD_MENU_DISCARD 10711
#define IDS_DOWNLOAD_MENU_KEEP 10712
#define IDS_DOWNLOAD_MENU_LEARN_MORE_SCANNING 10713
#define IDS_DOWNLOAD_MENU_LEARN_MORE_INTERRUPTED 10714
#define IDS_DOWNLOAD_MENU_LEARN_MORE_INSECURE 10715
#define IDS_DOWNLOAD_MENU_DEEP_SCAN 10716
#define IDS_ABANDON_DOWNLOAD_DIALOG_TITLE 10727
#define IDS_ABANDON_DOWNLOAD_DIALOG_CONTINUE_BUTTON 10728
#define IDS_ABANDON_DOWNLOAD_DIALOG_INCOGNITO_MESSAGE 10729
#define IDS_ABANDON_DOWNLOAD_DIALOG_GUEST_MESSAGE 10730
#define IDS_ABANDON_DOWNLOAD_DIALOG_EXIT_BUTTON 10731
#define IDS_DOWNLOAD_BUBBLE_HEADER_LABEL 10732
#define IDS_DOWNLOAD_BUBBLE_FOOTER_LABEL 10733
#define IDS_DOWNLOAD_BUBBLE_FOOTER_TOOLTIP_LABEL 10734
#define IDS_DOWNLOAD_BUBBLE_ESB_PROMO 10735
#define IDS_DOWNLOAD_BUBBLE_ESB_PROMO_CUSTOM_ACTION 10736
#define IDS_DOWNLOAD_BUBBLE_ESB_PROMO_DISMISS 10737
#define IDS_DOWNLOAD_BUBBLE_ESB_PROMO_TITLE 10738
#define IDS_DOWNLOAD_BUBBLE_DOWNLOAD_STATUS_MESSAGE_WITH_SEPARATOR 10739
#define IDS_DOWNLOAD_BUBBLE_DOWNLOAD_STATUS_WITH_SYMBOL 10740
#define IDS_DOWNLOAD_BUBBLE_STATUS_RESUMING 10741
#define IDS_DOWNLOAD_BUBBLE_STATUS_DONE 10742
#define IDS_DOWNLOAD_BUBBLE_STATUS_DEEP_SCANNING_DONE_UPDATED 10743
#define IDS_DOWNLOAD_BUBBLE_STATUS_WARNING_INSECURE 10744
#define IDS_DOWNLOAD_BUBBLE_STATUS_WARNING_SUSPICIOUS 10745
#define IDS_DOWNLOAD_BUBBLE_STATUS_WARNING_DANGEROUS 10746
#define IDS_DOWNLOAD_BUBBLE_STATUS_WARNING_UNVERIFIED 10747
#define IDS_DOWNLOAD_BUBBLE_STATUS_BLOCKED 10748
#define IDS_DOWNLOAD_BUBBLE_STATUS_MALWARE 10749
#define IDS_DOWNLOAD_BUBBLE_STATUS_SUSPICIOUS 10750
#define IDS_DOWNLOAD_BUBBLE_STATUS_DEEP_SCANNED_FAILED_UPDATED 10751
#define IDS_DOWNLOAD_BUBBLE_CHECKBOX_BYPASS 10752
#define IDS_DOWNLOAD_BUBBLE_CONTINUE 10753
#define IDS_DOWNLOAD_BUBBLE_CONTINUE_INSECURE_FILE 10754
#define IDS_DOWNLOAD_BUBBLE_CONTINUE_SUSPICIOUS_FILE 10755
#define IDS_DOWNLOAD_BUBBLE_CONTINUE_UNVERIFIED_FILE 10756
#define IDS_DOWNLOAD_BUBBLE_DELETE 10757
#define IDS_DOWNLOAD_BUBBLE_DELETE_FROM_HISTORY 10758
#define IDS_DOWNLOAD_BUBBLE_MAIN_BUTTON_SUBPAGE 10759
#define IDS_DOWNLOAD_BUBBLE_RESUME 10760
#define IDS_DOWNLOAD_BUBBLE_SCAN 10761
#define IDS_DOWNLOAD_BUBBLE_OPEN 10762
#define IDS_DOWNLOAD_BUBBLE_SCAN_UPDATED 10763
#define IDS_DOWNLOAD_BUBBLE_OPEN_UPDATED 10764
#define IDS_DOWNLOAD_BUBBLE_OPEN_NOW 10765
#define IDS_DOWNLOAD_BUBBLE_REVIEW 10766
#define IDS_DOWNLOAD_BUBBLE_RETRY 10767
#define IDS_DOWNLOAD_BUBBLE_OPEN_ANYWAY 10768
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_DISK_FULL 10769
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_DISK_FULL 10770
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_PATH_TOO_LONG 10771
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_PATH_TOO_LONG 10772
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_NEEDS_PERMISSION 10773
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_FILE_TOO_LARGE 10774
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_FILE_TOO_LARGE 10775
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_UNFINISHED 10776
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_BLOCKED_ORGANIZATION 10777
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_WRONG 10778
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_NETWORK_ERROR 10779
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_SITE_UNAVAILABLE 10780
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_FILE_UNAVAILABLE 10781
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_FILE_UNAVAILABLE 10782
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_FILE_UNFINISHED 10783
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_INSECURE 10784
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_DANGEROUS 10785
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_DECEPTIVE 10786
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_DANGEROUS_FILE_TYPE 10787
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_UNCOMMON_FILE 10788
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_NO_SAFE_BROWSING 10789
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_SAFE_BROWSING_SETTING_LABEL 10790
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_SAFE_BROWSING_SETTING_LINK 10791
#define IDS_DOWNLOAD_BUBBLE_STATUS_DANGEROUS 10792
#define IDS_DOWNLOAD_BUBBLE_STATUS_ENCRYPTED 10793
#define IDS_DOWNLOAD_BUBBLE_STATUS_TOO_BIG 10794
#define IDS_DOWNLOAD_BUBBLE_STATUS_ADVANCED_PROTECTION 10795
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ADVANCED_PROTECTION 10796
#define IDS_DOWNLOAD_BUBBLE_STATUS_UNCOMMON_FILE 10797
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_UNCOMMON_FILE 10798
#define IDS_DOWNLOAD_BUBBLE_STATUS_UNKNOWN_SOURCE 10799
#define IDS_DOWNLOAD_BUBBLE_STATUS_SENSITIVE_CONTENT 10800
#define IDS_DOWNLOAD_BUBBLE_STATUS_SCAN_FAILED 10801
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_SENSITIVE_CONTENT_WARNING 10802
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_SENSITIVE_CONTENT_BLOCK 10803
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ENCRYPTED 10804
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_TOO_BIG 10805
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING 10806
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING_SECONDARY 10807
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING_ENTERPRISE_SECONDARY 10808
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING_DISCARD 10809
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING_CANCEL 10810
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_SCAN_FAILED 10811
#define IDS_DOWNLOAD_BUBBLE_TRY_AGAIN 10812
#define IDS_DOWNLOAD_BUBBLE_STATUS_ASYNC_SCANNING_ENTERPRISE 10813
#define IDS_DOWNLOAD_BUBBLE_INCOGNITO_INFORMATION_ROW 10814
#define IDS_DOWNLOAD_BUBBLE_RESUME_QUICK_ACTION 10815
#define IDS_DOWNLOAD_BUBBLE_RESUME_QUICK_ACTION_ACCESSIBILITY 10816
#define IDS_DOWNLOAD_BUBBLE_PAUSE_QUICK_ACTION 10817
#define IDS_DOWNLOAD_BUBBLE_PAUSE_QUICK_ACTION_ACCESSIBILITY 10818
#define IDS_DOWNLOAD_BUBBLE_CANCEL_QUICK_ACTION 10819
#define IDS_DOWNLOAD_BUBBLE_CANCEL_QUICK_ACTION_ACCESSIBILITY 10820
#define IDS_DOWNLOAD_BUBBLE_OPEN_QUICK_ACTION 10821
#define IDS_DOWNLOAD_BUBBLE_OPEN_QUICK_ACTION_ACCESSIBILITY 10822
#define IDS_DOWNLOAD_BUBBLE_SHOW_IN_FOLDER_QUICK_ACTION 10823
#define IDS_DOWNLOAD_BUBBLE_SHOW_IN_FOLDER_QUICK_ACTION_ACCESSIBILITY 10824
#define IDS_DOWNLOAD_BUBBLE_BACK_RECENT_DOWNLOADS 10825
#define IDS_DOWNLOAD_BUBBLE_CANCEL_MAIN_BUTTON_ACCESSIBILITY 10826
#define IDS_DOWNLOAD_BUBBLE_DELETE_MAIN_BUTTON_ACCESSIBILITY 10827
#define IDS_DOWNLOAD_BUBBLE_KEEP_MAIN_BUTTON_ACCESSIBILITY 10828
#define IDS_DOWNLOAD_BUBBLE_SCAN_MAIN_BUTTON_ACCESSIBILITY 10829
#define IDS_DOWNLOAD_BUBBLE_OPEN_NOW_MAIN_BUTTON_ACCESSIBILITY 10830
#define IDS_DOWNLOAD_BUBBLE_RESUME_MAIN_BUTTON_ACCESSIBILITY 10831
#define IDS_DOWNLOAD_BUBBLE_REVIEW_MAIN_BUTTON_ACCESSIBILITY 10832
#define IDS_DOWNLOAD_BUBBLE_RETRY_MAIN_BUTTON_ACCESSIBILITY 10833
#define IDS_DOWNLOAD_BUBBLE_OPEN_MAIN_BUTTON_ACCESSIBILITY 10834
#define IDS_DOWNLOAD_BUBBLE_SUPPRESS_PARTIAL_VIEW 10835
#define IDS_DOWNLOAD_BUBBLE_SUPPRESS_PARTIAL_VIEW_SETTINGS_REMINDER 10836
#define IDS_DOWNLOAD_BUBBLE_SUPPRESS_PARTIAL_VIEW_SETTINGS_LINK 10837
#define IDS_DOWNLOAD_BUBBLE_TOOLTIP_IN_PROGRESS_COUNT 10838
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_COOKIE_THEFT 10841
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_ARCHIVE_MALWARE 10842
#define IDS_DOWNLOAD_BUBBLE_STATUS_DEEP_SCANNING_PROMPT_UPDATED 10843
#define IDS_DOWNLOAD_BUBBLE_STATUS_ASYNC_SCANNING 10844
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_DEEP_SCANNING_PROMPT_UPDATED 10845
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_DEEP_SCANNING_PROMPT_ENCRYPTED_ARCHIVE 10846
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_DEEP_SCANNING_LINK 10847
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT 10848
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_EMPTY 10849
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_INVALID 10850
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_ACCESSIBLE_ALERT 10851
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_ACCESSIBLE_ALERT_EMPTY 10852
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_ACCESSIBLE_ALERT_INVALID 10853
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_IMMEDIATE_DEEP_SCAN_IN_PROGRESS 10854
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_IMMEDIATE_DEEP_SCAN_CANCEL 10855
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_IMMEDIATE_DEEP_SCAN_BYPASS 10856
#define IDS_DOWNLOAD_BUBBLE_STATUS_LOCAL_DECRYPTION_STATUS 10857
#define IDS_DOWNLOAD_BUBBLE_STATUS_PASSWORD_NEEDED 10858
#define IDS_DOWNLOAD_BUBBLE_ACCEPT_LOCAL_DECRYPTION 10859
#define IDS_DOWNLOAD_BUBBLE_BYPASS_LOCAL_DECRYPTION 10860
#define IDS_DOWNLOAD_BUBBLE_LOCAL_DECRYPTION_CANCEL 10861
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_LOCAL_DECRYPTION_IN_PROGRESS 10862
#define IDS_DOWNLOAD_BUBBLE_STATUS_LOCAL_DECRYPTING 10863
#define IDS_DOWNLOAD_LOCAL_DECRYPTION_PROMPT_ALERT 10864
#define IDS_WEB_APP_WITH_APP_TITLE 10865
#define IDS_OMNIBOX_PWA_INSTALL_ICON_LABEL 10866
#define IDS_OMNIBOX_PWA_INSTALL_ICON_TOOLTIP 10867
#define IDS_WEBAPP_UPDATE_REVIEW_ACCEPT_BUTTON 10868
#define IDS_WEBAPP_UPDATE_REVIEW_UNINSTALL_BUTTON 10869
#define IDS_WEBAPP_UPDATE_REVIEW_IGNORE_BUTTON 10870
#define IDS_WEBAPP_UPDATE_REVIEW_ACCEPT_BUTTON_MIGRATION 10871
#define IDS_ADD_TO_OS_LAUNCH_SURFACE_BUBBLE_TITLE 10872
#define IDS_CREATE_SHORTCUTS_BUTTON_LABEL 10873
#define IDS_CREATE_SHORTCUT_NOT_APPS_DIALOG_TITLE 10874
#define IDS_CREATE_SHORTCUT_NOT_APPS_AX_BUBBLE_LABEL 10875
#define IDS_INSTALL_TO_OS_LAUNCH_SURFACE_BUBBLE_TITLE 10876
#define IDS_INSTALL_PWA_BUTTON_LABEL 10877
#define IDS_INSTALL_PWA_DIALOG_TITLE 10878
#define IDS_WEB_APP_DETAILED_INSTALL_DIALOG_DESCRIPTION_TITLE 10879
#define IDS_DIY_APP_INSTALL_DIALOG_TITLE 10880
#define IDS_DIY_APP_INSTALL_DIALOG_SUBTITLE 10881
#define IDS_DIY_APP_AX_BUBBLE_NAME_LABEL 10882
#define IDS_INSTALL_PWA_DIALOG_ORIGIN_LABEL 10883
#define IDS_BOOKMARK_APP_AX_BUBBLE_NAME_LABEL 10884
#define IDS_BOOKMARK_APP_BUBBLE_OPEN_AS_TAB 10885
#define IDS_BOOKMARK_APP_BUBBLE_OPEN_AS_WINDOW 10886
#define IDS_BOOKMARK_APP_BUBBLE_OPEN_AS_TABBED_WINDOW 10887
#define IDS_WEB_APP_INSTALL_NOT_SUPPORTED_DIALOG_TITLE_INCOGNITO_MODE 10888
#define IDS_WEB_APP_INSTALL_NOT_SUPPORTED_DIALOG_TITLE_GUEST_MODE 10889
#define IDS_WEB_APP_INSTALL_NOT_SUPPORTED_DIALOG_TITLE_POLICY_MODE 10890
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME 10891
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_ICON 10892
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME_AND_ICON 10893
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_LOGO 10894
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME_AND_LOGO 10895
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_URL 10896
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_URL_FORCED_MIGRATION 10897
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME_AND_URL 10898
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_LOGO_AND_URL 10899
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME_AND_LOGO_AND_URL 10900
#define IDS_WEBAPP_UPDATE_NEW_EXPLANATION 10901
#define IDS_WEBAPP_UPDATE_URL_ONLY_NEW_EXPLANATION 10902
#define IDS_WEBAPP_UPDATE_EXPLANATION 10903
#define IDS_WEBAPP_UPDATE_CURRENT_ICON 10904
#define IDS_WEBAPP_UPDATE_NEW_ICON 10905
#define IDS_WEBAPP_UPDATE_NEGATIVE_BUTTON 10906
#define IDS_FINISH_POLICY_WEB_APP_INSTALLATION 10907
#define IDS_FINISH_POLICY_WEB_APP_INSTALATION_RESTART 10908
#define IDS_FINISH_POLICY_WEB_APP_INSTALLATION_NOT_NOW 10909
#define IDS_ADD_TO_OS_LAUNCH_SURFACE 10914
#define IDS_INSTALL_TO_OS_LAUNCH_SURFACE 10915
#define IDS_INSTALL_DIY_TO_OS_LAUNCH_SURFACE 10916
#define IDS_UNINSTALL_FROM_OS_LAUNCH_SURFACE 10917
#define IDS_REVIEW_APP_UPDATE 10918
#define IDS_APPLICATION_INFO_WEB_STORE_LINK 10919
#define IDS_APPLICATION_INFO_HOMEPAGE_LINK 10920
#define IDS_ARC_APPLICATION_INFO_MANAGE_LINK 10921
#define IDS_APPLICATION_INFO_APP_OVERVIEW_TITLE 10922
#define IDS_APPLICATION_INFO_APP_PERMISSIONS_TITLE 10923
#define IDS_APPLICATION_INFO_UNINSTALL_BUTTON_TEXT 10924
#define IDS_APPLICATION_INFO_LICENSES_BUTTON_TEXT 10925
#define IDS_APPLICATION_INFO_SIZE_LABEL 10926
#define IDS_APPLICATION_INFO_VERSION_LABEL 10927
#define IDS_APPLICATION_INFO_CREATE_SHORTCUTS_BUTTON_TEXT 10928
#define IDS_APPLICATION_INFO_LAUNCH_OPTIONS_ACCNAME 10929
#define IDS_APPLICATION_INFO_SIZE_LOADING_LABEL 10930
#define IDS_APPLICATION_INFO_SIZE_SMALL_LABEL 10931
#define IDS_APPLICATION_INFO_REVOKE_PERMISSION_ALT_TEXT 10932
#define IDS_APPLICATION_INFO_APP_NO_PERMISSIONS_TEXT 10933
#define IDS_APPLICATION_INFO_EXTENSION_NO_PERMISSIONS_TEXT 10934
#define IDS_APPLICATION_INFO_RETAINED_FILES 10935
#define IDS_APPLICATION_INFO_RETAINED_DEVICES 10936
#define IDS_CREATE_SHORTCUTS_TITLE 10937
#define IDS_CREATE_SHORTCUTS_LABEL 10938
#define IDS_CREATE_SHORTCUTS_DESKTOP_CHKBOX 10939
#define IDS_CREATE_SHORTCUTS_MENU_CHKBOX 10940
#define IDS_CREATE_SHORTCUTS_COMMIT 10941
#define IDS_BLUETOOTH_DEVICE_CREDENTIALS_TITLE 10944
#define IDS_BLUETOOTH_DEVICE_CREDENTIALS_LABEL 10945
#define IDS_BLUETOOTH_DEVICE_PAIR_CONFIRM_TITLE 10946
#define IDS_BLUETOOTH_DEVICE_PAIR_CONFIRM_LABEL 10947
#define IDS_BLUETOOTH_DEVICE_PASSKEY_CONFIRM_TITLE 10948
#define IDS_BLUETOOTH_DEVICE_PASSKEY_CONFIRM_LABEL 10949
#define IDS_MANAGE 10950
#define IDS_LIST_BULLET 10951
#define IDS_BLOCKED_DOWNLOAD_NO_ACTION 10952
#define IDS_BLOCKED_DOWNLOAD_UNBLOCK 10953
#define IDS_ALLOWED_DOWNLOAD_TITLE 10954
#define IDS_BLOCKED_DOWNLOAD_TITLE 10955
#define IDS_BLOCKED_DOWNLOADS_EXPLANATION 10956
#define IDS_ALLOWED_DOWNLOAD_NO_ACTION 10957
#define IDS_ALLOWED_DOWNLOAD_BLOCK 10958
#define IDS_BLOCKED_ON_DEVICE_SITE_DATA_TITLE 10959
#define IDS_ACCESSED_ON_DEVICE_SITE_DATA_TITLE 10960
#define IDS_BLOCKED_ON_DEVICE_SITE_DATA_MESSAGE 10961
#define IDS_ACCESSED_ON_DEVICE_SITE_DATA_MESSAGE 10962
#define IDS_BLOCKED_IMAGES_TITLE 10963
#define IDS_BLOCKED_IMAGES_MESSAGE 10964
#define IDS_BLOCKED_ON_DEVICE_SITE_DATA_UNBLOCK 10965
#define IDS_BLOCKED_IMAGES_UNBLOCK 10966
#define IDS_BLOCKED_ON_DEVICE_SITE_DATA_NO_ACTION 10967
#define IDS_ALLOWED_ON_DEVICE_SITE_DATA_NO_ACTION 10968
#define IDS_ALLOWED_ON_DEVICE_SITE_DATA_BLOCK 10969
#define IDS_BLOCKED_IMAGES_NO_ACTION 10970
#define IDS_BLOCKED_POPUPS_TOOLTIP 10971
#define IDS_BLOCKED_POPUPS_TITLE 10972
#define IDS_BLOCKED_POPUPS_REDIRECTS_UNBLOCK 10973
#define IDS_BLOCKED_POPUPS_REDIRECTS_NO_ACTION 10974
#define IDS_BLOCKED_MEDIASTREAM_MIC_AND_CAMERA_ALLOW 10975
#define IDS_BLOCKED_MEDIASTREAM_MIC_ALLOW 10976
#define IDS_BLOCKED_MEDIASTREAM_CAMERA_ALLOW 10977
#define IDS_BLOCKED_MEDIASTREAM_MIC_AND_CAMERA_ASK 10978
#define IDS_BLOCKED_MEDIASTREAM_MIC_ASK 10979
#define IDS_BLOCKED_MEDIASTREAM_CAMERA_ASK 10980
#define IDS_ALLOWED_MEDIASTREAM_MIC_AND_CAMERA_BLOCK 10981
#define IDS_ALLOWED_MEDIASTREAM_MIC_BLOCK 10982
#define IDS_ALLOWED_MEDIASTREAM_CAMERA_BLOCK 10983
#define IDS_BLOCKED_MEDIASTREAM_MIC_AND_CAMERA_NO_ACTION 10984
#define IDS_BLOCKED_MEDIASTREAM_MIC_NO_ACTION 10985
#define IDS_BLOCKED_MEDIASTREAM_CAMERA_NO_ACTION 10986
#define IDS_ALLOWED_MEDIASTREAM_MIC_AND_CAMERA_NO_ACTION 10987
#define IDS_ALLOWED_MEDIASTREAM_MIC_AND_CAMERA_PAN_TILT_ZOOM_NO_ACTION 10988
#define IDS_ALLOWED_MEDIASTREAM_MIC_NO_ACTION 10989
#define IDS_ALLOWED_MEDIASTREAM_CAMERA_NO_ACTION 10990
#define IDS_ALLOWED_CAMERA_PAN_TILT_ZOOM_NO_ACTION 10991
#define IDS_BLOCKED_POPUPS_EXPLANATORY_TEXT 10992
#define IDS_BLOCKED_JAVASCRIPT_TITLE 10993
#define IDS_BLOCKED_JAVASCRIPT_MESSAGE 10994
#define IDS_BLOCKED_JAVASCRIPT_UNBLOCK 10995
#define IDS_BLOCKED_JAVASCRIPT_NO_ACTION 10996
#define IDS_BLOCKED_SOUND_TITLE 10997
#define IDS_BLOCKED_SOUND_UNBLOCK 10998
#define IDS_BLOCKED_SOUND_NO_ACTION 10999
#define IDS_NOTIFICATIONS_OFF_EXPLANATORY_TEXT 11000
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_TITLE 11001
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_DESCRIPTION 11002
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_DESCRIPTION 11003
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_ALLOW_BUTTON 11004
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_COMPACT_ALLOW_BUTTON 11005
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_CONTINUE_BLOCKING_BUTTON 11006
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_EARLY_PROMO 11007
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_CROWD_DENY_DESCRIPTION 11008
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_CROWD_DENY_DESCRIPTION 11009
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_ABUSIVE_DESCRIPTION 11010
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_DISRUPTIVE_DESCRIPTION 11011
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_PREDICTION_SERVICE_DESCRIPTION 11012
#define IDS_GEOLOCATION_OFF_EXPLANATORY_TEXT 11013
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_TITLE 11014
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_PREDICTION_SERVICE_DESCRIPTION 11015
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_ALLOW_BUTTON 11016
#define IDS_STORAGE_ACCESS_PERMISSION_BUBBLE_MESSAGE 11017
#define IDS_STORAGE_ACCESS_PERMISSION_ALLOWED_TOOLTIP 11018
#define IDS_STORAGE_ACCESS_PERMISSION_BLOCKED_TOOLTIP 11019
#define IDS_COOKIE_CONTROLS_BUBBLE_COOKIES_BLOCKED_TITLE 11020
#define IDS_COOKIE_CONTROLS_BUBBLE_COOKIES_ALLOWED_TITLE 11021
#define IDS_COOKIE_CONTROLS_BUBBLE_SITE_NOT_WORKING_TITLE 11022
#define IDS_TRACKING_PROTECTION_BUBBLE_SITE_NOT_WORKING_DESCRIPTION 11023
#define IDS_TRACKING_PROTECTION_BUBBLE_BLOCKING_RESTART_TITLE 11024
#define IDS_TRACKING_PROTECTION_BUBBLE_BLOCKING_RESTART_DESCRIPTION 11025
#define IDS_TRACKING_PROTECTION_BUBBLE_PERMANENT_ALLOWED_TITLE 11026
#define IDS_TRACKING_PROTECTION_BUBBLE_PERMANENT_ALLOWED_DESCRIPTION 11027
#define IDS_COOKIE_CONTROLS_BUBBLE_SEND_FEEDBACK_BUTTON_TITLE 11028
#define IDS_COOKIE_CONTROLS_BUBBLE_SEND_FEEDBACK_BUTTON_DESCRIPTION 11029
#define IDS_COOKIE_CONTROLS_BUBBLE_RELOADING_LABEL 11030
#define IDS_COOKIE_CONTROLS_BUBBLE_THIRD_PARTY_COOKIES_LABEL 11031
#define IDS_COOKIE_CONTROLS_BUBBLE_SEND_FEEDBACK_FORM_PLACEHOLDER 11032
#define IDS_COOKIE_CONTROLS_PAGE_ACTION_COOKIES_ALLOWED_LABEL 11033
#define IDS_COOKIE_CONTROLS_PAGE_ACTION_COOKIES_BLOCKED_LABEL 11034
#define IDS_COOKIE_CONTROLS_PROMO_TITLE 11035
#define IDS_COOKIE_CONTROLS_PROMO_TEXT 11036
#define IDS_COOKIE_CONTROLS_PROMO_CLOSE_BUTTON_TEXT 11037
#define IDS_COOKIE_CONTROLS_PROMO_SEE_HOW_BUTTON_TEXT 11038
#define IDS_JS_OPTIMIZATIONS_DISABLED_ICON_TOOLTIP 11039
#define IDS_JS_OPTIMIZATION_BUBBLE_TITLE 11040
#define IDS_JS_OPTIMIZATION_BUBBLE_POLICY_BODY 11041
#define IDS_JS_OPTIMIZATION_BUBBLE_BODY_NON_POLICY_BODY 11042
#define IDS_JS_OPTIMIZATION_BUBBLE_ENABLE_BUTTON 11043
#define IDS_JS_OPTIMIZATION_SITE_RELOAD_TEXT 11044
#define IDS_JS_OPTIMIZATION_SITE_RELOAD_BUTTON 11045
#define IDS_CERT_SELECTOR_SUBJECT_COLUMN 11046
#define IDS_CERT_SELECTOR_ISSUER_COLUMN 11047
#define IDS_CERT_SELECTOR_PROVIDER_COLUMN 11048
#define IDS_CERT_SELECTOR_SERIAL_COLUMN 11049
#define IDS_CERT_EXPORT_TYPE_BASE64_ALL 11050
#define IDS_CERT_EXPORT_TYPE_BASE64 11051
#define IDS_CERT_EXPORT_TYPE_BASE64_CHAIN 11052
#define IDS_CERT_EXPORT_TYPE_DER 11053
#define IDS_CERT_EXPORT_TYPE_PKCS7 11054
#define IDS_CERT_EXPORT_TYPE_PKCS7_CHAIN 11055
#define IDS_CERT_INFO_DIALOG_TITLE 11056
#define IDS_CERT_INFO_GENERAL_TAB_LABEL 11057
#define IDS_CERT_INFO_DETAILS_TAB_LABEL 11058
#define IDS_CERT_INFO_MODIFICATIONS_TAB_LABEL 11059
#define IDS_CERT_INFO_TRUST_LABEL 11060
#define IDS_CERT_INFO_TRUST_STATE_LABEL 11061
#define IDS_CERT_INFO_TRUST_STATE_DISTRUSTED 11062
#define IDS_CERT_INFO_TRUST_STATE_HINT 11063
#define IDS_CERT_INFO_TRUST_STATE_TRUSTED 11064
#define IDS_CERT_INFO_CONSTRAINTS_LABEL 11065
#define IDS_CERT_INFO_ADD_CONSTRAINTS_LABEL 11066
#define IDS_CERT_INFO_ADD_CONSTRAINTS_BUTTON_LABEL 11067
#define IDS_CERT_INFO_ADD_CONSTRAINTS_PLACEHOLDER 11068
#define IDS_CERT_INFO_ADD_CONSTRAINT_ERROR_MESSAGE 11069
#define IDS_CERT_INFO_DELETE_CONSTRAINT_ERROR_MESSAGE 11070
#define IDS_CERT_INFO_TRUST_STATE_ERROR_MESSAGE 11071
#define IDS_CERT_USAGE_SSL_CLIENT 11072
#define IDS_CERT_USAGE_SSL_SERVER 11073
#define IDS_CERT_USAGE_OBJECT_SIGNER 11074
#define IDS_CERT_USAGE_SSL_CA 11075
#define IDS_CERT_INFO_IDN_VALUE_FORMAT 11076
#define IDS_CERT_INFO_FIELD_NOT_PRESENT 11077
#define IDS_CERT_DETAILS_CERTIFICATE_HIERARCHY_LABEL 11078
#define IDS_CERT_DETAILS_CERTIFICATE_FIELDS_LABEL 11079
#define IDS_CERT_DETAILS_CERTIFICATE_FIELD_VALUE_LABEL 11080
#define IDS_CERT_DETAILS_CERTIFICATE 11081
#define IDS_CERT_DETAILS_VERSION 11082
#define IDS_CERT_DETAILS_VERSION_FORMAT 11083
#define IDS_CERT_DETAILS_SERIAL_NUMBER 11084
#define IDS_CERT_DETAILS_CERTIFICATE_SIG_ALG 11085
#define IDS_CERT_DETAILS_ISSUER 11086
#define IDS_CERT_DETAILS_VALIDITY 11087
#define IDS_CERT_DETAILS_NOT_BEFORE 11088
#define IDS_CERT_DETAILS_NOT_AFTER 11089
#define IDS_CERT_DETAILS_SUBJECT 11090
#define IDS_CERT_DETAILS_SUBJECT_KEY_INFO 11091
#define IDS_CERT_DETAILS_SUBJECT_KEY_ALG 11092
#define IDS_CERT_DETAILS_SUBJECT_KEY 11093
#define IDS_CERT_RSA_PUBLIC_KEY_DUMP_FORMAT 11094
#define IDS_CERT_DETAILS_CERTIFICATE_SIG_VALUE 11095
#define IDS_CERT_DETAILS_EXPORT_CERTIFICATE 11096
#define IDS_CERT_DETAILS_EXPORT_CERTIFICATE_A11Y_LABEL 11097
#define IDS_CERT_OID_AVA_COMMON_NAME 11098
#define IDS_CERT_OID_AVA_STATE_OR_PROVINCE 11099
#define IDS_CERT_OID_AVA_ORGANIZATION_NAME 11100
#define IDS_CERT_OID_AVA_ORGANIZATIONAL_UNIT_NAME 11101
#define IDS_CERT_OID_AVA_DN_QUALIFIER 11102
#define IDS_CERT_OID_AVA_COUNTRY_NAME 11103
#define IDS_CERT_OID_AVA_SERIAL_NUMBER 11104
#define IDS_CERT_OID_AVA_LOCALITY 11105
#define IDS_CERT_OID_AVA_DC 11106
#define IDS_CERT_OID_RFC1274_MAIL 11107
#define IDS_CERT_OID_RFC1274_UID 11108
#define IDS_CERT_OID_PKCS9_EMAIL_ADDRESS 11109
#define IDS_CERT_OID_BUSINESS_CATEGORY 11110
#define IDS_CERT_OID_EV_INCORPORATION_LOCALITY 11111
#define IDS_CERT_OID_EV_INCORPORATION_STATE 11112
#define IDS_CERT_OID_EV_INCORPORATION_COUNTRY 11113
#define IDS_CERT_OID_AVA_STREET_ADDRESS 11114
#define IDS_CERT_OID_AVA_POSTAL_CODE 11115
#define IDS_CERT_OID_PKCS1_RSA_ENCRYPTION 11116
#define IDS_CERT_OID_PKCS1_MD2_WITH_RSA_ENCRYPTION 11117
#define IDS_CERT_OID_PKCS1_MD4_WITH_RSA_ENCRYPTION 11118
#define IDS_CERT_OID_PKCS1_MD5_WITH_RSA_ENCRYPTION 11119
#define IDS_CERT_OID_PKCS1_SHA1_WITH_RSA_ENCRYPTION 11120
#define IDS_CERT_OID_PKCS1_SHA256_WITH_RSA_ENCRYPTION 11121
#define IDS_CERT_OID_PKCS1_SHA384_WITH_RSA_ENCRYPTION 11122
#define IDS_CERT_OID_PKCS1_SHA512_WITH_RSA_ENCRYPTION 11123
#define IDS_CERT_OID_ANSIX962_ECDSA_SHA1_SIGNATURE 11124
#define IDS_CERT_OID_ANSIX962_ECDSA_SHA256_SIGNATURE 11125
#define IDS_CERT_OID_ANSIX962_ECDSA_SHA384_SIGNATURE 11126
#define IDS_CERT_OID_ANSIX962_ECDSA_SHA512_SIGNATURE 11127
#define IDS_CERT_OID_ANSIX962_EC_PUBLIC_KEY 11128
#define IDS_CERT_OID_SECG_EC_SECP256R1 11129
#define IDS_CERT_OID_SECG_EC_SECP384R1 11130
#define IDS_CERT_OID_SECG_EC_SECP521R1 11131
#define IDS_CERT_EXT_NS_CERT_TYPE 11132
#define IDS_CERT_EXT_NS_CERT_TYPE_EMAIL 11133
#define IDS_CERT_EXT_NS_CERT_TYPE_EMAIL_CA 11134
#define IDS_CERT_EXT_NS_CERT_BASE_URL 11135
#define IDS_CERT_EXT_NS_CERT_REVOCATION_URL 11136
#define IDS_CERT_EXT_NS_CA_REVOCATION_URL 11137
#define IDS_CERT_EXT_NS_CERT_RENEWAL_URL 11138
#define IDS_CERT_EXT_NS_CA_POLICY_URL 11139
#define IDS_CERT_EXT_NS_SSL_SERVER_NAME 11140
#define IDS_CERT_EXT_NS_COMMENT 11141
#define IDS_CERT_EXT_NS_LOST_PASSWORD_URL 11142
#define IDS_CERT_EXT_NS_CERT_RENEWAL_TIME 11143
#define IDS_CERT_X509_SUBJECT_DIRECTORY_ATTR 11144
#define IDS_CERT_X509_SUBJECT_KEYID 11145
#define IDS_CERT_KEYID_FORMAT 11146
#define IDS_CERT_ISSUER_FORMAT 11147
#define IDS_CERT_SERIAL_NUMBER_FORMAT 11148
#define IDS_CERT_X509_KEY_USAGE 11149
#define IDS_CERT_X509_ISSUER_ALT_NAME 11150
#define IDS_CERT_X509_BASIC_CONSTRAINTS 11151
#define IDS_CERT_X509_NAME_CONSTRAINTS 11152
#define IDS_CERT_X509_CRL_DIST_POINTS 11153
#define IDS_CERT_X509_CERT_POLICIES 11154
#define IDS_CERT_X509_SCT_LIST 11155
#define IDS_CERT_QC_STATEMENTS 11156
#define IDS_CERT_X509_POLICY_MAPPINGS 11157
#define IDS_CERT_X509_POLICY_CONSTRAINTS 11158
#define IDS_CERT_X509_AUTH_KEYID 11159
#define IDS_CERT_X509_EXT_KEY_USAGE 11160
#define IDS_CERT_X509_AUTH_INFO_ACCESS 11161
#define IDS_CERT_X509_KEY_USAGE_SIGNING 11162
#define IDS_CERT_X509_KEY_USAGE_NONREP 11163
#define IDS_CERT_X509_KEY_USAGE_ENCIPHERMENT 11164
#define IDS_CERT_X509_KEY_USAGE_DATA_ENCIPHERMENT 11165
#define IDS_CERT_X509_KEY_USAGE_KEY_AGREEMENT 11166
#define IDS_CERT_X509_KEY_USAGE_CERT_SIGNER 11167
#define IDS_CERT_X509_KEY_USAGE_CRL_SIGNER 11168
#define IDS_CERT_X509_KEY_USAGE_ENCIPHER_ONLY 11169
#define IDS_CERT_X509_KEY_USAGE_DECIPHER_ONLY 11170
#define IDS_CERT_X509_BASIC_CONSTRAINT_IS_CA 11171
#define IDS_CERT_X509_BASIC_CONSTRAINT_IS_NOT_CA 11172
#define IDS_CERT_X509_BASIC_CONSTRAINT_PATH_LEN 11173
#define IDS_CERT_X509_BASIC_CONSTRAINT_PATH_LEN_UNLIMITED 11174
#define IDS_CERT_PKIX_CPS_POINTER_QUALIFIER 11175
#define IDS_CERT_PKIX_USER_NOTICE_QUALIFIER 11176
#define IDS_CERT_REVOCATION_REASON_UNUSED 11177
#define IDS_CERT_REVOCATION_REASON_KEY_COMPROMISE 11178
#define IDS_CERT_REVOCATION_REASON_CA_COMPROMISE 11179
#define IDS_CERT_REVOCATION_REASON_AFFILIATION_CHANGED 11180
#define IDS_CERT_REVOCATION_REASON_SUPERSEDED 11181
#define IDS_CERT_REVOCATION_REASON_CESSATION_OF_OPERATION 11182
#define IDS_CERT_REVOCATION_REASON_CERTIFICATE_HOLD 11183
#define IDS_CERT_OCSP_RESPONDER_FORMAT 11184
#define IDS_CERT_CA_ISSUERS_FORMAT 11185
#define IDS_CERT_UNKNOWN_OID_INFO_FORMAT 11186
#define IDS_CERT_EXT_KEY_USAGE_FORMAT 11187
#define IDS_CERT_MULTILINE_INFO_START_FORMAT 11188
#define IDS_CERT_GENERAL_NAME_RFC822_NAME 11189
#define IDS_CERT_GENERAL_NAME_DNS_NAME 11190
#define IDS_CERT_GENERAL_NAME_X400_ADDRESS 11191
#define IDS_CERT_GENERAL_NAME_DIRECTORY_NAME 11192
#define IDS_CERT_GENERAL_NAME_EDI_PARTY_NAME 11193
#define IDS_CERT_GENERAL_NAME_URI 11194
#define IDS_CERT_GENERAL_NAME_IP_ADDRESS 11195
#define IDS_CERT_GENERAL_NAME_REGISTERED_ID 11196
#define IDS_CERT_EXT_MS_APP_POLICIES 11197
#define IDS_CERT_EXT_MS_CERT_TEMPLATE 11198
#define IDS_CERT_EXT_MS_CERT_TYPE 11199
#define IDS_CERT_EXT_MS_CA_VERSION 11200
#define IDS_CERT_EXT_MS_NT_PRINCIPAL_NAME 11201
#define IDS_CERT_EXT_MS_NTDS_REPLICATION 11202
#define IDS_CERT_EKU_ANY_EKU 11203
#define IDS_CERT_EKU_TLS_WEB_SERVER_AUTHENTICATION 11204
#define IDS_CERT_EKU_TLS_WEB_CLIENT_AUTHENTICATION 11205
#define IDS_CERT_EKU_CODE_SIGNING 11206
#define IDS_CERT_EKU_EMAIL_PROTECTION 11207
#define IDS_CERT_EKU_TIME_STAMPING 11208
#define IDS_CERT_EKU_OCSP_SIGNING 11209
#define IDS_CERT_POLICY_ETSI_QEVCP_W 11210
#define IDS_CERT_POLICY_ETSI_QNCP_W 11211
#define IDS_CERT_QC_ETSI_QCS_QCCOMPLIANCE 11212
#define IDS_CERT_QC_ETSI_QCS_QCTYPE 11213
#define IDS_CERT_QC_ETSI_QCT_WEB 11214
#define IDS_CERT_EKU_MS_INDIVIDUAL_CODE_SIGNING 11215
#define IDS_CERT_EKU_MS_COMMERCIAL_CODE_SIGNING 11216
#define IDS_CERT_EKU_MS_TRUST_LIST_SIGNING 11217
#define IDS_CERT_EKU_MS_TIME_STAMPING 11218
#define IDS_CERT_EKU_MS_SERVER_GATED_CRYPTO 11219
#define IDS_CERT_EKU_MS_ENCRYPTING_FILE_SYSTEM 11220
#define IDS_CERT_EKU_MS_FILE_RECOVERY 11221
#define IDS_CERT_EKU_MS_WINDOWS_HARDWARE_DRIVER_VERIFICATION 11222
#define IDS_CERT_EKU_MS_QUALIFIED_SUBORDINATION 11223
#define IDS_CERT_EKU_MS_KEY_RECOVERY 11224
#define IDS_CERT_EKU_MS_DOCUMENT_SIGNING 11225
#define IDS_CERT_EKU_MS_LIFETIME_SIGNING 11226
#define IDS_CERT_EKU_MS_SMART_CARD_LOGON 11227
#define IDS_CERT_EKU_MS_KEY_RECOVERY_AGENT 11228
#define IDS_CERT_EKU_NETSCAPE_INTERNATIONAL_STEP_UP 11229
#define IDS_CERT_EXTENSION_CRITICAL 11230
#define IDS_CERT_EXTENSION_NON_CRITICAL 11231
#define IDS_CERT_DUMP_ERROR 11232
#define IDS_CERT_EXTENSION_DUMP_ERROR 11233
#define IDS_CERTIFICATE_MANAGER_TITLE 11234
#define IDS_CERT_MANAGER_HARDWARE_BACKED_KEY_FORMAT 11235
#define IDS_CERT_MANAGER_HARDWARE_BACKED 11236
#define IDS_CERT_MANAGER_EXTENSION_PROVIDED_FORMAT 11237
#define IDS_DEV_TOOLS_SHARED_PROCESS_INFOBAR 11238
#define IDS_DEV_TOOLS_SHARED_PROCESS_INFOBAR_LEARN_MORE 11239
#define IDS_DEV_TOOLS_SHARED_PROCESS_INFOBAR_OPT_OUT 11240
#define IDS_DEV_TOOLS_SHARED_PROCESS_INFOBAR_RESTART_NEEDED 11241
#define IDS_DEV_TOOLS_INFOBAR_LABEL 11242
#define IDS_DEV_TOOLS_CONFIRM_ADD_FILE_SYSTEM_MESSAGE 11243
#define IDS_DEV_TOOLS_EDIT_DIRECTORY_PERMISSION_TITLE 11244
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_TITLE 11245
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_MESSAGE_PART_1 11246
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_MESSAGE_PART_2 11247
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_ALLOW_TEXT 11248
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_DISABLE_TEXT 11249
#define IDS_DEV_TOOLS_CONFIRM_ALLOW_BUTTON 11250
#define IDS_DEV_TOOLS_CONFIRM_DENY_BUTTON 11251
#define IDS_RELOAD_MENU_NORMAL_RELOAD_ITEM 11252
#define IDS_RELOAD_MENU_HARD_RELOAD_ITEM 11253
#define IDS_RELOAD_MENU_EMPTY_AND_HARD_RELOAD_ITEM 11254
#define IDS_TAB_SHARING_INFOBAR_SHARING_CURRENT_TAB_LABEL 11255
#define IDS_TAB_SHARING_INFOBAR_SHARING_ANOTHER_UNTITLED_TAB_LABEL 11256
#define IDS_TAB_SHARING_INFOBAR_SHARING_ANOTHER_TAB_LABEL 11257
#define IDS_TAB_SHARING_INFOBAR_SHARING_ANOTHER_TAB_TO_THIS_TAB_LABEL 11258
#define IDS_TAB_SHARING_INFOBAR_SHARE_BUTTON 11259
#define IDS_TAB_SHARING_INFOBAR_STOP_BUTTON 11260
#define IDS_TAB_SHARING_INFOBAR_SWITCH_TO_BUTTON 11261
#define IDS_TAB_SHARING_INFOBAR_SWITCH_TO_CAPTURER_BUTTON 11262
#define IDS_TAB_SHARING_INFOBAR_SWITCH_TO_CAPTURED_BUTTON 11263
#define IDS_TAB_SHARING_INFOBAR_CAPTURED_SURFACE_CONTROL_PERMISSION_BUTTON 11264
#define IDS_TAB_CASTING_INFOBAR_CASTING_CURRENT_TAB_LABEL 11265
#define IDS_TAB_CASTING_INFOBAR_CASTING_CURRENT_TAB_NO_DEVICE_NAME_LABEL 11266
#define IDS_TAB_CASTING_INFOBAR_CASTING_ANOTHER_UNTITLED_TAB_LABEL 11267
#define IDS_TAB_CASTING_INFOBAR_CASTING_ANOTHER_UNTITLED_TAB_NO_DEVICE_NAME_LABEL 11268
#define IDS_TAB_CASTING_INFOBAR_CASTING_ANOTHER_TAB_LABEL 11269
#define IDS_TAB_CASTING_INFOBAR_CASTING_ANOTHER_TAB_NO_DEVICE_NAME_LABEL 11270
#define IDS_TAB_CASTING_INFOBAR_CAST_BUTTON 11271
#define IDS_TAB_CASTING_INFOBAR_STOP_BUTTON 11272
#define IDS_TASK_MANAGER_KILL 11273
#define IDS_TASK_MANAGER_KILL_V2 11274
#define IDS_TASK_MANAGER_PROCESS_ID_COLUMN 11275
#define IDS_TASK_MANAGER_GDI_HANDLES_COLUMN 11276
#define IDS_TASK_MANAGER_USER_HANDLES_COLUMN 11277
#define IDS_TASK_MANAGER_TASK_COLUMN 11278
#define IDS_TASK_MANAGER_NET_COLUMN 11279
#define IDS_TASK_MANAGER_CPU_COLUMN 11280
#define IDS_TASK_MANAGER_START_TIME_COLUMN 11281
#define IDS_TASK_MANAGER_CPU_TIME_COLUMN 11282
#define IDS_TASK_MANAGER_MEM_FOOTPRINT_COLUMN 11283
#define IDS_TASK_MANAGER_SWAPPED_MEM_COLUMN 11284
#define IDS_TASK_MANAGER_PROFILE_NAME_COLUMN 11285
#define IDS_TASK_MANAGER_IDLE_WAKEUPS_COLUMN 11286
#define IDS_TASK_MANAGER_HARD_FAULTS_COLUMN 11287
#define IDS_TASK_MANAGER_OPEN_FD_COUNT_COLUMN 11288
#define IDS_TASK_MANAGER_PROCESS_PRIORITY_COLUMN 11289
#define IDS_TASK_MANAGER_WEBCORE_IMAGE_CACHE_COLUMN 11290
#define IDS_TASK_MANAGER_WEBCORE_SCRIPTS_CACHE_COLUMN 11291
#define IDS_TASK_MANAGER_WEBCORE_CSS_CACHE_COLUMN 11292
#define IDS_TASK_MANAGER_VIDEO_MEMORY_COLUMN 11293
#define IDS_TASK_MANAGER_SQLITE_MEMORY_USED_COLUMN 11294
#define IDS_TASK_MANAGER_JAVASCRIPT_MEMORY_ALLOCATED_COLUMN 11295
#define IDS_TASK_MANAGER_KEEPALIVE_COUNT_COLUMN 11296
#define IDS_TASK_MANAGER_MEM_CELL_TEXT 11297
#define IDS_TASK_MANAGER_CACHE_SIZE_CELL_TEXT 11298
#define IDS_TASK_MANAGER_NA_CELL_TEXT 11299
#define IDS_TASK_MANAGER_BACKGROUNDED_TEXT 11300
#define IDS_TASK_MANAGER_FOREGROUNDED_TEXT 11301
#define IDS_TASK_MANAGER_HANDLES_CELL_TEXT 11302
#define IDS_TASK_MANAGER_TASK_GROUP_CONNECT_TEXT 11303
#define IDS_TASK_MANAGER_WEB_BROWSER_CELL_TEXT 11304
#define IDS_TASK_MANAGER_EXTENSION_PREFIX 11305
#define IDS_TASK_MANAGER_EXTENSION_INCOGNITO_PREFIX 11306
#define IDS_TASK_MANAGER_APP_PREFIX 11307
#define IDS_TASK_MANAGER_APP_INCOGNITO_PREFIX 11308
#define IDS_TASK_MANAGER_TAB_PREFIX 11309
#define IDS_TASK_MANAGER_TAB_INCOGNITO_PREFIX 11310
#define IDS_TASK_MANAGER_BACKGROUND_APP_PREFIX 11311
#define IDS_TASK_MANAGER_BACKGROUND_PREFIX 11312
#define IDS_TASK_MANAGER_BACK_FORWARD_CACHE_PREFIX 11313
#define IDS_TASK_MANAGER_BACK_FORWARD_CACHE_INCOGNITO_PREFIX 11314
#define IDS_TASK_MANAGER_PRELOADED_RENDERER_FOR_UI 11315
#define IDS_TASK_MANAGER_NO_STATE_PREFETCH_PREFIX 11316
#define IDS_TASK_MANAGER_PRERENDER_PREFIX 11317
#define IDS_TASK_MANAGER_SPARE_RENDERER_PREFIX 11318
#define IDS_TASK_MANAGER_UNKNOWN_RENDERER_PREFIX 11319
#define IDS_TASK_MANAGER_DEDICATED_WORKER_PREFIX 11320
#define IDS_TASK_MANAGER_SHARED_WORKER_PREFIX 11321
#define IDS_TASK_MANAGER_SERVICE_WORKER_PREFIX 11322
#define IDS_TASK_MANAGER_UTILITY_PREFIX 11323
#define IDS_TASK_MANAGER_GPU_PREFIX 11324
#define IDS_TASK_MANAGER_PRINT_PREFIX 11325
#define IDS_TASK_MANAGER_SUBFRAME_PREFIX 11326
#define IDS_TASK_MANAGER_SUBFRAME_INCOGNITO_PREFIX 11327
#define IDS_TASK_MANAGER_BACK_FORWARD_CACHE_SUBFRAME_PREFIX 11328
#define IDS_TASK_MANAGER_BACK_FORWARD_CACHE_INCOGNITO_SUBFRAME_PREFIX 11329
#define IDS_TASK_MANAGER_PDF_SUBFRAME_PREFIX 11330
#define IDS_TASK_MANAGER_PDF_SUBFRAME_INCOGNITO_PREFIX 11331
#define IDS_TASK_MANAGER_PORTAL_PREFIX 11332
#define IDS_TASK_MANAGER_PORTAL_INCOGNITO_PREFIX 11333
#define IDS_TASK_MANAGER_FENCED_FRAME_PREFIX 11334
#define IDS_TASK_MANAGER_FENCED_FRAME_INCOGNITO_PREFIX 11335
#define IDS_TASK_MANAGER_ARC_PREFIX 11336
#define IDS_TASK_MANAGER_TOOL_PREFIX 11337
#define IDS_TASK_MANAGER_ARC_PREFIX_BACKGROUND_SERVICE 11338
#define IDS_TASK_MANAGER_ARC_PREFIX_RECEIVER 11339
#define IDS_TASK_MANAGER_ARC_SYSTEM 11340
#define IDS_TASK_MANAGER_LINUX_VM_PREFIX 11341
#define IDS_TASK_MANAGER_PLUGIN_VM_PREFIX 11342
#define IDS_TASK_MANAGER_OMNIBOX 11343
#define IDS_UTILITY_PROCESS_FILE_UTILITY_NAME 11344
#define IDS_UTILITY_PROCESS_PROFILE_IMPORTER_NAME 11345
#define IDS_UTILITY_PROCESS_QRCODE_GENERATOR_SERVICE_NAME 11346
#define IDS_UTILITY_PROCESS_IMAGE_WRITER_NAME 11348
#define IDS_UTILITY_PROCESS_MEDIA_GALLERY_UTILITY_NAME 11349
#define IDS_UTILITY_PROCESS_NOOP_SERVICE_NAME 11350
#define IDS_SERVICE_PROCESS_DOCUMENT_ANALYSIS_NAME 11351
#define IDS_THEME_INSTALL_INFOBAR_LABEL 11352
#define IDS_THEME_INSTALL_INFOBAR_UNDO_BUTTON 11353
#define IDS_CRITICAL_NOTIFICATION_RESTART 11354
#define IDS_EXTENSION_DISABLED_ERROR_LABEL 11355
#define IDS_EXTENSION_DISABLED_REMOTE_INSTALL_ERROR_TITLE 11356
#define IDS_EXTENSION_DISABLED_ERROR_TITLE 11357
#define IDS_EXTENSION_SITE_RELOAD_PAGE_BUBBLE_HEADING 11358
#define IDS_EXTENSION_RELOAD_PAGE_BUBBLE_OK_BUTTON 11359
#define IDS_EXTENSION_RELOAD_PAGE_BUBBLE_ALLOW_SINGLE_EXTENSION_TITLE 11360
#define IDS_EXTENSION_RELOAD_PAGE_BUBBLE_ALLOW_MULTIPLE_EXTENSIONS_TITLE 11361
#define IDS_APP_UNINSTALL_PROMPT_TITLE 11362
#define IDS_ARC_APP_UNINSTALL_PROMPT_DATA_REMOVAL_WARNING 11363
#define IDS_EXTENSION_UNINSTALL_PROMPT_TITLE 11364
#define IDS_EXTENSION_CONFIRM_PERMISSIONS 11365
#define IDS_EXTENSION_INSTALL_PROMPT_TITLE 11366
#define IDS_EXTENSION_REQUEST_PROMPT_TITLE 11367
#define IDS_EXTENSION_PENDING_REQUEST_PROMPT_TITLE 11368
#define IDS_EXTENSION_BLOCKED_BY_POLICY_PROMPT_TITLE 11369
#define IDS_EXTENSION_RE_ENABLE_PROMPT_TITLE 11370
#define IDS_EXTENSION_PERMISSIONS_PROMPT_TITLE 11371
#define IDS_EXTENSION_REMOTE_INSTALL_PROMPT_TITLE 11372
#define IDS_EXTENSION_REPAIR_PROMPT_TITLE 11373
#define IDS_EXTENSION_ASK_PARENT_PROMPT_TITLE 11374
#define IDS_EXTENSION_ASK_PARENT_PROMPT_BODY 11375
#define IDS_EXTENSION_ASK_PARENT_PROMPT_ASK_IN_PERSON_BUTTON 11376
#define IDS_EXTENSION_PARENT_APPROVAL_PROMPT_TITLE 11377
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_ACCEPT_BUTTON_EXTENSION 11378
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_ACCEPT_BUTTON_APP 11379
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_ACCEPT_BUTTON_THEME 11380
#define IDS_EXTENSION_ALERT_TITLE 11381
#define IDS_APP_ALERT_TITLE 11382
#define IDS_EXTENSION_AND_APP_ALERT_TITLE 11383
#define IDS_POLICY_BLOCKED_EXTENSION_ALERT_TITLE 11384
#define IDS_POLICY_BLOCKED_EXTENSIONS_ALERT_ITEM_TITLE 11385
#define IDS_BLOCKLISTED_EXTENSIONS_ALERT_ITEM 11386
#define IDS_POLICY_BLOCKED_EXTENSION_ALERT_ITEM_DETAIL 11387
#define IDS_EXTENSION_ALERT_ITEM_OK 11388
#define IDS_EXTENSION_ALERT_ITEM_DETAILS 11389
#define IDS_EXTENSION_PROMPT_APP_CONNECT_FROM_INCOGNITO 11390
#define IDS_EXTENSION_PROMPT_EXTENSION_CONNECT_FROM_INCOGNITO 11391
#define IDS_EXTENSION_PROMPT_WILL_HAVE_ACCESS_TO 11392
#define IDS_EXTENSION_PROMPT_WILL_NOW_HAVE_ACCESS_TO 11393
#define IDS_EXTENSION_PROMPT_WANTS_ACCESS_TO 11394
#define IDS_EXTENSION_PROMPT_CAN_ACCESS 11395
#define IDS_EXTENSION_PROMPT_REQUESTS_PERMISSIONS 11396
#define IDS_EXTENSION_PROMPT_GRANT_PERMISSIONS_CHECKBOX 11397
#define IDS_EXTENSION_PROMPT_MESSAGE_FROM_ADMIN 11398
#define IDS_EXTENSION_PERMISSION_LINE 11399
#define IDS_EXTENSION_RATING_COUNT 11400
#define IDS_EXTENSION_PROMPT_RATING_ACCESSIBLE_TEXT 11401
#define IDS_EXTENSION_PROMPT_NO_RATINGS_ACCESSIBLE_TEXT 11402
#define IDS_EXTENSION_USER_COUNT 11403
#define IDS_EXTENSION_PROMPT_STORE_LINK 11404
#define IDS_EXTENSION_PROMPT_WARNING_FULL_ACCESS 11405
#define IDS_EXTENSION_PROMPT_WARNING_ALL_HOSTS 11406
#define IDS_EXTENSION_PROMPT_WARNING_ALL_HOSTS_READ_ONLY 11407
#define IDS_EXTENSION_PROMPT_WARNING_AUDIO_CAPTURE 11408
#define IDS_EXTENSION_PROMPT_WARNING_VIDEO_CAPTURE 11409
#define IDS_EXTENSION_PROMPT_WARNING_AUDIO_AND_VIDEO_CAPTURE 11410
#define IDS_EXTENSION_PROMPT_WARNING_BLUETOOTH 11411
#define IDS_EXTENSION_PROMPT_WARNING_BLUETOOTH_DEVICES 11412
#define IDS_EXTENSION_PROMPT_WARNING_BLUETOOTH_PRIVATE 11413
#define IDS_EXTENSION_PROMPT_WARNING_BLUETOOTH_SERIAL 11414
#define IDS_EXTENSION_PROMPT_WARNING_BOOKMARKS 11415
#define IDS_EXTENSION_PROMPT_WARNING_READING_LIST 11416
#define IDS_EXTENSION_PROMPT_WARNING_CLIPBOARD 11417
#define IDS_EXTENSION_PROMPT_WARNING_CLIPBOARD_READWRITE 11418
#define IDS_EXTENSION_PROMPT_WARNING_CLIPBOARD_WRITE 11419
#define IDS_EXTENSION_PROMPT_WARNING_DEBUGGER 11420
#define IDS_EXTENSION_PROMPT_WARNING_DECLARATIVE_WEB_REQUEST 11421
#define IDS_EXTENSION_PROMPT_WARNING_DECLARATIVE_NET_REQUEST 11422
#define IDS_EXTENSION_PROMPT_WARNING_DOCUMENT_SCAN 11423
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_HARDWARE_PLATFORM 11424
#define IDS_EXTENSION_PROMPT_WARNING_FAVICON 11425
#define IDS_EXTENSION_PROMPT_WARNING_GEOLOCATION 11426
#define IDS_EXTENSION_PROMPT_WARNING_HISTORY_READ 11427
#define IDS_EXTENSION_PROMPT_WARNING_HISTORY_READ_ON_ALL_DEVICES 11428
#define IDS_EXTENSION_PROMPT_WARNING_HISTORY_WRITE_ON_ALL_DEVICES 11429
#define IDS_EXTENSION_PROMPT_WARNING_HOME_PAGE_SETTING_OVERRIDE 11430
#define IDS_EXTENSION_PROMPT_WARNING_1_HOST 11431
#define IDS_EXTENSION_PROMPT_WARNING_1_HOST_READ_ONLY 11432
#define IDS_EXTENSION_PROMPT_WARNING_2_HOSTS 11433
#define IDS_EXTENSION_PROMPT_WARNING_2_HOSTS_READ_ONLY 11434
#define IDS_EXTENSION_PROMPT_WARNING_3_HOSTS 11435
#define IDS_EXTENSION_PROMPT_WARNING_3_HOSTS_READ_ONLY 11436
#define IDS_EXTENSION_PROMPT_WARNING_HOSTS_LIST 11437
#define IDS_EXTENSION_PROMPT_WARNING_HOSTS_LIST_READ_ONLY 11438
#define IDS_EXTENSION_PROMPT_WARNING_HOST_AND_SUBDOMAIN 11439
#define IDS_EXTENSION_PROMPT_WARNING_HOST_AND_SUBDOMAIN_LIST 11440
#define IDS_EXTENSION_PROMPT_WARNING_INPUT 11441
#define IDS_EXTENSION_PROMPT_WARNING_LOGIN 11442
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_LOGIN 11443
#define IDS_EXTENSION_PROMPT_WARNING_LOGIN_SCREEN_UI 11444
#define IDS_EXTENSION_PROMPT_WARNING_LOGIN_SCREEN_STORAGE 11445
#define IDS_EXTENSION_PROMPT_WARNING_MANAGEMENT 11446
#define IDS_EXTENSION_PROMPT_WARNING_MDNS 11447
#define IDS_EXTENSION_PROMPT_WARNING_NETWORK_STATE 11448
#define IDS_EXTENSION_PROMPT_WARNING_NETWORKING_PRIVATE 11449
#define IDS_EXTENSION_PROMPT_WARNING_PRINTING 11450
#define IDS_EXTENSION_PROMPT_WARNING_PRINTING_METRICS 11451
#define IDS_EXTENSION_PROMPT_WARNING_SEARCH_SETTINGS_OVERRIDE 11452
#define IDS_EXTENSION_PROMPT_WARNING_SERIAL 11453
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_ANY_HOST 11454
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_HOSTS_IN_DOMAIN 11455
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_HOSTS_IN_DOMAINS 11456
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_SPECIFIC_HOST 11457
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_SPECIFIC_HOSTS 11458
#define IDS_EXTENSION_PROMPT_WARNING_SPEECH_RECOGNITION 11459
#define IDS_EXTENSION_PROMPT_WARNING_START_PAGE_SETTING_OVERRIDE 11460
#define IDS_EXTENSION_PROMPT_WARNING_SYSTEM_STORAGE 11461
#define IDS_EXTENSION_PROMPT_WARNING_TAB_GROUPS 11462
#define IDS_EXTENSION_PROMPT_WARNING_TOPSITES 11463
#define IDS_EXTENSION_PROMPT_WARNING_TTS_ENGINE 11464
#define IDS_EXTENSION_PROMPT_WARNING_U2F_DEVICES 11465
#define IDS_EXTENSION_PROMPT_WARNING_NOTIFICATIONS 11466
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE 11467
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_LIST 11468
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_LIST_ITEM_UNKNOWN_PRODUCT 11469
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_LIST_ITEM_UNKNOWN_VENDOR 11470
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_UNKNOWN_PRODUCT 11471
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_UNKNOWN_VENDOR 11472
#define IDS_EXTENSION_PROMPT_WARNING_VPN 11473
#define IDS_EXTENSION_PROMPT_WARNING_CONTENT_SETTINGS 11474
#define IDS_EXTENSION_PROMPT_WARNING_PRIVACY 11475
#define IDS_EXTENSION_PROMPT_WARNING_DOWNLOADS 11476
#define IDS_EXTENSION_PROMPT_WARNING_DOWNLOADS_OPEN 11477
#define IDS_EXTENSION_PROMPT_WARNING_IDENTITY_EMAIL 11478
#define IDS_EXTENSION_PROMPT_WARNING_WALLPAPER 11479
#define IDS_EXTENSION_PROMPT_WARNING_FILE_SYSTEM_DIRECTORY 11480
#define IDS_EXTENSION_PROMPT_WARNING_FILE_SYSTEM_WRITE_DIRECTORY 11481
#define IDS_EXTENSION_PROMPT_WARNING_MEDIA_GALLERIES_READ 11482
#define IDS_EXTENSION_PROMPT_WARNING_MEDIA_GALLERIES_READ_WRITE 11483
#define IDS_EXTENSION_PROMPT_WARNING_MEDIA_GALLERIES_READ_DELETE 11484
#define IDS_EXTENSION_PROMPT_WARNING_MEDIA_GALLERIES_READ_WRITE_DELETE 11485
#define IDS_EXTENSION_PROMPT_WARNING_SYNCFILESYSTEM 11486
#define IDS_EXTENSION_PROMPT_WARNING_NATIVE_MESSAGING 11487
#define IDS_EXTENSION_PROMPT_WARNING_SCREENLOCK_PRIVATE 11488
#define IDS_EXTENSION_PROMPT_WARNING_ACTIVITY_LOG_PRIVATE 11489
#define IDS_EXTENSION_PROMPT_WARNING_DESKTOP_CAPTURE 11490
#define IDS_EXTENSION_PROMPT_WARNING_ACCESSIBILITY_FEATURES_MODIFY 11491
#define IDS_EXTENSION_PROMPT_WARNING_ACCESSIBILITY_FEATURES_READ 11492
#define IDS_EXTENSION_PROMPT_WARNING_ACCESSIBILITY_FEATURES_READ_MODIFY 11493
#define IDS_EXTENSION_PROMPT_WARNING_PLATFORMKEYS 11494
#define IDS_EXTENSION_PROMPT_WARNING_CERTIFICATEPROVIDER 11495
#define IDS_EXTENSION_PROMPT_WARNING_SETTINGS_PRIVATE 11496
#define IDS_EXTENSION_PROMPT_WARNING_AUTOFILL_PRIVATE 11497
#define IDS_EXTENSION_PROMPT_WARNING_PASSWORDS_PRIVATE 11498
#define IDS_EXTENSION_PROMPT_WARNING_USERS_PRIVATE 11499
#define IDS_EXTENSION_PROMPT_WARNING_NEW_TAB_PAGE_OVERRIDE 11500
#define IDS_EXTENSION_PROMPT_WARNING_TRANSIENT_BACKGROUND 11501
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_DEVICE_ATTRIBUTES 11502
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_KIOSK_INPUT 11503
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_NETWORKING_ATTRIBUTES 11504
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_PLATFORMKEYS 11505
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_REPORTING_PRIVATE_ENABLED_LINUX_AND_MACOS 11507
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_REPORTING_PRIVATE 11508
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_REMOTE_APPS 11509
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_ATTACHED_DEVICE_INFO 11510
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_BLUETOOTH_PERIPHERALS_INFO 11511
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_DIAGNOSTICS 11512
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_DIAGNOSTICS_NETWORK_INFO_FOR_MLAB 11513
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_EVENTS 11514
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_MANAGEMENT_AUDIO 11515
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_TELEMETRY 11516
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_TELEMETRY_SERIAL_NUMBER 11517
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_TELEMETRY_NETWORK_INFORMATION 11518
#define IDS_EXTENSION_PROMPT_WARNING_OMNIBOX_DIRECT_INPUT 11519
#define IDS_EXTENSION_INVALID_IMAGE_PATH 11522
#define IDS_EXTENSION_ASKS_IDENTITY_WHILE_SIGNED_IN_WEB_ONLY_BODY_PART_2 11524
#define IDS_EXTENSION_INSTALLED_PAGE_ACTION_INFO 11526
#define IDS_EXTENSION_INSTALLED_PAGE_ACTION_INFO_WITH_SHORTCUT 11527
#define IDS_EXTENSION_INSTALLED_BROWSER_ACTION_INFO 11528
#define IDS_EXTENSION_INSTALLED_BROWSER_ACTION_INFO_WITH_SHORTCUT 11529
#define IDS_EXTENSION_INSTALLED_OMNIBOX_KEYWORD_INFO 11530
#define IDS_EXTENSION_INSTALLED_MANAGE_INFO 11531
#define IDS_EXTENSION_INSTALLED_MANAGE_SHORTCUTS 11533
#define IDS_EXTENSION_INSTALLED_MANAGE_SHORTCUTS_LINK_TEXT 11534
#define IDS_EXTENSION_LAUNCH_WEB_AUTH_FLOW_TAB_INFO_BAR_TEXT 11535
#define IDS_EXTENSION_INSTALLED_DICE_PROMO_SYNC_MESSAGE 11536
#define IDS_EXTENSION_VERIFY_PROMO_SUBTITLE 11537
#define IDS_EXTENSIONS_DIRECTORY_CONFIRMATION_DIALOG_TITLE 11538
#define IDS_EXTENSIONS_DIRECTORY_CONFIRMATION_DIALOG_MESSAGE_READ_ONLY 11539
#define IDS_EXTENSIONS_DIRECTORY_CONFIRMATION_DIALOG_MESSAGE_WRITABLE 11540
#define IDS_DIRECT_SOCKETS_CONNECTION_BUBBLE_TITLE_LABEL 11541
#define IDS_DIRECT_SOCKETS_CONNECTION_BUBBLE_ADDRESS_LABEL 11542
#define IDS_DIRECT_SOCKETS_CONNECTION_BUBBLE_PORT_LABEL 11543
#define IDS_EXTENSIONS_WANTS_ACCESS_TO_SITE 11544
#define IDS_EXTENSIONS_HAS_ACCESS_TO_SITE 11545
#define IDS_EXTENSIONS_CONTEXT_MENU_SITE_PERMISSIONS 11546
#define IDS_EXTENSIONS_CONTEXT_MENU_CANT_ACCESS_PAGE 11547
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS 11548
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_ALL_EXTENSIONS_GRANTED 11549
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_ALL_EXTENSIONS_BLOCKED 11550
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_CLICK_V2 11551
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_SITE_V2 11552
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_ALL_SITES_V2 11553
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_PERMISSIONS_PAGE 11554
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_CLICK 11555
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_SITE 11556
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_ALL_SITES 11557
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_LEARN_MORE 11558
#define IDS_EXTENSIONS_CONTEXT_MENU_PIN_TO_TOOLBAR 11559
#define IDS_EXTENSIONS_CONTEXT_MENU_UNPIN_FROM_TOOLBAR 11560
#define IDS_EXTENSIONS_OPTIONS_MENU_ITEM 11561
#define IDS_EXTENSIONS_INSTALLED_BY_ADMIN 11562
#define IDS_EXTENSIONS_PIN_TO_TOOLBAR 11563
#define IDS_EXTENSIONS_UNPIN_FROM_TOOLBAR 11564
#define IDS_EXTENSIONS_PINNED_BY_ADMIN 11565
#define IDS_MANAGE_EXTENSION 11566
#define IDS_MANAGE_EXTENSIONS 11567
#define IDS_VIEW_WEB_PERMISSIONS 11568
#define IDS_EXTENSION_ACTION_INSPECT_POPUP 11569
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON 11570
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_DISMISSED_TEXT 11571
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_TOOLTIP_SINGLE_EXTENSION 11572
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_TITLE_HAS_ACCESS 11573
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_TITLE_BLOCKED_ACCESS 11574
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_TITLE_REQUESTS_ACCESS 11575
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_DESCRIPTION_ALL_EXTENSIONS_ALLOWED_ACCESS 11576
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_DESCRIPTION_ALL_EXTENSIONS_BLOCKED_ACCESS 11577
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_DESCRIPTION_EXTENSION_HAS_ACCESS 11578
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_DESCRIPTION_EXTENSION_REQUESTS_ACCESS 11579
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_POLICY_LABEL_PINNED_TEXT 11580
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_POLICY_LABEL_INSTALLED_TEXT 11581
#define IDS_EXTENSIONS_DISABLE 11582
#define IDS_EXTENSIONS_PIN_TO_TOOLBAR_ACCESSIBLE_NAME 11583
#define IDS_EXTENSIONS_UNPIN_FROM_TOOLBAR_ACCESSIBLE_NAME 11584
#define IDS_EXTENSIONS_PINNED_BY_ADMIN_ACCESSIBLE_NAME 11585
#define IDS_EXTENSIONS_SUBMENU_OPEN_SIDE_PANEL_ITEM 11586
#define IDS_EXTENSIONS_SUBMENU_CLOSE_SIDE_PANEL_ITEM 11587
#define IDS_EXTENSIONS_LOCKED_SUPERVISED_USER 11591
#define IDS_EXTENSION_LOAD_FROM_DIRECTORY 11592
#define IDS_EXTENSION_COMMANDS_GENERIC_ACTIVATE 11593
#define IDS_EXTENSIONS_SUPERVISED_USER_PARENTAL_PERMISSION_FAILURE 11594
#define IDS_EXTENSIONS_SUPERVISED_USER_BLOCKED_BY_PARENT 11595
#define IDS_EXTENSION_PACK_DIALOG_HEADING 11596
#define IDS_EXTENSION_PACK_DIALOG_SELECT_KEY 11597
#define IDS_EXTENSION_PACK_DIALOG_KEY_FILE_TYPE_DESCRIPTION 11598
#define IDS_EXTENSION_PACK_DIALOG_ERROR_ROOT_REQUIRED 11599
#define IDS_EXTENSION_PACK_DIALOG_ERROR_ROOT_INVALID 11600
#define IDS_EXTENSION_PACK_DIALOG_ERROR_KEY_INVALID 11601
#define IDS_EXTENSION_PACK_DIALOG_SUCCESS_BODY_NEW 11602
#define IDS_EXTENSION_PACK_DIALOG_SUCCESS_BODY_UPDATE 11603
#define IDS_EXTENSION_PROMPT_INSTALL_FRICTION_CONTINUE_BUTTON 11604
#define IDS_EXTENSION_PROMPT_INSTALL_FRICTION_TITLE 11605
#define IDS_EXTENSION_PROMPT_INSTALL_FRICTION_WARNING_TEXT 11606
#define IDS_EXTENSION_INSTALL_PROMPT_ACCEPT_BUTTON_EXTENSION 11607
#define IDS_EXTENSION_INSTALL_PROMPT_ACCEPT_BUTTON_APP 11608
#define IDS_EXTENSION_INSTALL_PROMPT_ACCEPT_BUTTON_THEME 11609
#define IDS_EXTENSION_INSTALL_PROMPT_ASK_A_PARENT_BUTTON 11610
#define IDS_EXTENSION_INSTALL_BLOCKED_BY_PARENT_PROMPT_TITLE 11611
#define IDS_EXTENSION_ENABLE_BLOCKED_BY_PARENT_PROMPT_TITLE 11612
#define IDS_PARENT_PERMISSION_PROMPT_GO_GET_A_PARENT_FOR_EXTENSION_LABEL 11613
#define IDS_PARENT_PERMISSION_PROMPT_EXTENSION_TYPE_EXTENSION 11614
#define IDS_PARENT_PERMISSION_PROMPT_EXTENSION_TYPE_APP 11615
#define IDS_PARENT_PERMISSION_PROMPT_CHILD_WANTS_TO_INSTALL_LABEL 11616
#define IDS_PARENT_PERMISSION_PROMPT_APPROVE_BUTTON 11617
#define IDS_PARENT_PERMISSION_PROMPT_CANCEL_BUTTON 11618
#define IDS_PARENT_PERMISSION_PROMPT_SELECT_PARENT_LABEL 11619
#define IDS_PARENT_PERMISSION_PROMPT_PARENT_ACCOUNT_LABEL 11620
#define IDS_PARENT_PERMISSION_PROMPT_PARENT_ACCOUNT_VERIFY_LABEL 11621
#define IDS_PARENT_PROMPT_ENTER_PASSWORD_TO_ALLOW_EXTENSION_LABEL 11622
#define IDS_SKIP_PARENT_PERMISSION_EXTENSION_INFORMATION 11623
#define IDS_PARENT_PERMISSION_PROMPT_ENTER_PASSWORD_LABEL 11624
#define IDS_PARENT_PERMISSION_PROMPT_PASSWORD_INCORRECT_LABEL 11625
#define IDS_EXTENSION_INSTALL_PROMPT_REQUEST_BUTTON 11626
#define IDS_EXTENSION_PROMPT_UNINSTALL_BUTTON 11627
#define IDS_EXTENSION_PROMPT_UNINSTALL_REPORT_ABUSE 11628
#define IDS_EXTENSION_PROMPT_UNINSTALL_REPORT_ABUSE_FROM_EXTENSION 11629
#define IDS_EXTENSION_PROMPT_UNINSTALL_TITLE 11630
#define IDS_EXTENSION_PROMPT_UNINSTALL_APP_BUTTON 11631
#define IDS_EXTENSION_PROMPT_MULTIPLE_UNINSTALL_NAME_BULLET_POINT 11632
#define IDS_EXTENSION_PROMPT_MULTIPLE_UNINSTALL_TITLE 11633
#define IDS_EXTENSION_PROMPT_UNINSTALL_TRIGGERED_BY_EXTENSION 11634
#define IDS_EXTENSION_PROMPT_RE_ENABLE_BUTTON 11635
#define IDS_EXTENSION_PROMPT_PERMISSIONS_BUTTON 11636
#define IDS_EXTENSION_PROMPT_PERMISSIONS_ACCEPT_BUTTON 11637
#define IDS_EXTENSION_PROMPT_PERMISSIONS_ABORT_BUTTON 11638
#define IDS_EXTENSION_PROMPT_REMOTE_INSTALL_BUTTON_EXTENSION 11639
#define IDS_EXTENSION_PROMPT_REMOTE_INSTALL_BUTTON_APP 11640
#define IDS_EXTENSION_PROMPT_REPAIR_BUTTON_EXTENSION 11641
#define IDS_EXTENSION_PROMPT_REPAIR_BUTTON_APP 11642
#define IDS_EXTENSION_WEB_STORE_TITLE_SHORT 11643
#define IDS_EXTENSIONS_SHOW_DETAILS 11644
#define IDS_EXTENSIONS_HIDE_DETAILS 11645
#define IDS_WEBSTORE_DOWNLOAD_ACCESS_DENIED 11646
#define IDS_EXTENSION_WARNINGS_WRENCH_MENU_ITEM 11647
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_EXTENSION 11648
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_APP 11649
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_THEME 11650
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_BUBBLE_TITLE 11651
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_BUBBLE_HEADING_APP 11652
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_BUBBLE_HEADING_EXTENSION 11653
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_BUBBLE_HEADING_THEME 11654
#define IDS_EXTENSIONS_ADDED_WITHOUT_KNOWLEDGE 11655
#define IDS_EXTENSIONS_ADDED_WITHOUT_KNOWLEDGE_LEARN_MORE 11656
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_KEEP_DIALOG_TITLE 11657
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_KEEP_DIALOG_OK_BUTTON 11658
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_DISABLED_DIALOG_TITLE 11659
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_DISABLED_DIALOG_PLURAL_TITLE 11660
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_DISABLED_DIALOG_OK_BUTTON 11661
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_DISABLED_DIALOG_CANCEL_BUTTON 11662
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_REENABLE_DIALOG_TITLE 11663
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_REENABLE_DIALOG_OK_BUTTON 11664
#define IDS_EXTENSION_SETTINGS_OVERRIDDEN_DIALOG_CHANGE_IT_BACK 11665
#define IDS_EXTENSION_SETTINGS_OVERRIDDEN_DIALOG_KEEP_IT 11666
#define IDS_EXTENSION_NTP_OVERRIDDEN_DIALOG_TITLE_GENERIC 11667
#define IDS_EXTENSION_NTP_OVERRIDDEN_DIALOG_TITLE_BACK_TO_GOOGLE 11668
#define IDS_EXTENSION_NTP_OVERRIDDEN_DIALOG_BODY_GENERIC 11669
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_TITLE_GENERIC 11670
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_TITLE_BACK_TO_GOOGLE 11671
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_TITLE_BACK_TO_OTHER 11672
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_TITLE_EXPLICIT_CHOICE 11673
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_BODY_GENERIC 11674
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_BODY_EXPLICIT_CHOICE 11675
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_RECENT_CHANGE 11676
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_PREVIOUS_CHOICE 11677
#define IDS_FORCE_INSTALLED_DEPRECATED_APPS_CONTENT 11678
#define IDS_FORCE_INSTALLED_PREINSTALLED_DEPRECATED_APPS_TITLE 11679
#define IDS_FORCE_INSTALLED_PREINSTALLED_DEPRECATED_APPS_CONTENT 11680
#define IDS_FORCE_INSTALLED_PREINSTALLED_DEPRECATED_APPS_GO_TO_SITE_BUTTON 11681
#define IDS_DEPRECATED_APPS_RENDERER_TITLE_PLURAL 11682
#define IDS_DEPRECATED_APPS_RENDERER_TITLE_WITH_APP_NAME 11683
#define IDS_DEPRECATED_APPS_MONITOR_RENDERER 11684
#define IDS_DEPRECATED_APPS_LEARN_MORE 11685
#define IDS_DEPRECATED_APPS_LEARN_MORE_AX_LABEL 11686
#define IDS_DEPRECATED_APPS_DELETION_LINK 11687
#define IDS_DEPRECATED_APPS_OK_LABEL 11688
#define IDS_DEPRECATED_APPS_CANCEL_LABEL 11689
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_TOOLTIP_MULTIPLE_EXTENSIONS 11690
#define IDS_EXTENSIONS_MENU_TITLE 11691
#define IDS_EXTENSIONS_MENU_CONTEXT_MENU_TOOLTIP 11692
#define IDS_EXTENSIONS_MENU_ZERO_STATE_HEADER 11693
#define IDS_EXTENSIONS_MENU_CONTEXT_MENU_TOOLTIP_ACCESSIBLE_NAME 11694
#define IDS_EXTENSIONS_MENU_PIN_BUTTON_TOOLTIP 11695
#define IDS_EXTENSIONS_MENU_UNPIN_BUTTON_TOOLTIP 11696
#define IDS_EXTENSIONS_MENU_ACCESSING_SITE_DATA_SHORT 11697
#define IDS_EXTENSIONS_MENU_ACCESSING_SITE_DATA 11698
#define IDS_EXTENSIONS_MENU_WANTS_TO_ACCESS_SITE_DATA_SHORT 11699
#define IDS_EXTENSIONS_MENU_WANTS_TO_ACCESS_SITE_DATA 11700
#define IDS_EXTENSIONS_MENU_CANT_ACCESS_SITE_DATA_SHORT 11701
#define IDS_EXTENSIONS_MENU_CANT_ACCESS_SITE_DATA 11702
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_LABEL 11703
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_NOT_ALLOWED_LABEL 11704
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_TOGGLE_ON_TOOLTIP 11705
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_TOGGLE_OFF_TOOLTIP 11706
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_TOGGLE_ACCESSIBLE_NAME 11707
#define IDS_EXTENSIONS_MENU_MESSAGE_SECTION_ENTERPRISE_TOOLTIP_ICON_TEXT 11708
#define IDS_EXTENSIONS_MENU_MESSAGE_SECTION_RELOAD_CONTAINER_DESCRIPTION_TEXT 11709
#define IDS_EXTENSIONS_MENU_MESSAGE_SECTION_RELOAD_CONTAINER_BUTTON_TEXT 11710
#define IDS_EXTENSIONS_MENU_MESSAGE_SECTION_RELOAD_CONTAINER_BUTTON_TOOLTIP 11711
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_TITLE 11712
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_ALLOW_BUTTON_TEXT 11713
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_ALLOW_BUTTON_TOOLTIP 11714
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_ALLOW_BUTTON_ACCESSIBLE_NAME 11715
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_DISMISS_BUTTON_TEXT 11716
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_DISMISS_BUTTON_TOOLTIP 11717
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_DISMISS_BUTTON_ACCESSIBLE_NAME 11718
#define IDS_EXTENSIONS_MENU_EXTENSION_SITE_ACCESS_TOGGLE_ON_TOOLTIP 11719
#define IDS_EXTENSIONS_MENU_EXTENSION_SITE_ACCESS_TOGGLE_OFF_TOOLTIP 11720
#define IDS_EXTENSIONS_MENU_EXTENSION_SITE_ACCESS_TOGGLE_ACCESSIBLE_NAME 11721
#define IDS_EXTENSIONS_MENU_EXTENSION_CONTEXT_MENU_BUTTON_TOOLTIP 11722
#define IDS_EXTENSIONS_MENU_EXTENSION_CONTEXT_MENU_BUTTON_ACCESSIBLE_NAME 11723
#define IDS_EXTENSIONS_MENU_EXTENSION_CONTEXT_MENU_BUTTON_PINNED_ACCESSIBLE_NAME 11724
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_NONE 11725
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_DISCOVER_EXTENSIONS 11726
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_TOOLTIP 11727
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_ENTERPRISE_EXTENSION_SITE_ACCESS_TOOLTIP 11728
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_ACCESSIBLE_NAME 11729
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_ENTERPRISE_EXTENSION_SITE_ACCESS_ACCESSIBLE_NAME 11730
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_BUTTON_HAS_ACCESS_TOOLTIP 11731
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_BUTTON_BLOCKED_ACCESS_TOOLTIP 11732
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_BUTTON_REQUESTS_TOOLTIP 11733
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_ON_CLICK 11734
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_ON_SITE 11735
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_ON_ALL_SITES 11736
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SETTINGS_BUTTON 11737
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SETTINGS_BUTTON_TOOLTIP 11738
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SHOW_REQUESTS_LABEL 11739
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SHOW_REQUESTS_TOGGLE_ON 11740
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SHOW_REQUESTS_TOGGLE_OFF 11741
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_LABEL 11742
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_CLICK_TEXT 11743
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_SITE_TEXT 11744
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_ALL_SITES_TEXT 11745
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_CLICK_DESCRIPTION 11746
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_SITE_DESCRIPTION 11747
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_ALL_SITES_DESCRIPTION 11748
#define IDS_EXTENSIONS_CONTROLLED_HOME_DIALOG_TITLE 11749
#define IDS_EXTENSIONS_CONTROLLED_HOME_DIALOG_DESCRIPTION 11750
#define IDS_EXTENSIONS_CONTROLLED_HOME_DIALOG_LEARN_MORE_LINK 11751
#define IDS_EXTENSIONS_SETTINGS_API_SECOND_LINE_SEARCH_ENGINE 11752
#define IDS_EXTENSIONS_PRINTING_API_PRINT_REQUEST_BUBBLE_TITLE 11753
#define IDS_EXTENSIONS_PRINTING_API_PRINT_REQUEST_BUBBLE_HEADING 11754
#define IDS_EXTENSIONS_PRINTING_API_PRINT_REQUEST_ALLOW 11755
#define IDS_EXTENSIONS_PRINTING_API_PRINT_REQUEST_DENY 11756
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_DISCOVERY_REQUEST_BUBBLE_TITLE 11757
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_DISCOVERY_REQUEST_BUBBLE_HEADING 11758
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_DISCOVERY_REQUEST_ALLOW 11759
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_DISCOVERY_REQUEST_DENY 11760
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_START_SCAN_REQUEST_BUBBLE_TITLE 11761
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_START_SCAN_REQUEST_BUBBLE_HEADING 11762
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_START_SCAN_REQUEST_ALLOW 11763
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_START_SCAN_REQUEST_DENY 11764
#define IDS_EXTENSIONS_NTP_CONTROLLED_FIRST_LINE 11765
#define IDS_EXTENSIONS_PROXY_CONTROLLED_FIRST_LINE 11766
#define IDS_EXTENSIONS_PROXY_CONTROLLED_FIRST_LINE_EXTENSION_SPECIFIC 11767
#define IDS_EXTENSIONS_SETTINGS_API_THIRD_LINE_CONFIRMATION 11768
#define IDS_EXTENSION_CONTROLLED_RESTORE_SETTINGS 11769
#define IDS_EXTENSION_CONTROLLED_KEEP_CHANGES 11770
#define IDS_SUB_APPS_INSTALL_DIALOG_TITLE 11771
#define IDS_SUB_APPS_INSTALL_DIALOG_DESCRIPTION 11772
#define IDS_SUB_APPS_INSTALL_DIALOG_PERMISSIONS_DESCRIPTION 11773
#define IDS_SUB_APPS_INSTALL_DIALOG_MANAGE_PERMISSIONS_LINK 11774
#define IDS_SUB_APPS_INSTALL_DIALOG_PERMISSIONS_BUTTON 11775
#define IDS_SUB_APPS_INSTALL_DIALOG_CANCEL_BUTTON 11776
#define IDS_WEB_APP_MENU_BUTTON_TOOLTIP 11777
#define IDS_WEB_APP_MENU_BUTTON_TOOLTIP_UPDATE_AVAILABLE 11778
#define IDS_WEB_APP_MENU_BUTTON_UPDATE 11779
#define IDS_WEB_APP_BLOCKED_MIGRATION_MESSAGE 11780
#define IDS_WEB_APP_ENABLE_WINDOW_CONTROLS_OVERLAY_TOOLTIP 11781
#define IDS_WEB_APP_DISABLE_WINDOW_CONTROLS_OVERLAY_TOOLTIP 11782
#define IDS_WEB_APP_WINDOW_CONTROLS_OVERLAY_ENABLED_ALERT 11783
#define IDS_WEB_APP_WINDOW_CONTROLS_OVERLAY_DISABLED_ALERT 11784
#define IDS_APP_HOME_TITLE 11785
#define IDS_APP_HOME_OPEN_IN_WINDOW 11786
#define IDS_APP_HOME_LAUNCH_AT_STARTUP 11787
#define IDS_APP_HOME_CREATE_SHORTCUT 11788
#define IDS_APP_HOME_INSTALL_LOCALLY 11789
#define IDS_APP_HOME_UNINSTALL_APP 11790
#define IDS_APP_HOME_REMOVE_APP 11791
#define IDS_APP_HOME_APP_SETTINGS 11792
#define IDS_ACCNAME_APP_HOME_NOT_INSTALLED 11793
#define IDS_APP_HOME_APP_NO_APPS 11794
#define IDS_APP_HOME_APP_LEARN_INSTALL 11795
#define IDS_WEB_APP_SETTINGS_TITLE 11796
#define IDS_WEB_APP_SETTINGS_LINK 11797
#define IDS_WEB_APP_SETTINGS_LINK_TOOLTIP 11798
#define IDS_COMPONENTS_TITLE 11799
#define IDS_COMPONENTS_VERSION 11800
#define IDS_COMPONENTS_NONE_INSTALLED 11801
#define IDS_COMPONENTS_NO_COMPONENTS 11802
#define IDS_COMPONENTS_CHECK_FOR_UPDATE 11803
#define IDS_COMPONENTS_STATUS_LABEL 11804
#define IDS_COMPONENTS_CHECKING_LABEL 11805
#define IDS_COMPONENTS_SVC_STATUS_NEW 11806
#define IDS_COMPONENTS_SVC_STATUS_CHECKING 11807
#define IDS_COMPONENTS_SVC_STATUS_UPDATE 11808
#define IDS_COMPONENTS_SVC_STATUS_DNL 11809
#define IDS_COMPONENTS_SVC_STATUS_DECOMPRESSING 11810
#define IDS_COMPONENTS_SVC_STATUS_PATCHING 11811
#define IDS_COMPONENTS_SVC_STATUS_UPDATING 11812
#define IDS_COMPONENTS_SVC_STATUS_UPDATED 11813
#define IDS_COMPONENTS_SVC_STATUS_UPTODATE 11814
#define IDS_COMPONENTS_SVC_STATUS_UPDATE_ERROR 11815
#define IDS_COMPONENTS_UNKNOWN 11816
#define IDS_PASSWORD_MANAGER_ACCOUNT_CHOOSER_TITLE 11817
#define IDS_PASSWORD_GENERATION_SUGGESTION_GPM 11818
#define IDS_PASSWORD_GENERATION_SUGGESTION_GPM_WITHOUT_STRONG 11819
#define IDS_PASSWORD_GENERATION_NUDGE_CANCEL_BUTTON 11820
#define IDS_PASSWORD_MANAGER_CONFIRM_SAVED_TITLE 11821
#define IDS_PASSWORD_MANAGER_CONFIRM_UPDATE_TITLE 11822
#define IDS_PASSWORD_GENERATION_EDITING_SUGGESTION 11823
#define IDS_SAVE_PASSWORD 11824
#define IDS_SAVE_ACCOUNT 11825
#define IDS_ADD_USERNAME_TITLE 11826
#define IDS_ADD_USERNAME 11827
#define IDS_ADD_USERNAME_BODY 11828
#define IDS_UPDATE_PASSWORD 11829
#define IDS_VERIFY_IT_IS_YOU 11830
#define IDS_PASSWORD_ERROR_DESCRIPTION_SIGN_IN 11831
#define IDS_PASSWORD_ERROR_DESCRIPTION_SIGN_UP 11832
#define IDS_PASSWORD_ERROR_VERIFY_BUTTON_TITLE 11833
#define IDS_SAVE_PASSWORD_DIFFERENT_DOMAINS_TITLE 11835
#define IDS_UPDATE_PASSWORD_DIFFERENT_DOMAINS_TITLE 11836
#define IDS_SAVE_PASSWORD_FOOTER 11837
#define IDS_PASSWORD_BUBBLES_PASSWORD_MANAGER_LINK_TEXT_SYNCED_TO_ACCOUNT 11838
#define IDS_PASSWORD_BUBBLES_FOOTER_SYNCED_TO_ACCOUNT 11839
#define IDS_PASSWORD_BUBBLES_FOOTER_SAVING_ON_DEVICE 11840
#define IDS_PASSWORD_GENERATION_PROMPT_GOOGLE_PASSWORD_MANAGER 11841
#define IDS_PASSWORD_GENERATION_NUDGE_TITLE 11842
#define IDS_PASSWORD_MANAGEMENT_BUBBLE_FOOTER_ACCOUNT_STORE_USERS 11843
#define IDS_PASSWORD_MANAGER_GENERATED_PASSWORD_SAVED_MESSAGE_DESCRIPTION 11844
#define IDS_PASSWORD_MANAGER_SAVE_PASSWORD_SIGNED_IN_MESSAGE_DESCRIPTION 11845
#define IDS_PASSWORD_MANAGER_UPDATE_PASSWORD_SIGNED_IN_MESSAGE_DESCRIPTION 11846
#define IDS_PASSWORD_CROSS_DOMAIN_FILLING_CONFIRMATION_TITLE 11847
#define IDS_PASSWORD_CROSS_DOMAIN_FILLING_CONFIRMATION_DESCRIPTION 11848
#define IDS_PASSWORD_CROSS_DOMAIN_FILLING_CONFIRMATION_CONFIRM_BUTTON_LABEL 11849
#define IDS_PASSWORD_CROSS_DOMAIN_FILLING_WARNING_DESCRIPTION 11850
#define IDS_PASSWORD_MANAGER_ACCOUNT_CHOOSER_SIGN_IN 11851
#define IDS_PASSWORD_MANAGER_MANAGE_PASSWORDS_BUTTON 11852
#define IDS_PASSWORD_MANAGER_MANAGE_PASSWORD_BUTTON 11853
#define IDS_SETTINGS_PASSWORDS_ANDROID_APP 11854
#define IDS_SHARED_PASSWORDS_NOTIFICATION_GOT_IT_BUTTON 11855
#define IDS_SHARED_PASSWORDS_NOTIFICATION_TEXT_SINGLE_PASSWORD 11856
#define IDS_SHARED_PASSWORDS_NOTIFICATION_TEXT_MULTIPLE_PASSWORD 11857
#define IDS_SHARED_PASSWORDS_NOTIFICATION_TITLE 11858
#define IDS_PASSWORD_MANAGER_ONBOARDING_TITLE_A 11859
#define IDS_PASSWORD_MANAGER_ONBOARDING_TITLE_B 11860
#define IDS_PASSWORD_MANAGER_ONBOARDING_TITLE_C 11861
#define IDS_PASSWORD_MANAGER_ONBOARDING_DETAILS_A 11862
#define IDS_PASSWORD_MANAGER_ONBOARDING_DETAILS_B 11863
#define IDS_PASSWORD_MANAGER_DICE_PROMO_SIGNIN_MESSAGE 11864
#define IDS_PASSWORD_MANAGER_DICE_PROMO_SYNC_MESSAGE 11865
#define IDS_WEBRTC_LOGS_TITLE 11866
#define IDS_WEBRTC_TEXT_LOGS_LOG_COUNT_BANNER_FORMAT 11867
#define IDS_WEBRTC_EVENT_LOGS_LOG_COUNT_BANNER_FORMAT 11868
#define IDS_WEBRTC_LOGS_LOG_HEADER_FORMAT 11869
#define IDS_WEBRTC_LOGS_LOG_LOCAL_FILE_LABEL_FORMAT 11870
#define IDS_WEBRTC_LOGS_NO_LOCAL_LOG_FILE_MESSAGE 11871
#define IDS_WEBRTC_LOGS_LOG_UPLOAD_TIME_FORMAT 11872
#define IDS_WEBRTC_LOGS_LOG_FAILED_UPLOAD_TIME_FORMAT 11873
#define IDS_WEBRTC_LOGS_LOG_REPORT_ID_FORMAT 11874
#define IDS_WEBRTC_LOGS_BUG_LINK_LABEL 11875
#define IDS_WEBRTC_LOGS_LOG_PENDING_MESSAGE 11876
#define IDS_WEBRTC_LOGS_LOG_ACTIVELY_UPLOADED_MESSAGE 11877
#define IDS_WEBRTC_LOGS_LOG_NOT_UPLOADED_MESSAGE 11878
#define IDS_WEBRTC_LOGS_EVENT_LOG_LOCAL_LOG_ID 11879
#define IDS_WEBRTC_LOGS_NO_TEXT_LOGS_MESSAGE 11880
#define IDS_WEBRTC_LOGS_NO_EVENT_LOGS_MESSAGE 11881
#define IDS_PLUGIN_HIDE 11882
#define IDS_PLUGIN_BLOCKED 11883
#define IDS_PLUGIN_BLOCKED_BY_POLICY 11884
#define IDS_PLUGIN_NOT_AUTHORIZED 11885
#define IDS_PLUGIN_DISABLED 11886
#define IDS_PLUGIN_DEPRECATED 11887
#define IDS_SESSION_CRASHED_BUBBLE_TITLE 11888
#define IDS_SESSION_CRASHED_BUBBLE_UMA_LINK_TEXT 11889
#define IDS_IDLE_BUBBLE_TITLE_CLEAR 11890
#define IDS_SETTINGS_STORAGE_PRESSURE_BUBBLE_VIEW_TITLE 11891
#define IDS_SETTINGS_STORAGE_PRESSURE_BUBBLE_VIEW_MESSAGE 11892
#define IDS_SETTINGS_STORAGE_PRESSURE_BUBBLE_VIEW_BUTTON_LABEL 11893
#define IDS_BAD_FLAGS_WARNING_MESSAGE 11894
#define IDS_BAD_FEATURES_WARNING_MESSAGE 11895
#define IDS_BAD_ENVIRONMENT_VARIABLES_WARNING_MESSAGE 11896
#define IDS_BLOCKED_DISPLAYING_INSECURE_CONTENT_TITLE 11897
#define IDS_BLOCKED_DISPLAYING_INSECURE_CONTENT 11898
#define IDS_ALLOW_INSECURE_CONTENT_BUTTON 11899
#define IDS_ADD_TO_SHELF_INFOBAR_TITLE 11900
#define IDS_ADD_TO_SHELF_INFOBAR_ADD_BUTTON 11901
#define IDS_ABOUT_SYS_TITLE 11902
#define IDS_ABOUT_SYS_DESC 11903
#define IDS_ABOUT_SYS_TABLE_TITLE 11904
#define IDS_ABOUT_SYS_LOG_FILE_TABLE_TITLE 11905
#define IDS_ABOUT_SYS_EXPAND_ALL 11906
#define IDS_ABOUT_SYS_COLLAPSE_ALL 11907
#define IDS_ABOUT_SYS_EXPAND 11908
#define IDS_ABOUT_SYS_COLLAPSE 11909
#define IDS_ABOUT_SYS_PARSE_ERROR 11910
#define IDS_ABOUT_BROWSER_SWITCH_TITLE 11911
#define IDS_ABOUT_BROWSER_SWITCH_OPENING_TITLE_UNKNOWN_BROWSER 11912
#define IDS_ABOUT_BROWSER_SWITCH_OPENING_TITLE_KNOWN_BROWSER 11913
#define IDS_ABOUT_BROWSER_SWITCH_ERROR_TITLE_UNKNOWN_BROWSER 11914
#define IDS_ABOUT_BROWSER_SWITCH_ERROR_TITLE_KNOWN_BROWSER 11915
#define IDS_ABOUT_BROWSER_SWITCH_COUNTDOWN_TITLE_UNKNOWN_BROWSER 11916
#define IDS_ABOUT_BROWSER_SWITCH_COUNTDOWN_TITLE_KNOWN_BROWSER 11917
#define IDS_ABOUT_BROWSER_SWITCH_GENERIC_ERROR_UNKNOWN_BROWSER 11918
#define IDS_ABOUT_BROWSER_SWITCH_GENERIC_ERROR_KNOWN_BROWSER 11919
#define IDS_ABOUT_BROWSER_SWITCH_PROTOCOL_ERROR 11920
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_DESC 11921
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_TITLE 11922
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_NOTHING_SHOWN 11923
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_LBS_DISABLED 11924
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_URL_CHECKER_TITLE 11925
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_URL_CHECKER_DESC 11926
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER 11927
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER_PROTOCOL_REASON 11928
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER_RULE_REASON 11929
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER_INVERT_RULE_REASON 11930
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER_DEFAULT_REASON 11931
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_INVALID_URL 11932
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_TITLE 11933
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_DESC 11934
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SOURCE 11935
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_NOT_CONFIGURED 11936
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SITELIST_NOT_FETCHED 11937
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SITELIST_DOWNLOAD_BUTTON 11938
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SITELIST_LAST_DOWNLOAD_DATE 11939
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SITELIST_NEXT_DOWNLOAD_DATE 11940
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_IN_TITLE 11941
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_IN_DESCRIPTION 11942
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_IN_FIRST_PARAGRAPH 11943
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_IN_SECOND_PARAGRAPH 11944
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_TABLE_COLUMN_RULE 11945
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_TABLE_COLUMN_OPENS_IN 11946
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_TABLE_COLUMN_SOURCE 11947
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_TITLE 11948
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_DESCRIPTION 11949
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_FIRST_PARAGRAPH 11950
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_SECOND_PARAGRAPH 11951
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_TABLE_COLUMN_RULE 11952
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_TABLE_COLUMN_SOURCE 11953
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_POLICIES_DOWNLOAD_BUTTON 11954
#define IDS_OMNIBOX_PLACEHOLDER_TEXT 11959
#define IDS_OMNIBOX_AIM_PLACEHOLDER_TEXT 11960
#define IDS_PASTE_AND_GO 11961
#define IDS_PASTE_AND_SEARCH 11962
#define IDS_PASTE_AND_GO_EMPTY 11963
#define IDS_OMNIBOX_KEYWORD_TEXT 11964
#define IDS_OMNIBOX_CLEAR_ALL 11965
#define IDS_OMNIBOX_WHY_THIS_SUGGESTION 11966
#define IDS_OMNIBOX_CLOSE_IPH_SUGGESTION 11967
#define IDS_OMNIBOX_THUMBS_UP_SUGGESTION 11968
#define IDS_OMNIBOX_THUMBS_DOWN_SUGGESTION 11969
#define IDS_OMNIBOX_REMOVE_SUGGESTION 11970
#define IDS_OMNIBOX_REMOVE_SUGGESTION_BUBBLE_TITLE 11971
#define IDS_OMNIBOX_REMOVE_SUGGESTION_BUBBLE_DESCRIPTION 11972
#define IDS_CONTEXT_MENU_SHOW_FULL_URLS 11973
#define IDS_CONTEXT_MENU_SHOW_SEARCH_TOOLS 11974
#define IDS_WEBUI_OMNIBOX_PLACEHOLDER_TEXT 11977
#define IDS_WEBUI_OMNIBOX_COMPOSE_ASK_ABOUT_THIS_TAB 11978
#define IDS_WEBUI_OMNIBOX_COMPOSE_ASK_ABOUT_THIS_TAB_ARIA_LABEL 11979
#define IDS_WEBUI_OMNIBOX_COMPOSE_ASK_ABOUT_THIS_PAGE 11980
#define IDS_WEBUI_OMNIBOX_COMPOSE_ASK_ABOUT_THIS_PAGE_ARIA_LABEL 11981
#define IDS_WEBUI_OMNIBOX_COMPOSE_LENS_SEARCH_THIS_TAB 11982
#define IDS_WEBUI_OMNIBOX_COMPOSE_LENS_SEARCH_THIS_TAB_ARIA_LABEL 11983
#define IDS_WEBUI_OMNIBOX_COMPOSE_LENS_SEARCH_THIS_PAGE 11984
#define IDS_WEBUI_OMNIBOX_COMPOSE_LENS_SEARCH_THIS_PAGE_ARIA_LABEL 11985
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_MD 11986
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_SHORT 11987
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_MULTIMODAL 11988
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_CONTEXTUAL 11989
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_CONTEXTUAL_PDF 11990
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_LOADING_HINT_PRIMARY 11991
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_LOADING_HINT_PRIMARY_PDF 11992
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_LOADING_HINT_SECONDARY 11993
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_ERROR_TEXT 11994
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_LOADING_HINT_PRIMARY_ALT 11995
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_NO_SUGGEST_TEXT 11996
#define IDS_GOOGLE_SEARCH_BOX_MULTIMODAL_IMAGE_THUMBNAIL 11997
#define IDS_GOOGLE_LENS_SEARCH_BOX_EMPTY_HINT 11998
#define IDS_NTP_SEARCH_BOX_PLACEHOLDER_ASK_OR_TYPE 11999
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_ASK_GOOGLE 12000
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_PLAN 12001
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_COMPARE 12002
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_RESEARCH 12003
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_TEACH 12004
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_WRITE 12005
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_TAB 12006
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_IMAGE 12007
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_CANVAS 12008
#define IDS_NTP_CUSTOM_LINKS_ADD_SHORTCUT_TOOLTIP 12009
#define IDS_NTP_CUSTOM_LINKS_ADD_SHORTCUT_TITLE 12010
#define IDS_NTP_CUSTOM_LINKS_EDIT_SHORTCUT_TOOLTIP 12011
#define IDS_NTP_CUSTOM_LINKS_EDIT_SHORTCUT 12012
#define IDS_NTP_CUSTOM_LINKS_SHORTCUT_DETAILS_TITLE 12013
#define IDS_NTP_CUSTOM_LINKS_MORE_ACTIONS 12014
#define IDS_NTP_ENTERPRISE_SHORTCUT_SUBTITLE 12015
#define IDS_UPLOAD_IMAGE_FORMAT 12016
#define IDS_NTP_CUSTOM_LINKS_NAME 12017
#define IDS_NTP_CUSTOM_LINKS_URL 12018
#define IDS_NTP_CUSTOM_LINKS_REMOVE 12019
#define IDS_NTP_MOST_VISITED_SITES_REMOVE 12020
#define IDS_NTP_CUSTOM_LINKS_CANCEL 12021
#define IDS_NTP_CUSTOM_LINKS_DONE 12022
#define IDS_NTP_CUSTOM_LINKS_DETAILS 12023
#define IDS_NTP_CUSTOM_LINKS_INVALID_URL 12024
#define IDS_NTP_CUSTOM_LINKS_CANT_CREATE 12025
#define IDS_NTP_CUSTOM_LINKS_CANT_EDIT 12026
#define IDS_NTP_CUSTOM_LINKS_CANT_REMOVE 12027
#define IDS_NTP_CUSTOM_LINKS_HELP_PIN 12028
#define IDS_NTP_CONFIRM_MSG_SHORTCUT_REMOVED 12029
#define IDS_NTP_CONFIRM_MSG_SHORTCUT_EDITED 12030
#define IDS_NTP_CONFIRM_MSG_SHORTCUT_ADDED 12031
#define IDS_NTP_CUSTOM_LINKS_ALREADY_EXISTS 12032
#define IDS_NTP_CONFIRM_MSG_RESTORE_DEFAULTS 12033
#define IDS_NTP_CONFIRM_MSG_RESTORE_ENTERPRISE_DEFAULTS 12034
#define IDS_NTP_CUSTOM_BG_UPLOAD_AN_IMAGE 12035
#define IDS_NTP_CUSTOM_BG_SELECT_A_COLLECTION 12036
#define IDS_NTP_CUSTOM_BG_DAILY_REFRESH 12037
#define IDS_NTP_CUSTOM_BG_RESTORE_DEFAULT 12038
#define IDS_NTP_CUSTOM_BG_CANCEL 12039
#define IDS_NTP_CONNECTION_ERROR_NO_PERIOD 12040
#define IDS_NTP_CONNECTION_ERROR 12041
#define IDS_NTP_ERROR_MORE_INFO 12042
#define IDS_NTP_CUSTOM_BG_BACKGROUNDS_UNAVAILABLE 12043
#define IDS_NTP_CUSTOM_BG_BACK_LABEL 12044
#define IDS_NTP_CUSTOM_BG_IMAGE_SELECTED 12045
#define IDS_NTP_CUSTOM_BG_CUSTOMIZE_NTP_LABEL 12046
#define IDS_NTP_CUSTOM_BG_CUSTOMIZE_NTP_WALLPAPER_SEARCH_LABEL 12047
#define IDS_NTP_DISMISS 12048
#define IDS_NTP_DISMISS_PROMO 12049
#define IDS_NTP_DOODLE_SHARE_LABEL 12050
#define IDS_NTP_DOODLE_SHARE_DIALOG_CLOSE_LABEL 12051
#define IDS_NTP_DOODLE_SHARE_DIALOG_FACEBOOK_LABEL 12052
#define IDS_NTP_DOODLE_SHARE_DIALOG_TWITTER_LABEL 12053
#define IDS_NTP_DOODLE_SHARE_DIALOG_MAIL_LABEL 12054
#define IDS_NTP_DOODLE_SHARE_DIALOG_COPY_LABEL 12055
#define IDS_NTP_DOODLE_SHARE_DIALOG_LINK_LABEL 12056
#define IDS_NTP_CUSTOMIZE_APPEARANCE_LABEL 12057
#define IDS_NTP_CUSTOMIZE_THEMES_HEADER 12058
#define IDS_NTP_CUSTOMIZE_MENU_SHORTCUTS_LABEL 12059
#define IDS_NTP_CUSTOMIZE_MENU_TOOLBAR_LABEL 12060
#define IDS_NTP_CUSTOMIZE_MENU_EXTENSIONS_LABEL 12061
#define IDS_NTP_CUSTOMIZE_MENU_MODULES_LABEL 12062
#define IDS_NTP_CUSTOMIZE_NO_BACKGROUND_LABEL 12063
#define IDS_NTP_CUSTOMIZE_CHROME_CHANGE_THEME_LABEL 12064
#define IDS_NTP_CUSTOMIZE_FOOTER_HEADER 12065
#define IDS_NTP_CUSTOMIZE_TOOLS_HEADER 12066
#define IDS_NTP_MANAGED_BY_SEARCH_ENGINE 12067
#define IDS_NTP_MANAGED_BY_EXTENSION 12068
#define IDS_NTP_CUSTOMIZE_CHROME_MANAGED_NEW_TAB_PAGE_ACCESSIBILITY 12069
#define IDS_NTP_CUSTOMIZE_CHROME_RESET_TO_CLASSIC_CHROME_COMPLETE 12070
#define IDS_NTP_CUSTOMIZE_CHROME_RESET_TO_UPLOADED_IMAGE_COMPLETE 12071
#define IDS_NTP_CUSTOMIZE_CHROME_FOLLOW_THEME_LABEL 12072
#define IDS_NTP_CUSTOMIZE_UPLOADED_IMAGE_LABEL 12073
#define IDS_NTP_CUSTOMIZE_YOUR_UPLOADED_IMAGE_LABEL 12074
#define IDS_NTP_CUSTOMIZE_YOUR_SEARCHED_IMAGE_LABEL 12075
#define IDS_NTP_CUSTOMIZE_CHROME_CURRENT_THEME_LABEL 12076
#define IDS_NTP_CUSTOMIZE_SHOW_CARDS_LABEL 12077
#define IDS_NTP_CUSTOMIZE_SHOW_FOOTER_LABEL 12078
#define IDS_NTP_CUSTOMIZE_SHOW_CHIPS_LABEL 12079
#define IDS_NTP_CUSTOMIZE_SHOW_SUGGESTIONS_CHIPS_LABEL 12080
#define IDS_NTP_CUSTOMIZE_SHOW_SHORTCUTS_LABEL 12081
#define IDS_NTP_CUSTOMIZE_SHOW_PERSONAL_SHORTCUTS_LABEL 12082
#define IDS_NTP_CUSTOMIZE_SHOW_PERSONAL_SHORTCUTS_DESC 12083
#define IDS_NTP_CUSTOMIZE_MY_SHORTCUTS_LABEL 12084
#define IDS_NTP_CUSTOMIZE_MOST_VISITED_LABEL 12085
#define IDS_NTP_CUSTOMIZE_ENTERPRISE_SHORTCUTS_LABEL 12086
#define IDS_NTP_CUSTOMIZE_MOST_VISITED_DESC 12087
#define IDS_NTP_CUSTOMIZE_MY_SHORTCUTS_DESC 12088
#define IDS_NTP_CUSTOMIZE_ENTERPRISE_SHORTCUTS_DESC 12089
#define IDS_NTP_CUSTOMIZE_COLOR_PICKER_LABEL 12090
#define IDS_NTP_CUSTOMIZE_COLOR_HUE_SLIDER_TITLE 12091
#define IDS_NTP_CUSTOMIZE_COLOR_HUE_SLIDER_ARIA_LABEL 12092
#define IDS_NTP_CUSTOMIZE_COLOR_HUE_SLIDER_DELETE_TITLE 12093
#define IDS_NTP_CUSTOMIZE_COLOR_HUE_SLIDER_DELETE_A11Y_LABEL 12094
#define IDS_NTP_THEME_MANAGED_DIALOG_TITLE 12095
#define IDS_NTP_THEME_MANAGED_DIALOG_BODY 12096
#define IDS_NTP_THEMES_CONTAINER_LABEL 12097
#define IDS_NTP_CUSTOMIZE_DEFAULT_LABEL 12098
#define IDS_NTP_CUSTOMIZE_GREY_DEFAULT_LABEL 12099
#define IDS_NTP_COLORS_WARM_GREY 12100
#define IDS_NTP_COLORS_COOL_GREY 12101
#define IDS_NTP_COLORS_MIDNIGHT_BLUE 12102
#define IDS_NTP_COLORS_BLACK 12103
#define IDS_NTP_COLORS_BEIGE_AND_WHITE 12104
#define IDS_NTP_COLORS_YELLOW_AND_WHITE 12105
#define IDS_NTP_COLORS_GREEN_AND_WHITE 12106
#define IDS_NTP_COLORS_LIGHT_TEAL_AND_WHITE 12107
#define IDS_NTP_COLORS_LIGHT_PURPLE_AND_WHITE 12108
#define IDS_NTP_COLORS_PINK_AND_WHITE 12109
#define IDS_NTP_COLORS_BEIGE 12110
#define IDS_NTP_COLORS_ORANGE 12111
#define IDS_NTP_COLORS_LIGHT_GREEN 12112
#define IDS_NTP_COLORS_LIGHT_TEAL 12113
#define IDS_NTP_COLORS_LIGHT_BLUE 12114
#define IDS_NTP_COLORS_PINK 12115
#define IDS_NTP_COLORS_DARK_PINK_AND_RED 12116
#define IDS_NTP_COLORS_DARK_RED_AND_ORANGE 12117
#define IDS_NTP_COLORS_DARK_GREEN 12118
#define IDS_NTP_COLORS_DARK_TEAL 12119
#define IDS_NTP_COLORS_DARK_BLUE 12120
#define IDS_NTP_COLORS_DARK_PURPLE 12121
#define IDS_NTP_COLORS_BLUE 12122
#define IDS_NTP_COLORS_GREY 12123
#define IDS_NTP_COLORS_AQUA 12124
#define IDS_NTP_COLORS_GREEN 12125
#define IDS_NTP_COLORS_VIRIDIAN 12126
#define IDS_NTP_COLORS_CITRON 12127
#define IDS_NTP_COLORS_APRICOT 12128
#define IDS_NTP_COLORS_ROSE 12129
#define IDS_NTP_COLORS_FUCHSIA 12130
#define IDS_NTP_COLORS_VIOLET 12131
#define IDS_NTP_COLORS_BATCH_UPLOAD_DESCRIPTION 12132
#define IDS_NTP_UNDO_DISMISS_PROMO_BUTTON_TOAST 12133
#define IDS_NTP_CUSTOMIZE_CHROME_COLOR_SCHEME_MODE_GROUP_LABEL 12134
#define IDS_NTP_CUSTOMIZE_CHROME_COLOR_SCHEME_MODE_LIGHT_LABEL 12135
#define IDS_NTP_CUSTOMIZE_CHROME_COLOR_SCHEME_MODE_DARK_LABEL 12136
#define IDS_NTP_CUSTOMIZE_CHROME_COLOR_SCHEME_MODE_SYSTEM_LABEL 12137
#define IDS_NTP_CUSTOMIZE_CHROME_WEBSTORE_LABEL 12138
#define IDS_NTP_SHOW_MORE_BUTTON_LABEL 12139
#define IDS_NTP_SHOW_LESS_BUTTON_LABEL 12140
#define IDS_NTP_THREADS_HISTORY_LABEL 12141
#define IDS_NTP_THREADS_NEW_SEARCH_LABEL 12142
#define IDS_NTP_WEBSTORE_SHOPPING_CATEOGRY_LABEL 12143
#define IDS_NTP_WEBSTORE_WRITTING_HELP_COLLECTION_LABEL 12144
#define IDS_NTP_WEBSTORE_PRODUCTIVITY_CATEOGRY_LABEL 12145
#define IDS_NTP_WEBSTORE_TOAST_MESSAGE 12146
#define IDS_NTP_WEBSTORE_TOAST_BUTTON_TEXT 12147
#define IDS_NTP_WALLPAPER_SEARCH_FEEDBACK_PLACEHOLDER 12148
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_DESCRIPTION 12149
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_DESCRIPTION_WITH_HISTORY 12150
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_DESCRIPTION_WITH_INSPIRATION 12151
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_DESCRIPTION_WITH_HISTORY_AND_INSPIRATION 12152
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_TITLE 12153
#define IDS_NTP_WALLPAPER_SEARCH_TILE_LABEL 12154
#define IDS_NTP_WALLPAPER_SEARCH_PAGE_HEADER 12155
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_HEADER 12156
#define IDS_NTP_WALLPAPER_SEARCH_OFFLINE_DESCRIPTION 12157
#define IDS_NTP_WALLPAPER_SEARCH_OFFLINE_DESCRIPTION_WITH_HISTORY 12158
#define IDS_NTP_WALLPAPER_SEARCH_OFFLINE_TITLE 12159
#define IDS_NTP_WALLPAPER_SEARCH_OPTIONAL_DETAILS_LABEL 12160
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_RED_LABEL 12161
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_BLUE_LABEL 12162
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_YELLOW_LABEL 12163
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_GREEN_LABEL 12164
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_BLACK_LABEL 12165
#define IDS_NTP_WALLPAPER_SEARCH_REQUEST_THROTTLED_DESCRIPTION 12166
#define IDS_NTP_WALLPAPER_SEARCH_REQUEST_THROTTLED_TITLE 12167
#define IDS_NTP_WALLPAPER_SEARCH_SUBMIT_BTN_TEXT 12168
#define IDS_NTP_WALLPAPER_SEARCH_TRY_AGAIN_CTA 12169
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL_NO_DESCRIPTOR 12170
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL 12171
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL_WITH_DESCRIPTOR_B 12172
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL_WITH_DESCRIPTOR_C 12173
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL_WITH_DESCRIPTORS_B_AND_C 12174
#define IDS_NTP_WALLPAPER_SEARCH_RESULT_LABEL 12175
#define IDS_NTP_WALLPAPER_SEARCH_RESULT_LABEL_WITH_DESCRIPTOR_B 12176
#define IDS_NTP_WALLPAPER_SEARCH_RESULT_LABEL_WITH_DESCRIPTOR_C 12177
#define IDS_NTP_WALLPAPER_SEARCH_RESULT_LABEL_WITH_DESCRIPTORS_B_AND_C 12178
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_LABEL 12179
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_DEFAULT_OPTION_LABEL 12180
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_LABEL 12181
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_DEFAULT_OPTION_LABEL 12182
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_LABEL 12183
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_DEFAULT_OPTION_LABEL 12184
#define IDS_LEARN_MORE_ABOUT_FEATURE_A11Y_LABEL 12185
#define IDS_THUMBS_DOWN_OPENS_FEEDBACK_FORM_A11Y_LABEL 12186
#define IDS_THUMBS_UP_RESULTS_A11Y_LABEL 12187
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_HEADER 12188
#define IDS_NTP_WALLPAPER_SEARCH_LOADING_A11Y_MESSAGE 12189
#define IDS_NTP_WALLPAPER_SEARCH_SUCCESS_A11Y_MESSAGE 12190
#define IDS_NTP_WALLPAPER_SEARCH_DISCLAIMER 12191
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_CARD_TOGGLE_TITLE 12192
#define IDS_NTP_WALLPAPER_SEARCH_DESCRIPTORS_CHANGED_A11Y_MESSAGE 12193
#define IDS_NTP_WALLPAPER_SEARCH_SIGNED_OUT_DESCRIPTION 12194
#define IDS_NTP_WALLPAPER_SEARCH_SIGNED_OUT_TITLE 12195
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_DESSERTS 12196
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_INTERIORS 12197
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_LANDSCAPE 12198
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_NATURE 12199
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_OUTER_SPACE 12200
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_PLACES 12201
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_STRUCTURES 12202
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CAKE_POPS 12203
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CHEESECAKE 12204
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_FRUIT_TART 12205
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ICE_CREAM 12206
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_MACARON 12207
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_PANNA_COTTA 12208
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CHEMISTRY_LAB 12209
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_HALLWAY 12210
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_KITCHEN 12211
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_LIVING_ROOM 12212
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_READING_NOOK 12213
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_DESERT 12214
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_FOREST 12215
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_HIGHLANDS 12216
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_MEADOW 12217
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_MOUNTAIN 12218
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_OCEAN 12219
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_RAINFOREST 12220
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_RICE_PADDY 12221
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SALT_FLAT 12222
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SHORELINE 12223
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_TUNDRA 12224
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_WATERFALL 12225
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_AURORA_BOREALIS 12226
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CLIFF 12227
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CRASHING_WAVES 12228
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CREEK 12229
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ECLIPSES 12230
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_FLOWERS 12231
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_LIGHTNING 12232
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_NIGHT_SKY 12233
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_PALM_TREE 12234
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_RAINBOW 12235
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_RIVER 12236
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SLOT_CANYON 12237
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SUNSET 12238
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ASTEROID 12239
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_COMET 12240
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_MOON 12241
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_NEBULA 12242
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_PLANET 12243
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SPACE_STATION 12244
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_STARS 12245
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CHICHEN_ITZA 12246
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_GRAND_CANYON 12247
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_GRAND_TETON_NATIONAL_PARK 12248
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_GREAT_PYRAMID_OF_GIZA 12249
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ROCKY_MOUNTAINS_NATIONAL_PARK 12250
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_THE_COLOSSEUM 12251
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ZION_NATIONAL_PARK 12252
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_BRICK_BUILDING 12253
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CASTLE 12254
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_HIGHWAY 12255
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_HOUSE 12256
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_LIGHTHOUSE 12257
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_PIER 12258
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_ANIMATED 12259
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_COLORED_PENCIL 12260
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_CYBERPUNK 12261
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_DREAM 12262
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_EXPRESSIONISM 12263
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_FANTASY 12264
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_IMPRESSIONISM 12265
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_OIL_PAINTING 12266
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_ORGANIC 12267
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_PHOTOGRAPHY 12268
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_SPLATTER 12269
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_STEAMPUNK 12270
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_WATERCOLOR 12271
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_CHAOTIC 12272
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_CREATIVE 12273
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_DARK 12274
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_DREAMY 12275
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_EXCITED 12276
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_HAPPY 12277
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_INTELLECTUAL 12278
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_ORDERLY 12279
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_ROMANTIC 12280
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_SERENE 12281
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_SNOWY 12282
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_SUBDUED 12283
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_SUNNY 12284
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_THOUGHTFUL 12285
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_WHIMSICAL 12286
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_WILD 12287
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_1 12288
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_2 12289
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_3 12290
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_4 12291
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_5 12292
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_6 12293
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_7 12294
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_8 12295
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_9 12296
#define IDS_NTP_WALLPAPER_SEARCH_SEPARATOR 12297
#define IDS_NTP_CUSTOMIZE_TOOLBAR_BUTTON_A11Y_LABEL 12298
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CHOOSE_ICONS_LABEL 12299
#define IDS_NTP_CUSTOMIZE_TOOLBAR_ENTERPRISE_ENABLED_LABEL 12300
#define IDS_NTP_CUSTOMIZE_TOOLBAR_REORDER_TIP_LABEL 12301
#define IDS_NTP_CUSTOMIZE_TOOLBAR_RESET_TO_DEFAULT_ANNOUNCEMENT 12302
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CATEGORY_NAVIGATION 12303
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CATEGORY_SIDE_PANELS 12304
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CATEGORY_TOOLS_AND_ACTIONS 12305
#define IDS_NTP_CUSTOMIZE_TOOLBAR_RESET_TO_DEFAULT_BUTTON_LABEL 12306
#define IDS_NTP_COMPOSE_ENTRYPOINT 12307
#define IDS_NTP_COMPOSE_ENTRYPOINT_A11Y_LABEL 12308
#define IDS_NTP_COMPOSE_PLACEHOLDER_TEXT 12309
#define IDS_NTP_COMPOSE_CANCEL_BUTTON_A11Y_LABEL 12310
#define IDS_NTP_COMPOSE_CANCEL_BUTTON_A11Y_LABEL_INPUT 12311
#define IDS_NTP_COMPOSE_IMAGE_UPLOAD_BUTTON_A11Y_LABEL 12312
#define IDS_NTP_COMPOSE_PDF_UPLOAD_BUTTON_A11Y_LABEL 12313
#define IDS_NTP_COMPOSE_SUBMIT_BUTTON_A11Y_LABEL 12314
#define IDS_NTP_COMPOSE_DELETE_FILE_A11Y_LABEL 12315
#define IDS_NTP_COMPOSE_FILE_UPLOAD_STARTED_A11Y_TEXT 12316
#define IDS_NTP_COMPOSE_FILE_UPLOAD_COMPLETE_A11Y_TEXT 12317
#define IDS_NTP_COMPOSE_FILE_UPLOAD_INVALID_EMPTY_SIZE 12318
#define IDS_NTP_COMPOSE_FILE_UPLOAD_INVALID_TOO_LARGE 12319
#define IDS_NTP_COMPOSE_FILE_UPLOAD_IMAGE_PROCESSING_ERROR 12320
#define IDS_NTP_COMPOSE_FILE_UPLOAD_VALIDATION_FAILED 12321
#define IDS_NTP_COMPOSE_DRAG_AND_DROP_HINT 12322
#define IDS_NTP_COMPOSE_MAX_FILES_REACHED_ERROR 12323
#define IDS_NTP_COMPOSE_MAX_IMAGES_REACHED_ERROR 12324
#define IDS_NTP_COMPOSE_MAX_PDFS_REACHED_ERROR 12325
#define IDS_NTP_COMPOSE_FILE_TYPE_NOT_ALLOWED_ERROR 12326
#define IDS_NTP_COMPOSE_FILE_UPLOAD_NOT_ALLOWED 12327
#define IDS_NTP_COMPOSE_FILE_UPLOAD_FAILED 12328
#define IDS_NTP_COMPOSE_FILE_UPLOAD_EXPIRED 12329
#define IDS_NTP_COMPOSE_MOST_RECENT_TABS 12330
#define IDS_NTP_COMPOSEBOX_TAB_PICKER_ADD_TABS_TITLE 12331
#define IDS_NTP_COMPOSE_ADD_IMAGE 12332
#define IDS_NTP_COMPOSE_ADD_FILE 12333
#define IDS_NTP_COMPOSE_ADD_CONTEXT 12334
#define IDS_NTP_COMPOSE_ADD_CONTEXTS 12335
#define IDS_NTP_COMPOSE_ADD_CONTEXT_TITLE 12336
#define IDS_NTP_COMPOSE_SUGGESTIONS_INFO 12337
#define IDS_NTP_COMPOSE_SMART_COMPOSE_A11Y_LABEL 12338
#define IDS_NTP_COMPOSE_SMART_COMPOSE_TAB 12339
#define IDS_NTP_COMPOSE_DEEP_SEARCH 12340
#define IDS_NTP_COMPOSE_CREATE_IMAGES 12341
#define IDS_NTP_COMPOSE_CANVAS 12342
#define IDS_NTP_COMPOSE_MODELS_LABEL 12343
#define IDS_NTP_COMPOSE_AUTO_MODEL 12344
#define IDS_NTP_COMPOSE_THINKING_3_PRO 12345
#define IDS_COMPOSE_DEEP_SEARCH_PLACEHOLDER 12346
#define IDS_COMPOSE_CREATE_IMAGE_IPH 12347
#define IDS_COMPOSE_DEEP_SEARCH_IPH 12348
#define IDS_COMPOSE_CREATE_IMAGE_PLACEHOLDER 12349
#define IDS_COMPOSE_HINT_TEXT_ASK_ABOUT_THESE 12350
#define IDS_COMPOSE_HINT_TEXT_ASK_ABOUT_THIS_IMAGE 12351
#define IDS_COMPOSE_HINT_TEXT_ASK_ABOUT_THIS_TAB 12352
#define IDS_COMPOSE_HINT_TEXT_ASK_ABOUT_THIS_DOC 12353
#define IDS_NTP_ACTION_CHIP_TAB_HEADING_1 12354
#define IDS_NTP_ACTION_CHIP_TAB_HEADING_2 12355
#define IDS_NTP_ACTION_CHIP_TAB_BODY_1 12356
#define IDS_NTP_ACTION_CHIP_TAB_BODY_2 12357
#define IDS_NTP_ACTION_CHIP_CREATE_IMAGE_HEADING 12358
#define IDS_NTP_ACTION_CHIP_CREATE_IMAGE_BODY_1 12359
#define IDS_NTP_ACTION_CHIP_CREATE_IMAGE_BODY_2 12360
#define IDS_NTP_ACTION_CHIP_DEEP_SEARCH_HEADING 12361
#define IDS_NTP_ACTION_CHIP_DEEP_SEARCH_BODY 12362
#define IDS_NTP_ACTION_CHIP_CANVAS_HEADING 12363
#define IDS_NTP_ACTION_CHIP_CANVAS_BODY 12364
#define IDS_NTP_ACTION_CHIP_DISABLE_TEXT 12365
#define IDS_NTP_ACTION_CHIPS_UNDO_DISABLEMENT_TOAST_MESSAGE 12366
#define IDS_COMPOSE_REMOVE_TOOL_CHIP_A11Y_LABEL 12367
#define IDS_COMPOSE_ASK_ABOUT_THIS_TAB 12368
#define IDS_COMPOSE_ASK_ABOUT_THIS_TAB_ARIA_LABEL 12369
#define IDS_COMPOSE_ASK_ABOUT_THIS_PAGE 12370
#define IDS_COMPOSE_ASK_ABOUT_THIS_PAGE_ARIA_LABEL 12371
#define IDS_NTP_MODULES_SETUP_LIST_DISABLE_TOAST_MESSAGE 12372
#define IDS_NTP_MODULES_SETUP_LIST_DISMISS_TOAST_MESSAGE 12373
#define IDS_NTP_MODULES_SETUP_LIST_INFO 12374
#define IDS_NTP_MODULES_INFO_BUTTON_TITLE 12375
#define IDS_NTP_MODULES_DISMISS_TOAST_MESSAGE 12376
#define IDS_NTP_MODULES_DISABLE_TOAST_MESSAGE 12377
#define IDS_NTP_MODULE_INACTIVITY_REMOVAL 12378
#define IDS_NTP_MODULES_INACTIVITY_REMOVAL 12379
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DISABLE_TOAST_MESSAGE 12380
#define IDS_NTP_MODULES_DISMISS_BUTTON_TEXT 12381
#define IDS_NTP_MODULES_DRIVE_MORE_ACTIONS_BUTTON_TEXT 12382
#define IDS_NTP_MODULES_DISABLE_BUTTON_TEXT 12383
#define IDS_NTP_MODULES_DISABLE_BUTTON_TEXT_V2 12384
#define IDS_NTP_MODULES_MORE_ACTIONS 12385
#define IDS_NTP_MODULE_HEADER_MORE_ACTIONS_MENU 12386
#define IDS_NTP_MODULES_CUSTOMIZE_BUTTON_TEXT 12387
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_TODAY 12388
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_YESTERDAY 12389
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_PAST_WEEK 12390
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_PAST_MONTH 12391
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_PREVIOUSLY 12392
#define IDS_NTP_MODULES_SHOPPING_TASKS_SENTENCE 12393
#define IDS_NTP_MODULES_SHOPPING_TASKS_LOWER 12394
#define IDS_NTP_MODULES_DRIVE_DISABLE_BUTTON_TEXT 12395
#define IDS_NTP_MODULES_DRIVE_DISABLE_BUTTON_TEXT_V2 12396
#define IDS_NTP_MODULES_DRIVE_NAME 12397
#define IDS_NTP_MODULES_FILES_SENTENCE 12398
#define IDS_NTP_MODULES_DUMMY_LOWER 12399
#define IDS_NTP_MODULES_DUMMY_TITLE 12400
#define IDS_NTP_MODULES_DRIVE_INFO 12401
#define IDS_NTP_MODULES_MICROSOFT_FILES_NAME 12402
#define IDS_NTP_MODULES_MICROSOFT_FILES_INFO 12403
#define IDS_NTP_MODULES_MICROSOFT_FILES_DISABLE_BUTTON_TEXT 12404
#define IDS_NTP_MODULES_MICROSOFT_FILES_TRENDING_JUSTIFICATION_TEXT 12405
#define IDS_NTP_MODULES_MICROSOFT_FILES_OPENED_TODAY_JUSTIFICATION_TEXT 12406
#define IDS_NTP_MODULES_MICROSOFT_FILES_OPENED_YESTERDAY_JUSTIFICATION_TEXT 12407
#define IDS_NTP_MODULES_MICROSOFT_FILES_OPENED_PAST_WEEK_JUSTIFICATION_TEXT 12408
#define IDS_NTP_MODULES_MICROSOFT_FILES_SHARED_BY_JUSTIFICATION_TEXT 12409
#define IDS_NTP_MODULES_DISMISS_FOR_HOURS_BUTTON_TEXT 12410
#define IDS_NTP_MODULES_DISMISS_FOR_DAYS_BUTTON_TEXT 12411
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_DISMISS_TOAST_MESSAGE 12412
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_DISABLE_TOAST_MESSAGE 12413
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_INFO 12414
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_MORE_ACTIONS 12415
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_TITLE 12416
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_DISABLE_BUTTON_TEXT 12417
#define IDS_NTP_MODULES_MICROSOFT_SIGN_OUT_BUTTON_TEXT 12418
#define IDS_NTP_MODULES_OUTLOOK_CALENDAR_TITLE 12419
#define IDS_NTP_MODULES_OUTLOOK_CALENDAR_DISABLE_BUTTON_TEXT 12420
#define IDS_NTP_MODULES_OUTLOOK_CALENDAR_DISMISS_TOAST_MESSAGE 12421
#define IDS_NTP_MODULES_OUTLOOK_CALENDAR_INFO 12422
#define IDS_NTP_MODULES_CALENDAR_DOUBLE_BOOKED 12423
#define IDS_NTP_MODULES_CALENDAR_JOIN_MEETING_BUTTON_TEXT 12424
#define IDS_NTP_MODULES_CALENDAR_JOIN_MEETING_BUTTON_ACCNAME 12425
#define IDS_NTP_MODULES_CALENDAR_IN_PROGRESS 12426
#define IDS_NTP_MODULES_CALENDAR_IN_X_MIN 12427
#define IDS_NTP_MODULES_CALENDAR_IN_X_HR 12428
#define IDS_NTP_MODULES_CALENDAR_SEE_MORE 12429
#define IDS_NTP_MODULES_CALENDAR_SEE_MORE_ACCNAME 12430
#define IDS_NTP_MODULES_KALEIDOSCOPE_TITLE 12431
#define IDS_NTP_MODULES_SHOPPING_TASKS_INFO_TITLE 12432
#define IDS_NTP_MODULES_TASKS_INFO 12433
#define IDS_NTP_MODULES_SHOPPING_TASKS_INFO_CLOSE 12434
#define IDS_NTP_MODULES_SHOPPING_TASKS_RELATED 12435
#define IDS_NTP_MODULES_CART_DISCOUNT_CHIP_AMOUNT 12436
#define IDS_NTP_MODULES_CART_DISCOUNT_CHIP_UP_TO_AMOUNT 12437
#define IDS_NTP_MODULES_CUSTOMIZE_IPH 12438
#define IDS_NTP_MODULES_FEED_TITLE 12439
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_RESUME_BROWSING 12440
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_RESUME_BROWSING_FOR 12441
#define IDS_NTP_MODULES_SHOW_ALL 12442
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_BOOKMARKED 12443
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_INFO 12444
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_WITH_DISCOUNT_INFO 12445
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_SENTENCE2 12446
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DISABLE_TOAST_NAME 12447
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DISMISS_BUTTON 12448
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DISABLE_DROPDOWN_TEXT 12449
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DONE_BUTTON 12450
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_OPEN_ALL_IN_NEW_TAB_GROUP_BUTTON_TEXT 12451
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_SHOW_ALL_BUTTON 12452
#define IDS_ACCNAME_SHOW_ALL 12453
#define IDS_ACCNAME_SEARCH_SUGG 12454
#define IDS_NTP_MODULES_TAB_RESUMPTION_DISMISS_BUTTON 12455
#define IDS_NTP_MODULES_TAB_RESUMPTION_INFO 12456
#define IDS_NTP_MODULES_TAB_RESUMPTION_MULTI_DISMISS 12457
#define IDS_NTP_MODULES_TAB_RESUMPTION_SINGLE_DISMISS 12458
#define IDS_NTP_MODULES_TAB_RESUMPTION_RECENTLY_OPENED 12459
#define IDS_NTP_MODULES_TAB_RESUMPTION_DEVICE_PREFIX 12460
#define IDS_NTP_MODULES_MOST_RELEVANT_TAB_RESUMPTION_DISMISS_BUTTON 12461
#define IDS_NTP_MODULES_MOST_RELEVANT_TAB_RESUMPTION_TITLE 12462
#define IDS_NTP_MODULES_MOST_RELEVANT_TAB_RESUMPTION_SEE_MORE 12463
#define IDS_NTP_MODULES_MICROSOFT_AUTHENTICATION_NAME 12464
#define IDS_NTP_MODULES_TAB_GROUPS_DISMISS_TOAST_MESSAGE 12465
#define IDS_NTP_MODULES_TAB_GROUPS_DISABLE_TOAST_MESSAGE 12466
#define IDS_NTP_MODULES_TAB_GROUPS_INFO 12467
#define IDS_NTP_MODULES_TAB_GROUPS_TITLE 12468
#define IDS_NTP_MODULES_TAB_GROUPS_TIME_DELTA 12469
#define IDS_NTP_MODULES_TAB_GROUPS_RECENTLY_USED 12470
#define IDS_NTP_MODULES_TAB_GROUPS_ZERO_STATE_TITLE 12471
#define IDS_NTP_MODULES_TAB_GROUPS_ZERO_STATE_TEXT 12472
#define IDS_NTP_MICROSOFT_AUTHENTICATION_DISABLE_BUTTON_TEXT 12473
#define IDS_NTP_MICROSOFT_AUTHENTICATION_DISMISS_BUTTON_TEXT 12474
#define IDS_NTP_MICROSOFT_AUTHENTICATION_HEADING 12475
#define IDS_NTP_MICROSOFT_AUTHENTICATION_SUBHEADING 12476
#define IDS_NTP_MICROSOFT_AUTHENTICATION_SIGN_IN_BUTTON_TEXT 12477
#define IDS_NTP_MICROSOFT_AUTHENTICATION_SIDE_PANEL_DESCRIPTION 12478
#define IDS_NTP_MOBILE_PROMO_HEADER 12479
#define IDS_NTP_MOBILE_PROMO_DESCRIPTION 12480
#define IDS_NTP_MOBILE_PROMO_QR_CODE_LABEL 12481
#define IDS_NTP_MOST_VISITED_SHORTCUTS_INACTIVITY_REMOVAL 12482
#define IDS_EXTENSIONS_PROMO_PERFORMANCE 12483
#define IDS_EXTENSIONS_PROMO_PRIVACY 12484
#define IDS_EXTENSIONS_PROMO_NEUTRAL 12485
#define IDS_NEW_TAB_FOOTER_NAME 12486
#define IDS_OPENS_MANAGEMENT_PAGE 12487
#define IDS_HIDE_NEW_TAB_FOOTER 12488
#define IDS_NEW_TAB_FOOTER_BACKGROUND_ATTRIBUTION_ARIA_DESC 12489
#define IDS_NEW_TAB_FOOTER_BACKGROUND_ATTRIBUTION_TEXT 12490
#define IDS_STAR_VIEW_MENU_ADD_BOOKMARK 12491
#define IDS_STAR_VIEW_MENU_EDIT_BOOKMARK 12492
#define IDS_STAR_VIEW_MENU_MOVE_TO_READ_LATER 12493
#define IDS_STAR_VIEW_MENU_MARK_AS_READ 12494
#define IDS_READ_LATER_TITLE 12495
#define IDS_READ_LATER_EXPAND_BUTTON_ARIA_LABEL 12496
#define IDS_READ_LATER_COLLAPSE_BUTTON_ARIA_LABEL 12497
#define IDS_READ_LATER_MENU_UNREAD_HEADER 12498
#define IDS_READ_LATER_MENU_READ_HEADER 12499
#define IDS_READ_LATER_MENU_TOOLTIP_MARK_AS_READ 12500
#define IDS_READ_LATER_MENU_TOOLTIP_MARK_AS_UNREAD 12501
#define IDS_READ_LATER_MENU_EMPTY_STATE_ADD_FROM_DIALOG_SUBHEADER 12502
#define IDS_READ_LATER_MENU_EMPTY_STATE_HEADER 12503
#define IDS_READ_LATER_MENU_EMPTY_STATE_SUBHEADER 12504
#define IDS_READ_LATER_ADD_CURRENT_TAB 12505
#define IDS_READ_LATER_CANT_ADD_CURRENT_TAB 12506
#define IDS_READ_LATER_MARK_CURRENT_TAB_READ 12507
#define IDS_READ_LATER_REMOVE_CURRENT_TAB 12508
#define IDS_READ_LATER_CONTEXT_MENU_MARK_AS_UNREAD 12509
#define IDS_READ_LATER_CONTEXT_MENU_MARK_AS_READ 12510
#define IDS_READ_LATER_CONTEXT_MENU_DELETE 12511
#define IDS_READING_LIST_MENU 12512
#define IDS_READING_LIST_MENU_ADD_TAB 12513
#define IDS_READING_LIST_MENU_SHOW_UI 12514
#define IDS_ACCNAME_SIDE_PANEL_RESIZE 12515
#define IDS_ACCNAME_SIDE_PANEL_CLOSE 12516
#define IDS_SIDE_PANEL_RESIZE_ACCESSIBLE_ALERT 12517
#define IDS_SIDE_PANEL_RESIZE_LEFT_SIDE_ACCESSIBLE_ALERT 12518
#define IDS_SIDE_PANEL_RESIZE_RIGHT_SIDE_ACCESSIBLE_ALERT 12519
#define IDS_ACCNAME_SIDE_PANEL_SELECTOR 12520
#define IDS_ACCNAME_SIDE_PANEL_COMPANION_SHOW 12521
#define IDS_ACCNAME_SIDE_PANEL_COMPANION_HIDE 12522
#define IDS_SIDE_PANEL_COMPANION_TITLE 12523
#define IDS_SIDE_PANEL_COMPANION_TOOLBAR_TOOLTIP 12524
#define IDS_SIDE_PANEL_COMPANION_PROMO 12525
#define IDS_SIDE_PANEL_COMPANION_PROMO_PINNING 12526
#define IDS_SIDE_PANEL_COMPANION_PROMO_SCREEN_READER 12527
#define IDS_SIDE_PANEL_COMPANION_ERROR_PAGE_FIRST_LINE 12528
#define IDS_SIDE_PANEL_COMPANION_ERROR_PAGE_SECOND_LINE 12529
#define IDS_SHOW_CUSTOMIZE_CHROME_SIDE_PANEL 12530
#define IDS_SHOW_CUSTOMIZE_CHROME_TOOLBAR 12531
#define IDS_SIDE_PANEL_TOOLBAR_BUTTON_CXMENU_UNPIN 12532
#define IDS_SIDE_PANEL_TOOLBAR_BUTTON_CXMENU_PIN 12533
#define IDS_SIDE_PANEL_HEADER_UNPIN_BUTTON_TOOLTIP 12534
#define IDS_SIDE_PANEL_HEADER_PIN_BUTTON_TOOLTIP 12535
#define IDS_SIDE_PANEL_UNPINNED 12536
#define IDS_SIDE_PANEL_PINNED 12537
#define IDS_PINNED_ACTION_BUTTON_ACCESSIBLE_TITLE 12538
#define IDS_SIDE_PANEL_GENERIC_PINNABLE_IPH 12539
#define IDS_SIDE_PANEL_GENERIC_PINNABLE_IPH_SCREENREADER 12540
#define IDS_SIDE_PANEL_HEADER_MORE_INFO_BUTTON_TOOLTIP 12541
#define IDS_BOOKMARKS_MOVE_TO_ACCOUNT_DIALOG_TITLE 12542
#define IDS_BOOKMARKS_MOVE_TO_ACCOUNT_DIALOG_SUBTITLE 12543
#define IDS_BOOKMARKS_MOVE_TO_ACCOUNT_DIALOG_FOLDER_SUBTITLE 12544
#define IDS_BOOKMARKS_MOVE_TO_ACCOUNT_DIALOG_OK_BUTTON_LABEL 12545
#define IDS_BOOKMARKS_MOVE_TO_DEVICE_DIALOG_TITLE 12546
#define IDS_BOOKMARKS_MOVE_TO_DEVICE_DIALOG_SUBTITLE 12547
#define IDS_BOOKMARKS_MOVE_TO_DEVICE_DIALOG_FOLDER_SUBTITLE 12548
#define IDS_BOOKMARKS_MOVE_TO_DEVICE_DIALOG_OK_BUTTON_LABEL 12549
#define IDS_BOOKMARKS_SORT_BY_TYPE 12550
#define IDS_BOOKMARKS_ALL_BOOKMARKS 12551
#define IDS_BOOKMARKS_ALL_BOOKMARKS_OPEN_SIDE_PANEL 12552
#define IDS_BOOKMARKS_ACCOUNT_BOOKMARKS 12553
#define IDS_BOOKMARKS_DEVICE_BOOKMARKS 12554
#define IDS_BOOKMARKS_LABEL_TRACKED_PRODUCTS 12555
#define IDS_BOOKMARKS_SORT_NEWEST 12556
#define IDS_BOOKMARKS_SORT_NEWEST_LOWER 12557
#define IDS_BOOKMARKS_SORT_OLDEST 12558
#define IDS_BOOKMARKS_SORT_OLDEST_LOWER 12559
#define IDS_BOOKMARKS_SORT_ALPHABETICALLY 12560
#define IDS_BOOKMARKS_SORT_REVERSE_ALPHABETICALLY 12561
#define IDS_BOOKMARKS_SORT_LAST_OPENED 12562
#define IDS_BOOKMARKS_SORT_LAST_OPENED_LOWER 12563
#define IDS_BOOKMARKS_VISUAL_VIEW 12564
#define IDS_BOOKMARKS_COMPACT_VIEW 12565
#define IDS_BOOKMARKS_SORT_MENU_A11Y_LABEL 12566
#define IDS_BOOKMARKS_CREATE_NEW_FOLDER_A11Y_LABEL 12567
#define IDS_BOOKMARKS_NEW_FOLDER_TOOLTIP 12568
#define IDS_BOOKMARKS_EDIT_BOOKMARK_LIST_A11Y_LABEL 12569
#define IDS_BOOKMARKS_EMPTY_STATE_TITLE 12570
#define IDS_BOOKMARKS_EMPTY_STATE_BODY 12571
#define IDS_BOOKMARKS_EMPTY_STATE_TITLE_FOLDER 12572
#define IDS_BOOKMARKS_EMPTY_STATE_BODY_FOLDER 12573
#define IDS_BOOKMARKS_EMPTY_STATE_TITLE_GUEST 12574
#define IDS_BOOKMARKS_EMPTY_STATE_BODY_GUEST 12575
#define IDS_BOOKMARKS_EMPTY_STATE_TITLE_SEARCH 12576
#define IDS_BOOKMARKS_EMPTY_STATE_BODY_SEARCH 12577
#define IDS_BOOKMARK_FOLDER_CHILD_COUNT 12578
#define IDS_BOOKMARKS_EDIT_BOOKMARK 12579
#define IDS_BOOKMARKS_EDIT_MOVE_TO_ANOTHER_FOLDER 12580
#define IDS_BOOKMARKS_EDIT_MORE 12581
#define IDS_BOOKMARKS_EDIT_MOVE_TO 12582
#define IDS_BOOKMARKS_EDIT_NEW_FOLDER 12583
#define IDS_BOOKMARKS_EDIT_CANCEL 12584
#define IDS_BOOKMARKS_EDIT_SAVE 12585
#define IDS_BOOKMARKS_EDIT_NAME 12586
#define IDS_BOOKMARKS_EDIT_URL 12587
#define IDS_BOOKMARK_DELETION_COUNT 12588
#define IDS_UNDO_BOOKMARK_DELETION 12589
#define IDS_BOOKMARKS_MOVE_TO_BOOKMARKS_BAR 12590
#define IDS_BOOKMARKS_MOVE_TO_ALL_BOOKMARKS 12591
#define IDS_BOOKMARKS_EDIT 12592
#define IDS_BOOKMARKS_RENAME 12593
#define IDS_BOOKMARKS_URL_FOLDER_DESCRIPTION 12594
#define IDS_BOOKMARKS_DISABLED_FEATURE 12595
#define IDS_BOOKMARKS_BACK_BUTTON_LABEL 12596
#define IDS_BOOKMARKS_BACK_BUTTON_TOOLTIP 12597
#define IDS_BOOKMARKS_FORWARD_BUTTON_LABEL 12598
#define IDS_BOOKMARK_OPTIONS_LABEL 12599
#define IDS_FOLDER_OPTIONS_LABEL 12600
#define IDS_BOOKMARKS_OPEN_FOLDER_LABEL 12601
#define IDS_BOOKMARKS_OPEN_BOOKMARK_LABEL 12602
#define IDS_BOOKMARKS_SELECT_FOLDER_LABEL 12603
#define IDS_BOOKMARKS_SELECT_BOOKMARK_LABEL 12604
#define IDS_BOOKMARKS_DESELECT_FOLDER_LABEL 12605
#define IDS_BOOKMARKS_DESELECT_BOOKMARK_LABEL 12606
#define IDS_BOOKMARK_ACCESSIBLE_DESCRIPTION_PRICE_TRACKING 12607
#define IDS_BOOKMARK_ACCESSIBLE_DESCRIPTION_PRICE_CHANGE 12608
#define IDS_BOOKMARKS_CHECKBOX_LABEL 12609
#define IDS_BOOKMARKS_PRIMARY_FILTER_HEADING 12610
#define IDS_BOOKMARKS_SECONDARY_FILTER_HEADING 12611
#define IDS_SHOW_READING_MODE_SIDE_PANEL 12612
#define IDS_READING_MODE_TITLE 12613
#define IDS_READING_MODE_NOT_SELECTABLE_HEADER 12614
#define IDS_READING_MODE_EMPTY_STATE_HEADER 12615
#define IDS_READING_MODE_EMPTY_STATE_SUBHEADER 12616
#define IDS_READING_MODE_TOOLBAR_LABEL 12617
#define IDS_READING_MODE_READ_ALOUD_TOOLBAR_LABEL 12618
#define IDS_READING_MODE_FONT_SIZE 12619
#define IDS_READING_MODE_FONT_NAME_COMBOBOX_LABEL 12620
#define IDS_READING_MODE_DECREASE_FONT_SIZE_BUTTON_LABEL 12621
#define IDS_READING_MODE_INCREASE_FONT_SIZE_BUTTON_LABEL 12622
#define IDS_READING_MODE_INCREASE_FONT_SIZE_ANNOUNCEMENT 12623
#define IDS_READING_MODE_DECREASE_FONT_SIZE_ANNOUNCEMENT 12624
#define IDS_READING_MODE_DISABLE_LINKS_BUTTON_LABEL 12625
#define IDS_READING_MODE_ENABLE_LINKS_BUTTON_LABEL 12626
#define IDS_READING_MODE_IMAGES_LABEL 12627
#define IDS_READING_MODE_DISABLE_IMAGES_BUTTON_LABEL 12628
#define IDS_READING_MODE_ENABLE_IMAGES_BUTTON_LABEL 12629
#define IDS_READING_MODE_PIN_LABEL 12630
#define IDS_READING_MODE_DISABLE_PIN_BUTTON_LABEL 12631
#define IDS_READING_MODE_ENABLE_PIN_BUTTON_LABEL 12632
#define IDS_READING_MODE_COLORS_COMBOBOX_LABEL 12633
#define IDS_READING_MODE_LINE_SPACING_COMBOBOX_LABEL 12634
#define IDS_READING_MODE_LETTER_SPACING_COMBOBOX_LABEL 12635
#define IDS_READING_MODE_SPACING_COMBOBOX_STANDARD 12636
#define IDS_READING_MODE_SPACING_COMBOBOX_LOOSE 12637
#define IDS_READING_MODE_SPACING_COMBOBOX_VERY_LOOSE 12638
#define IDS_READING_MODE_SPACING_COMBOBOX_WIDE 12639
#define IDS_READING_MODE_SPACING_COMBOBOX_VERY_WIDE 12640
#define IDS_READING_MODE_DEFAULT_COLOR_LABEL 12641
#define IDS_READING_MODE_LIGHT_COLOR_LABEL 12642
#define IDS_READING_MODE_DARK_COLOR_LABEL 12643
#define IDS_READING_MODE_YELLOW_COLOR_LABEL 12644
#define IDS_READING_MODE_HIGH_CONTRAST_COLOR_LABEL 12645
#define IDS_READING_MODE_LOW_CONTRAST_LIGHT_COLOR_LABEL 12646
#define IDS_READING_MODE_LOW_CONTRAST_DARK_COLOR_LABEL 12647
#define IDS_READING_MODE_BLUE_COLOR_LABEL 12648
#define IDS_READING_MODE_VOICE_HIGHLIGHT 12649
#define IDS_READING_MODE_AUTO_HIGHLIGHT_LABEL 12650
#define IDS_READING_MODE_WORD_HIGHLIGHT_LABEL 12651
#define IDS_READING_MODE_PHRASE_HIGHLIGHT_LABEL 12652
#define IDS_READING_MODE_SENTENCE_HIGHLIGHT_LABEL 12653
#define IDS_READING_MODE_OFF_HIGHLIGHT_LABEL 12654
#define IDS_READING_MODE_LINE_FOCUS_WINDOW_HEADING 12655
#define IDS_READING_MODE_LINE_FOCUS_STYLE_HEADING 12656
#define IDS_READING_MODE_LINE_FOCUS_SMALL_FOCUS_LABEL 12657
#define IDS_READING_MODE_LINE_FOCUS_MEDIUM_FOCUS_LABEL 12658
#define IDS_READING_MODE_LINE_FOCUS_LARGE_FOCUS_LABEL 12659
#define IDS_READING_MODE_LINE_FOCUS_UNDERLINE_LABEL 12660
#define IDS_READING_MODE_LINE_FOCUS_LINE_HEADING 12661
#define IDS_READING_MODE_LINE_FOCUS_MOVEMENT_HEADING 12662
#define IDS_READING_MODE_LINE_FOCUS_STATIC_LABEL 12663
#define IDS_READING_MODE_LINE_FOCUS_STATIC_LINE_LABEL 12664
#define IDS_READING_MODE_LINE_FOCUS_CURSOR_LINE_LABEL 12665
#define IDS_READING_MODE_LINE_FOCUS_OFF_LABEL 12666
#define IDS_READ_ANYTHING_LOADING 12667
#define IDS_READING_MODE_FONT_RESET 12668
#define IDS_READING_MODE_FONT_RESET_TOOLTIP 12669
#define IDS_READING_MODE_TURN_HIGHLIGHT_OFF 12670
#define IDS_READING_MODE_TURN_HIGHLIGHT_ON 12671
#define IDS_READING_MODE_PLAY_DESCRIPTION 12672
#define IDS_READING_MODE_PLAY_SPEECH 12673
#define IDS_READING_MODE_PLAY_TOOLTIP 12674
#define IDS_READING_MODE_PREVIEW_TOOLTIP 12675
#define IDS_READING_MODE_PAUSE_TOOLTIP 12676
#define IDS_READING_MODE_STOP_SPEECH 12677
#define IDS_READING_MODE_NAVIGATE_PREVIOUS_SENTENCE 12678
#define IDS_READING_MODE_NAVIGATE_NEXT_SENTENCE 12679
#define IDS_READING_MODE_MORE_OPTIONS 12680
#define IDS_READING_MODE_SETTINGS 12681
#define IDS_READING_MODE_VOICE_SPEED 12682
#define IDS_READING_MODE_VOICE_SPEED_WITH_RATE 12683
#define IDS_READING_MODE_VOICE_SPEED_OPTION_TITLE 12684
#define IDS_READING_MODE_VOICE_SELECTION 12685
#define IDS_READING_MODE_SYSTEM_VOICE 12686
#define IDS_READING_MODE_ITEM_SELECTED 12687
#define IDS_READING_MODE_LANGUAGE_MENU 12688
#define IDS_READING_MODE_LANGUAGE_MENU_TITLE 12689
#define IDS_READING_MODE_LANGUAGE_MENU_CLOSE 12690
#define IDS_READING_MODE_CLOSE 12691
#define IDS_READING_MODE_LANGUAGE_MENU_NO_RESULTS 12692
#define IDS_READING_MODE_LANGUAGE_MENU_SEARCH_LABEL 12693
#define IDS_READING_MODE_LANGUAGE_MENU_SEARCH_CLEAR 12694
#define IDS_READING_MODE_LANGUAGE_MENU_DOWNLOADING 12695
#define IDS_READING_MODE_VOICE_MENU_DOWNLOADING 12696
#define IDS_READING_MODE_LANGUAGE_MENU_VOICES_UNAVAILABLE 12697
#define IDS_READING_MODE_LANGUAGE_MENU_NO_INTERNET 12698
#define IDS_READING_MODE_CANT_USE_READ_ALOUD 12699
#define IDS_READING_MODE_VOICE_MENU_NO_INTERNET 12700
#define IDS_READING_MODE_LANGUAGE_MENU_DOWNLOAD_FAILED 12701
#define IDS_READING_MODE_LANGUAGE_MENU_NO_SPACE 12702
#define IDS_READING_MODE_TOAST_NO_SPACE 12703
#define IDS_READING_MODE_VOICE_MENU_NO_SPACE 12704
#define IDS_READING_MODE_VOICE_MENU_PREVIEW_LANGUAGE 12705
#define IDS_READING_MODE_LANGUAGE_MENU_NO_SPACE_BUT_VOICES_EXIST 12706
#define IDS_READING_MODE_LANGUAGE_MENU_ITEM_LABEL 12707
#define IDS_READING_MODE_VOICE_DOWNLOADED_TITLE 12708
#define IDS_READING_MODE_VOICE_DOWNLOADED_MESSAGE 12709
#define IDS_READING_MODE_SIDE_PANEL_PROMO 12710
#define IDS_READING_MODE_SIDE_PANEL_PROMO_PINNING 12711
#define IDS_READING_MODE_OMNIBOX_ENTRY_POINT_PROMO 12712
#define IDS_READING_MODE_OMNIBOX_ENTRY_POINT_PROMO_SCREEN_READER 12713
#define IDS_READING_MODE_VOICE_PREVIEW_STRING 12714
#define IDS_READING_MODE_FONT_LOADING_STRING 12715
#define IDS_READING_MODE_LINE_FOCUS_LABEL 12716
#define IDS_READING_MODE_SIDE_PANEL_LABEL 12717
#define IDS_READING_MODE_VIEW_FULL_PAGE_LABEL 12718
#define IDS_READING_MODE_FULL_SCREEN_LABEL 12719
#define IDS_READING_MODE_VIEW_LABEL 12720
#define IDS_READING_MODE_LINKS_LABEL 12721
#define IDS_GOOGLE_LENS_TITLE 12722
#define IDS_LENS_DEFAULT_TITLE 12723
#define IDS_TOOLTIP_BACK 12724
#define IDS_ACCDESCRIPTION_BACK 12725
#define IDS_TOOLTIP_CHROMELABS_BUTTON 12726
#define IDS_TOOLTIP_LEFT_ALIGNED_SIDE_PANEL_BUTTON 12727
#define IDS_TOOLTIP_CHROMELABS_COMBOBOX 12728
#define IDS_TOOLTIP_CHROMELABS_FEEDBACK_BUTTON 12729
#define IDS_TOOLTIP_FORWARD 12730
#define IDS_ACCDESCRIPTION_FORWARD 12731
#define IDS_TOOLTIP_DOWNLOAD_ICON 12732
#define IDS_TOOLTIP_DOWNLOAD_ICON_NEW_DOWNLOAD 12733
#define IDS_TOOLTIP_HOME 12734
#define IDS_TOOLTIP_RELOAD 12735
#define IDS_TOOLTIP_RELOAD_WITH_MENU 12736
#define IDS_TOOLTIP_STOP 12737
#define IDS_TOOLTIP_EXTENSIONS_BUTTON 12738
#define IDS_TOOLTIP_OVERFLOW_BUTTON 12739
#define IDS_TOOLTIP_EXTENSIONS_BUTTON_ALL_EXTENSIONS_BLOCKED 12740
#define IDS_TOOLTIP_EXTENSIONS_BUTTON_ANY_EXTENSION_HAS_ACCESS 12741
#define IDS_ACC_NAME_EXTENSIONS_BUTTON 12742
#define IDS_ACC_NAME_EXTENSIONS_BUTTON_ALL_EXTENSIONS_BLOCKED 12743
#define IDS_ACC_NAME_EXTENSIONS_BUTTON_ANY_EXTENSION_HAS_ACCESS 12744
#define IDS_TOOLTIP_EXTENSIONS_SITE_ACCESS_BUTTON 12745
#define IDS_TOOLTIP_SIDE_PANEL_SHOW 12746
#define IDS_TOOLTIP_SIDE_PANEL_HIDE 12747
#define IDS_TOOLTIP_SIDE_PANEL 12748
#define IDS_TOOLTIP_LOCATION_ICON 12750
#define IDS_TOOLTIP_NEW_TAB 12751
#define IDS_TOOLTIP_TAB_SCROLL_LEADING 12752
#define IDS_TOOLTIP_TAB_SCROLL_TRAILING 12753
#define IDS_TOOLTIP_MIC_SEARCH 12754
#define IDS_TOOLTIP_LENS_SEARCH 12755
#define IDS_TOOLTIP_LENS_REINVOKE_VISUAL_SELECTION_A11Y_LABEL 12756
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_CLOSE_BUTTON_LABEL 12757
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_TITLE 12758
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_TITLE_SHORT 12759
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_DRAG_TITLE 12760
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_UPLOAD_FILE_TITLE 12761
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_OR_TEXT 12762
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_TEXT_PLACEHOLDER 12763
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_SEARCH_BUTTON_LABEL 12764
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_DRAG_DROP_TITLE 12765
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_LOADING_TEXT 12766
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_OFFLINE_TEXT 12767
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_OFFLINE_SUBTITLE_TEXT 12768
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_OFFLINE_BUTTON_LABEL 12769
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_ERROR_FILE_TYPE 12770
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_ERROR_FILE_SIZE 12771
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_ERROR_MULTIPLE_FILES 12772
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_VALIDATION_ERROR_SCHEME 12773
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_VALIDATION_ERROR_CONFORMANCE 12774
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_ERROR_MULTIPLE_URLS 12775
#define IDS_TOOLTIP_SAVE_CREDIT_CARD 12776
#define IDS_TOOLTIP_SAVE_CREDIT_CARD_PENDING 12777
#define IDS_TOOLTIP_SAVE_CVC 12778
#define IDS_TOOLTIP_SAVE_IBAN 12779
#define IDS_TOOLTIP_MIGRATE_LOCAL_CARD 12780
#define IDS_TOOLTIP_TRANSLATE 12781
#define IDS_TOOLTIP_ZOOM 12782
#define IDS_TOOLTIP_ZOOM_EXTENSION_ICON 12783
#define IDS_ZOOM_SET_DEFAULT 12784
#define IDS_TOOLTIP_FIND 12785
#define IDS_TOOLTIP_TAB_SEARCH 12786
#define IDS_TOOLTIP_TAB_ORGANIZE 12787
#define IDS_TAB_ORGANIZE 12788
#define IDS_TOOLTIP_TAB_ORGANIZE_CLOSE 12789
#define IDS_TAB_ORGANIZATION_FEEDBACK_PLACEHOLDER 12790
#define IDS_TAB_ORGANIZE_MENU 12791
#define IDS_TAB_ORGANIZATION_SUCCESS_IPH 12792
#define IDS_TAB_ORGANIZATION_SUCCESS_IPH_SCREENREADER 12793
#define IDS_SPLIT_VIEW_NTP_EMPTY_TITLE 12794
#define IDS_SPLIT_VIEW_NTP_EMPTY_BODY 12795
#define IDS_SPLIT_VIEW_NTP_TITLE 12796
#define IDS_SPLIT_VIEW_NTP_TAB_TITLE 12797
#define IDS_ACCNAME_SPLIT_VIEW_MINI_TOOLBAR_MENU_BUTTON 12798
#define IDS_SPLIT_VIEW_NTP_CLOSE_BUTTON_ARIA_LABEL 12799
#define IDS_SPLIT_VIEW_TITLE_IPH 12800
#define IDS_SPLIT_VIEW_BODY_IPH 12801
#define IDS_SPLIT_VIEW_PIN_ACTION_2_IPH 12802
#define IDS_SPLIT_VIEW_TAB_SWITCH_ENTRY_IPH_TITLE 12803
#define IDS_SPLIT_VIEW_TAB_SWITCH_ENTRY_IPH_BODY 12804
#define IDS_SPLIT_VIEW_TAB_SWITCH_STEP_IPH_BODY 12805
#define IDS_SPLIT_VIEW_TAB_SWITCH_COMPLETION_IPH_BODY 12806
#define IDS_SPLIT_VIEW_TOOLBAR_BUTTON_STEP_IPH_BODY 12807
#define IDS_SPLIT_VIEW_DRAG_ENTRYPOINT_LABEL 12808
#define IDS_SWITCH_TO_VERTICAL_TAB 12809
#define IDS_SWITCH_TO_HORIZONTAL_TAB 12810
#define IDS_COLLAPSE_VERTICAL_TABS 12811
#define IDS_EXPAND_VERTICAL_TABS 12812
#define IDS_VERTICAL_TABS_SEND_FEEDBACK 12813
#define IDS_VERTICAL_TABS_TUTORIAL_STEP_SHOW_VERTICAL 12814
#define IDS_VERTICAL_TABS_TUTORIAL_STEP_COLLAPSE 12815
#define IDS_VERTICAL_TABS_TUTORIAL_STEP_END 12816
#define IDS_VERTICAL_TABS_IPH_TITLE 12817
#define IDS_VERTICAL_TABS_IPH_BODY 12818
#define IDS_VERTICAL_RESIZE_AREA 12819
#define IDS_VERTICAL_TAB_RESIZE_ACCESSIBLE_ALERT 12820
#define IDS_VERTICAL_TAB_GROUP_MORE_OPTIONS 12821
#define IDS_VIEW_PROJECTS_PANEL 12822
#define IDS_HIDE_PROJECTS_PANEL 12823
#define IDS_TAB_GROUPS_TITLE 12824
#define IDS_RECENT_CHATS_TITLE 12825
#define IDS_TAB_GROUP_MORE_OPTIONS 12826
#define IDS_THREADS_SHOW_MORE 12827
#define IDS_THREADS_SHOW_LESS 12828
#define IDS_PROJECTS_PANEL 12829
#define IDS_PROJECTS_PANEL_GEMINI_ACTIVITY 12830
#define IDS_PROJECTS_PANEL_AI_MODE_ACTIVITY 12831
#define IDS_TAB_GROUPS_NO_TAB_GROUPS 12832
#define IDS_OPEN_GEMINI_THREAD_TOOLTIP 12833
#define IDS_OPEN_AI_MODE_THREAD_TOOLTIP 12834
#define IDS_OPEN_GEMINI_THREAD_ACCESSIBILITY_LABEL 12835
#define IDS_OPEN_AI_MODE_THREAD_ACCESSIBILITY_LABEL 12836
#define IDS_TAB_SEARCH_BUTTON_CXMENU_UNPIN 12837
#define IDS_TAB_SEARCH_BUTTON_CXMENU_PIN 12838
#define IDS_PROJECTS_PANEL_BUTTON_CXMENU_UNPIN 12839
#define IDS_PROJECTS_PANEL_BUTTON_CXMENU_PIN 12840
#define IDS_EVERYTHING_MENU_BUTTON_CXMENU_UNPIN 12841
#define IDS_EVERYTHING_MENU_BUTTON_CXMENU_PIN 12842
#define IDS_TOOLTIP_INTENT_PICKER_ICON 12843
#define IDS_INTENT_PICKER_BUBBLE_VIEW_OPEN_WITH 12844
#define IDS_INTENT_PICKER_BUBBLE_VIEW_OPEN_IN_APP 12845
#define IDS_INTENT_PICKER_BUBBLE_VIEW_REMEMBER_SELECTION 12846
#define IDS_INTENT_PICKER_BUBBLE_VIEW_OPEN 12847
#define IDS_INTENT_PICKER_BUBBLE_VIEW_STAY_IN_CHROME 12848
#define IDS_INTENT_PICKER_BUBBLE_VIEW_INITIATING_ORIGIN 12849
#define IDS_INTENT_CHIP_OPEN_IN_APP 12850
#define IDR_INTENT_PICKER_SUPPORTED_LINKS_INFOBAR_MESSAGE 12851
#define IDR_INTENT_PICKER_SUPPORTED_LINKS_INFOBAR_OK_LABEL 12852
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_BUTTON_ACCEPT_REMINDER 12859
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_BUTTON_DECLINE 12860
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_REMINDER_CONFIRMATION_BUTTON 12861
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_REMINDER_CONFIRMATION_TITLE 12862
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_LENS_FEATURE_NAME 12863
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_ENHANCED_BROWSING_FEATURE_NAME 12864
#define IDS_IOS_DEVICE_TYPE_IPHONE 12865
#define IDS_IOS_DEVICE_TYPE_IPAD 12866
#define IDS_NTP_MOBILE_PROMO_BODY 12867
#define IDS_NTP_MOBILE_PROMO_PASSWORDS_BODY 12868
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_TITLE 12869
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_FOOTER_TITLE_REMINDER 12870
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_BUTTON_DECLINE 12871
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_SUBTITLE 12872
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_NOTIFICATION_BODY 12873
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_TITLE 12874
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_FOOTER_TITLE 12875
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_BUTTON_DECLINE 12876
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_SUBTITLE 12877
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_FOOTER_DESCRIPTION_QR 12878
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_TITLE 12879
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_FOOTER_TITLE 12880
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_BUTTON_DECLINE 12881
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_SUBTITLE 12882
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_FOOTER_DESCRIPTION_QR 12883
#define IDS_IOS_DESKTOP_ESB_PROMO_BUBBLE_DESCRIPTION_QR 12884
#define IDS_IOS_DESKTOP_ESB_PROMO_BUBBLE_TITLE_REMINDER 12885
#define IDS_IOS_DESKTOP_SAFE_BROWSING_PROMO_NOTIFICATION_BODY 12886
#define IDS_IOS_DESKTOP_LENS_PROMO_BUBBLE_DESCRIPTION_QR 12887
#define IDS_IOS_DESKTOP_LENS_PROMO_BUBBLE_TITLE_REMINDER 12888
#define IDS_IOS_DESKTOP_LENS_PROMO_NOTIFICATION_BODY 12889
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_BUBBLE_DESCRIPTION_REMINDER 12890
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_BUBBLE_TITLE_QR 12891
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_BUBBLE_TITLE_REMINDER 12892
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_NOTIFICATION_BODY 12893
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_NOTIFICATION_TITLE 12894
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_BUBBLE_DESCRIPTION_REMINDER 12895
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_BUBBLE_TITLE_QR 12896
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_BUBBLE_TITLE_REMINDER 12897
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_NOTIFICATION_BODY 12898
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_NOTIFICATION_TITLE 12899
#define IDS_ACCESSIBLE_INCOGNITO_WINDOW_TITLE_FORMAT 12900
#define IDS_ACCESSIBLE_GUEST_WINDOW_TITLE_FORMAT 12901
#define IDS_ACCESSIBLE_WINDOW_TITLE_WITH_PROFILE_FORMAT 12902
#define IDS_ACCNAME_APP_UPGRADE_RECOMMENDED 12903
#define IDS_ACCNAME_FULLSCREEN 12904
#define IDS_ACCNAME_EXIT_FULLSCREEN 12905
#define IDS_ACCNAME_FULLSCREEN_DISABLED 12906
#define IDS_ACCNAME_HOME 12907
#define IDS_ACCNAME_RELOAD 12908
#define IDS_ACCNAME_SPLIT_TABS_TOOLBAR_BUTTON_PINNED 12909
#define IDS_ACCNAME_SPLIT_TABS_TOOLBAR_BUTTON_ENABLED 12910
#define IDS_ACCNAME_FIND 12911
#define IDS_ACCNAME_BOOKMARKS 12912
#define IDS_ACCNAME_SAVED_TAB_GROUPS 12913
#define IDS_ACCNAME_SAVED_TAB_GROUPS_CHEVRON 12914
#define IDS_SAVED_TAB_GROUPS_OVERFLOW_BUTTON_TOOLTIP 12915
#define IDS_TAB_GROUP_EDITOR_BUBBLE_FOOTER_SYNC_DISABLED 12916
#define IDS_TAB_GROUP_EDITOR_BUBBLE_FOOTER_SYNC_ENABLED 12917
#define IDS_TAB_GROUP_EDITOR_BUBBLE_FOOTER_LEARN_MORE 12918
#define IDS_ACCNAME_TAB_GROUPS_EVERYTHING 12919
#define IDS_TAB_GROUPS_EVERYTHING_BUTTON_TOOLTIP 12920
#define IDS_ACCNAME_BOOKMARKS_CHEVRON 12921
#define IDS_ACCNAME_BOOKMARK_BUTTON_ROLE_DESCRIPTION 12922
#define IDS_ACCNAME_BOOKMARK_FOLDER_BUTTON_ROLE_DESCRIPTION 12923
#define IDS_ACCNAME_SAVED_TAB_GROUP_BUTTON_ROLE_DESCRIPTION 12924
#define IDS_ACCNAME_CHROMELABS_BUTTON 12925
#define IDS_ACCNAME_LEFT_ALIGNED_SIDE_PANEL_BUTTON 12926
#define IDS_ACCESSIBLE_TEXT_CHROMELABS_BUTTON_ADDED_BY_ENTERPRISE_POLICY 12927
#define IDS_ACCESSIBLE_TEXT_CHROMELABS_BUTTON_REMOVED_BY_ENTERPRISE_POLICY 12928
#define IDS_ACCNAME_CHROMELABS_COMBOBOX 12929
#define IDS_ACCNAME_CHROMELABS_COMBOBOX_MAC 12930
#define IDS_ACCNAME_SEPARATOR 12931
#define IDS_ACCNAME_EXTENSIONS 12932
#define IDS_ACCNAME_NEWTAB 12933
#define IDS_ACCNAME_MINIMIZE 12934
#define IDS_ACCNAME_MAXIMIZE 12935
#define IDS_ACCNAME_RESTORE 12936
#define IDS_ACCNAME_CLOSE_TAB 12937
#define IDS_ACCNAME_ZOOM_SET_DEFAULT 12938
#define IDS_ACCNAME_TAB_SEARCH 12939
#define IDS_ACCNAME_TAB_ORGANIZE 12940
#define IDS_ACCNAME_TAB_SCROLL_LEADING 12941
#define IDS_ACCNAME_TAB_SCROLL_TRAILING 12942
#define IDS_ACCNAME_MUTE_TAB 12943
#define IDS_ACCNAME_WEB_APP_DETAILED_INSTALL_DIALOG_LEADING_SCROLL_BUTTON 12944
#define IDS_ACCNAME_WEB_APP_DETAILED_INSTALL_DIALOG_TRAILING_SCROLL_BUTTON 12945
#define IDS_TOOLBAR_BUTTON_UNPINNED 12946
#define IDS_TOOLBAR_BUTTON_PINNED 12947
#define IDS_ALLOWED_CLIPBOARD_TITLE 12948
#define IDS_BLOCKED_CLIPBOARD_TITLE 12949
#define IDS_ALLOWED_CLIPBOARD_MESSAGE 12950
#define IDS_ALLOWED_CLIPBOARD_BLOCK 12951
#define IDS_ALLOWED_CLIPBOARD_NO_ACTION 12952
#define IDS_BLOCKED_CLIPBOARD_MESSAGE 12953
#define IDS_BLOCKED_CLIPBOARD_UNBLOCK 12954
#define IDS_BLOCKED_CLIPBOARD_NO_ACTION 12955
#define IDS_BACK_NAVIGATION_MENU_PROMO 12956
#define IDS_BACK_NAVIGATION_MENU_PROMO_ACCESSIBLE_TEXT 12957
#define IDS_BOOKMARK_PROMO_0 12958
#define IDS_BOOKMARK_PROMO_1 12959
#define IDS_BOOKMARK_PROMO_2 12960
#define IDS_CHROME_TIP 12961
#define IDS_EXTENSIONS_MENU_IPH_ENTRY_POINT_TITLE 12962
#define IDS_EXTENSIONS_MENU_IPH_ENTRY_POINT_BODY 12963
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_IPH_ENTRY_POINT_TITLE 12964
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_IPH_ENTRY_POINT_BODY 12965
#define IDS_EXTENSIONS_ZERO_STATE_PROMO_IPH_TITLE 12966
#define IDS_EXTENSIONS_ZERO_STATE_PROMO_CUSTOM_ACTION_IPH_DESCRIPTION 12967
#define IDS_EXTENSIONS_ZERO_STATE_PROMO_CUSTOM_ACTION_IPH_ACCEPT 12968
#define IDS_GLOBAL_MEDIA_CONTROLS_PROMO 12969
#define IDS_INCOGNITOWINDOW_PROMO_0 12970
#define IDS_INCOGNITOWINDOW_PROMO_1 12971
#define IDS_INCOGNITOWINDOW_PROMO_2 12972
#define IDS_INCOGNITOWINDOW_PROMO_3 12973
#define IDS_NEWTAB_PROMO_0 12974
#define IDS_NEWTAB_PROMO_1 12975
#define IDS_NEWTAB_PROMO_2 12976
#define IDS_POWER_BOOKMARKS_SIDE_PANEL_PROMO 12977
#define IDS_POWER_BOOKMARKS_SIDE_PANEL_PROMO_PINNING 12978
#define IDS_READING_LIST_DISCOVERY_PROMO 12979
#define IDS_READING_LIST_DISCOVERY_PROMO_PINNING 12980
#define IDS_READING_LIST_ENTRY_POINT_PROMO 12981
#define IDS_DESKTOP_PWA_INSTALL_PROMO 12982
#define IDS_DESKTOP_PWA_LINK_CAPTURING_TEXT 12983
#define IDS_DESKTOP_PWA_LINK_CAPTURING_SETTINGS 12984
#define IDS_UPDATED_CONNECTION_SECURITY_INDICATORS_PROMO 12985
#define IDS_READING_LIST_IN_SIDE_PANEL_PROMO 12986
#define IDS_READING_LIST_IN_SIDE_PANEL_PROMO_PINNING 12987
#define IDS_TAB_GROUPS_UNNAMED_GROUP_TOOLTIP 12988
#define IDS_TAB_GROUPS_NAMED_GROUP_TOOLTIP 12989
#define IDS_SHARED_HIGHLIGHTING_PROMO 12990
#define IDS_TAB_AUDIO_MUTING_PROMO 12991
#define IDS_BATTERY_SAVER_MODE_PROMO_TITLE 12992
#define IDS_BATTERY_SAVER_MODE_PROMO_TEXT 12993
#define IDS_BATTERY_SAVER_MODE_PROMO_ACTION_TEXT 12994
#define IDS_MEMORY_SAVER_MODE_PROMO_TEXT 12995
#define IDS_MEMORY_SAVER_MODE_PROMO_ACTION_TEXT 12996
#define IDS_TAB_GROUPS_HOVER_CARD_HEADER 12997
#define IDS_TAB_GROUPS_UNNAMED_GROUP_HOVER_CARD_HEADER 12998
#define IDS_TAB_GROUPS_HOVER_CARD_FOOTER 12999
#define IDS_DISCARD_RING_PROMO_TITLE 13000
#define IDS_DISCARD_RING_PROMO_TEXT 13001
#define IDS_DISCARD_RING_PROMO_ACTION_TEXT 13002
#define IDS_DISCARD_RING_SETTINGS_TOAST 13003
#define IDS_TUTORIAL_GENERIC_SUCCESS_TITLE 13004
#define IDS_TUTORIAL_TAB_GROUP_ADD_TAB_TO_GROUP 13005
#define IDS_TUTORIAL_ADD_TAB_TO_GROUP_WITH_EXISTING_GROUP_IN_TAB_STRIP 13006
#define IDS_TUTORIAL_TAB_GROUP_EDIT_BUBBLE 13007
#define IDS_TUTORIAL_TAB_GROUP_DRAG_TAB 13008
#define IDS_TUTORIAL_TAB_GROUP_COLLAPSE 13009
#define IDS_TUTORIAL_TAB_GROUP_SUCCESS_DESCRIPTION 13010
#define IDS_TUTORIAL_SAVED_TAB_GROUP_ADD_TAB_TO_GROUP 13011
#define IDS_TUTORIAL_SAVED_TAB_GROUP_OPEN_EDITOR 13012
#define IDS_TUTORIAL_SAVED_TAB_GROUP_NAME_SAVE_GROUP 13013
#define IDS_TUTORIAL_SAVED_TAB_GROUP_HIDE_GROUP 13014
#define IDS_TUTORIAL_SAVED_TAB_GROUP_REOPEN_GROUP 13015
#define IDS_TUTORIAL_SAVED_TAB_GROUP_SUCCESS_DESCRIPTION 13016
#define IDS_TUTORIAL_SIDE_PANEL_READING_LIST_OPEN_SIDE_PANEL 13017
#define IDS_TUTORIAL_SIDE_PANEL_READING_LIST_ADD_TAB 13018
#define IDS_TUTORIAL_SIDE_PANEL_READING_LIST_MARK_READ 13019
#define IDS_TUTORIAL_SIDE_PANEL_READING_LIST_CLICK_DROPDOWN 13020
#define IDS_TUTORIAL_SIDE_PANEL_READING_LIST_SUCCESS_BODY 13021
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_START_TUTORIAL_IPH 13022
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_OPEN_SIDE_PANEL 13023
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_CHANGE_THEME 13024
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_SELECT_COLLECTION 13025
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_APPLY_THEME 13026
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_CLICK_BACK_ARROW 13027
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_SUCCESS_BODY 13028
#define IDS_TUTORIAL_PASSWORD_MANAGER_OPEN_MENU 13029
#define IDS_TUTORIAL_PASSWORD_MANAGER_CLICK_PASSWORDS_MENU 13030
#define IDS_TUTORIAL_PASSWORD_MANAGER_SELECT_SETTINGS 13031
#define IDS_TUTORIAL_PASSWORD_MANAGER_ADD_SHORTCUT 13032
#define IDS_TUTORIAL_PASSWORD_MANAGER_CLICK_INSTALL 13033
#define IDS_TUTORIAL_LENS_OVERLAY_INTRO_HEADER 13034
#define IDS_TUTORIAL_LENS_OVERLAY_INTRO_BODY 13035
#define IDS_TUTORIAL_LENS_OVERLAY_CLICK_ADDRESS_BAR 13036
#define IDS_TUTORIAL_LENS_OVERLAY_CLICK_LENS 13037
#define IDS_TUTORIAL_LENS_OVERLAY_HOMEWORK_INTRO_HEADER 13038
#define IDS_TUTORIAL_LENS_OVERLAY_HOMEWORK_INTRO_BODY 13039
#define IDS_TUTORIAL_LENS_OVERLAY_HOMEWORK_CLICK_LENS 13040
#define IDS_TUTORIAL_LENS_OVERLAY_SELECT 13041
#define IDS_TUTORIAL_LENS_OVERLAY_CLICK_SEARCH_BOX 13042
#define IDS_TUTORIAL_LENS_OVERLAY_CLICK_PIN_ICON 13043
#define IDS_TUTORIAL_LENS_OVERLAY_SUCCESS_BODY 13044
#define IDS_BROWSER_HANGMONITOR_RENDERER_TITLE 13046
#define IDS_BROWSER_HANGMONITOR_RENDERER 13047
#define IDS_BROWSER_HANGMONITOR_IFRAME_TITLE 13048
#define IDS_BROWSER_HANGMONITOR_RENDERER_WAIT 13049
#define IDS_BROWSER_HANGMONITOR_RENDERER_END 13050
#define IDS_BROWSER_HANGMONITOR_PLUGIN_INFOBAR 13051
#define IDS_BROWSER_HANGMONITOR_PLUGIN_INFOBAR_KILLBUTTON 13052
#define IDS_PASSWORDS_AUTO_SIGNIN_TITLE 13053
#define IDS_PASSWORDS_AUTO_SIGNIN_DESCRIPTION 13054
#define IDS_PASSWORDS_VIA_FEDERATION 13055
#define IDS_CONFIRM_MESSAGEBOX_YES_BUTTON_LABEL 13056
#define IDS_CONFIRM_MESSAGEBOX_NO_BUTTON_LABEL 13057
#define IDS_NEAR_OOM_REDUCTION_MESSAGE_TITLE 13058
#define IDS_NEAR_OOM_REDUCTION_MESSAGE_DESCRIPTION 13059
#define IDS_TAILORED_SECURITY_UNCONSENTED_MESSAGE_TITLE 13060
#define IDS_TAILORED_SECURITY_UNCONSENTED_MESSAGE_ACCEPT 13061
#define IDS_TAILORED_SECURITY_DISPLAY_SOURCE 13062
#define IDS_PASSWORD_MANAGER_CANCEL_BUTTON 13063
#define IDS_PASSWORD_MANAGER_USERNAME_LABEL 13064
#define IDS_PASSWORD_MANAGER_PASSWORD_LABEL 13065
#define IDS_PASSWORD_MANAGER_UPDATED_BUBBLE_TITLE 13066
#define IDS_PASSWORD_MANAGER_MORE_TO_FIX_BODY_MESSAGE_GOOGLE_PASSWORD_MANAGER 13067
#define IDS_PASSWORD_MANAGER_SAFE_STATE_BODY_MESSAGE_GOOGLE_PASSWORD_MANAGER 13068
#define IDS_PASSWORD_MANAGER_CHECK_REMAINING_BUTTON 13069
#define IDS_PASSWORD_MANAGER_SAVE_BUTTON 13070
#define IDS_PASSWORD_MANAGER_MOVE_BUBBLE_CANCEL_BUTTON 13071
#define IDS_PASSWORD_MANAGER_UPDATE_BUTTON 13072
#define IDS_PASSWORD_MANAGER_BUBBLE_BLOCKLIST_BUTTON 13073
#define IDS_PASSWORD_MANAGER_DESTINATION_DROPDOWN_ACCESSIBLE_NAME 13074
#define IDS_PASSWORD_MANAGER_DESTINATION_DROPDOWN_SAVE_TO_ACCOUNT 13075
#define IDS_PASSWORD_MANAGER_DESTINATION_DROPDOWN_SAVE_TO_DEVICE 13076
#define IDS_PASSWORD_MANAGER_IPH_TITLE_SAVE_TO_ACCOUNT 13077
#define IDS_PASSWORD_MANAGER_IPH_BODY_SAVE_TO_ACCOUNT 13078
#define IDS_PASSWORDS_SAVE_PRIMING_PROMO_BODY_TEMPLATE 13079
#define IDS_PASSWORDS_SAVE_PRIMING_PROMO_BODY_SIGNED_IN 13080
#define IDS_PASSWORDS_SAVE_PRIMING_PROMO_BODY_NOT_SIGNED_IN 13081
#define IDS_PASSWORDS_SAVE_PRIMING_PROMO_SCREENREADER 13082
#define IDS_PASSWORDS_SAVE_RECOVERY_PROMO_BODY 13083
#define IDS_PASSWORDS_SAVE_RECOVERY_PROMO_SCREENREADER 13084
#define IDS_PASSWORD_MANAGER_TOOLTIP_BLOCKED 13085
#define IDS_PASSWORD_MANAGER_IPH_MANAGEMENT_BUBBLE_AFTER_SAVE 13086
#define IDS_PASSWORD_MANAGER_IPH_MANAGEMENT_BUBBLE_AFTER_SAVE_SCREENREADER 13087
#define IDS_PASSWORD_MANAGER_IPH_SHARE_PASSWORD_BUTTON 13088
#define IDS_PASSWORD_MANAGER_IPH_SHARE_PASSWORD_BUTTON_SCREENREADER 13089
#define IDS_PASSWORD_MANAGER_IPH_ACCOUNT_STORAGE_TOGGLE 13090
#define IDS_PASSWORD_MANAGER_IPH_CREATE_SHORTCUT_TITLE 13091
#define IDS_PASSWORD_MANAGER_IPH_MANAGEMENT_BUBBLE_DURING_SIGNIN 13092
#define IDS_PASSWORD_MANAGER_IPH_MANAGEMENT_BUBBLE_DURING_SIGNIN_SCREENREADER 13093
#define IDS_PASSWORD_MANAGER_TOOLTIP_SAVE 13094
#define IDS_PASSWORD_MANAGER_TOOLTIP_MANAGE 13095
#define IDS_PASSWORD_MANAGER_TOOLTIP_MOVE 13096
#define IDS_PASSWORD_MANAGER_TOOLTIP_PROTECT 13097
#define IDS_PASSWORD_MANAGER_TOOLTIP_SHARED_NOTIFICATION 13098
#define IDS_PASSWORD_MANAGER_TOOLTIP_KEYCHAIN_ERROR 13099
#define IDS_IMPORT_FROM_FIREFOX 13121
#define IDS_IMPORT_FROM_ICEWEASEL 13122
#define IDS_IMPORT_FROM_SAFARI 13123
#define IDS_IMPORT_FROM_BOOKMARKS_HTML_FILE 13124
#define IDS_IMPORTER_LOCK_TITLE 13128
#define IDS_IMPORTER_LOCK_TEXT 13129
#define IDS_IMPORTER_LOCK_OK 13130
#define IDS_FEEDBACK_REPORT_APP_TITLE 13131
#define IDS_FEEDBACK_REPORT_PAGE_TITLE 13132
#define IDS_FEEDBACK_REPORT_PAGE_TITLE_SAD_TAB_FLOW 13133
#define IDS_FEEDBACK_MINIMIZE_BUTTON_LABEL 13134
#define IDS_FEEDBACK_CLOSE_BUTTON_LABEL 13135
#define IDS_FEEDBACK_FREE_TEXT_LABEL 13136
#define IDS_FEEDBACK_FREE_TEXT_AI_LABEL 13137
#define IDS_FEEDBACK_REPORT_URL_LABEL 13138
#define IDS_FEEDBACK_USER_EMAIL_LABEL 13139
#define IDS_FEEDBACK_ANONYMOUS_EMAIL_OPTION 13140
#define IDS_FEEDBACK_CONSENT_CHECKBOX_LABEL 13141
#define IDS_FEEDBACK_SCREENSHOT_LABEL 13142
#define IDS_FEEDBACK_SCREENSHOT_A11Y_TEXT 13143
#define IDS_FEEDBACK_OFFLINE_DIALOG_TITLE 13144
#define IDS_FEEDBACK_OFFLINE_DIALOG_TEXT 13145
#define IDS_FEEDBACK_INCLUDE_SYSTEM_INFORMATION_CHKBOX 13146
#define IDS_FEEDBACK_ATTACH_FILE_NOTE 13149
#define IDS_FEEDBACK_ATTACH_FILE_LABEL 13150
#define IDS_FEEDBACK_ATTACH_FILE_TO_BIG 13151
#define IDS_FEEDBACK_INCLUDE_AUTOFILL_METADATA_CHECKBOX 13152
#define IDS_FEEDBACK_IWLWIFI_DEBUG_DUMP_EXPLAINER 13153
#define IDS_FEEDBACK_LOG_ID_CHECKBOX_LABEL 13154
#define IDS_FEEDBACK_PRIVACY_NOTE 13155
#define IDS_FEEDBACK_NO_DESCRIPTION 13156
#define IDS_FEEDBACK_OFFENSIVE_CHECKBOX_LABEL 13157
#define IDS_FEEDBACK_SEND_REPORT 13158
#define IDS_FEEDBACK_AUTOFILL_METADATA_PAGE_TITLE 13159
#define IDS_FEEDBACK_SYSINFO_PAGE_TITLE 13160
#define IDS_FEEDBACK_SYSINFO_PAGE_LOADING 13161
#define IDS_FEEDBACK_ADDITIONAL_INFO_LABEL 13162
#define IDS_CLEAR_BROWSING_DATA_TITLE 13163
#define IDS_CLEAR_BROWSING_DATA_HISTORY_NOTICE 13164
#define IDS_CLEAR_BROWSING_DATA_HISTORY_NOTICE_TITLE 13165
#define IDS_CLEAR_BROWSING_DATA_HISTORY_NOTICE_OK 13166
#define IDS_CLEAR_BROWSING_DATA_PASSWORDS_NOTICE 13167
#define IDS_CLEAR_BROWSING_DATA_PASSWORDS_NOTICE_TITLE 13168
#define IDS_CLEAR_BROWSING_DATA_PASSWORDS_NOTICE_OK 13169
#define IDS_MEDIA_SELECTED_MIC_LABEL 13170
#define IDS_MEDIA_SELECTED_CAMERA_LABEL 13171
#define IDS_MEDIA_MENU_NO_DEVICE_TITLE 13172
#define IDS_MEDIA_CONTROLS_TITLE_PLACEHOLDER_INCOGNITO 13173
#define IDS_ZOOMLEVELS_CHROME_ERROR_PAGES_LABEL 13174
#define IDS_STORAGE_ACCESS_MANAGE_TEXT 13175
#define IDS_STORAGE_ACCESS_MANAGE_TOOLTIP 13176
#define IDS_REPORT_AN_ISSUE 13187
#define IDS_REENABLE_UPDATES 13188
#define IDS_PICTURE_IN_PICTURE_TITLE_TEXT 13189
#define IDS_PICTURE_IN_PICTURE_PAUSE_CONTROL_TEXT 13190
#define IDS_PICTURE_IN_PICTURE_PLAY_CONTROL_TEXT 13191
#define IDS_PICTURE_IN_PICTURE_REPLAY_CONTROL_TEXT 13192
#define IDS_PICTURE_IN_PICTURE_BACK_TO_TAB_CONTROL_TEXT 13193
#define IDS_PICTURE_IN_PICTURE_SKIP_AD_CONTROL_TEXT 13194
#define IDS_PICTURE_IN_PICTURE_LIVE_STATUS_TEXT 13195
#define IDS_PICTURE_IN_PICTURE_MUTE_MICROPHONE_TEXT 13196
#define IDS_PICTURE_IN_PICTURE_UNMUTE_MICROPHONE_TEXT 13197
#define IDS_PICTURE_IN_PICTURE_TURN_ON_CAMERA_TEXT 13198
#define IDS_PICTURE_IN_PICTURE_TURN_OFF_CAMERA_TEXT 13199
#define IDS_PICTURE_IN_PICTURE_HANG_UP_TEXT 13200
#define IDS_PICTURE_IN_PICTURE_CLOSE_CONTROL_TEXT 13201
#define IDS_PICTURE_IN_PICTURE_MINIMIZE_CONTROL_TEXT 13202
#define IDS_PICTURE_IN_PICTURE_LIVE_CAPTION_CONTROL_TEXT 13203
#define IDS_PICTURE_IN_PICTURE_REPLAY_10_TEXT 13204
#define IDS_PICTURE_IN_PICTURE_FORWARD_10_TEXT 13205
#define IDS_PICTURE_IN_PICTURE_RESIZE_HANDLE_TEXT 13206
#define IDS_PICTURE_IN_PICTURE_PLAY_PAUSE_CONTROL_ACCESSIBLE_TEXT 13207
#define IDS_PICTURE_IN_PICTURE_NEXT_TRACK_CONTROL_ACCESSIBLE_TEXT 13208
#define IDS_PICTURE_IN_PICTURE_PREVIOUS_TRACK_CONTROL_ACCESSIBLE_TEXT 13209
#define IDS_PICTURE_IN_PICTURE_PREVIOUS_SLIDE_CONTROL_ACCESSIBLE_TEXT 13210
#define IDS_PICTURE_IN_PICTURE_NEXT_SLIDE_CONTROL_ACCESSIBLE_TEXT 13211
#define IDS_AUTO_PICTURE_IN_PICTURE_DESCRIPTION 13212
#define IDS_LOAD_STATE_WAITING_FOR_SOCKET_SLOT 13213
#define IDS_LOAD_STATE_WAITING_FOR_DELEGATE 13214
#define IDS_LOAD_STATE_WAITING_FOR_DELEGATE_GENERIC 13215
#define IDS_LOAD_STATE_WAITING_FOR_CACHE 13216
#define IDS_LOAD_STATE_ESTABLISHING_PROXY_TUNNEL 13217
#define IDS_LOAD_STATE_RESOLVING_PROXY_FOR_URL 13218
#define IDS_LOAD_STATE_RESOLVING_HOST_IN_PAC_FILE 13219
#define IDS_LOAD_STATE_DOWNLOADING_PAC_FILE 13220
#define IDS_LOAD_STATE_RESOLVING_HOST 13221
#define IDS_LOAD_STATE_CONNECTING 13222
#define IDS_LOAD_STATE_SSL_HANDSHAKE 13223
#define IDS_LOAD_STATE_SENDING_REQUEST 13224
#define IDS_LOAD_STATE_SENDING_REQUEST_WITH_PROGRESS 13225
#define IDS_LOAD_STATE_WAITING_FOR_RESPONSE 13226
#define IDS_TAB_CXMENU_NEWTABTORIGHT 13227
#define IDS_TAB_CXMENU_NEWTABTOLEFT 13228
#define IDS_TAB_CXMENU_NEWTABBELOW 13229
#define IDS_TAB_CXMENU_RELOAD 13230
#define IDS_TAB_CXMENU_DUPLICATE 13231
#define IDS_TAB_CXMENU_CLOSETAB 13232
#define IDS_TAB_CXMENU_CLOSEOTHERTABS 13233
#define IDS_TAB_CXMENU_CLOSETABSTORIGHT 13234
#define IDS_TAB_CXMENU_CLOSETABSTOLEFT 13235
#define IDS_TAB_CXMENU_CLOSETABSBELOW 13236
#define IDS_TAB_CXMENU_CLOSEALLTABS 13237
#define IDS_TAB_CXMENU_FOCUS_THIS_TAB 13238
#define IDS_TAB_CXMENU_PIN_TAB 13239
#define IDS_TAB_CXMENU_UNPIN_TAB 13240
#define IDS_TAB_CXMENU_SOUND_MUTE_SITE 13241
#define IDS_TAB_CXMENU_SOUND_UNMUTE_SITE 13242
#define IDS_TAB_CXMENU_READ_LATER 13243
#define IDS_TAB_CXMENU_ADD_TAB_TO_GROUP 13244
#define IDS_TAB_CXMENU_ADD_TAB_TO_NEW_GROUP 13245
#define IDS_TAB_CXMENU_ADD_TAB_TO_NEW_SPLIT 13246
#define IDS_TAB_CXMENU_NEW_SPLIT_WITH_CURRENT 13247
#define IDS_TAB_CXMENU_ARRANGE_SPLIT 13248
#define IDS_TAB_CXMENU_SWAP_WITH_ACTIVE_SPLIT 13249
#define IDS_TAB_CXMENU_SUBMENU_NEW_GROUP 13250
#define IDS_TAB_CXMENU_REMOVE_TAB_FROM_GROUP 13251
#define IDS_TAB_CXMENU_PLACEHOLDER_GROUP_TITLE 13252
#define IDS_TAB_CXMENU_MOVE_TABS_TO_NEW_WINDOW 13253
#define IDS_TAB_CXMENU_MOVETOANOTHERWINDOW 13254
#define IDS_TAB_CXMENU_MOVETOANOTHERNEWWINDOW 13255
#define IDS_TAB_CXMENU_ORGANIZE_TABS 13256
#define IDS_TAB_CXMENU_COMMERCE_PRODUCT_SPEC 13257
#define IDS_TAB_CXMENU_ADD_TAB_TO_NEW_COMPARISON_TABLE 13258
#define IDS_TOOLTIP_WEBUI_TAB_STRIP_TAB_COUNTER 13262
#define IDS_WEBUI_TAB_STRIP_TAB_COUNTER_CXMENU_NEW_TAB 13263
#define IDS_WEBUI_TAB_STRIP_TAB_COUNTER_CXMENU_CLOSE_TAB 13264
#define IDS_ACCNAME_SPLIT_TABS_RESIZE 13265
#define IDS_PIN_SPLIT_TAB_TOGGLE 13266
#define IDS_SPLIT_TAB_REVERSE_VIEWS 13267
#define IDS_SPLIT_TAB_CLOSE 13268
#define IDS_SPLIT_TAB_CLOSE_LEFT_VIEW 13269
#define IDS_SPLIT_TAB_CLOSE_RIGHT_VIEW 13270
#define IDS_SPLIT_TAB_CLOSE_TOP_VIEW 13271
#define IDS_SPLIT_TAB_CLOSE_BOTTOM_VIEW 13272
#define IDS_SPLIT_TAB_SEPARATE_VIEWS 13273
#define IDS_SPLIT_TAB_SWAP_LEFT_VIEW 13274
#define IDS_SPLIT_TAB_SWAP_RIGHT_VIEW 13275
#define IDS_SPLIT_TAB_SWAP_TOP_VIEW 13276
#define IDS_SPLIT_TAB_SWAP_BOTTOM_VIEW 13277
#define IDS_SPLIT_TAB_SEND_FEEDBACK 13278
#define IDS_TAB_SEARCH_TOOLBAR_BUTTON_PROMO_TITLE 13279
#define IDS_TAB_SEARCH_TOOLBAR_BUTTON_PROMO_BODY 13280
#define IDS_TAB_SEARCH_TOOLBAR_BUTTON_PROMO_ACTION 13281
#define IDS_TAB_SEARCH_COMBO_BUTTON_PROMO_TITLE 13282
#define IDS_TAB_SEARCH_COMBO_BUTTON_PROMO_BODY 13283
#define IDS_TAB_SEARCH_COMBO_BUTTON_PROMO_SCREENREADER 13284
#define IDS_TAB_SEARCH_SEARCH_TABS 13285
#define IDS_TAB_SEARCH_NO_RESULTS_FOUND 13286
#define IDS_TAB_SEARCH_CLOSE_TAB 13287
#define IDS_TAB_SEARCH_SUBMIT_FEEDBACK 13288
#define IDS_TAB_SEARCH_A11Y_TAB_CLOSED 13289
#define IDS_TAB_SEARCH_A11Y_FOUND_TAB 13290
#define IDS_TAB_SEARCH_A11Y_FOUND_TABS 13291
#define IDS_TAB_SEARCH_A11Y_FOUND_TAB_FOR 13292
#define IDS_TAB_SEARCH_A11Y_FOUND_TABS_FOR 13293
#define IDS_TAB_SEARCH_A11Y_OPEN_TAB 13294
#define IDS_TAB_SEARCH_A11Y_RECENTLY_CLOSED_TAB 13295
#define IDS_TAB_SEARCH_A11Y_RECENTLY_CLOSED_TAB_GROUP 13296
#define IDS_TAB_SEARCH_MEDIA_TABS 13297
#define IDS_TAB_SEARCH_OPEN_TABS 13298
#define IDS_TAB_SEARCH_RECENTLY_CLOSED 13299
#define IDS_TAB_SEARCH_RECENTLY_CLOSED_TABS 13300
#define IDS_TAB_SEARCH_ONE_TAB 13301
#define IDS_TAB_SEARCH_TAB_COUNT 13302
#define IDS_TAB_SEARCH_EXPAND_RECENTLY_CLOSED_ITEMS 13303
#define IDS_TAB_SEARCH_EXPAND_RECENTLY_CLOSED 13304
#define IDS_TAB_SEARCH_COLLAPSE_RECENTLY_CLOSED 13305
#define IDS_TAB_SEARCH_TAB_NAME 13306
#define IDS_TAB_SEARCH_MENU 13307
#define IDS_TAB_ORGANIZATION_TAB_NAME 13308
#define IDS_TAB_ORGANIZATION_CREATE_GROUP 13309
#define IDS_TAB_ORGANIZATION_CREATE_GROUPS 13310
#define IDS_TAB_ORGANIZATION_DISMISS 13311
#define IDS_TAB_ORGANIZATION_NEW_TABS 13312
#define IDS_TAB_ORGANIZATION_NOT_STARTED_TITLE 13313
#define IDS_TAB_ORGANIZATION_NOT_STARTED_TITLE_FRE 13314
#define IDS_TAB_ORGANIZATION_NOT_STARTED_BODY 13315
#define IDS_TAB_ORGANIZATION_NOT_STARTED_BODY_FRE_HEADER 13316
#define IDS_TAB_ORGANIZATION_NOT_STARTED_BODY_FRE_BULLET_1 13317
#define IDS_TAB_ORGANIZATION_NOT_STARTED_BODY_FRE_BULLET_2 13318
#define IDS_TAB_ORGANIZATION_NOT_STARTED_BODY_FRE_BULLET_3 13319
#define IDS_TAB_ORGANIZATION_NOT_STARTED_BODY_SIGNED_OUT 13320
#define IDS_TAB_ORGANIZATION_NOT_STARTED_BUTTON 13321
#define IDS_TAB_ORGANIZATION_NOT_STARTED_BUTTON_FRE 13322
#define IDS_TAB_ORGANIZATION_NOT_STARTED_BUTTON_SIGNED_OUT 13323
#define IDS_TAB_ORGANIZATION_NOT_STARTED_BUTTON_ARIA_LABEL 13324
#define IDS_TAB_ORGANIZATION_NOT_STARTED_BUTTON_FRE_ARIA_LABEL 13325
#define IDS_TAB_ORGANIZATION_NOT_STARTED_BUTTON_SIGNED_OUT_ARIA_LABEL 13326
#define IDS_TAB_ORGANIZATION_IN_PROGRESS_TITLE 13327
#define IDS_TAB_ORGANIZATION_SUCCESS_MISSING_ACTIVE_TAB_TITLE 13328
#define IDS_TAB_ORGANIZATION_SUCCESS_TITLE_SINGLE 13329
#define IDS_TAB_ORGANIZATION_SUCCESS_TITLE_MULTI 13330
#define IDS_TAB_ORGANIZATION_FAILURE_TITLE_GENERIC 13331
#define IDS_TAB_ORGANIZATION_FAILURE_TITLE_GROUPING 13332
#define IDS_TAB_ORGANIZATION_FAILURE_BODY_GENERIC 13333
#define IDS_TAB_ORGANIZATION_FAILURE_BODY_GROUPING 13334
#define IDS_TAB_ORGANIZATION_TIP_TITLE 13335
#define IDS_TAB_ORGANIZATION_TIP_BODY 13336
#define IDS_TAB_ORGANIZATION_TIP_ACTION 13337
#define IDS_TAB_ORGANIZATION_TIP_ARIA_DESCRIPTION 13338
#define IDS_TAB_ORGANIZATION_DISCLAIMER_1 13339
#define IDS_TAB_ORGANIZATION_DISCLAIMER_2 13340
#define IDS_TAB_ORGANIZATION_LEARN_MORE 13341
#define IDS_TAB_ORGANIZATION_LEARN_MORE_ARIA_LABEL 13342
#define IDS_TAB_ORGANIZATION_CLOSE_TAB_ARIA_LABEL 13343
#define IDS_TAB_ORGANIZATION_CLOSE_TAB_TOOLTIP 13344
#define IDS_TAB_ORGANIZATION_CLEAR_SUGGESTIONS 13345
#define IDS_TAB_ORGANIZATION_CLEAR_ARIA_LABEL 13346
#define IDS_TAB_ORGANIZATION_INPUT_ARIA_LABEL 13347
#define IDS_TAB_ORGANIZATION_EDIT_ARIA_LABEL 13348
#define IDS_TAB_ORGANIZATION_REJECT_ARIA_LABEL 13349
#define IDS_TAB_ORGANIZATION_THUMBS_DOWN 13350
#define IDS_TAB_ORGANIZATION_THUMBS_UP 13351
#define IDS_TAB_ORGANIZATION_A11Y_TAB_EXCLUDED 13352
#define IDS_BROWSER_WINDOW_TITLE_MENU_ENTRY 13353
#define IDS_TABS_TITLE_CXMENU 13354
#define IDS_SAVED_TAB_GROUP_TABS_COUNT 13355
#define IDS_CREATE_NEW_TAB_GROUP 13356
#define IDS_GROUP_UNGROUPED_TABS 13357
#define IDS_SAVED_TAB_GROUPS_MENU 13358
#define IDS_OPEN_GROUP_IN_BROWSER_MENU 13359
#define IDS_NEW_TAB_IN_GROUP 13360
#define IDS_NEW_TAB_IN_GROUP_NO_GROUPS 13361
#define IDS_NEW_TAB_IN_GROUP_NO_NAME 13362
#define IDS_NEW_TAB_GROUP 13363
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_IPH_APP_MENU_SYNCED_BODY 13364
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_DEFAULT_BODY_A11Y 13365
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_IPH_APP_MENU_NOT_SYNCED_BODY 13366
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_IPH_BOOKMARKS_BAR_SYNCED_BODY 13367
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_IPH_BOOKMARKS_BAR_NOT_SYNCED_BODY 13368
#define IDS_RESUMPTION_RAIL_IPH_TITLE 13369
#define IDS_RESUMPTION_RAIL_IPH_BODY 13370
#define IDS_RESUMPTION_RAIL_IPH_BODY_ONLY_GEMINI 13371
#define IDS_RESUMPTION_RAIL_IPH_BODY_ONLY_AI_MODE 13372
#define IDS_RESUMPTION_RAIL_IPH_BODY_NO_THREADS 13373
#define IDS_RESUMPTION_RAIL_THREADS_IPH_TITLE 13374
#define IDS_RESUMPTION_RAIL_THREADS_IPH_TITLE_ONLY_GEMINI 13375
#define IDS_RESUMPTION_RAIL_THREADS_IPH_TITLE_ONLY_AI_MODE 13376
#define IDS_RESUMPTION_RAIL_THREADS_IPH_BODY 13377
#define IDS_RESUMPTION_RAIL_THREADS_IPH_BODY_ONLY_GEMINI 13378
#define IDS_RESUMPTION_RAIL_THREADS_IPH_BODY_ONLY_AI_MODE 13379
#define IDS_RESUMPTION_RAIL_IPH_OK_BUTTON 13380
#define IDS_SAVED_TAB_GROUPS_UNSUPPORTED_ERROR 13381
#define IDS_TAB_GROUP_DELETION_DIALOG_MISSING_EMAIL 13382
#define IDS_TAB_GROUP_DELETION_DIALOG_BODY_SYNCED_DELETE 13383
#define IDS_TAB_GROUP_DELETION_DIALOG_BODY_SYNCED_UNGROUP 13384
#define IDS_TAB_GROUP_DELETION_DIALOG_BODY_NOT_SYNCED_DELETE 13385
#define IDS_TAB_GROUP_DELETION_DIALOG_BODY_NOT_SYNCED_UNGROUP 13386
#define IDS_TAB_GROUP_DELETION_DIALOG_DONT_ASK 13387
#define IDS_TAB_GROUP_DELETION_DIALOG_TITLE_DELETE 13388
#define IDS_TAB_GROUP_DELETION_DIALOG_TITLE_UNGROUP 13389
#define IDS_TAB_GROUP_DELETION_DIALOG_TITLE_CLOSE_TAB_AND_DELETE 13390
#define IDS_TAB_GROUP_DELETION_DIALOG_TITLE_REMOVE_TAB_AND_DELETE 13391
#define IDS_TAB_GROUP_DELETION_DIALOG_OK_TEXT_DELETE 13392
#define IDS_TAB_GROUP_DELETION_DIALOG_OK_TEXT_UNGROUP 13393
#define IDS_TAB_GROUP_HEADER_CXMENU_TAB_GROUP_TITLE_ACCESSIBLE_NAME 13394
#define IDS_TAB_GROUP_HEADER_CXMENU_TAB_GROUP_FACE_PILE_ACCESSIBLE_NAME 13395
#define IDS_TAB_GROUP_HEADER_CXMENU_NEW_TAB_IN_GROUP 13396
#define IDS_TAB_GROUP_HEADER_CXMENU_UNGROUP 13397
#define IDS_TAB_GROUP_HEADER_CXMENU_FOCUS_GROUP 13398
#define IDS_TAB_GROUP_HEADER_CXMENU_UNFOCUS_GROUP 13399
#define IDS_TAB_GROUP_HEADER_CXMENU_SHARE_GROUP 13400
#define IDS_TAB_GROUP_HEADER_CXMENU_RECENT_ACTIVITY 13401
#define IDS_TAB_GROUP_HEADER_CXMENU_MANAGE_GROUP 13402
#define IDS_TAB_GROUP_HEADER_CXMENU_CLOSE_GROUP 13403
#define IDS_TAB_GROUP_HEADER_CXMENU_HIDE_GROUP 13404
#define IDS_TAB_GROUP_HEADER_CXMENU_DELETE_GROUP 13405
#define IDS_TAB_GROUP_HEADER_CXMENU_MOVE_GROUP_TO_NEW_WINDOW 13406
#define IDS_TAB_GROUP_HEADER_CXMENU_OPEN_GROUP_IN_NEW_WINDOW 13407
#define IDS_TAB_GROUP_HEADER_CXMENU_PIN_GROUP 13408
#define IDS_TAB_GROUP_HEADER_CXMENU_UNPIN_GROUP 13409
#define IDS_TAB_GROUP_HEADER_CXMENU_CONVERT_GROUP_TO_BOOKMARK_FOLDER 13410
#define IDS_TAB_GROUP_HEADER_CXMENU_SEND_FEEDBACK 13411
#define IDS_TAB_GROUP_HEADER_BUBBLE_TITLE_PLACEHOLDER 13412
#define IDS_DATA_SHARING_SHARE_GROUP_TITLE 13413
#define IDS_DATA_SHARING_COPY_LINK 13414
#define IDS_DATA_SHARING_COPY_LINK_SUCCESS 13415
#define IDS_DATA_SHARING_MANAGE_GROUP_TITLE 13416
#define IDS_DATA_SHARING_MANAGE_STOP_SHARING_OPTION 13417
#define IDS_DATA_SHARING_MANAGE_ACTIVITY_LOG_OPTION 13418
#define IDS_DATA_SHARING_OWNER_STOP_SHARING_DIALOG_TITLE 13419
#define IDS_DATA_SHARING_OWNER_REMOVE_MEMBER_DIALOG_TITLE 13420
#define IDS_DATA_SHARING_OWNER_REMOVE_MEMBER_DIALOG_CONFIRM 13421
#define IDS_DATA_SHARING_OWNER_DELETE_DIALOG_TITLE 13422
#define IDS_DATA_SHARING_OWNER_DELETE_DIALOG_CONFIRM 13423
#define IDS_DATA_SHARING_PREVIEW_DIALOG_TITLE 13424
#define IDS_DATA_SHARING_PREVIEW_DIALOG_TITLE_ZERO 13425
#define IDS_DATA_SHARING_PREVIEW_DIALOG_TITLE_SINGULAR 13426
#define IDS_DATA_SHARING_PREVIEW_DIALOG_TITLE_PLURAL 13427
#define IDS_DATA_SHARING_PREVIEW_DIALOG_CONFIRM 13428
#define IDS_DATA_SHARING_PREVIEW_DIALOG_DETAILS_TITLE 13429
#define IDS_DATA_SHARING_LINK_FAILED_TITLE 13430
#define IDS_DATA_SHARING_LEAVE_DIALOG_TITLE 13431
#define IDS_DATA_SHARING_BLOCK_LEAVE_DIALOG_TITLE 13432
#define IDS_DATA_SHARING_BLOCK_LEAVE_DIALOG_CONFIRM 13433
#define IDS_DATA_SHARING_NEED_SIGN_IN 13434
#define IDS_DATA_SHARING_NEED_SYNC 13435
#define IDS_DATA_SHARING_NEED_SYNC_TAB_GROUPS 13436
#define IDS_DATA_SHARING_NEED_VERIFY_ACCOUNT 13437
#define IDS_DATA_SHARING_NEED_VERIFY_ACCOUNT_BUTTON 13438
#define IDS_DATA_SHARING_GOT_IT 13439
#define IDS_DATA_SHARING_SOMETHING_WRONG 13440
#define IDS_DATA_SHARING_ORGANIZATION_DISALLOW_SIGN_IN 13441
#define IDS_DATA_SHARING_ORGANIZATION_LIMIT_SAVE 13442
#define IDS_DATA_SHARING_SIGNED_OUT 13443
#define IDS_DATA_SHARING_GROUP_FULL 13444
#define IDS_DATA_SHARING_DELETE_LAST_TAB_TITLE 13445
#define IDS_DATA_SHARING_DELETE_LAST_TAB_CONFIRM 13446
#define IDS_DATA_SHARING_OWNER_DELETE_LAST_TAB_CANCEL 13447
#define IDS_DATA_SHARING_MEMBER_DELETE_LAST_TAB_CANCEL 13448
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TITLE 13449
#define IDS_DATA_SHARING_RECENT_ACTIVITY_LATEST_UPDATE_TAB 13450
#define IDS_DATA_SHARING_RECENT_ACTIVITY_LATEST_UPDATE_GROUP 13451
#define IDS_DATA_SHARING_SHARE_GROUP_BODY 13452
#define IDS_DATA_SHARING_SHARE_GROUP_SHARE_AS 13453
#define IDS_DATA_SHARING_MANAGE_SHARE_WISELY 13454
#define IDS_DATA_SHARING_OWNER_STOP_SHARING_DIALOG_BODY 13455
#define IDS_DATA_SHARING_OWNER_REMOVE_MEMBER_DIALOG_BODY 13456
#define IDS_DATA_SHARING_OWNER_DELETE_DIALOG_BODY 13457
#define IDS_DATA_SHARING_OWNER_DELETE_DIALOG_BODY_NO_GROUP_TITLE 13458
#define IDS_DATA_SHARING_PREVIEW_DIALOG_BODY 13459
#define IDS_DATA_SHARING_PREVIEW_DIALOG_DETAILS_TABS_IN_GROUP 13460
#define IDS_DATA_SHARING_LINK_FAILED_BODY 13461
#define IDS_DATA_SHARING_JOIN_GROUP_JOIN_AS 13462
#define IDS_DATA_SHARING_GET_GROUP_PREVIEW_ARIA_LABEL 13463
#define IDS_DATA_SHARING_PREVIEW_A11Y_NAME 13464
#define IDS_DATA_SHARING_LEAVE_DIALOG_BODY 13465
#define IDS_DATA_SHARING_LEAVE_DIALOG_BODY_NO_GROUP_TITLE 13466
#define IDS_DATA_SHARING_LEAVE_DIALOG_CONFIRM 13467
#define IDS_DATA_SHARING_BLOCK_DIALOG_TITLE 13468
#define IDS_DATA_SHARING_BLOCK_DIALOG_BODY 13469
#define IDS_DATA_SHARING_BLOCK_LEAVE_DIALOG_BODY 13470
#define IDS_DATA_SHARING_BLOCK_LEAVE_LEARN_MORE 13471
#define IDS_DATA_SHARING_NEED_SIGN_IN_BODY 13472
#define IDS_DATA_SHARING_NEED_SIGN_IN_CONTINUE_BUTTON 13473
#define IDS_DATA_SHARING_NEED_SYNC_BODY 13474
#define IDS_DATA_SHARING_NEED_SYNC_TAB_GROUPS_BODY 13475
#define IDS_DATA_SHARING_NEED_VERIFY_ACCOUNT_BODY 13476
#define IDS_SYNC_HISTORY_TITLE 13477
#define IDS_DATA_SHARING_NEED_SIGN_IN_AND_SYNC_HISTORY_BODY 13478
#define IDS_DATA_SHARING_NEED_SYNC_HISTORY_BODY 13479
#define IDS_DATA_SHARING_NEED_VERIFY_ACCOUNT_SYNC_HISTORY_BODY 13480
#define IDS_SYNC_HISTORY_BUTTON 13481
#define IDS_SYNC_HISTORY_FOOTER 13482
#define IDS_DATA_SHARING_SOMETHING_WRONG_BODY 13483
#define IDS_DATA_SHARING_SHARE_ERROR_BODY 13484
#define IDS_DATA_SHARING_JOIN_WARNING 13485
#define IDS_DATA_SHARING_ORGANIZATION_DISALLOW_SIGN_IN_BODY 13486
#define IDS_DATA_SHARING_ORGANIZATION_LIMIT_SAVE_BODY 13487
#define IDS_DATA_SHARING_SIGNED_OUT_BODY 13488
#define IDS_DATA_SHARING_SETTINGS 13489
#define IDS_DATA_SHARING_GROUP_FULL_BODY 13490
#define IDS_DATA_SHARING_OWNER_CANNOT_SHARE 13491
#define IDS_DATA_SHARING_DELETE_LAST_DIALOG_HEADER 13492
#define IDS_DATA_SHARING_OWNER_DELETE_LAST_TAB_BODY 13493
#define IDS_DATA_SHARING_OWNER_DELETE_LAST_TAB_BODY_SINGULAR 13494
#define IDS_DATA_SHARING_OWNER_DELETE_LAST_TAB_BODY_2 13495
#define IDS_DATA_SHARING_MEMBER_DELETE_LAST_TAB_BODY 13496
#define IDS_DATA_SHARING_MEMBER_DELETE_LAST_TAB_BODY_SINGULAR 13497
#define IDS_DATA_SHARING_RECENT_ACTIVITY_NO_UPDATES 13498
#define IDS_DATA_SHARING_PAGE_ACTION_ADDED_NEW_TAB 13499
#define IDS_DATA_SHARING_PAGE_ACTION_CHANGED_TAB 13500
#define IDS_DATA_SHARING_USER_ED_FIRST_TAB_CHANGE 13501
#define IDS_DATA_SHARING_SHARED_GROUPS_FEEDBACK 13502
#define IDS_DATA_SHARING_SHARED_GROUPS_FEEDBACK_IPH 13503
#define IDS_DATA_SHARING_SHARED_GROUPS_FEEDBACK_IPH_SCREENREADER 13504
#define IDS_DATA_SHARING_LEARN_ABOUT_SHARED_GROUPS 13505
#define IDS_DATA_SHARING_PEOPLE_WITH_ACCESS 13506
#define IDS_DATA_SHARING_LINK_EDIT_ACCESS 13507
#define IDS_DATA_SHARING_LINK_JOIN_TOGGLE 13508
#define IDS_DATA_SHARING_CANCEL 13509
#define IDS_DATA_SHARING_CLOSE 13510
#define IDS_DATA_SHARING_BACK 13511
#define IDS_DATA_SHARING_BLOCK 13512
#define IDS_DATA_SHARING_REMOVE 13513
#define IDS_DATA_SHARING_LEAVE_GROUP 13514
#define IDS_DATA_SHARING_KEEP_GROUP 13515
#define IDS_DATA_SHARING_DELETE_GROUP 13516
#define IDS_DATA_SHARING_LOADING 13517
#define IDS_DATA_SHARING_COPY_LINK_FAILED 13518
#define IDS_DATA_SHARING_YOU 13519
#define IDS_DATA_SHARING_OWNER 13520
#define IDS_DATA_SHARING_MEMBER_COUNT_SINGULAR 13521
#define IDS_DATA_SHARING_MEMBER_COUNT_PLURAL 13522
#define IDS_DATA_SHARING_TAB_COUNT_SINGULAR 13523
#define IDS_DATA_SHARING_TAB_COUNT_PLURAL 13524
#define IDS_DATA_SHARING_MORE_OPTIONS 13525
#define IDS_DATA_SHARING_MORE_OPTIONS_DESCRIPTION 13526
#define IDS_APP_MENU_RELOAD 13527
#define IDS_APP_MENU_NEW_WEB_PAGE 13528
#define IDS_APP_MENU_COPY_LINK 13529
#define IDS_APP_MENU_CREATE_QR_CODE 13530
#define IDS_APP_MENU_BUTTON_UPDATE 13531
#define IDS_APP_MENU_BUTTON_UPDATE_ALT1 13532
#define IDS_APP_MENU_BUTTON_UPDATE_ALT2 13533
#define IDS_APP_MENU_BUTTON_UPDATE_ALT3 13534
#define IDS_APP_MENU_BUTTON_ERROR 13535
#define IDS_APP_MENU_BUTTON_ACTION_REQUIRED 13536
#define IDS_MEDIA_SCREEN_CAPTURE_CONFIRMATION_TITLE 13537
#define IDS_MEDIA_SCREEN_CAPTURE_CONFIRMATION_TEXT 13538
#define IDS_MEDIA_SCREEN_AND_AUDIO_CAPTURE_CONFIRMATION_TEXT 13539
#define IDS_MEDIA_SCREEN_CAPTURE_NOTIFICATION_TEXT 13540
#define IDS_MEDIA_SCREEN_CAPTURE_WITH_AUDIO_NOTIFICATION_TEXT 13541
#define IDS_MEDIA_WINDOW_CAPTURE_NOTIFICATION_TEXT 13542
#define IDS_MEDIA_WINDOW_CAPTURE_WITH_AUDIO_NOTIFICATION_TEXT 13543
#define IDS_MEDIA_TAB_CAPTURE_NOTIFICATION_TEXT 13544
#define IDS_MEDIA_TAB_CAPTURE_WITH_AUDIO_NOTIFICATION_TEXT 13545
#define IDS_MEDIA_SCREEN_CAPTURE_NOTIFICATION_HIDE 13546
#define IDS_MEDIA_SCREEN_CAPTURE_NOTIFICATION_SOURCE 13547
#define IDS_MEDIA_SCREEN_CAPTURE_NOTIFICATION_STOP 13548
#define IDS_PLATFORM_KEYS_SELECT_CERT_DIALOG_TEXT 13549
#define IDS_UNSAFE_FRAME_MESSAGE 13550
#define IDS_CLIENT_CERT_DIALOG_TITLE 13551
#define IDS_CLIENT_CERT_DIALOG_TEXT 13552
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TITLE 13553
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_CERT_ENROLLMENT 13554
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_CLIENT_AUTH 13555
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_LIST_CERTS 13556
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_CERT_IMPORT 13557
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_CERT_EXPORT 13558
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_PASSWORD_FIELD 13559
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_OK_BUTTON_LABEL 13560
#define IDS_FR_ENABLE_LOGGING 13562
#define IDS_CRASHED_TAB_FEEDBACK_MESSAGE 13566
#define IDS_CRASHED_TAB_FEEDBACK_LINK 13567
#define IDS_KILLED_TAB_FEEDBACK_MESSAGE 13569
#define IDS_DEFAULT_BROWSER_CHANGED_TITLE 13571
#define IDS_DEFAULT_BROWSER_CHANGED_YES_BUTTON 13572
#define IDS_DEFAULT_BROWSER_CHANGED_NO_THANKS_BUTTON 13573
#define IDS_DEFAULT_BROWSER_MODAL_CONFIRM_BUTTON 13574
#define IDS_DEFAULT_BROWSER_MODAL_CANCEL_BUTTON 13575
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_STEPS_COMBINED 13576
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_OPEN_SETTINGS_LABEL 13577
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_SET_DEFAULT_LABEL 13578
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_YES_LABEL 13579
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_SET_LATER_LABEL 13580
#define IDS_RELAUNCH_BUTTON 13581
#define IDS_HELP_MANAGED_BY_YOUR_PARENT 13582
#define IDS_TOOLBAR_INFORM_SET_HOME_PAGE 13585
#define IDS_MANAGE_EXTENSIONS_SETTING_WINDOWS_TITLE 13586
#define IDS_CONTROLLED_SETTING_POLICY 13587
#define IDS_CONTROLLED_SETTING_EXTENSION 13588
#define IDS_CONTROLLED_SETTING_EXTENSION_WITHOUT_NAME 13589
#define IDS_CONTROLLED_SETTING_RECOMMENDED 13590
#define IDS_CONTROLLED_SETTING_HAS_RECOMMENDATION 13591
#define IDS_CONTROLLED_SETTING_CHILD_RESTRICTION 13592
#define IDS_CONTROLLED_SETTING_PARENT 13593
#define IDS_EXTENSIONS_INSTALL_LOCATION_UNKNOWN 13594
#define IDS_EXTENSIONS_INSTALL_LOCATION_3RD_PARTY 13595
#define IDS_EXTENSIONS_INSTALL_LOCATION_ENTERPRISE 13596
#define IDS_EXTENSIONS_INSTALL_LOCATION_SHARED_MODULE 13597
#define IDS_EXTENSIONS_BLOCKLISTED_MALWARE 13598
#define IDS_EXTENSIONS_BLOCKLISTED_SECURITY_VULNERABILITY 13599
#define IDS_EXTENSIONS_BLOCKLISTED_CWS_POLICY_VIOLATION 13600
#define IDS_EXTENSIONS_BLOCKLISTED_POTENTIALLY_UNWANTED 13601
#define IDS_EXTENSIONS_SAFE_BROWSING_CRX_ALLOWLIST_WARNING 13602
#define IDS_EXTENSIONS_SAFE_BROWSING_CRX_ALLOWLIST_WARNING_LEARN_MORE 13603
#define IDS_EXTENSIONS_ACCESS_REQUESTS_LEARN_MORE 13604
#define IDS_UPLOAD_MOVE_TO_ACCOUNT_DIALOG_TITLE 13605
#define IDS_EXTENSIONS_MOVE_TO_ACCOUNT_DIALOG_SUBTITLE 13606
#define IDS_BOOKMARK_UPLOAD_MOVE_TO_ACCOUNT_DIALOG_SUBTITLE 13607
#define IDS_EXTENSIONS_MOVE_TO_ACCOUNT_DIALOG_OK_BUTTON_LABEL 13608
#define IDS_BOOKMARK_MOVE_TO_ACCOUNT_ICON_TOOLTIP 13609
#define IDS_RESET_PROFILE_SETTINGS_EXPLANATION 13610
#define IDS_TRIGGERED_RESET_PROFILE_SETTINGS_TITLE 13611
#define IDS_TRIGGERED_RESET_PROFILE_SETTINGS_EXPLANATION 13612
#define IDS_TRIGGERED_RESET_PROFILE_SETTINGS_DEFAULT_TOOL_NAME 13613
#define IDS_RESET_PROFILE_SETTINGS_LOCALE 13614
#define IDS_RESET_PROFILE_SETTINGS_STARTUP_URLS 13615
#define IDS_RESET_PROFILE_SETTINGS_STARTUP_TYPE 13616
#define IDS_RESET_PROFILE_SETTINGS_HOMEPAGE 13617
#define IDS_RESET_PROFILE_SETTINGS_HOMEPAGE_IS_NTP 13618
#define IDS_RESET_PROFILE_SETTINGS_YES 13619
#define IDS_RESET_PROFILE_SETTINGS_NO 13620
#define IDS_RESET_PROFILE_SETTINGS_SHOW_HOME_BUTTON 13621
#define IDS_RESET_PROFILE_SETTINGS_DSE 13622
#define IDS_RESET_PROFILE_SETTINGS_EXTENSIONS 13623
#define IDS_RESET_PROFILE_SETTINGS_SHORTCUTS 13624
#define IDS_RESET_PROFILE_SETTINGS_PROCESSING_SHORTCUTS 13625
#define IDS_AUTOFILL_DIALOG_PLACEHOLDER_EXPIRY_MONTH 13627
#define IDS_AUTOFILL_DIALOG_PLACEHOLDER_EXPIRY_YEAR 13628
#define IDS_AUTOFILL_FROM_GOOGLE_ACCOUNT 13629
#define IDS_SHOW_WINDOW_DECORATIONS 13630
#define IDS_OMNIBOX_ICON_SEND_TAB_TO_SELF 13631
#define IDS_OMNIBOX_TOOLTIP_SEND_TAB_TO_SELF 13632
#define IDS_OMNIBOX_BUBBLE_ITEM_SUBTITLE_TODAY_SEND_TAB_TO_SELF 13633
#define IDS_OMNIBOX_BUBBLE_ITEM_SUBTITLE_DAY_SEND_TAB_TO_SELF 13634
#define IDS_OMNIBOX_BUBBLE_ITEM_SUBTITLE_DAYS_SEND_TAB_TO_SELF 13635
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_FROM_DEVICE 13636
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_TITLE 13637
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_BUTTON_LABEL 13638
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_BUTTON_A11Y_NAME 13639
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_BUTTON_HINT_TEXT 13640
#define IDS_MENU_SEND_TAB_TO_SELF 13641
#define IDS_SEND_TAB_TO_SELF 13642
#define IDS_SEND_TAB_TO_SELF_SENDING_ANNOUNCE 13645
#define IDS_SEND_TAB_TO_SELF_MANAGE_DEVICES_LINK 13646
#define IDS_SEND_TAB_TO_SELF_SIGN_IN_PROMO_LABEL 13647
#define IDS_SEND_TAB_TO_SELF_NO_TARGET_DEVICE_LABEL 13648
#define IDS_CONTEXT_MENU_GENERATE_QR_CODE_PAGE 13649
#define IDS_CONTEXT_MENU_GENERATE_QR_CODE_IMAGE 13650
#define IDS_CONTEXT_MENU_GENERATE_QR_CODE_LINK 13651
#define IDS_OMNIBOX_QRCODE_GENERATOR_ICON_LABEL 13652
#define IDS_OMNIBOX_QRCODE_GENERATOR_ICON_TOOLTIP 13653
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_TITLE 13654
#define IDS_SHARING_HUB_GENERATE_QR_CODE_LABEL 13655
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_URL_TEXTFIELD_ACCESSIBLE_NAME 13656
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_TOOLTIP 13657
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_DOWNLOAD_BUTTON_LABEL 13658
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_COPY_BUTTON_LABEL 13659
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_ERROR_TOO_LONG 13660
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_ERROR_UNKNOWN 13661
#define IDS_SHARING_HUB_TITLE 13662
#define IDS_SHARING_HUB_TOOLTIP 13663
#define IDS_SHARING_HUB_SCREENSHOT_LABEL 13664
#define IDS_SHARING_HUB_COPY_LINK_LABEL 13665
#define IDS_SHARING_HUB_SAVE_PAGE_LABEL 13666
#define IDS_SHARING_HUB_MEDIA_ROUTER_LABEL 13667
#define IDS_SHARING_HUB_SHARE_LABEL 13668
#define IDS_BROWSER_SHARING_SCREENSHOT_POST_CAPTURE_TITLE 13669
#define IDS_BROWSER_SHARING_SCREENSHOT_DIALOG_DOWNLOAD_BUTTON_LABEL 13670
#define IDS_BROWSER_SHARING_SCREENSHOT_DIALOG_EDIT_BUTTON_LABEL 13671
#define IDS_BROWSER_SHARING_SCREENSHOT_DIALOG_SHARE_BUTTON_LABEL 13672
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_SELECTION 13673
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_CROP 13674
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_TEXT 13675
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ELLIPSE 13676
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_RECTANGLE 13677
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_LINE 13678
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ARROW 13679
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_BRUSH 13680
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_EMOJI 13681
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_HIGHLIGHTER 13682
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_UNDO 13683
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_REDO 13684
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ZOOM_IN 13685
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ZOOM_OUT 13686
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_COMMIT_CROP 13687
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_COMMIT_CROP 13688
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_CANCEL_CROP 13689
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_CANCEL_CROP 13690
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_BUTTON_DOWNLOAD_IMAGE 13691
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_BUTTON_COPY 13692
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TITLE 13693
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_BUTTON_TEXT_CLEAR 13694
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ALIGN_LEFT 13695
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ALIGN_CENTER 13696
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ALIGN_RIGHT 13697
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_SHADOW_NONE 13698
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_SHADOW_SMALL 13699
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_SHADOW_LARGE 13700
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_FONT_DEFAULT 13701
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_FONT_MONOSPACE 13702
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_FONT_ITALIC 13703
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_FONT_OUTLINE 13704
#define IDS_CONTEXT_MENU_PASTE_FROM_CLIPBOARD 13705
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_TITLE_TEXT_CONTENT_UNKNOWN_DEVICE 13706
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_TITLE_TEXT_CONTENT 13707
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_TITLE_IMAGE_CONTENT_UNKNOWN_DEVICE 13708
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_TITLE_IMAGE_CONTENT 13709
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_DESCRIPTION 13710
#define IDS_CONTENT_CONTEXT_SHARING_CLICK_TO_CALL_MULTIPLE_DEVICES 13711
#define IDS_CONTENT_CONTEXT_SHARING_CLICK_TO_CALL_SINGLE_DEVICE 13712
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_MULTIPLE_DEVICES 13713
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_SINGLE_DEVICE 13714
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_NOTIFICATION_TITLE_UNKNOWN_DEVICE 13715
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_NOTIFICATION_TITLE 13716
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_NOTIFICATION_DESCRIPTION 13717
#define IDS_OMNIBOX_TOOLTIP_SHARED_CLIPBOARD 13718
#define IDS_COLLECTED_COOKIES_DIALOG_TITLE 13719
#define IDS_COLLECTED_COOKIES_ALLOWED_COOKIES_LABEL 13720
#define IDS_COLLECTED_COOKIES_BLOCKED_COOKIES_LABEL 13721
#define IDS_COLLECTED_COOKIES_BLOCKED_THIRD_PARTY_BLOCKING_ENABLED 13722
#define IDS_COLLECTED_COOKIES_ALLOW_BUTTON 13723
#define IDS_COLLECTED_COOKIES_SESSION_ONLY_BUTTON 13724
#define IDS_COLLECTED_COOKIES_BLOCK_BUTTON 13725
#define IDS_COLLECTED_COOKIES_ALLOW_RULE_CREATED 13726
#define IDS_COLLECTED_COOKIES_BLOCK_RULE_CREATED 13727
#define IDS_COLLECTED_COOKIES_SESSION_RULE_CREATED 13728
#define IDS_COLLECTED_COOKIES_ALLOWED_COOKIES_TAB_LABEL 13729
#define IDS_COLLECTED_COOKIES_BLOCKED_COOKIES_TAB_LABEL 13730
#define IDS_COLLECTED_COOKIES_ALLOWED_AUX_TEXT 13731
#define IDS_COLLECTED_COOKIES_BLOCKED_AUX_TEXT 13732
#define IDS_COLLECTED_COOKIES_CLEAR_ON_EXIT_AUX_TEXT 13733
#define IDS_COLLECTED_COOKIES_INFOBAR_MESSAGE 13734
#define IDS_COLLECTED_COOKIES_INFOBAR_BUTTON 13735
#define IDS_COLLECTED_COOKIES_PARTITIONED_COOKIE 13736
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_TITLE 13737
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_SUBTITLE 13738
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_SETTINGS_LINK 13739
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_FIRST_PARTY_TITLE 13740
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_FIRST_PARTY_SUBTITLE 13741
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_THIRD_PARTY_TITLE 13742
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_THIRD_PARTY_SUBTITLE 13743
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_EMPTY_STATE_LABEL 13744
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_RELATED_APPS_TITLE 13745
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_RELATED_APPS_SUBTITLE 13746
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_RELATED_APPS_SETTINGS_LINK_TOOLTIP 13747
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_ALLOW_MENU_ITEM 13748
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_ALLOW_THIRD_PARTY_MENU_ITEM 13749
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_BLOCK_MENU_ITEM 13750
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_SESSION_ONLY_MENU_ITEM 13751
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_ALLOWED_STATE_SUBTITLE 13752
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_BLOCKED_STATE_SUBTITLE 13753
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_SESSION_ONLY_STATE_SUBTITLE 13754
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_PARTITIONED_STATE_SUBTITLE 13755
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_PARTITIONED_SESSION_ONLY_STATE_SUBTITLE 13756
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_CONTEXT_MENU_TOOLTIP 13757
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_DELETE_BUTTON_TOOLTIP 13758
#define IDS_ACCNAME_INFOBAR_CONTAINER 13759
#define IDS_ACCNAME_INFOBAR 13760
#define IDS_ONE_CLICK_BUBBLE_UNDO 13761
#define IDS_ENTERPRISE_SIGNIN_CANCEL 13762
#define IDS_ENTERPRISE_SIGNIN_CREATE_NEW_PROFILE 13763
#define IDS_ENTERPRISE_SIGNIN_CREATE_NEW_WORK_PROFILE 13764
#define IDS_ENTERPRISE_SIGNIN_CONTINUE 13765
#define IDS_ENTERPRISE_SIGNIN_ALERT 13766
#define IDS_PROFILE_WILL_BE_DELETED_DIALOG_TITLE 13767
#define IDS_PROFILE_WILL_BE_DELETED_DIALOG_DESCRIPTION 13768
#define IDS_MANAGED_WITH_HYPERLINK 13771
#define IDS_MANAGED_BY_WITH_HYPERLINK 13772
#define IDS_PROFILE_MANAGED_BY_WITH_HYPERLINK 13773
#define IDS_BROWSER_MANAGED_AND_PROFILE_MANAGED_BY_WITH_HYPERLINK 13774
#define IDS_BROWSER_AND_PROFILE_DIFFERENT_MANAGED_BY_WITH_HYPERLINK 13775
#define IDS_BROWSER_AND_PROFILE_SAME_MANAGED_BY_WITH_HYPERLINK 13776
#define IDS_MANAGED_BY_PARENT_WITH_HYPERLINK 13777
#define IDS_BROWSER_MANAGED_AND_PROFILE_MANAGED_BY_TOOLTIP 13778
#define IDS_BROWSER_AND_PROFILE_DIFFERENT_MANAGED_BY_TOOLTIP 13779
#define IDS_COOKIES_COOKIE_EXPIRES_SESSION 13780
#define IDS_COOKIES_COOKIE_SENDFOR_ANY 13781
#define IDS_COOKIES_COOKIE_SENDFOR_SECURE 13782
#define IDS_COOKIES_COOKIE_SENDFOR_SAME_SITE 13783
#define IDS_COOKIES_COOKIE_SENDFOR_SECURE_SAME_SITE 13784
#define IDS_COOKIES_COOKIE_ACCESSIBLE_TO_SCRIPT_YES 13785
#define IDS_COOKIES_COOKIE_ACCESSIBLE_TO_SCRIPT_NO 13786
#define IDS_COOKIES_COOKIES 13787
#define IDS_COOKIES_WEB_DATABASES 13788
#define IDS_COOKIES_LOCAL_STORAGE 13789
#define IDS_COOKIES_SESSION_STORAGE 13790
#define IDS_COOKIES_INDEXED_DBS 13791
#define IDS_COOKIES_FILE_SYSTEMS 13792
#define IDS_COOKIES_FILE_SYSTEM_USAGE_NONE 13793
#define IDS_COOKIES_SERVICE_WORKER 13794
#define IDS_COOKIES_SERVICE_WORKERS 13795
#define IDS_COOKIES_SHARED_WORKERS 13796
#define IDS_COOKIES_CACHE_STORAGE 13797
#define IDS_APP_DEFAULT_PAGE_NAME 13798
#define IDS_APP_LAUNCHER_TAB_TITLE 13799
#define IDS_NEW_TAB_GUEST_SESSION_HEADING 13800
#define IDS_NEW_TAB_GUEST_SESSION_DESCRIPTION 13801
#define IDS_NEW_TAB_GUEST_SESSION_LEARN_MORE_ACCESSIBILITY_TEXT 13802
#define IDS_NEW_TAB_ENTERPRISE_GUEST_SESSION_LEARN_MORE_ACCESSIBILITY_TEXT 13803
#define IDS_NEW_TAB_TILE_GRID_ACCESSIBLE_DESCRIPTION 13804
#define IDS_NEW_TAB_APP_INSTALL_HINT_LABEL 13805
#define IDS_NEW_TAB_MOST_VISITED 13806
#define IDS_NEW_TAB_RESTORE_THUMBNAILS_SHORT_LINK 13807
#define IDS_NEW_TAB_ATTRIBUTION_INTRO 13808
#define IDS_NEW_TAB_THUMBNAIL_REMOVED_NOTIFICATION 13809
#define IDS_NEW_TAB_REMOVE_THUMBNAIL_TOOLTIP 13810
#define IDS_NEW_TAB_PAGE_SWITCHER_CHANGE_TITLE 13811
#define IDS_NEW_TAB_PAGE_SWITCHER_SAME_TITLE 13812
#define IDS_NEW_TAB_VOICE_AUDIO_ERROR 13813
#define IDS_NEW_TAB_VOICE_CLOSE_TOOLTIP 13814
#define IDS_NEW_TAB_VOICE_DETAILS 13815
#define IDS_NEW_TAB_VOICE_LANGUAGE_ERROR 13816
#define IDS_NEW_TAB_VOICE_LISTENING 13817
#define IDS_NEW_TAB_VOICE_NETWORK_ERROR 13818
#define IDS_NEW_TAB_VOICE_NO_TRANSLATION 13819
#define IDS_NEW_TAB_VOICE_NO_VOICE 13820
#define IDS_NEW_TAB_VOICE_OTHER_ERROR 13821
#define IDS_NEW_TAB_VOICE_PERMISSION_ERROR 13822
#define IDS_NEW_TAB_VOICE_LEARN_MORE_ACCESSIBILITY_LABEL 13823
#define IDS_NEW_TAB_VOICE_READY 13824
#define IDS_NEW_TAB_VOICE_TRY_AGAIN 13825
#define IDS_NEW_TAB_VOICE_WAITING 13826
#define IDS_NEW_TAB_VOICE_SEARCH_CLOSED 13827
#define IDS_NEW_TAB_APP_OPTIONS 13828
#define IDS_NEW_TAB_APP_DETAILS 13829
#define IDS_NEW_TAB_APP_CREATE_SHORTCUT 13830
#define IDS_NEW_TAB_APP_INSTALL_LOCALLY 13831
#define IDS_APP_CONTEXT_MENU_SHOW_INFO 13832
#define IDS_APP_CONTEXT_MENU_OPEN_PINNED 13833
#define IDS_APP_CONTEXT_MENU_OPEN_REGULAR 13834
#define IDS_APP_CONTEXT_MENU_OPEN_WINDOW 13835
#define IDS_APP_CONTEXT_MENU_OPEN_FULLSCREEN 13836
#define IDS_APP_CONTEXT_MENU_OPEN_MAXIMIZED 13837
#define IDS_APP_CONTEXT_MENU_OPEN_TAB 13838
#define IDS_APP_CONTEXT_MENU_RUN_ON_OS_LOGIN 13843
#define IDS_APPS_PAGE_DEPRECATED_APP_TITLE 13846
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_TITLE 13847
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_PROCEED_BUTTON 13848
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_CANCEL_BUTTON 13849
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_BODY_TEXT 13850
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_DEFAULT_BODY_TEXT 13851
#define IDS_SYNC_CONFIRMATION_SETTINGS_INFO 13852
#define IDS_SYNC_CONFIRMATION_CONFIRM_BUTTON_LABEL 13853
#define IDS_SYNC_CONFIRMATION_SETTINGS_BUTTON_LABEL 13854
#define IDS_SYNC_CONFIRMATION_REFRESHED_SETTINGS_BUTTON_LABEL 13855
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_TITLE 13856
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_INFO_TITLE 13857
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_INFO_TITLE_SIGNIN_INTERCEPT_V2 13858
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_BOOKMARKS 13859
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_READING_LIST 13860
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_AUTOFILL 13861
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_EXTENSIONS 13862
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_HISTORY_AND_MORE 13863
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_INFO_DESC 13864
#define IDS_SYNC_CONFIRMATION_WELCOME_TITLE_SIGNIN_INTERCEPT 13865
#define IDS_SYNC_CONFIRMATION_TURN_ON_SYNC_BUTTON_LABEL 13866
#define IDS_SYNC_DISABLED_CONFIRMATION_CHROME_SYNC_TITLE 13867
#define IDS_SYNC_DISABLED_CONFIRMATION_DETAILS 13868
#define IDS_SYNC_DISABLED_CONFIRMATION_CONFIRM_BUTTON_LABEL 13869
#define IDS_SYNC_DISABLED_CONFIRMATION_CONFIRM_BUTTON_MANAGED_ACCOUNT_SIGNOUT_DISALLOWED_LABEL 13870
#define IDS_SYNC_DISABLED_CONFIRMATION_UNDO_BUTTON_LABEL 13871
#define IDS_SYNC_LOADING_CONFIRMATION_TITLE 13872
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_NEW_PROFILE_BUTTON_LABEL 13873
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_AVATAR_BUTTON_SEPARATE_BROWSING_TEXT 13874
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_AVATAR_BUTTON_SWITCH_PROFILE_TEXT 13875
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CREATE_PROFILE_BUTTON_LABEL 13876
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_STAY_HERE_BUTTON_LABEL 13877
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_TITLE_SUPERVISED 13878
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CANCEL_BUTTON_LABEL 13879
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CANCEL_SWITCH_BUTTON_LABEL 13880
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_CREATE_BUBBLE_DESC_SUPERVISED 13881
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_CONTINUE_BUTTON_LABEL 13882
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_ACCEPT_TEXT 13883
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_ENTERPRISE_BUBBLE_DESC_MANAGED_BY_TOKEN 13884
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_MANAGED_DISCLAIMER 13885
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_MANAGED_BY_DISCLAIMER 13886
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_IPH_TITLE_SIGNIN_REMINDER 13887
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_IPH_OK_BUTTON 13888
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_TITLE 13889
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_DELETE_AND_SIGNOUT_BUTTON 13890
#define IDS_CLOSE_WARNING_FOR_CLEAR_COOKIES_ON_EXIT_TEXT_LINK 13891
#define IDS_SYNC_PASSPHRASE_DIALOG_FOOTER_LINK 13892
#define IDS_SYNC_PASSPHRASE_DIALOG_TITLE 13893
#define IDS_SYNC_PASSPHRASE_DIALOG_OK_BUTTON 13894
#define IDS_CLOSE_WARNING_FOR_CLEAR_COOKIES_ON_EXIT_CLOSE 13895
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_ENTERPRISE_PROFILE_NAME 13896
#define IDS_SIGNIN_ERROR_TITLE 13897
#define IDS_SIGNIN_ERROR_EMAIL_TITLE 13898
#define IDS_SIGNIN_ERROR_CLOSE_BUTTON_LABEL 13899
#define IDS_SIGNIN_ERROR_OK_BUTTON_LABEL 13900
#define IDS_SIGNIN_ERROR_SWITCH_BUTTON_LABEL 13901
#define IDS_SIGNIN_ACCESSIBLE_CLOSE_BUTTON 13902
#define IDS_SIGNIN_ACCESSIBLE_BACK_BUTTON 13903
#define IDS_SIGNIN_EMAIL_CONFIRMATION_CREATE_PROFILE_RADIO_BUTTON_TITLE 13904
#define IDS_SIGNIN_EMAIL_CONFIRMATION_CREATE_PROFILE_RADIO_BUTTON_SUBTITLE 13905
#define IDS_SIGNIN_EMAIL_CONFIRMATION_START_SYNC_RADIO_BUTTON_TITLE 13906
#define IDS_SIGNIN_EMAIL_CONFIRMATION_START_SYNC_RADIO_BUTTON_SUBTITLE 13907
#define IDS_SIGNIN_EMAIL_CONFIRMATION_CLOSE_BUTTON_LABEL 13908
#define IDS_SIGNIN_EMAIL_CONFIRMATION_CONFIRM_BUTTON_LABEL 13909
#define IDS_PLUGIN_CRASHED_PROMPT 13910
#define IDS_RELOAD_PAGE_WITH_PLUGIN 13911
#define IDS_EXTERNAL_PROTOCOL_TITLE 13912
#define IDS_EXTERNAL_PROTOCOL_MESSAGE_WITH_INITIATING_ORIGIN 13913
#define IDS_EXTERNAL_PROTOCOL_MESSAGE 13914
#define IDS_EXTERNAL_PROTOCOL_OK_BUTTON_TEXT 13915
#define IDS_EXTERNAL_PROTOCOL_CANCEL_BUTTON_TEXT 13916
#define IDS_EXTERNAL_PROTOCOL_CHECKBOX_PER_ORIGIN_TEXT 13917
#define IDS_DIRECTORY_LISTING_HEADER 13919
#define IDS_DIRECTORY_LISTING_PARENT 13920
#define IDS_DIRECTORY_LISTING_NAME 13921
#define IDS_DIRECTORY_LISTING_SIZE 13922
#define IDS_DIRECTORY_LISTING_DATE_MODIFIED 13923
#define IDS_SAVE_PAGE_DESC_HTML_ONLY 13924
#define IDS_SAVE_PAGE_DESC_SINGLE_FILE 13925
#define IDS_SAVE_PAGE_DESC_COMPLETE 13926
#define IDS_PROFILE_ERROR_DIALOG_TITLE 13927
#define IDS_COULDNT_OPEN_PROFILE_ERROR 13928
#define IDS_OPEN_PROFILE_DATA_LOSS 13929
#define IDS_PROFILE_ERROR_DIALOG_CHECKBOX 13930
#define IDS_PROFILE_ERROR_FEEDBACK_DESCRIPTION 13931
#define IDS_REFUSE_TO_RUN_AS_ROOT 13932
#define IDS_REFUSE_TO_RUN_AS_ROOT_2 13933
#define IDS_CANT_WRITE_USER_DIRECTORY_TITLE 13935
#define IDS_RECENT_TABS_MENU 13936
#define IDS_RECENTLY_CLOSED_WINDOW 13937
#define IDS_RECENTLY_CLOSED_GROUP 13938
#define IDS_RECENTLY_CLOSED_GROUP_UNNAMED 13939
#define IDS_RECENT_TABS_NO_DEVICE_TABS 13940
#define IDS_RECENT_TABS_LOGIN_FOR_DEVICE_TABS 13941
#define IDS_RECENT_TABS_SEE_DEVICE_TABS 13942
#define IDS_HISTORY_MENU 13943
#define IDS_DEFAULT_DOWNLOAD_FILENAME 13944
#define IDS_DEFAULT_BROWSER_INFOBAR_OK_BUTTON_LABEL 13946
#define IDS_MINIMIZE_WINDOW_MENU 13947
#define IDS_MAXIMIZE_WINDOW_MENU 13948
#define IDS_RESTORE_WINDOW_MENU 13949
#define IDS_CLOSE_WINDOW_MENU 13950
#define IDS_SHOW_WINDOW_DECORATIONS_MENU 13951
#define IDS_USED_EXISTING_BROWSER 13952
#define IDS_DECLINE_RECOVERY 13953
#define IDS_SYNC_ACCOUNT_SYNCING 13954
#define IDS_SYNC_ACCOUNT_SYNCING_CUSTOM_DATA_TYPES 13955
#define IDS_SIGNIN_ERROR_DISPLAY_SOURCE 13956
#define IDS_SIGNIN_ERROR_BUBBLE_VIEW_TITLE 13957
#define IDS_SYNC_ERROR_BUBBLE_VIEW_TITLE 13958
#define IDS_SYNC_ERROR_PASSWORDS_BUBBLE_VIEW_TITLE 13959
#define IDS_SYNC_ERROR_USER_MENU_TITLE 13960
#define IDS_SYNC_ERROR_PASSWORDS_USER_MENU_ERROR_DESCRIPTION 13961
#define IDS_SYNC_ERROR_RECOVERABILITY_DEGRADED_FOR_PASSWORDS_USER_MENU_ERROR_DESCRIPTION 13962
#define IDS_SYNC_NEEDS_VERIFICATION_BUBBLE_VIEW_TITLE 13963
#define IDS_SYNC_ERROR_USER_MENU_CONFIRM_SYNC_SETTINGS_BUTTON 13964
#define IDS_SYNC_ERROR_USER_MENU_SIGNOUT_BUTTON 13965
#define IDS_SYNC_ERROR_USER_MENU_CONFIRM_SYNC_SETTINGS_BUTTON_MAYBE_TITLE_CASE 13966
#define IDS_SYNC_ERROR_USER_MENU_SIGNOUT_BUTTON_MAYBE_TITLE_CASE 13967
#define IDS_SYNC_EMPTY_STRING 13973
#define IDS_SYNC_OVERVIEW 13974
#define IDS_SYNC_START_SYNC_BUTTON_LABEL 13975
#define IDS_SIGNED_IN_WITH_SYNC_DISABLED_BY_POLICY 13976
#define IDS_SYNC_SETTINGS_NOT_CONFIRMED 13978
#define IDS_SYNC_SETUP_IN_PROGRESS 13979
#define IDS_SYNC_STATUS_UNRECOVERABLE_ERROR 13980
#define IDS_SYNC_STATUS_UNRECOVERABLE_ERROR_NEEDS_SIGNOUT 13981
#define IDS_SYNC_STATUS_NEEDS_PASSWORD 13982
#define IDS_SYNC_STATUS_NEEDS_PASSWORD_BUTTON 13983
#define IDS_SYNC_STATUS_NEEDS_KEYS_BUTTON 13984
#define IDS_SYNC_STATUS_NEEDS_PASSWORD_BUTTON_MAYBE_TITLE_CASE 13985
#define IDS_SYNC_STATUS_NEEDS_KEYS_BUTTON_MAYBE_TITLE_CASE 13986
#define IDS_SYNC_RELOGIN_ERROR 13987
#define IDS_SYNC_RELOGIN_BUTTON 13988
#define IDS_SYNC_RELOGIN_BUTTON_MAYBE_TITLE_CASE 13989
#define IDS_SYNC_ADVANCED_OPTIONS 13991
#define IDS_SYNC_FULL_ENCRYPTION_BODY_CUSTOM 13993
#define IDS_SYNC_FULL_ENCRYPTION_BODY_CUSTOM_WITH_DATE 13994
#define IDS_SYNC_FULL_ACCOUNT_DATA_ENCRYPTION_BODY_CUSTOM 13995
#define IDS_SYNC_FULL_ACCOUNT_DATA_ENCRYPTION_BODY_CUSTOM_WITH_DATE 13996
#define IDS_PARTIAL_TRANSLATE_BUBBLE_WAITING_TITLE 13997
#define IDS_TRANSLATE_BUBBLE_BEFORE_TRANSLATE_TITLE 13998
#define IDS_TRANSLATE_BUBBLE_TRANSLATED_TITLE 13999
#define IDS_PARTIAL_TRANSLATE_BUBBLE_COULD_NOT_TRANSLATE_TITLE 14000
#define IDS_TRANSLATE_BUBBLE_COULD_NOT_TRANSLATE_TITLE 14001
#define IDS_TRANSLATE_BUBBLE_SOURCE_LANG_COMBOBOX_ACCNAME 14002
#define IDS_TRANSLATE_BUBBLE_TARGET_LANG_COMBOBOX_ACCNAME 14003
#define IDS_TRANSLATE_BUBBLE_TRANSLATION_COMPLETE_ANNOUNCEMENT 14004
#define IDS_TRANSLATE_BUBBLE_ADVANCED_BUTTON 14005
#define IDS_TRANSLATE_BUBBLE_ADVANCED_MENU_BUTTON 14006
#define IDS_TRANSLATE_BUBBLE_CHANGE_TARGET_LANGUAGE 14007
#define IDS_TRANSLATE_BUBBLE_CHANGE_SOURCE_LANGUAGE 14008
#define IDS_TRANSLATE_BUBBLE_OPEN_LANGUAGE_SETTINGS 14009
#define IDS_PARTIAL_TRANSLATE_BUBBLE_CHANGE_SOURCE_LANGUAGE 14010
#define IDS_TRANSLATE_BUBBLE_ACCEPT 14011
#define IDS_TRANSLATE_BUBBLE_DENY 14012
#define IDS_TRANSLATE_BUBBLE_ALWAYS_TRANSLATE_LANG 14013
#define IDS_TRANSLATE_BUBBLE_NEVER_TRANSLATE_LANG 14014
#define IDS_TRANSLATE_BUBBLE_NEVER_TRANSLATE_SITE 14015
#define IDS_TRANSLATE_BUBBLE_TRANSLATING 14016
#define IDS_TRANSLATE_BUBBLE_REVERT 14017
#define IDS_TRANSLATE_BUBBLE_TRY_AGAIN 14018
#define IDS_TRANSLATE_BUBBLE_ALWAYS 14019
#define IDS_TRANSLATE_BUBBLE_OPTIONS_MENU_BUTTON 14020
#define IDS_TRANSLATE_BUBBLE_PAGE_LANGUAGE 14021
#define IDS_TRANSLATE_BUBBLE_TRANSLATION_LANGUAGE 14022
#define IDS_TRANSLATE_BUBBLE_ADVANCED_TARGET 14023
#define IDS_TRANSLATE_BUBBLE_ADVANCED_SOURCE 14024
#define IDS_PARTIAL_TRANSLATE_BUBBLE_ADVANCED_SOURCE 14025
#define IDS_PARTIAL_TRANSLATE_BUBBLE_TRANSLATE_FULL_PAGE 14026
#define IDS_TRANSLATE_BUBBLE_RESET 14027
#define IDS_NOTIFICATION_BUTTON_SETTINGS 14028
#define IDS_NOTIFICATION_BUTTON_CLOSE 14029
#define IDS_NOTIFICATION_BUTTON_MORE 14030
#define IDS_NOTIFICATION_REPLY_PLACEHOLDER 14031
#define IDS_NOTIFICATION_MUTED_MESSAGE 14032
#define IDS_NOTIFICATION_MUTED_TITLE 14033
#define IDS_NOTIFICATION_MUTED_ACTION_SHOW 14034
#define IDS_NOTIFICATION_MUTED_ACTION_SNOOZE 14035
#define IDS_FILE_MENU_LINUX 14156
#define IDS_EDIT_MENU_LINUX 14157
#define IDS_VIEW_MENU_LINUX 14158
#define IDS_HISTORY_MENU_LINUX 14159
#define IDS_TOOLS_MENU_LINUX 14160
#define IDS_HELP_MENU_LINUX 14161
#define IDS_REOPEN_CLOSED_TABS_LINUX 14162
#define IDS_OPEN_FILE_LINUX 14163
#define IDS_OPEN_LOCATION_LINUX 14164
#define IDS_CLOSE_WINDOW_LINUX 14165
#define IDS_CLOSE_TAB_LINUX 14166
#define IDS_STOP_MENU_LINUX 14167
#define IDS_RELOAD_MENU_LINUX 14168
#define IDS_TEXT_DEFAULT_LINUX 14169
#define IDS_TEXT_BIGGER_LINUX 14170
#define IDS_TEXT_SMALLER_LINUX 14171
#define IDS_HISTORY_HOME_LINUX 14172
#define IDS_HISTORY_BACK_LINUX 14173
#define IDS_HISTORY_FORWARD_LINUX 14174
#define IDS_HISTORY_VISITED_LINUX 14175
#define IDS_HISTORY_CLOSED_LINUX 14176
#define IDS_HISTORY_CLOSED_RESTORE_WINDOW_LINUX 14177
#define IDS_ALLOWED_GEOLOCATION_TITLE 14178
#define IDS_BLOCKED_GEOLOCATION_TITLE 14179
#define IDS_ALLOWED_GEOLOCATION_MESSAGE 14180
#define IDS_ALLOWED_GEOLOCATION_BLOCK 14181
#define IDS_ALLOWED_GEOLOCATION_NO_ACTION 14182
#define IDS_BLOCKED_GEOLOCATION_MESSAGE 14183
#define IDS_BLOCKED_GEOLOCATION_UNBLOCK 14184
#define IDS_BLOCKED_GEOLOCATION_NO_ACTION 14185
#define IDS_GEOLOCATION 14186
#define IDS_GEOLOCATION_WILL_ASK_AGAIN 14187
#define IDS_GEOLOCATION_TURNED_OFF 14189
#define IDS_ALLOWED_MIDI_SYSEX_TITLE 14190
#define IDS_BLOCKED_MIDI_SYSEX_TITLE 14191
#define IDS_ALLOWED_MIDI_SYSEX_MESSAGE 14192
#define IDS_ALLOWED_MIDI_SYSEX_BLOCK 14193
#define IDS_ALLOWED_MIDI_SYSEX_NO_ACTION 14194
#define IDS_BLOCKED_MIDI_SYSEX_MESSAGE 14195
#define IDS_BLOCKED_MIDI_SYSEX_UNBLOCK 14196
#define IDS_BLOCKED_MIDI_SYSEX_NO_ACTION 14197
#define IDS_MICROPHONE_CAMERA_ALLOWED 14198
#define IDS_MICROPHONE_CAMERA_BLOCKED 14199
#define IDS_MICROPHONE_ACCESSED 14200
#define IDS_CAMERA_ACCESSED 14201
#define IDS_MICROPHONE_BLOCKED 14202
#define IDS_CAMERA_BLOCKED 14203
#define IDS_MICROPHONE_CAMERA_ALLOWED_TITLE 14204
#define IDS_MICROPHONE_CAMERA_BLOCKED_TITLE 14205
#define IDS_MICROPHONE_ACCESSED_TITLE 14206
#define IDS_CAMERA_ACCESSED_TITLE 14207
#define IDS_MICROPHONE_BLOCKED_TITLE 14208
#define IDS_CAMERA_BLOCKED_TITLE 14209
#define IDS_MEDIASTREAM_SETTING_CHANGED_MESSAGE 14210
#define IDS_A11Y_OMNIBOX_CHIP_HINT 14220
#define IDS_A11Y_INDICATORS_ANNOUNCEMENT 14221
#define IDS_MICROPHONE_CAMERA_IN_USE 14222
#define IDS_MICROPHONE_CAMERA_NOT_ALLOWED 14223
#define IDS_MICROPHONE_IN_USE 14224
#define IDS_CAMERA_IN_USE 14225
#define IDS_MICROPHONE_NOT_ALLOWED 14226
#define IDS_CAMERA_NOT_ALLOWED 14227
#define IDS_CAMERA_CANNOT_ACCESS 14228
#define IDS_MICROPHONE_CANNOT_ACCESS 14229
#define IDS_CAMERA_MICROPHONE_CANNOT_ACCESS 14230
#define IDS_MANAGE_PASSWORDS_CONFIRM_GENERATED_TEXT 14231
#define IDS_PASSWORDS_WEB_LINK 14232
#define IDS_MANAGE_PASSWORDS_LINK 14234
#define IDS_MANAGE_PASSWORDS_TITLE 14235
#define IDS_MANAGE_PASSWORDS_NO_PASSWORDS_TITLE 14236
#define IDS_MANAGE_PASSWORDS_DIFFERENT_DOMAIN_TITLE 14237
#define IDS_MANAGE_PASSWORDS_DIFFERENT_DOMAIN_NO_PASSWORDS_TITLE 14238
#define IDS_MANAGE_PASSWORDS_SHOW_PASSWORD 14239
#define IDS_MANAGE_PASSWORDS_HIDE_PASSWORD 14240
#define IDS_MANAGE_PASSWORDS_EMPTY_NOTE 14241
#define IDS_MANAGE_PASSWORDS_EDIT_USERNAME_TOOLTIP 14242
#define IDS_MANAGE_PASSWORDS_EDIT_NOTE_TOOLTIP 14243
#define IDS_MANAGE_PASSWORDS_NOTE_ACCESSIBLE_NAME 14244
#define IDS_MANAGE_PASSWORDS_NOTE_TEXTFIELD 14245
#define IDS_MANAGE_PASSWORDS_UPDATE 14246
#define IDS_MANAGE_PASSWORDS_USERNAME_ACCESSIBLE_NAME 14247
#define IDS_MANAGE_PASSWORDS_USERNAME_TEXTFIELD 14248
#define IDS_MANAGE_PASSWORDS_AUTO_SIGNIN_TITLE_MD 14249
#define IDS_MANAGE_PASSWORDS_AUTO_SIGNIN_TOAST_BODY 14250
#define IDS_AUTO_SIGNIN_FIRST_RUN_TITLE_MANY_DEVICES 14251
#define IDS_AUTO_SIGNIN_FIRST_RUN_TITLE_LOCAL_DEVICE 14252
#define IDS_AUTO_SIGNIN_FIRST_RUN_TEXT 14253
#define IDS_AUTO_SIGNIN_FIRST_RUN_OK 14254
#define IDS_FILE_SELECTION_DIALOG_INFOBAR 14263
#define IDS_ABOUT_LINUX_PROXY_CONFIG_TITLE 14264
#define IDS_ABOUT_LINUX_PROXY_CONFIG_BODY 14265
#define IDS_IMAGE_FILES 14266
#define IDS_AUDIO_FILES 14267
#define IDS_VIDEO_FILES 14268
#define IDS_CUSTOM_FILES 14269
#define IDS_SENSORS_ALLOWED_TOOLTIP 14270
#define IDS_MOTION_SENSORS_ALLOWED_TOOLTIP 14271
#define IDS_SENSORS_BLOCKED_TOOLTIP 14272
#define IDS_MOTION_SENSORS_BLOCKED_TOOLTIP 14273
#define IDS_BLOCKED_SENSORS_UNBLOCK 14274
#define IDS_BLOCKED_SENSORS_NO_ACTION 14275
#define IDS_ALLOWED_SENSORS_TITLE 14276
#define IDS_BLOCKED_SENSORS_TITLE 14277
#define IDS_ALLOWED_SENSORS_MESSAGE 14278
#define IDS_ALLOWED_MOTION_SENSORS_MESSAGE 14279
#define IDS_BLOCKED_SENSORS_MESSAGE 14280
#define IDS_BLOCKED_MOTION_SENSORS_MESSAGE 14281
#define IDS_ALLOWED_SENSORS_NO_ACTION 14282
#define IDS_ALLOWED_SENSORS_BLOCK 14283
#define IDS_LIVE_CAPTION_PROMO 14290
#define IDS_LIVE_CAPTION_PROMO_SCREENREADER 14291
#define IDS_ENABLE_CARET_BROWSING_INFO 14292
#define IDS_CARET_BROWSING_DO_NOT_ASK 14299
#define IDS_ENABLE_CARET_BROWSING_TITLE 14300
#define IDS_ENABLE_CARET_BROWSING_TURN_ON 14301
#define IDS_MEDIA_GALLERIES_DIALOG_HEADER 14302
#define IDS_MEDIA_GALLERIES_DIALOG_SUBTEXT_READ_WRITE 14303
#define IDS_MEDIA_GALLERIES_DIALOG_SUBTEXT_READ_DELETE 14304
#define IDS_MEDIA_GALLERIES_DIALOG_SUBTEXT_READ_ONLY 14305
#define IDS_MEDIA_GALLERIES_PERMISSION_SUGGESTIONS 14306
#define IDS_MEDIA_GALLERIES_LAST_ATTACHED 14307
#define IDS_MEDIA_GALLERIES_DIALOG_ADD_GALLERY 14308
#define IDS_MEDIA_GALLERIES_DIALOG_CONFIRM 14309
#define IDS_MEDIA_GALLERIES_DIALOG_ADD_GALLERY_TITLE 14310
#define IDS_MEDIA_GALLERIES_DIALOG_DEVICE_ATTACHED 14311
#define IDS_MEDIA_GALLERIES_DIALOG_DEVICE_NOT_ATTACHED 14312
#define IDS_MEDIA_GALLERIES_DIALOG_DELETE 14313
#define IDS_CHROME_SHORTCUT_DESCRIPTION 14335
#define IDS_WEBSTORE_NAME_STORE 14336
#define IDS_DESKTOP_MEDIA_PICKER_TITLE 14337
#define IDS_DISPLAY_MEDIA_PICKER_TITLE 14338
#define IDS_DESKTOP_MEDIA_PICKER_TITLE_SCREEN_ONLY 14339
#define IDS_DESKTOP_MEDIA_PICKER_TITLE_WINDOW_ONLY 14340
#define IDS_DESKTOP_MEDIA_PICKER_TEXT 14341
#define IDS_DISPLAY_MEDIA_PICKER_TEXT 14342
#define IDS_DESKTOP_MEDIA_PICKER_TEXT_DELEGATED 14343
#define IDS_DESKTOP_MEDIA_PICKER_AUDIO_SHARE_SCREEN_WITH_MUTE_WARNING 14344
#define IDS_DESKTOP_MEDIA_PICKER_ALSO_SHARE_SYSTEM_AUDIO 14345
#define IDS_DESKTOP_MEDIA_PICKER_ALSO_SHARE_APPLICATION_AUDIO 14346
#define IDS_DESKTOP_MEDIA_PICKER_ALSO_SHARE_ALL_AUDIO_OUTPUT 14347
#define IDS_DESKTOP_MEDIA_PICKER_ALSO_SHARE_TAB_AUDIO 14348
#define IDS_DESKTOP_MEDIA_PICKER_AUDIO_SHARE_HINT_TAB 14349
#define IDS_DESKTOP_MEDIA_PICKER_AUDIO_SHARE_HINT_TAB_OR_SCREEN 14350
#define IDS_DESKTOP_MEDIA_PICKER_AUDIO_SHARE_HINT_TAB_OR_WINDOW 14351
#define IDS_DESKTOP_MEDIA_PICKER_SOURCE_TYPE_SCREEN 14352
#define IDS_DESKTOP_MEDIA_PICKER_SOURCE_TYPE_WINDOW 14353
#define IDS_DESKTOP_MEDIA_PICKER_SINGLE_SCREEN_NAME 14354
#define IDS_DESKTOP_MEDIA_PICKER_MULTIPLE_SCREEN_NAME 14355
#define IDS_DESKTOP_MEDIA_PICKER_MANAGED 14356
#define IDS_DESKTOP_MEDIA_PICKER_PERMISSION_BUTTON_MAC 14357
#define IDS_DESKTOP_MEDIA_PICKER_RESELECT_SCREEN 14358
#define IDS_DESKTOP_MEDIA_PICKER_RESELECT_WINDOW 14359
#define IDS_DESKTOP_MEDIA_PICKER_SOURCE_TYPE_THIS_TAB 14360
#define IDS_DESKTOP_MEDIA_PICKER_EMPTY_PREVIEW 14361
#define IDS_DESKTOP_MEDIA_PICKER_PREVIEW_ACCESSIBLE_NAME 14362
#define IDS_DESKTOP_MEDIA_SOURCE_EMPTY_ACCESSIBLE_NAME 14363
#define IDS_DESKTOP_MEDIA_PICKER_DELEGATED_SOURCE_LIST_WINDOW_TEXT 14364
#define IDS_DESKTOP_MEDIA_PICKER_DELEGATED_SOURCE_LIST_WINDOW_BUTTON 14365
#define IDS_DESKTOP_MEDIA_PICKER_DELEGATED_SOURCE_LIST_SCREEN_TEXT 14366
#define IDS_DESKTOP_MEDIA_PICKER_DELEGATED_SOURCE_LIST_SCREEN_BUTTON 14367
#define IDS_SHARE_THIS_TAB_DIALOG_TITLE 14368
#define IDS_SHARE_THIS_TAB_DIALOG_TEXT 14369
#define IDS_SHARE_THIS_TAB_DIALOG_ALLOW 14370
#define IDS_SHARE_THIS_TAB_AUDIO_SHARE 14371
#define IDS_TAB_CAPTURE_TERMINATED_BY_POLICY_TITLE 14372
#define IDS_TAB_CAPTURE_TERMINATED_BY_POLICY_TEXT 14373
#define IDS_TOOLTIP_TAB_ALERT_STATE_MEDIA_RECORDING 14374
#define IDS_TOOLTIP_TAB_ALERT_STATE_AUDIO_RECORDING 14375
#define IDS_TOOLTIP_TAB_ALERT_STATE_VIDEO_RECORDING 14376
#define IDS_TOOLTIP_TAB_ALERT_STATE_TAB_CAPTURING 14377
#define IDS_TOOLTIP_TAB_ALERT_STATE_AUDIO_PLAYING 14378
#define IDS_TOOLTIP_TAB_ALERT_STATE_AUDIO_MUTING 14379
#define IDS_TOOLTIP_TAB_ALERT_STATE_BLUETOOTH_CONNECTED 14380
#define IDS_TOOLTIP_TAB_ALERT_STATE_BLUETOOTH_SCAN_ACTIVE 14381
#define IDS_TOOLTIP_TAB_ALERT_STATE_USB_CONNECTED 14382
#define IDS_TOOLTIP_TAB_ALERT_STATE_HID_CONNECTED 14383
#define IDS_TOOLTIP_TAB_ALERT_STATE_SERIAL_CONNECTED 14384
#define IDS_TOOLTIP_TAB_ALERT_STATE_PIP_PLAYING 14385
#define IDS_TOOLTIP_TAB_ALERT_STATE_DESKTOP_CAPTURING 14386
#define IDS_TOOLTIP_TAB_ALERT_STATE_VR_PRESENTING 14387
#define IDS_TAB_AX_LABEL_MEDIA_RECORDING_FORMAT 14388
#define IDS_TAB_AX_LABEL_AUDIO_RECORDING_FORMAT 14389
#define IDS_TAB_AX_LABEL_VIDEO_RECORDING_FORMAT 14390
#define IDS_TAB_AX_LABEL_TAB_CAPTURING_FORMAT 14391
#define IDS_TAB_AX_LABEL_PIP_PLAYING_FORMAT 14392
#define IDS_TAB_AX_LABEL_AUDIO_PLAYING_FORMAT 14393
#define IDS_TAB_AX_LABEL_AUDIO_MUTING_FORMAT 14394
#define IDS_TAB_AX_LABEL_BLUETOOTH_CONNECTED_FORMAT 14395
#define IDS_TAB_AX_LABEL_BLUETOOTH_SCAN_ACTIVE_FORMAT 14396
#define IDS_TAB_AX_LABEL_USB_CONNECTED_FORMAT 14397
#define IDS_TAB_AX_LABEL_HID_CONNECTED_FORMAT 14398
#define IDS_TAB_AX_LABEL_SERIAL_CONNECTED_FORMAT 14399
#define IDS_TAB_AX_LABEL_NETWORK_ERROR_FORMAT 14400
#define IDS_TAB_AX_LABEL_CRASHED_FORMAT 14401
#define IDS_TAB_AX_LABEL_DESKTOP_CAPTURING_FORMAT 14402
#define IDS_TAB_AX_LABEL_VR_PRESENTING 14403
#define IDS_TAB_AX_LABEL_SPLIT_TAB_LEFT_VIEW_FORMAT 14404
#define IDS_TAB_AX_LABEL_SPLIT_TAB_RIGHT_VIEW_FORMAT 14405
#define IDS_TAB_AX_LABEL_UNNAMED_GROUP_FORMAT 14406
#define IDS_TAB_AX_LABEL_NAMED_GROUP_FORMAT 14407
#define IDS_TAB_AX_LABEL_PINNED_FORMAT 14408
#define IDS_TAB_AX_LABEL_PERMISSION_REQUESTED_FORMAT 14409
#define IDS_GROUP_AX_LABEL_UNNAMED_GROUP_FORMAT 14410
#define IDS_GROUP_AX_LABEL_NAMED_GROUP_FORMAT 14411
#define IDS_GROUP_AX_LABEL_COLLAPSED 14412
#define IDS_GROUP_AX_LABEL_EXPANDED 14413
#define IDS_GROUP_AX_LABEL_UNNAMED_SAVED_GROUP_FORMAT 14414
#define IDS_GROUP_AX_LABEL_NAMED_SAVED_GROUP_FORMAT 14415
#define IDS_GROUP_AX_LABEL_GROUP_MENU_ITEM_FORMAT 14416
#define IDS_SAVED_GROUP_AX_LABEL_OPENED 14417
#define IDS_SAVED_GROUP_AX_LABEL_CLOSED 14418
#define IDS_SAVED_GROUP_AX_LABEL_SHARED 14419
#define IDS_TAB_AX_ANNOUNCE_MOVED_RIGHT 14420
#define IDS_TAB_AX_ANNOUNCE_MOVED_LEFT 14421
#define IDS_TAB_AX_ANNOUNCE_MOVED_UP 14422
#define IDS_TAB_AX_ANNOUNCE_MOVED_DOWN 14423
#define IDS_TAB_AX_ANNOUNCE_MOVED_FIRST 14424
#define IDS_TAB_AX_ANNOUNCE_MOVED_LAST 14425
#define IDS_TAB_AX_ANNOUNCE_TAB_ADDED_TO_UNNAMED_GROUP 14426
#define IDS_TAB_AX_ANNOUNCE_TAB_ADDED_TO_NAMED_GROUP 14427
#define IDS_TAB_AX_ANNOUNCE_TAB_REMOVED_FROM_UNNAMED_GROUP 14428
#define IDS_TAB_AX_ANNOUNCE_TAB_REMOVED_FROM_NAMED_GROUP 14429
#define IDS_PAGE_LOADING_AX_TITLE_FORMAT 14430
#define IDS_TAB_AX_INACTIVE_TAB 14431
#define IDS_TAB_AX_MEMORY_SAVINGS 14432
#define IDS_TAB_AX_MEMORY_USAGE 14433
#define IDS_TAB_AX_HIGH_MEMORY_USAGE 14434
#define IDS_PROFILE_IN_USE_LINUX_QUIT 14435
#define IDS_PROFILE_IN_USE_LINUX_RELAUNCH 14436
#define IDS_DESKTOP_MEDIA_PICKER_SHARE 14454
#define IDS_PUSH_MESSAGING_GENERIC_NOTIFICATION_BODY 14455
#define IDS_DEVICE_PERMISSIONS_DIALOG_SELECT 14456
#define IDS_DEVICE_PERMISSIONS_DIALOG_LOADING_LABEL 14457
#define IDS_DEVICE_PERMISSIONS_DIALOG_LOADING_LABEL_TOOLTIP 14458
#define IDS_DEVICE_LOG_TITLE 14459
#define IDS_DEVICE_AUTO_REFRESH 14460
#define IDS_DEVICE_SELECT_TYPES 14461
#define IDS_DEVICE_LOG_REFRESH 14462
#define IDS_DEVICE_LOG_CLEAR 14463
#define IDS_DEVICE_LOG_CLEAR_TYPES 14464
#define IDS_DEVICE_LOG_NO_ENTRIES 14465
#define IDS_DEVICE_LOG_LEVEL_LABEL 14466
#define IDS_DEVICE_LOG_LEVEL_ERROR 14467
#define IDS_DEVICE_LOG_LEVEL_USER 14468
#define IDS_DEVICE_LOG_LEVEL_EVENT 14469
#define IDS_DEVICE_LOG_LEVEL_DEBUG 14470
#define IDS_DEVICE_LOG_TYPE_LOGIN 14471
#define IDS_DEVICE_LOG_TYPE_MEMORY 14472
#define IDS_DEVICE_LOG_TYPE_NETWORK 14473
#define IDS_DEVICE_LOG_TYPE_POWER 14474
#define IDS_DEVICE_LOG_TYPE_BLUETOOTH 14475
#define IDS_DEVICE_LOG_TYPE_USB 14476
#define IDS_DEVICE_LOG_TYPE_HID 14477
#define IDS_DEVICE_LOG_TYPE_PRINTER 14478
#define IDS_DEVICE_LOG_TYPE_FIDO 14479
#define IDS_DEVICE_LOG_TYPE_SERIAL 14480
#define IDS_DEVICE_LOG_TYPE_CAMERA 14481
#define IDS_DEVICE_LOG_TYPE_GEOLOCATION 14482
#define IDS_DEVICE_LOG_TYPE_EXTENSIONS 14483
#define IDS_DEVICE_LOG_TYPE_DISPLAY 14484
#define IDS_DEVICE_LOG_TYPE_FIRMWARE 14485
#define IDS_DEVICE_LOG_FILEINFO 14486
#define IDS_DEVICE_LOG_TIME_DETAIL 14487
#define IDS_DEVICE_LOG_ENTRY 14488
#define IDS_WEBUSB_DEVICE_DETECTED_NOTIFICATION 14489
#define IDS_WEBUSB_DEVICE_DETECTED_NOTIFICATION_TITLE 14490
#define IDS_WEBHID_SYSTEM_TRAY_ICON_HID_SETTINGS 14491
#define IDS_WEBHID_SYSTEM_TRAY_ICON_ABOUT_HID_DEVICE 14492
#define IDS_WEBUSB_SYSTEM_TRAY_ICON_USB_SETTINGS 14493
#define IDS_WEBUSB_SYSTEM_TRAY_ICON_ABOUT_USB_DEVICE 14494
#define IDS_DEVICE_CONNECTED_BY_EXTENSION 14497
#define IDS_DEFAULT_AUDIO_DEVICE_NAME 14506
#define IDS_SERIAL_DEVICE_CHOOSER_ADAPTER_OFF 14515
#define IDS_SERIAL_DEVICE_CHOOSER_TURN_ON_BLUETOOTH_LINK_TEXT 14516
#define IDS_SERIAL_DEVICE_CHOOSER_AUTHORIZE_BLUETOOTH_LINK_TEXT 14517
#define IDS_BLUETOOTH_DEVICE_CHOOSER_RE_SCAN 14518
#define IDS_BLUETOOTH_DEVICE_CHOOSER_RE_SCAN_TOOLTIP 14519
#define IDS_DEVICE_CHOOSER_GET_HELP_LINK_WITH_SCANNING_STATUS 14520
#define IDS_DEVICE_CHOOSER_GET_HELP_LINK_WITH_RE_SCAN_LINK 14521
#define IDS_DEVICE_CHOOSER_PAIRED_STATUS_TEXT 14522
#define IDS_DEVICE_CHOOSER_DEVICE_NAME_AND_PAIRED_STATUS_TEXT 14523
#define IDS_DEVICE_CHOOSER_ACCNAME_COMPATIBLE_DEVICES_LIST 14524
#define IDS_DEVICE_CHOOSER_DEVICE_NAME_UNKNOWN_DEVICE_WITH_VENDOR_NAME 14525
#define IDS_DEVICE_CHOOSER_DEVICE_NAME_UNKNOWN_DEVICE_WITH_VENDOR_ID_AND_PRODUCT_ID 14526
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_PRODUCT_ID_AND_VENDOR_NAME 14527
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_PRODUCT_ID_AND_VENDOR_ID 14528
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_VENDOR_ID 14529
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_VENDOR_NAME 14530
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_ANY_VENDOR 14531
#define IDS_SERIAL_PORT_CHOOSER_PROMPT 14532
#define IDS_SERIAL_PORT_CHOOSER_CONNECT_BUTTON_TEXT 14533
#define IDS_SERIAL_PORT_CHOOSER_LOADING_LABEL 14534
#define IDS_SERIAL_PORT_CHOOSER_LOADING_LABEL_TOOLTIP 14535
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_USB_PRODUCT_ID_AND_VENDOR_NAME 14536
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_USB_VENDOR_NAME 14537
#define IDS_SERIAL_PORT_CHOOSER_NAME_WITH_PATH 14538
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_USB_PRODUCT_ID_AND_VENDOR_ID 14539
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_USB_VENDOR_ID 14540
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_ANY_PORT 14541
#define IDS_HID_CHOOSER_PROMPT 14542
#define IDS_HID_CHOOSER_ITEM_WITHOUT_NAME 14543
#define IDS_HID_CHOOSER_LOADING_LABEL 14544
#define IDS_HID_CHOOSER_LOADING_LABEL_TOOLTIP 14545
#define IDS_HID_POLICY_DESCRIPTION_FOR_VENDOR_ID_AND_PRODUCT_ID 14546
#define IDS_HID_POLICY_DESCRIPTION_FOR_VENDOR_ID 14547
#define IDS_HID_POLICY_DESCRIPTION_FOR_USAGE_AND_USAGE_PAGE 14548
#define IDS_HID_POLICY_DESCRIPTION_FOR_USAGE_PAGE 14549
#define IDS_HID_POLICY_DESCRIPTION_FOR_ANY_DEVICE 14550
#define IDS_WEB_APP_FILE_HANDLING_LIST_SEPARATOR 14551
#define IDS_WEB_APP_FILE_HANDLING_DIALOG_QUESTION 14552
#define IDS_WEB_APP_FILE_HANDLING_DIALOG_QUESTION_MULTIPLE 14553
#define IDS_WEB_APP_FILE_HANDLING_DIALOG_STICKY_CHOICE 14554
#define IDS_WEB_APP_FILE_HANDLING_POSITIVE_BUTTON 14555
#define IDS_WEB_APP_FILE_HANDLING_NEGATIVE_BUTTON 14556
#define IDS_WEB_APP_PERMISSION_NEGATIVE_BUTTON 14557
#define IDS_PROTOCOL_HANDLER_INTENT_PICKER_QUESTION 14558
#define IDS_FONT_ACCESS_CHOOSER_PROMPT_ORIGIN 14559
#define IDS_FONT_ACCESS_CHOOSER_NO_FONTS_FOUND_PROMPT 14560
#define IDS_FONT_ACCESS_CHOOSER_IMPORT_BUTTON_TEXT 14561
#define IDS_FONT_ACCESS_CHOOSER_CANCEL_BUTTON_TEXT 14562
#define IDS_FONT_ACCESS_CHOOSER_SELECT_ALL_CHECKBOX_TEXT 14563
#define IDS_FONT_ACCESS_CHOOSER_LOADING_LABEL 14564
#define IDS_FONT_ACCESS_CHOOSER_LOADING_LABEL_TOOLTIP 14565
#define IDS_IME_API_ACTIVATED_WARNING 14566
#define IDS_IME_API_NEVER_SHOW 14567
#define IDS_BLOCKED_ADS_PROMPT_TOOLTIP 14568
#define IDS_REDIRECT_BLOCKED_MESSAGE 14571
#define IDS_REDIRECT_BLOCKED_TITLE 14572
#define IDS_REDIRECT_BLOCKED_TOOLTIP 14573
#define IDS_ALWAYS_ALLOW_REDIRECTS 14574
#define IDS_OPEN_REDIRECT 14575
#define IDS_UTILITY_PROCESS_SYSTEM_SIGNALS_NAME 14576
#define IDS_CONTROLLED_BY_AUTOMATION 14579
#define IDS_CHROME_FOR_TESTING_DISCLAIMER 14580
#define IDS_DOWNLOAD_CHROME 14581
#define IDS_DOWNLOAD_OPEN_CONFIRMATION_DIALOG_TITLE 14583
#define IDS_DOWNLOAD_OPEN_CONFIRMATION_DIALOG_MESSAGE 14584
#define IDS_CONFIRM_FILE_UPLOAD_TITLE 14585
#define IDS_CONFIRM_FILE_UPLOAD_TEXT 14586
#define IDS_CONFIRM_FILE_UPLOAD_OK_BUTTON 14587
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_TITLE 14588
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_ALLOW_TEXT 14589
#define IDS_FILE_SYSTEM_ACCESS_ORIGIN_SCOPED_WRITE_PERMISSION_FILE_TEXT 14590
#define IDS_FILE_SYSTEM_ACCESS_ORIGIN_SCOPED_WRITE_PERMISSION_DIRECTORY_TEXT 14591
#define IDS_FILE_SYSTEM_ACCESS_ORIGIN_SCOPED_READ_PERMISSION_FILE_TEXT 14592
#define IDS_FILE_SYSTEM_ACCESS_ORIGIN_SCOPED_READ_PERMISSION_DIRECTORY_TEXT 14593
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_FILE_TEXT 14594
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_DIRECTORY_TEXT 14595
#define IDS_FILE_SYSTEM_ACCESS_READ_PERMISSION_FILE_TEXT 14596
#define IDS_FILE_SYSTEM_ACCESS_READ_PERMISSION_DIRECTORY_TEXT 14597
#define IDS_FILE_SYSTEM_ACCESS_EDIT_FILE_PERMISSION_TITLE 14598
#define IDS_FILE_SYSTEM_ACCESS_EDIT_DIRECTORY_PERMISSION_TITLE 14599
#define IDS_FILE_SYSTEM_ACCESS_READ_FILE_PERMISSION_TITLE 14600
#define IDS_FILE_SYSTEM_ACCESS_READ_DIRECTORY_PERMISSION_TITLE 14601
#define IDS_FILE_SYSTEM_ACCESS_EDIT_FILE_PERMISSION_ALLOW_TEXT 14602
#define IDS_FILE_SYSTEM_ACCESS_EDIT_DIRECTORY_PERMISSION_ALLOW_TEXT 14603
#define IDS_FILE_SYSTEM_ACCESS_VIEW_FILE_PERMISSION_ALLOW_TEXT 14604
#define IDS_FILE_SYSTEM_ACCESS_VIEW_DIRECTORY_PERMISSION_ALLOW_TEXT 14605
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_CANCEL_TEXT 14606
#define IDS_FILE_SYSTEM_ACCESS_EDIT_FILE_PERMISSION_CANCEL_TEXT 14607
#define IDS_FILE_SYSTEM_ACCESS_EDIT_DIRECTORY_PERMISSION_CANCEL_TEXT 14608
#define IDS_FILE_SYSTEM_ACCESS_VIEW_FILE_PERMISSION_CANCEL_TEXT 14609
#define IDS_FILE_SYSTEM_ACCESS_VIEW_DIRECTORY_PERMISSION_CANCEL_TEXT 14610
#define IDS_FILE_SYSTEM_ACCESS_RESTORE_PERMISSION_DESCRIPTION 14611
#define IDS_FILE_SYSTEM_ACCESS_WRITE_USAGE_TOOLTIP 14612
#define IDS_FILE_SYSTEM_ACCESS_DIRECTORY_USAGE_TOOLTIP 14613
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SINGLE_WRITABLE_FILE_TEXT 14614
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_WRITABLE_FILES_TEXT 14615
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SINGLE_WRITABLE_DIRECTORY_TEXT 14616
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_WRITABLE_DIRECTORIES_TEXT 14617
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_WRITABLE_FILES_AND_DIRECTORIES_TEXT 14618
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SINGLE_READABLE_FILE_TEXT 14619
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_READABLE_FILES_TEXT 14620
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SINGLE_READABLE_DIRECTORY_TEXT 14621
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_READABLE_DIRECTORIES_TEXT 14622
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_READABLE_FILES_AND_DIRECTORIES_TEXT 14623
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_READ_AND_WRITE 14624
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SAVE_CHANGES 14625
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_VIEW_CHANGES 14626
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_FILES_TEXT 14627
#define IDS_FILE_SYSTEM_ACCESS_USAGE_EXPAND 14628
#define IDS_FILE_SYSTEM_ACCESS_USAGE_COLLAPSE 14629
#define IDS_FILE_SYSTEM_ACCESS_USAGE_REMOVE_ACCESS 14630
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_READABLE_DIRECTORY_TITLE 14631
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_WRITABLE_DIRECTORY_TITLE 14632
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_SAVE_FILE_TITLE 14633
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_READABLE_FILE_TITLE 14634
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_READABLE_FILES_TITLE 14635
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_DIRECTORY_TITLE 14636
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_DIRECTORY_TEXT 14637
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_DIRECTORY_BUTTON 14638
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_FILE_TITLE 14639
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_FILE_TEXT 14640
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_FILE_BUTTON 14641
#define IDS_FILE_SYSTEM_ACCESS_DANGEROUS_FILE_TITLE 14642
#define IDS_FILE_SYSTEM_ACCESS_DANGEROUS_FILE_TEXT 14643
#define IDS_FILE_SYSTEM_ACCESS_DANGEROUS_FILE_DONT_SAVE 14644
#define IDS_FILE_SYSTEM_ACCESS_DANGEROUS_FILE_SAVE 14645
#define IDS_RELAUNCH_ACCEPT_BUTTON 14646
#define IDS_RELAUNCH_REQUIRED_CANCEL_BUTTON 14647
#define IDS_IDLE_TIMEOUT_INCOGNITO 14648
#define IDS_IDLE_TIMEOUT_CLOSE_COUNTDOWN 14649
#define IDS_IDLE_TIMEOUT_CLEAR_COUNTDOWN 14650
#define IDS_WEBAUTHN_GENERIC_TITLE 14651
#define IDS_WEBAUTHN_CONTINUE 14652
#define IDS_WEBAUTHN_TRANSPORT_USB 14653
#define IDS_WEBAUTHN_TRANSPORT_INTERNAL 14655
#define IDS_WEBAUTHN_TRANSPORT_CABLE 14656
#define IDS_WEBAUTHN_TRANSPORT_WINDOWS_HELLO_OR_SECURITY_KEY 14657
#define IDS_WEBAUTHN_TRANSPORT_WINDOWS_HELLO 14658
#define IDS_WEBAUTHN_TRANSPORT_ICLOUD_KEYCHAIN 14659
#define IDS_WEBAUTHN_TRANSPORT_EXTERNAL_SECURITY_KEY 14660
#define IDS_WEBAUTHN_USB_ACTIVATE_DESCRIPTION 14661
#define IDS_WEBAUTHN_ERROR_GENERIC_TITLE 14662
#define IDS_WEBAUTHN_ERROR_WRONG_KEY_TITLE 14663
#define IDS_WEBAUTHN_ERROR_WRONG_DEVICE_TITLE 14664
#define IDS_WEBAUTHN_ERROR_WRONG_DEVICE_REGISTER_DESCRIPTION 14665
#define IDS_WEBAUTHN_ERROR_WRONG_KEY_SIGN_DESCRIPTION 14666
#define IDS_WEBAUTHN_ERROR_TIMEOUT_DESCRIPTION 14667
#define IDS_WEBAUTHN_ERROR_INTERNAL_UNRECOGNIZED_TITLE 14668
#define IDS_WEBAUTHN_ERROR_INTERNAL_UNRECOGNIZED_DESCRIPTION 14669
#define IDS_WEBAUTHN_WINDOWS_HELLO_NOT_ENABLED_TITLE 14670
#define IDS_WEBAUTHN_WINDOWS_HELLO_NOT_ENABLED_DESCRIPTION 14671
#define IDS_WEBAUTHN_ERROR_NO_PASSKEYS_TITLE 14672
#define IDS_WEBAUTHN_ERROR_NO_PASSKEYS_DESCRIPTION 14673
#define IDS_WEBAUTHN_ERROR_GPM_DISABLED_TITLE 14674
#define IDS_WEBAUTHN_ERROR_GPM_DISABLED_DESCRIPTION 14675
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_AUTO_TITLE 14676
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_AUTO_DESCRIPTION 14677
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_AUTO_NEXT 14678
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_MANUAL_TITLE 14679
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_MANUAL_DESCRIPTION 14680
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_MANUAL_NEXT 14681
#define IDS_WEBAUTHN_LOADING 14682
#define IDS_WEBAUTHN_CABLE_ACTIVATE_TITLE 14684
#define IDS_WEBAUTHN_CABLE_ACTIVATE_TITLE_DEVICE 14685
#define IDS_WEBAUTHN_CABLE_ACTIVATE_DESCRIPTION 14686
#define IDS_WEBAUTHN_CABLEV2_CONNECTING_TITLE 14687
#define IDS_WEBAUTHN_CABLEV2_CONNECTED_DESCRIPTION 14688
#define IDS_WEBAUTHN_CABLEV2_ERROR_DESCRIPTION 14689
#define IDS_WEBAUTHN_CABLEV2_ERROR_CLOSE 14690
#define IDS_WEBAUTHN_PASSKEY_PHONE_OR_TABLET_LABEL 14691
#define IDS_WEBAUTHN_PASSKEY_PHONE_TABLET_OR_SECURITY_KEY_LABEL 14692
#define IDS_WEBAUTHN_PIN_ENTRY_TITLE 14693
#define IDS_WEBAUTHN_PIN_ENTRY_DESCRIPTION 14694
#define IDS_WEBAUTHN_PIN_ENTRY_PIN_LABEL 14695
#define IDS_WEBAUTHN_PIN_ENTRY_NEXT 14696
#define IDS_WEBAUTHN_PIN_SETUP_DESCRIPTION 14697
#define IDS_WEBAUTHN_PIN_SETUP_CONFIRMATION_LABEL 14698
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_INVALID_CHARACTERS 14699
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_TOO_SHORT 14700
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_FAILED_RETRIES 14701
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_FAILED 14702
#define IDS_WEBAUTHN_PIN_SETUP_ERROR_FAILED 14703
#define IDS_WEBAUTHN_PIN_TAP_AGAIN_DESCRIPTION 14704
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_MISMATCH 14705
#define IDS_WEBAUTHN_CLIENT_PIN_SOFT_BLOCK_DESCRIPTION 14706
#define IDS_WEBAUTHN_CLIENT_PIN_HARD_BLOCK_DESCRIPTION 14707
#define IDS_WEBAUTHN_CLIENT_PIN_AUTHENTICATOR_REMOVED_DESCRIPTION 14708
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_SAME_AS_CURRENT 14709
#define IDS_WEBAUTHN_USE_PHONE_WITH_NAME 14710
#define IDS_WEBAUTHN_INLINE_ENROLLMENT_CANCEL_LABEL 14711
#define IDS_WEBAUTHN_UV_RETRY_TITLE 14712
#define IDS_WEBAUTHN_UV_RETRY_DESCRIPTION 14713
#define IDS_WEBAUTHN_UV_RETRY_ERROR_FAILED_RETRIES 14714
#define IDS_WEBAUTHN_UV_ERROR_LOCKED 14715
#define IDS_WEBAUTHN_FORCE_PIN_CHANGE 14716
#define IDS_WEBAUTHN_UNKNOWN_ACCOUNT 14717
#define IDS_WEBAUTHN_RESIDENT_KEY_PRIVACY 14718
#define IDS_WEBAUTHN_RESIDENT_KEY_PREFERRED_PRIVACY 14719
#define IDS_WEBAUTHN_ERROR_MISSING_CAPABILITY_TITLE 14720
#define IDS_WEBAUTHN_ERROR_MISSING_CAPABILITY_DESC 14721
#define IDS_WEBAUTHN_STORAGE_FULL_DESC 14722
#define IDS_WEBAUTHN_ATTESTATION_WARNING 14723
#define IDS_WEBAUTHN_ENTERPRISE_ATTESTATION_WARNING 14724
#define IDS_WEBAUTHN_RETRY 14725
#define IDS_WEBAUTHN_PLATFORM_AUTHENTICATOR_OFF_THE_RECORD_INTERSTITIAL_TITLE 14726
#define IDS_WEBAUTHN_PLATFORM_AUTHENTICATOR_OFF_THE_RECORD_INTERSTITIAL_DESCRIPTION 14727
#define IDS_WEBAUTHN_PLATFORM_AUTHENTICATOR_OFF_THE_RECORD_INTERSTITIAL_DENY 14728
#define IDS_WEBAUTHN_CREATE_PASSKEY_TITLE 14729
#define IDS_WEBAUTHN_CREATE_PASSKEY_EXTRA 14730
#define IDS_WEBAUTHN_CREATE_PASSKEY_EXTRA_INCOGNITO 14731
#define IDS_WEBAUTHN_CREATE_PASSKEY_CHOOSE_DEVICE_TITLE 14732
#define IDS_WEBAUTHN_USE_PASSKEY_CHOOSE_DEVICE_TITLE 14733
#define IDS_WEBAUTHN_USE_PASSKEY_CHOOSE_DEVICE_BODY 14734
#define IDS_WEBAUTHN_USE_PASSKEY_TITLE 14735
#define IDS_WEBAUTHN_CHOOSE_PASSKEY_TITLE 14736
#define IDS_WEBAUTHN_CHOOSE_PASSKEY_BODY 14737
#define IDS_WEBAUTHN_CREATE_PASSKEY_QR_TITLE 14738
#define IDS_WEBAUTHN_CREATE_PASSKEY_QR_BODY 14739
#define IDS_WEBAUTHN_USE_PASSKEY_QR_TITLE 14740
#define IDS_WEBAUTHN_USE_PASSKEY_QR_BODY 14741
#define IDS_WEBAUTHN_QR_CODE_ALT_TEXT 14742
#define IDS_WEBAUTHN_USE_A_DIFFERENT_PASSKEY 14743
#define IDS_WEBAUTHN_QR_CREATE_PASSKEY_ON_SECURITY_KEY_LABEL 14744
#define IDS_WEBAUTHN_QR_USE_PASSKEY_ON_SECURITY_KEY_LABEL 14745
#define IDS_WEBAUTHN_CHOOSE_PASSKEY_FOR_RP_TITLE 14746
#define IDS_WEBAUTHN_THIS_DEVICE_LABEL 14747
#define IDS_WEBAUTHN_FROM_PHONE_LABEL 14748
#define IDS_WEBAUTHN_OTHER_DEVICES_LABEL 14749
#define IDS_WEBAUTHN_SOURCE_CHROME_PROFILE 14750
#define IDS_WEBAUTHN_SOURCE_ICLOUD_KEYCHAIN 14751
#define IDS_WEBAUTHN_SOURCE_WINDOWS_HELLO 14752
#define IDS_WEBAUTHN_SOURCE_GOOGLE_PASSWORD_MANAGER 14753
#define IDS_WEBAUTHN_SOURCE_USB_SECURITY_KEY 14754
#define IDS_WEBAUTHN_PASSKEYS_AND_SECURITY_KEYS 14755
#define IDS_WEBAUTHN_PASSKEYS 14756
#define IDS_WEBAUTHN_USE_YOUR_PHONE_OR_TABLET 14757
#define IDS_WEBAUTHN_USE_YOUR_PHONE_OR_TABLET_CREATE_DESCRIPTION 14758
#define IDS_WEBAUTHN_USE_YOUR_PHONE_OR_TABLET_SIGN_IN_DESCRIPTION 14759
#define IDS_WEBAUTHN_USE_YOUR_SECURITY_KEY 14760
#define IDS_WEBAUTHN_USE_YOUR_SECURITY_KEY_CREATE_DESCRIPTION 14761
#define IDS_WEBAUTHN_USE_YOUR_SECURITY_KEY_SIGN_IN_DESCRIPTION 14762
#define IDS_WEBAUTHN_CREATE 14763
#define IDS_WEBAUTHN_CREATE_PASSKEY 14764
#define IDS_WEBAUTHN_GPM_CREATE_PASSKEY_TITLE 14765
#define IDS_WEBAUTHN_GPM_CREATE_PASSKEY_DESC 14766
#define IDS_WEBAUTHN_SAVE_ANOTHER_WAY 14767
#define IDS_WEBAUTHN_GPM_TRUST_THIS_COMPUTER_CREATION_TITLE 14768
#define IDS_WEBAUTHN_GPM_TRUST_THIS_COMPUTER_CREATION_DESC 14769
#define IDS_WEBAUTHN_GPM_TRUST_THIS_COMPUTER_ASSERTION_TITLE 14770
#define IDS_WEBAUTHN_GPM_TRUST_THIS_COMPUTER_ASSERTION_DESC 14771
#define IDS_WEBAUTHN_USE_A_DIFFERENT_DEVICE 14772
#define IDS_WEBAUTHN_TOUCH_ID_ASSERTION_DESC 14773
#define IDS_WEBAUTHN_TOUCH_ID_CONTINUE 14774
#define IDS_WEBAUTHN_TOUCH_ID_LOCKED 14775
#define IDS_WEBAUTHN_TOUCH_ID_ENTER_PASSWORD 14776
#define IDS_WEBAUTHN_GPM_ERROR_TITLE 14777
#define IDS_WEBAUTHN_GPM_ERROR_DESC 14778
#define IDS_WEBAUTHN_SIGN_IN_AGAIN_TITLE 14779
#define IDS_WEBAUTHN_SIGN_IN_AGAIN_DESCRIPTION 14780
#define IDS_WEBAUTHN_GPM_INCOGNITO_CREATE_TITLE 14781
#define IDS_WEBAUTHN_GPM_INCOGNITO_CREATE_DESC 14782
#define IDS_WEBAUTHN_GPM_PIN_OPTION_NUMBERS 14783
#define IDS_WEBAUTHN_GPM_PIN_OPTION_ALPHANUMERIC 14784
#define IDS_WEBAUTHN_GPM_CREATE_PIN_TITLE 14785
#define IDS_WEBAUTHN_GPM_CREATE_ALPHANUMERIC_PIN_ACCESSIBILITY 14786
#define IDS_WEBAUTHN_GPM_CREATE_SIX_DIGIT_PIN_ACCESSIBILITY 14787
#define IDS_WEBAUTHN_GPM_CREATE_SIX_DIGIT_PIN_ACCESSIBILITY_WITH_FOCUSED_DIGIT 14788
#define IDS_WEBAUTHN_GPM_CREATE_PIN_DESC 14789
#define IDS_WEBAUTHN_GPM_ENTER_PIN_TITLE 14790
#define IDS_WEBAUTHN_GPM_ENTER_ALPHANUMERIC_PIN_ACCESSIBILITY 14791
#define IDS_WEBAUTHN_GPM_ENTER_ALPHANUMERIC_PIN_ACCESSIBILITY_WITH_WEBSITE 14792
#define IDS_WEBAUTHN_GPM_ENTER_SIX_DIGIT_PIN_ACCESSIBILITY 14793
#define IDS_WEBAUTHN_GPM_ENTER_SIX_DIGIT_PIN_ACCESSIBILITY_WITH_FOCUSED_DIGIT 14794
#define IDS_WEBAUTHN_GPM_ENTER_PIN_DESC 14795
#define IDS_WEBAUTHN_GPM_SIX_DIGIT_PIN_ACCESSIBILITY_LABEL 14796
#define IDS_WEBAUTHN_FORGOT_GPM_PIN_BUTTON 14797
#define IDS_WEBAUTHN_GPM_PIN_OPTIONS_BUTTON 14798
#define IDS_WEBAUTHN_GPM_WRONG_PIN_ERROR 14799
#define IDS_WEBAUTHN_GPM_PASSKEY_SAVED_TITLE 14800
#define IDS_WEBAUTHN_GPM_PASSKEY_SAVED_PIN_CREATED_TITLE 14801
#define IDS_WEBAUTHN_SHOW_PIN 14802
#define IDS_WEBAUTHN_HIDE_PIN 14803
#define IDS_WEBAUTHN_CHANGE_PIN 14804
#define IDS_WEBAUTHN_LOCKED_GPM_PIN_TITLE 14805
#define IDS_WEBAUTHN_LOCKED_GPM_PIN_DESCRIPTION 14806
#define IDS_WEBAUTHN_GPM_PIN_DIGIT_HINT 14807
#define IDS_WEBAUTHN_GPM_PIN_LENGTH_HINT 14808
#define IDS_WEBAUTHN_GPM_PASSKEY_SAVED_LABEL 14809
#define IDS_WEBAUTHN_GPM_PASSKEY_SAVED_LINK 14810
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATE_NEEDED_TITLE 14811
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATE_NEEDED_LABEL 14812
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATED_TITLE 14813
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATED_LABEL 14814
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATED_LINK 14815
#define IDS_WEBAUTHN_GPM_PASSKEY_DELETED_TITLE 14816
#define IDS_WEBAUTHN_GPM_PASSKEY_DELETED_LABEL 14817
#define IDS_WEBAUTHN_GPM_PASSKEY_DOESNT_WORK_LABEL 14818
#define IDS_WEBAUTHN_GPM_PASSKEY_DELETED_LINK 14819
#define IDS_WEBAUTHN_GPM_SETTINGS 14820
#define IDS_WEBAUTHN_SIGN_IN_TO_WEBSITE_DIALOG_TITLE 14821
#define IDS_PASSKEY_UPGRADE_BUBBLE_TITLE 14822
#define IDS_PASSKEY_UPGRADE_BUBBLE_DESCRIPTION 14823
#define IDS_PASSKEY_UPGRADE_BUBBLE_LEARN_MORE 14824
#define IDS_PASSKEY_UPGRADE_BUBBLE_MANAGE_BUTTON 14825
#define IDS_WEB_DIGITAL_CREDENTIALS_BLUETOOTH_POWER_ON_MANUAL_TITLE 14826
#define IDS_WEB_DIGITAL_CREDENTIALS_BLUETOOTH_POWER_ON_MANUAL_DESCRIPTION 14827
#define IDS_WEB_DIGITAL_CREDENTIALS_BLUETOOTH_POWER_ON_MANUAL_NEXT 14828
#define IDS_WEB_DIGITAL_CREDENTIALS_QR_TITLE 14829
#define IDS_WEB_DIGITAL_CREDENTIALS_PRESENTATION_QR_BODY 14830
#define IDS_WEB_DIGITAL_CREDENTIALS_ISSUANCE_QR_BODY 14831
#define IDS_WEB_DIGITAL_CREDENTIALS_QR_CODE_ALT_TEXT 14832
#define IDS_WEB_DIGITAL_CREDENTIALS_CABLEV2_CONNECTING_TITLE 14833
#define IDS_WEB_DIGITAL_CREDENTIALS_CABLEV2_CONNECTED_TITLE 14834
#define IDS_WEB_DIGITAL_CREDENTIALS_FLOW_CANCEL_BUTTON_TEXT 14835
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_DIALOG_TITLE 14836
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_LOW_RISK_DIALOG_TEXT 14837
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_LOW_RISK_NEGATIVE_BUTTON_TEXT 14838
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_HIGH_RISK_DIALOG_TEXT 14839
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_HIGH_RISK_NEGATIVE_BUTTON_TEXT 14840
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_POSITIVE_BUTTON_TEXT 14841
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_REQUEST_ABORTED_DIALOG_TEXT 14842
#define IDS_INCOGNITO_PROFILE_MENU_TITLE 14843
#define IDS_INCOGNITO_PROFILE_MENU_CLOSE_BUTTON 14844
#define IDS_INCOGNITO_CLEAR_BROWSING_DATA_DIALOG_PRIMARY_TEXT 14845
#define IDS_INCOGNITO_CLEAR_BROWSING_DATA_DIALOG_SECONDARY_TEXT 14846
#define IDS_INCOGNITO_CLEAR_BROWSING_DATA_DIALOG_CLOSE_WINDOWS_BUTTON 14847
#define IDS_INCOGNITO_HISTORY_BUBBLE_PRIMARY_TEXT 14848
#define IDS_INCOGNITO_HISTORY_BUBBLE_SECONDARY_TEXT 14849
#define IDS_INCOGNITO_HISTORY_BUBBLE_CLOSE_INCOGNITO_BUTTON_TEXT 14850
#define IDS_INCOGNITO_HISTORY_BUBBLE_CANCEL_BUTTON_TEXT 14851
#define IDS_NOTIFICATION_DEFAULT_HELPFUL_BUTTON_TEXT 14852
#define IDS_NOTIFICATION_DEFAULT_UNHELPFUL_BUTTON_TEXT 14853
#define IDS_DEEP_SCANNING_DIALOG_TITLE 14854
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_PENDING_MESSAGE 14855
#define IDS_DEEP_SCANNING_DIALOG_PRINT_PENDING_MESSAGE 14856
#define IDS_DEEP_SCANNING_DIALOG_SUCCESS_MESSAGE 14857
#define IDS_DEEP_SCANNING_DIALOG_PRINT_SUCCESS_MESSAGE 14858
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_FAILURE_MESSAGE 14859
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_FAIL_CLOSED_MESSAGE 14860
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_WARNING_MESSAGE 14861
#define IDS_DEEP_SCANNING_DIALOG_PRINT_WARNING_MESSAGE 14862
#define IDS_DEEP_SCANNING_DIALOG_TIMEOUT_MESSAGE 14863
#define IDS_DEEP_SCANNING_DIALOG_PROCEED_BUTTON 14864
#define IDS_DEEP_SCANNING_DIALOG_CANCEL_WARNING_BUTTON 14865
#define IDS_DEEP_SCANNING_DIALOG_CANCEL_UPLOAD_BUTTON 14866
#define IDS_DEEP_SCANNING_DIALOG_LARGE_FILE_FAILURE_MESSAGE 14867
#define IDS_DEEP_SCANNING_DIALOG_LARGE_PRINT_FAILURE_MESSAGE 14868
#define IDS_DEEP_SCANNING_DIALOG_ENCRYPTED_FILE_FAILURE_MESSAGE 14869
#define IDS_DEEP_SCANNING_DIALOG_CUSTOM_MESSAGE 14870
#define IDS_DEEP_SCANNING_DIALOG_DOWNLOADS_CUSTOM_MESSAGE 14871
#define IDS_DEEP_SCANNING_DIALOG_CUSTOM_MESSAGE_LEARN_MORE_LINK 14872
#define IDS_DEEP_SCANNING_DIALOG_DOWNLOADS_DISCARD_FILE_BUTTON 14873
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_BYPASS_JUSTIFICATION_LABEL 14874
#define IDS_DEEP_SCANNING_DIALOG_PASTE_BYPASS_JUSTIFICATION_LABEL 14875
#define IDS_DEEP_SCANNING_DIALOG_PRINT_BYPASS_JUSTIFICATION_LABEL 14876
#define IDS_DEEP_SCANNING_DIALOG_DOWNLOAD_BYPASS_JUSTIFICATION_LABEL 14877
#define IDS_DEEP_SCANNING_DIALOG_BYPASS_JUSTIFICATION_TEXT_LIMIT_LABEL 14878
#define IDS_DEEP_SCANNING_DIALOG_SAVE_TO_CLOUD_STORAGE_LABEL 14879
#define IDS_DEEP_SCANNING_DIALOG_SAVE_TO_CLOUD_FILENAME_PLACEHOLDER 14880
#define IDS_DEEP_SCANNING_DIALOG_SAVE_TO_CLOUD_STORAGE_MESSAGE 14881
#define IDS_DATA_SHARING_BUBBLE_DIALOG_TITLE 14882
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_IPH_BUBBLE_TEXT 14883
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_IPH_BUBBLE_CLOSE_BUTTON_ARIA_LABEL_TEXT 14884
#define IDS_TAILORED_SECURITY_ENABLED_DIALOG_TITLE 14885
#define IDS_TAILORED_SECURITY_DISABLED_DIALOG_TITLE 14886
#define IDS_TAILORED_SECURITY_ENABLED_DIALOG_MAIN_TEXT 14887
#define IDS_TAILORED_SECURITY_DISABLED_DIALOG_MAIN_TEXT 14888
#define IDS_TAILORED_SECURITY_DISABLED_DIALOG_ACCEPT_BUTTON 14889
#define IDS_TAILORED_SECURITY_DIALOG_SETTINGS_BUTTON 14890
#define IDS_TAILORED_SECURITY_UNCONSENTED_MODAL_TITLE 14891
#define IDS_TAILORED_SECURITY_UNCONSENTED_MODAL_BODY 14892
#define IDS_TAILORED_SECURITY_UNCONSENTED_ACCEPT_BUTTON 14893
#define IDS_TAILORED_SECURITY_UNCONSENTED_CANCEL_BUTTON 14894
#define IDS_TAILORED_SECURITY_CONSENTED_ENABLE_MESSAGE_TITLE 14895
#define IDS_TAILORED_SECURITY_CONSENTED_ENABLE_MESSAGE_DESCRIPTION 14896
#define IDS_TAILORED_SECURITY_CONSENTED_DISABLE_MESSAGE_TITLE 14897
#define IDS_TAILORED_SECURITY_CONSENTED_DISABLE_MESSAGE_DESCRIPTION 14898
#define IDS_TAILORED_SECURITY_CONSENTED_MESSAGE_OK_BUTTON 14899
#define IDS_TAILORED_SECURITY_CONSENTED_ENHANCED_PROTECTION_ENABLE_MESSAGE_TITLE 14900
#define IDS_PROMPT_APP_UNINSTALL_TITLE 14901
#define IDS_APP_UNINSTALL_PROMPT_REMOVE_DATA_CHECKBOX_FOR_NON_GOOGLE 14902
#define IDS_APP_UNINSTALL_PROMPT_REMOVE_DATA_CHECKBOX_FOR_GOOGLE 14903
#define IDS_APP_UNINSTALL_PROMPT_LEARN_MORE 14904
#define IDS_APP_UNINSTALL_PROMPT_ADDITIONAL_UNINSTALLS_MESSAGE 14905
#define IDS_SUB_APPS_UNINSTALL_NOTIFICATION_TITLE 14906
#define IDS_SUB_APPS_UNINSTALL_NOTIFICATION_DESCRIPTION 14907
#define IDS_UTILITY_PROCESS_SPEECH_RECOGNITION_SERVICE_NAME 14908
#define IDS_APP_PAUSE_PROMPT_TITLE 14909
#define IDS_APP_PAUSE_HEADING 14910
#define IDS_APP_PAUSE_HEADING_FOR_WEB_APPS 14911
#define IDS_APP_BLOCK_PROMPT_TITLE 14912
#define IDS_APP_BLOCK_HEADING_FOR_CHILD 14913
#define IDS_APP_BLOCK_HEADING 14914
#define IDS_APP_LOCAL_BLOCK_PROMPT_TITLE 14915
#define IDS_APP_LOCAL_BLOCK_PROMPT_MULTIPLE_TITLE 14916
#define IDS_APP_LOCAL_BLOCK_HEADING 14917
#define IDS_ENTERPRISE_EXTENSION_REQUEST_APPROVED_TITLE 14918
#define IDS_ENTERPRISE_EXTENSION_REQUEST_REJECTED_TITLE 14919
#define IDS_ENTERPRISE_EXTENSION_REQUEST_FORCE_INSTALLED_TITLE 14920
#define IDS_ENTERPRISE_EXTENSION_REQUEST_CLICK_TO_INSTALL 14921
#define IDS_ENTERPRISE_EXTENSION_REQUEST_CLICK_TO_VIEW 14922
#define IDS_ENTERPRISE_EXTENSION_REQUEST_JUSTIFICATION 14923
#define IDS_ENTERPRISE_EXTENSION_REQUEST_JUSTIFICATION_PLACEHOLDER 14924
#define IDS_ENTERPRISE_EXTENSION_REQUEST_JUSTIFICATION_LENGTH_LIMIT 14925
#define IDS_NAME_WINDOW_PROMPT_TITLE 14926
#define IDS_NAME_WINDOW_PROMPT_FIELD_LABEL 14927
#define IDS_CHROMELABS_RELAUNCH_BUTTON_LABEL 14928
#define IDS_WINDOW_TITLE_EXPERIMENTS 14929
#define IDS_CHROMELABS_SEND_FEEDBACK 14930
#define IDS_CHROMELABS_SEND_FEEDBACK_DESCRIPTION_PLACEHOLDER 14931
#define IDS_CHROMELABS_DEFAULT 14932
#define IDS_CHROMELABS_ENABLED 14933
#define IDS_CHROMELABS_DISABLED 14934
#define IDS_CHROMELABS_ENABLED_WITH_VARIATION_NAME 14935
#define IDS_LENS_REGION_SEARCH_BUBBLE_TEXT 14936
#define IDS_CAPTURE_REGION_BUBBLE_TEXT 14937
#define IDS_THUMBNAIL_TAB_STRIP_EXPERIMENT_NAME 14938
#define IDS_THUMBNAIL_TAB_STRIP_EXPERIMENT_DESCRIPTION 14939
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_NOTIFICATION_DESCRIPTION 14942
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_NOTIFICATION_ACCEPT 14943
#define IDS_TAILORED_SECURITY_CONSENTED_PROMOTION_MESSAGE_TURN_ON 14944
#define IDS_TAILORED_SECURITY_CONSENTED_ESB_OFF_MESSAGE_TITLE 14945
#define IDS_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT_SIGN_IN 14946
#define IDS_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT_SIGN_UP 14947
#define IDS_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT_USE 14948
#define IDS_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT_CONTINUE 14949
#define IDS_ACCOUNT_SELECTION_SHEET_SUBTITLE_FOR_EMBED 14950
#define IDS_ACCOUNT_SELECTION_CONTINUE 14951
#define IDS_ACCOUNT_SELECTION_CHOOSE_AN_ACCOUNT 14952
#define IDS_ACCOUNT_SELECTION_CHOOSE_AN_ACCOUNT_BUTTON 14953
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_NAME 14954
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_EMAIL 14955
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_PICTURE 14956
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_PHONE 14957
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_USERNAME 14958
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_CONSENT_NO_PP_OR_TOS 14959
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_CONSENT_NO_PP 14960
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_CONSENT_NO_TOS 14961
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_CONSENT 14962
#define IDS_ACCOUNT_SELECTION_USE_OTHER_ACCOUNT 14963
#define IDS_ACCOUNT_SELECTION_USE_OTHER_ACCOUNT_MULTI_IDP 14964
#define IDS_ACCOUNT_SELECTION_OPENS_IN_NEW_TAB 14965
#define IDS_ACCOUNT_SELECTION_BACK 14966
#define IDS_SIGNIN_CONTINUE 14967
#define IDS_IDP_SIGNIN_STATUS_MISMATCH_DIALOG_BODY 14968
#define IDS_SIGNIN_GENERIC_ERROR_DIALOG_SUMMARY 14969
#define IDS_SIGNIN_GENERIC_ERROR_DIALOG_DESCRIPTION 14970
#define IDS_SIGNIN_UNAUTHORIZED_CLIENT_ERROR_DIALOG_SUMMARY 14971
#define IDS_SIGNIN_UNAUTHORIZED_CLIENT_ERROR_DIALOG_DESCRIPTION 14972
#define IDS_SIGNIN_INVALID_REQUEST_ERROR_DIALOG_SUMMARY 14973
#define IDS_SIGNIN_INVALID_REQUEST_ERROR_DIALOG_DESCRIPTION 14974
#define IDS_SIGNIN_ACCESS_DENIED_ERROR_DIALOG_SUMMARY 14975
#define IDS_SIGNIN_ACCESS_DENIED_ERROR_DIALOG_DESCRIPTION 14976
#define IDS_SIGNIN_SERVER_ERROR_DIALOG_SUMMARY 14977
#define IDS_SIGNIN_SERVER_ERROR_DIALOG_DESCRIPTION 14978
#define IDS_SIGNIN_TEMPORARILY_UNAVAILABLE_ERROR_DIALOG_SUMMARY 14979
#define IDS_SIGNIN_TEMPORARILY_UNAVAILABLE_ERROR_DIALOG_DESCRIPTION 14980
#define IDS_SIGNIN_ERROR_DIALOG_GOT_IT_BUTTON 14981
#define IDS_SIGNIN_ERROR_DIALOG_MORE_DETAILS_BUTTON 14982
#define IDS_SIGNIN_ERROR_DIALOG_MORE_DETAILS_PROMPT 14983
#define IDS_SIGNIN_ERROR_DIALOG_TRY_OTHER_WAYS_PROMPT 14984
#define IDS_SIGNIN_ERROR_DIALOG_MORE_DETAILS_RETRY_PROMPT 14985
#define IDS_SIGNIN_ERROR_DIALOG_TRY_OTHER_WAYS_RETRY_PROMPT 14986
#define IDS_MULTI_IDP_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT 14987
#define IDS_MULTI_IDP_ACCOUNT_ORIGIN_AND_LAST_USED 14988
#define IDS_USED_ON_THIS_SITE 14989
#define IDS_VERIFY_SHEET_TITLE 14990
#define IDS_VERIFY_SHEET_TITLE_AUTO_REAUTHN 14991
#define IDS_AUTO_REAUTHN_OPTOUT_CHECKBOX 14992
#define IDS_FILTERED_ACCOUNT_MESSAGE 14993
#define IDS_BATTERY_SAVER_BUTTON_TOOLTIP 14996
#define IDS_BATTERY_SAVER_BUTTON_ACCNAME 14997
#define IDS_BATTERY_SAVER_BUBBLE_TITLE 14998
#define IDS_BATTERY_SAVER_BUBBLE_DESCRIPTION 14999
#define IDS_BATTERY_SAVER_SESSION_TURN_OFF 15000
#define IDS_MEMORY_SAVER_CHIP_LABEL 15001
#define IDS_MEMORY_SAVER_CHIP_ACCNAME 15002
#define IDS_MEMORY_SAVER_CHIP_WITH_SAVINGS_ACCNAME 15003
#define IDS_MEMORY_SAVER_CHIP_SAVINGS_LABEL 15004
#define IDS_MEMORY_SAVER_DIALOG_TITLE 15005
#define IDS_MEMORY_SAVER_DIALOG_SETTINGS_BUTTON 15006
#define IDS_MEMORY_SAVER_DIALOG_SAVINGS_ACCNAME 15007
#define IDS_MEMORY_SAVER_DIALOG_BUTTON_ADD_TO_EXCLUSION_LIST 15008
#define IDS_MEMORY_SAVER_DIALOG_SAVINGS_LABEL 15009
#define IDS_MEMORY_SAVER_DIALOG_SMALL_SAVINGS_LABEL 15010
#define IDS_MEMORY_SAVER_DIALOG_MEDIUM_SAVINGS_LABEL 15011
#define IDS_MEMORY_SAVER_DIALOG_LARGE_SAVINGS_LABEL 15012
#define IDS_MEMORY_SAVER_DIALOG_VERY_LARGE_SAVINGS_LABEL 15013
#define IDS_HOVERCARD_TAB_MEMORY_USAGE 15014
#define IDS_HOVERCARD_TAB_HIGH_MEMORY_USAGE 15015
#define IDS_HOVERCARD_INACTIVE_TAB_MEMORY_SAVINGS 15016
#define IDS_HOVERCARD_INACTIVE_TAB 15017
#define IDS_PERFORMANCE_INTERVENTION_CLOSE_BUTTON_ACCNAME 15018
#define IDS_PERFORMANCE_INTERVENTION_SINGLE_SUGGESTED_ROW_ACCNAME 15019
#define IDS_PERFORMANCE_INTERVENTION_TAB_LIST_ACCNAME 15020
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_TITLE_V1 15021
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_TITLE_UPDATED_V1 15022
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_TITLE_UPDATED_V2 15023
#define IDS_PERFORMANCE_INTERVENTION_DEACTIVATE_TABS_BUTTON_V1 15024
#define IDS_PERFORMANCE_INTERVENTION_DEACTIVATE_TABS_BUTTON_UPDATED_V1 15025
#define IDS_PERFORMANCE_INTERVENTION_DEACTIVATE_TABS_BUTTON_UPDATED_V2 15026
#define IDS_PERFORMANCE_INTERVENTION_DISMISS_BUTTON 15027
#define IDS_PERFORMANCE_INTERVENTION_BUTTON_TOOLTIP 15028
#define IDS_PERFORMANCE_INTERVENTION_BUTTON_ACCNAME 15029
#define IDS_TOAST_MENU_BUTTON_NAME 15030
#define IDS_TRANSLATE_TOAST_BODY 15031
#define IDS_TRANSLATE_TOAST_UNDO_BUTTON 15032
#define IDS_LINK_COPIED_TOAST_BODY 15033
#define IDS_IMAGE_COPIED_TOAST_BODY 15034
#define IDS_VIDEO_FRAME_COPIED_TOAST_BODY 15035
#define IDS_LINK_COPIED_TO_HIGHLIGHT_TOAST_BODY 15036
#define IDS_READING_LIST_TOAST_BODY 15037
#define IDS_READING_LIST_TOAST_BUTTON 15038
#define IDS_CLOSE_PINNED_TAB_TOAST_BODY 15039
#define IDS_TOAST_CLOSE_TOOLTIP 15040
#define IDS_NON_MILESTONE_UPDATE_TOAST_BODY 15041
#define IDS_GLIC_SHARE_IMAGE_FAILED_TOAST_BODY 15042
#define IDS_GLIC_SELECTION_OVERLAY_RENDERER_LABEL 15043
#define IDS_COPIED_TO_CLIPBOARD_TOAST_BODY 15044
#define IDS_PROTECTED_AUDIENCE_DEBUGGING_DISCLAIMER 15048
#define IDS_OVERFLOW_MENU_ITEM_TEXT_PROFILE 15049
#define IDS_OVERFLOW_MENU_ITEM_TEXT_DOWNLOADS 15050
#define IDS_OVERFLOW_MENU_ITEM_TEXT_EXTENSIONS 15051
#define IDS_OVERFLOW_MENU_ITEM_TEXT_FORWARD 15052
#define IDS_OVERFLOW_MENU_ITEM_TEXT_HOME 15053
#define IDS_OVERFLOW_MENU_ITEM_TEXT_LABS 15054
#define IDS_OVERFLOW_MENU_ITEM_TEXT_MEDIA_CONTROLS 15055
#define IDS_OVERFLOW_MENU_ITEM_TEXT_NEW_TAB 15056
#define IDS_OVERFLOW_MENU_ITEM_TEXT_SIDE_PANEL 15057
#define IDS_OVERFLOW_MENU_ITEM_TEXT_SPLIT_TABS 15058
#define IDS_OVERFLOW_MENU_ITEM_TEXT_CONTEXTUAL_TASKS 15059
#define IDS_PROMISE_STATUS_WAITING 15060
#define IDS_PROMISE_STATUS_INSTALLING 15061
#define IDS_PROMISE_APP_ACCESSIBLE_LABEL_WAITING 15062
#define IDS_PROMISE_APP_ACCESSIBLE_LABEL_INSTALLING 15063
#define IDS_PROMISE_APP_PLACEHOLDER_ACCESSIBLE_LABEL_WAITING 15064
#define IDS_PROMISE_APP_PLACEHOLDER_ACCESSIBLE_LABEL_INSTALLING 15065
#define IDS_IWA_INSTALLER_DISABLED_TITLE 15066
#define IDS_IWA_INSTALLER_DISABLED_CHANGE_PREFERENCE 15067
#define IDS_IWA_INSTALLER_DISABLED_SUBTITLE 15068
#define IDS_IWA_INSTALLER_ALREADY_INSTALLED_TITLE 15069
#define IDS_IWA_INSTALLER_ALREADY_INSTALLED_SUBTITLE 15070
#define IDS_IWA_INSTALLER_BODY_SCREENREADER_NAME 15071
#define IDS_IWA_INSTALLER_DETAILS_SCREENREADER_NAME 15072
#define IDS_IWA_INSTALLER_PROGRESS_SCREENREADER_NAME 15073
#define IDS_IWA_INSTALLER_INSTALL_SUBTITLE 15074
#define IDS_IWA_INSTALLER_INSTALL_PROGRESS 15075
#define IDS_IWA_INSTALLER_SHOW_METADATA_SUBTITLE 15076
#define IDS_IWA_INSTALLER_SHOW_METADATA_APP_NAME_LABEL 15077
#define IDS_IWA_INSTALLER_SHOW_METADATA_APP_VERSION_LABEL 15078
#define IDS_IWA_INSTALLER_SHOW_METADATA_APP_ENTERPRISE_NAME_LABEL 15079
#define IDS_IWA_INSTALLER_CONFIRM_TITLE 15080
#define IDS_IWA_INSTALLER_CONFIRM_SUBTITLE 15081
#define IDS_IWA_INSTALLER_CONFIRM_CONTINUE 15082
#define IDS_IWA_INSTALLER_INSTALL_FAILED_TITLE 15083
#define IDS_IWA_INSTALLER_INSTALL_FAILED_SUBTITLE 15084
#define IDS_IWA_INSTALLER_INSTALL_FAILED_BUNDLE_NOT_ON_USER_INSTALL_ALLOWLIST_SUBTITLE 15085
#define IDS_IWA_INSTALLER_INSTALL_FAILED_BUNDLE_BLOCKLISTED 15086
#define IDS_IWA_INSTALLER_INSTALL_FAILED_RETRY 15087
#define IDS_IWA_INSTALLER_SUCCESS_SUBTITLE 15088
#define IDS_IWA_INSTALLER_SUCCESS_FINISH 15089
#define IDS_IWA_INSTALLER_SUCCESS_LAUNCH_APPLICATION 15090
#define IDS_IWA_INSTALLER_VERIFICATION_TITLE 15091
#define IDS_IWA_INSTALLER_VERIFICATION_SUBTITLE 15092
#define IDS_IWA_INSTALLER_VERIFICATION_STATUS 15093
#define IDS_IWA_INSTALLER_VERIFICATION_ERROR_TITLE 15094
#define IDS_IWA_INSTALLER_VERIFICATION_ERROR_SUBTITLE 15095
#define IDS_ISOLATED_WEB_APPS_WINDOW_OPEN_PERMISSION_NOTIFICATION_TITLE 15097
#define IDS_ISOLATED_WEB_APPS_WINDOW_OPEN_PERMISSION_NOTIFICATION_MESSAGE 15098
#define IDS_ISOLATED_WEB_APPS_WINDOW_OPEN_PERMISSION_NOTIFICATION_BUTTON_SETTINGS 15099
#define IDS_THUMBS_DOWN 15106
#define IDS_THUMBS_UP 15107
#define IDS_EXPERIMENTAL_FEATURE_DISCLAIMER 15108
#define IDS_PDF_INK_SIGNATURES_IPH_BODY 15109
#define IDS_PDF_SEARCHIFY_IPH_TITLE 15110
#define IDS_PDF_SEARCHIFY_IPH_BODY 15111
#define IDS_PDF_SEARCHIFY_IPH_BODY_SCREEN_READER 15112
#define IDS_SELECT_AUDIO_OUTPUT_DIALOG_TITLE 15113
#define IDS_SELECT_AUDIO_OUTPUT_DIALOG_CHOOSE_DEVICE 15114
#define IDS_CHROME_NO_LONGER_SHOW_WARNINGS_NOTIFICATION_TITLE 15130
#define IDS_CHROME_NO_LONGER_SHOW_WARNINGS_NOTIFICATION_BODY 15131
#define IDS_CHROME_NO_LONGER_SHOW_WARNINGS_NOTIFICATION_TITLE_NEW 15132
#define IDS_CHROME_NO_LONGER_SHOW_WARNINGS_NOTIFICATION_BODY_NEW 15133
#define IDS_MERCHANT_TRUST_IPH_TITLE 15134
#define IDS_MERCHANT_TRUST_IPH_BODY 15135
#define IDS_MERCHANT_TRUST_IPH_BODY_SCREEN_READER 15136
#define IDS_PDF_GLIC_SUMMARIZE 15141
#define IDS_PDF_GLIC_SUMMARIZE_TOOLTIP 15142
#define IDS_NTP_EXTENSIONS_PROMO 15151
#define IDS_ACCOUNT_CHOOSER_SINGLE_ACCOUNT_TITLE 15152
#define IDS_ACCOUNT_CHOOSER_MULTI_ACCOUNT_TITLE 15153
#define IDS_ACCOUNT_CHOOSER_SUBTITLE 15154
#define IDS_SAVE_TO_DRIVE_FOLDER_NAME 15155
#define IDS_ACCOUNT_CHOOSER_DRIVE 15156
#define IDS_ACCOUNT_CHOOSER_ADD_ACCOUNT 15157
#define IDS_ACCOUNT_CHOOSER_RADIO_GROUP_ACCESSIBILITY_LABEL 15158
#define IDS_ACCOUNT_CHOOSER_HEADER_ACCESSIBILITY_LABEL 15159
#define IDS_TIPS_NOTIFICATIONS_HELPFUL_BUTTON_TEXT 15160
#define IDS_TIPS_NOTIFICATIONS_ENHANCED_SAFE_BROWSING_TITLE 15161
#define IDS_TIPS_NOTIFICATIONS_ENHANCED_SAFE_BROWSING_SUBTITLE 15162
#define IDS_TIPS_NOTIFICATIONS_QUICK_DELETE_TITLE 15163
#define IDS_TIPS_NOTIFICATIONS_QUICK_DELETE_SUBTITLE 15164
#define IDS_TIPS_NOTIFICATIONS_GOOGLE_LENS_TITLE 15165
#define IDS_TIPS_NOTIFICATIONS_GOOGLE_LENS_SUBTITLE 15166
#define IDS_TIPS_NOTIFICATIONS_BOTTOM_OMNIBOX_TITLE 15167
#define IDS_TIPS_NOTIFICATIONS_BOTTOM_OMNIBOX_SUBTITLE 15168
#define IDS_TIPS_NOTIFICATIONS_PASSWORD_AUTOFILL_TITLE 15169
#define IDS_TIPS_NOTIFICATIONS_PASSWORD_AUTOFILL_SUBTITLE 15170
#define IDS_TIPS_NOTIFICATIONS_SIGNIN_TITLE 15171
#define IDS_TIPS_NOTIFICATIONS_SIGNIN_SUBTITLE 15172
#define IDS_TIPS_NOTIFICATIONS_CREATE_TAB_GROUPS_TITLE 15173
#define IDS_TIPS_NOTIFICATIONS_CREATE_TAB_GROUPS_SUBTITLE 15174
#define IDS_TIPS_NOTIFICATIONS_CUSTOMIZE_MVT_TITLE 15175
#define IDS_TIPS_NOTIFICATIONS_CUSTOMIZE_MVT_SUBTITLE 15176
#define IDS_TIPS_NOTIFICATIONS_RECENT_TABS_TITLE 15177
#define IDS_TIPS_NOTIFICATIONS_RECENT_TABS_SUBTITLE 15178
#define IDS_UPDATER_ACTIVATION_FAILED 15179
#define IDS_UPDATER_ACTIVATION_SUCCEEDED 15180
#define IDS_UPDATER_ADD_FILTER 15181
#define IDS_UPDATER_APP 15182
#define IDS_UPDATER_APP_COLUMN 15183
#define IDS_UPDATER_APPLY 15184
#define IDS_UPDATER_APP_NAME_OR_ID 15185
#define IDS_UPDATER_APP_POLICIES 15186
#define IDS_UPDATER_APP_STATES_QUERY_FAILED 15187
#define IDS_UPDATER_CANCEL 15188
#define IDS_UPDATER_CLEAR_ALL_FILTERS 15189
#define IDS_UPDATER_COLLAPSE_ALL 15190
#define IDS_UPDATER_COMMAND_LINE 15191
#define IDS_UPDATER_COMMAND_OUTCOME 15192
#define IDS_UPDATER_COMMON 15193
#define IDS_UPDATER_DATE 15194
#define IDS_UPDATER_DATE_FILTER_AFTER 15195
#define IDS_UPDATER_DATE_FILTER_BEFORE 15196
#define IDS_UPDATER_DATE_FILTER_RANGE 15197
#define IDS_UPDATER_DISPLAYED_EVENTS_COUNT 15198
#define IDS_UPDATER_DURATION 15199
#define IDS_UPDATER_EFFECTIVE_POLICY_SET 15200
#define IDS_UPDATER_END_DATE 15201
#define IDS_UPDATER_ERROR_ACCESS_DENIED 15202
#define IDS_UPDATER_ERROR_CORRUPT 15203
#define IDS_UPDATER_ERROR_DISABLED 15204
#define IDS_UPDATER_ERROR_DISK_FULL 15205
#define IDS_UPDATER_ERROR_DOWNLOAD 15206
#define IDS_UPDATER_ERROR_INSTALL 15207
#define IDS_UPDATER_ERROR_INSTALLER_FAILED 15208
#define IDS_UPDATER_ERROR_NETWORK 15209
#define IDS_UPDATER_ERROR_RESTRICTED 15210
#define IDS_UPDATER_ERROR_UNPACK 15211
#define IDS_UPDATER_ERROR_UPDATE_CHECK 15212
#define IDS_UPDATER_ERROR_UNKNOWN 15213
#define IDS_UPDATER_EVENT_LIST_TITLE 15214
#define IDS_UPDATER_EVENT_TYPE 15215
#define IDS_UPDATER_EVENT_TYPE_ACTIVATE 15216
#define IDS_UPDATER_EVENT_TYPE_APP_COMMAND 15217
#define IDS_UPDATER_EVENT_TYPE_INSTALL 15218
#define IDS_UPDATER_EVENT_TYPE_LOAD_POLICY 15219
#define IDS_UPDATER_EVENT_TYPE_PERSISTED_DATA 15220
#define IDS_UPDATER_EVENT_TYPE_POST_REQUEST 15221
#define IDS_UPDATER_EVENT_TYPE_QUALIFY 15222
#define IDS_UPDATER_EVENT_TYPE_UNINSTALL 15223
#define IDS_UPDATER_EVENT_TYPE_UPDATE 15224
#define IDS_UPDATER_EVENT_TYPE_UPDATER_PROCESS 15225
#define IDS_UPDATER_EXPAND_ALL 15226
#define IDS_UPDATER_FILTER_CHIP_APP 15227
#define IDS_UPDATER_FILTER_CHIP_DATE 15228
#define IDS_UPDATER_FILTER_CHIP_EVENT_TYPE 15229
#define IDS_UPDATER_FILTER_CHIP_UPDATE_OUTCOME 15230
#define IDS_UPDATER_FILTER_CHIP_UPDATER_SCOPE 15231
#define IDS_UPDATER_INACTIVE_VERSIONS_LABEL 15232
#define IDS_UPDATER_INSTALL_PATH_LABEL 15233
#define IDS_UPDATER_INSTALL_SUMMARY 15234
#define IDS_UPDATER_INSTALLED_APPS_TITLE 15235
#define IDS_UPDATER_INTERNAL 15236
#define IDS_UPDATER_LAST_CHECKED_LABEL 15237
#define IDS_UPDATER_LAST_STARTED_LABEL 15238
#define IDS_UPDATER_NO_APPS_FOUND 15239
#define IDS_UPDATER_NO_POLICIES 15240
#define IDS_UPDATER_NO_UPDATER_FOUND 15241
#define IDS_UPDATER_NEVER 15242
#define IDS_UPDATER_NEXT_VERSION 15243
#define IDS_UPDATER_NO_UPDATE 15244
#define IDS_UPDATER_OMAHA_REQUEST 15245
#define IDS_UPDATER_OMAHA_RESPONSE 15246
#define IDS_UPDATER_OTHER 15247
#define IDS_UPDATER_OUTCOME 15248
#define IDS_UPDATER_OUTCOME_UNKNOWN 15249
#define IDS_UPDATER_PAGE_TITLE 15250
#define IDS_UPDATER_PARSE_ERROR_EVENTS 15251
#define IDS_UPDATER_PERSISTED_DATA_SUMMARY 15252
#define IDS_UPDATER_POLICY_CONFLICT_WARNING 15253
#define IDS_UPDATER_POLICY_IGNORED 15254
#define IDS_UPDATER_POLICY_NAME 15255
#define IDS_UPDATER_POLICY_OK 15256
#define IDS_UPDATER_POLICY_SOURCE 15257
#define IDS_UPDATER_POLICY_STATUS 15258
#define IDS_UPDATER_POLICY_VALUE 15259
#define IDS_UPDATER_PROCESS_SUMMARY 15260
#define IDS_UPDATER_QUALIFICATION_FAILED 15261
#define IDS_UPDATER_QUALIFICATION_SUCCEEDED 15262
#define IDS_UPDATER_QUERY_FAILED 15263
#define IDS_UPDATER_REMOVE_FILTER 15264
#define IDS_UPDATER_SCOPE 15265
#define IDS_UPDATER_SCOPE_SYSTEM 15266
#define IDS_UPDATER_SCOPE_USER 15267
#define IDS_UPDATER_START_DATE 15268
#define IDS_UPDATER_STATE_TITLE 15269
#define IDS_UPDATER_UNDATED_EVENTS 15270
#define IDS_UPDATER_UNINSTALL_SUMMARY 15271
#define IDS_UPDATER_UPDATED_TO 15272
#define IDS_UPDATER_UPDATER_POLICIES 15273
#define IDS_UPDATER_UPDATER_VERSION 15274
#define IDS_UPDATER_VERSION_COLUMN 15275
#define IDS_UPDATER_VERSION_LABEL 15276
#define IDS_UPDATER_UPDATE_ERROR 15277
#define IDS_UPDATER_UPDATE_OUTCOME 15278
#define IDS_UPDATER_UPDATE_OUTCOME_NO_UPDATE 15279
#define IDS_UPDATER_UPDATE_OUTCOME_UPDATED 15280
#define IDS_UPDATER_UPDATE_OUTCOME_UPDATE_ERROR 15281
#define IDS_UPDATER_VIEW_RAW_DETAILS 15282
#define IDS_REPORT_UNSAFE_SITE_DIALOG_INCLUDE_SCREENSHOT_CHECKBOX_LABEL 15283
#define IDS_REPORT_UNSAFE_SITE_DIALOG_SEND_BUTTON_LABEL 15284
#define IDS_REPORT_UNSAFE_SITE_DIALOG_URL_LABEL 15285

// ---------------------------------------------------------------------------
// From locale_settings.h:

#define IDS_SPELLCHECK_DICTIONARY 16000
#define IDS_EDITBOOKMARK_DIALOG_WIDTH_CHARS 16001
#define IDS_EDITBOOKMARK_DIALOG_HEIGHT_LINES 16002
#define IDS_WEBSTORE_URL 16003
#define IDS_MEDIA_GALLERIES_DIALOG_CONTENT_WIDTH_CHARS 16004

// ---------------------------------------------------------------------------
// From omnibox_pedal_synonyms.h:

#define IDS_OMNIBOX_PEDALS_IGNORE_GROUP 41080
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLEAR_BROWSING_DATA_ONE_REQUIRED_CLEAR_BROWSER_CACHE 41081
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLEAR_BROWSING_DATA_ONE_OPTIONAL_GOOGLE_CHROME 41082
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLEAR_BROWSING_DATA_ONE_REQUIRED_DELETE 41083
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLEAR_BROWSING_DATA_ONE_REQUIRED_INFORMATION 41084
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_PASSWORDS_ONE_REQUIRED_MANAGE_CHROME_PASSWORDS 41085
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_PASSWORDS_ONE_OPTIONAL_GOOGLE_CHROME 41086
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_PASSWORDS_ONE_OPTIONAL_MANAGER 41087
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_PASSWORDS_ONE_REQUIRED_PASSWORDS 41088
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CREDIT_CARD_ONE_REQUIRED_MANAGE_PAYMENT_METHODS 41089
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CREDIT_CARD_ONE_OPTIONAL_GOOGLE_CHROME 41090
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CREDIT_CARD_ONE_REQUIRED_CHANGE 41091
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CREDIT_CARD_ONE_REQUIRED_CREDIT_CARD_INFORMATION 41092
#define IDS_OMNIBOX_PEDAL_SYNONYMS_LAUNCH_INCOGNITO_ONE_REQUIRED_ENTER_INCOGNITO_MODE 41093
#define IDS_OMNIBOX_PEDAL_SYNONYMS_LAUNCH_INCOGNITO_ONE_OPTIONAL_GOOGLE_CHROME 41094
#define IDS_OMNIBOX_PEDAL_SYNONYMS_LAUNCH_INCOGNITO_ONE_OPTIONAL_CREATE 41095
#define IDS_OMNIBOX_PEDAL_SYNONYMS_LAUNCH_INCOGNITO_ONE_REQUIRED_INCOGNITO_WINDOW 41096
#define IDS_OMNIBOX_PEDAL_SYNONYMS_TRANSLATE_ONE_REQUIRED_TRANSLATE_THIS_PAGE 41097
#define IDS_OMNIBOX_PEDAL_SYNONYMS_TRANSLATE_ONE_OPTIONAL_GOOGLE_CHROME 41098
#define IDS_OMNIBOX_PEDAL_SYNONYMS_TRANSLATE_ONE_REQUIRED_CHANGE_LANGUAGE 41099
#define IDS_OMNIBOX_PEDAL_SYNONYMS_TRANSLATE_ONE_REQUIRED_THIS_PAGE 41100
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CHROME_ONE_REQUIRED_UPDATE_CHROME 41101
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CHROME_ONE_REQUIRED_GOOGLE_CHROME 41102
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CHROME_ONE_REQUIRED_INSTALL 41103
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_REQUIRED_RUN_CHROME_SAFETY_CHECK 41104
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_OPTIONAL_ACTIVATE 41105
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_OPTIONAL_GOOGLE_CHROME 41106
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_REQUIRED_CHECKUP 41107
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_REQUIRED_PASSWORDS 41108
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SECURITY_SETTINGS_ONE_REQUIRED_MANAGE_SECURITY_SETTINGS 41109
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SECURITY_SETTINGS_ANY_OPTIONAL_GOOGLE_CHROME 41110
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SECURITY_SETTINGS_ONE_REQUIRED_ENHANCED_PROTECTION 41111
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SECURITY_SETTINGS_ONE_OPTIONAL_ALTER 41112
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_COOKIES_ONE_REQUIRED_CHROME_COOKIE_SETTINGS 41113
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_COOKIES_ONE_REQUIRED_COOKIE_SETTINGS 41114
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_COOKIES_ANY_REQUIRED_GOOGLE_CHROME 41115
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_COOKIES_ANY_OPTIONAL_THIRD_PARTY 41116
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_ADDRESSES_ONE_REQUIRED_ADD_ADDRESS 41117
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_ADDRESSES_ONE_REQUIRED_CONTROL 41118
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_ADDRESSES_ONE_REQUIRED_SHIPPING_ADDRESSES 41119
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_ADDRESSES_ONE_OPTIONAL_GOOGLE_CHROME 41120
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_ONE_REQUIRED_CHANGE_CHROME_BROWSER_SYNC_SETTINGS 41121
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_ONE_REQUIRED_SYNC_SETTINGS 41122
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_ONE_REQUIRED_SYNC_SETTINGS_UPDATED 41123
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_ANY_REQUIRED_GOOGLE_CHROME 41124
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_UPDATED 41125
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SITE_SETTINGS_ONE_REQUIRED_ADJUST_SITE_PERMISSIONS 41126
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SITE_SETTINGS_ONE_REQUIRED_SITE_PERMISSIONS 41127
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SITE_SETTINGS_ANY_REQUIRED_GOOGLE_CHROME 41128
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_DOC_ONE_REQUIRED_CREATE_GOOGLE_DOC 41129
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_DOC_ONE_REQUIRED_GOOGLE_WORKSPACE 41130
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_DOC_ANY_REQUIRED_CREATE 41131
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_DOC_ONE_REQUIRED_DOCUMENT 41132
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SHEET_ONE_REQUIRED_CREATE_GOOGLE_SHEET 41133
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SHEET_ANY_REQUIRED_CREATE 41134
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SHEET_ONE_REQUIRED_GOOGLE_WORKSPACE 41135
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SHEET_ONE_REQUIRED_SPREADSHEET 41136
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SLIDE_ONE_REQUIRED_CREATE_GOOGLE_SLIDE 41137
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SLIDE_ONE_REQUIRED_CREATE 41138
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SLIDE_ONE_REQUIRED_PRESENTATION 41139
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SLIDE_ANY_REQUIRED_WORKSPACE 41140
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_CALENDAR_EVENT_ONE_REQUIRED_CREATE_GOOGLE_CAL_INVITE 41141
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_CALENDAR_EVENT_ANY_REQUIRED_SCHEDULE 41142
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_CALENDAR_EVENT_ANY_REQUIRED_WORKSPACE 41143
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_CALENDAR_EVENT_ONE_REQUIRED_MEETING 41144
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SITE_ONE_REQUIRED_CREATE_GOOGLE_SITE 41145
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SITE_ANY_REQUIRED_CREATE 41146
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SITE_ANY_REQUIRED_WORKSPACE 41147
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SITE_ONE_REQUIRED_WEBSITE 41148
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_KEEP_NOTE_ONE_REQUIRED_CREATE_GOOGLE_KEEP_NOTE 41149
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_KEEP_NOTE_ANY_REQUIRED_CREATE 41150
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_KEEP_NOTE_ANY_REQUIRED_WORKSPACE 41151
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_KEEP_NOTE_ONE_REQUIRED_NOTES 41152
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_FORM_ONE_REQUIRED_CREATE_GOOGLE_FORM 41153
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_FORM_ANY_REQUIRED_CREATE 41154
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_FORM_ANY_REQUIRED_WORKSPACE 41155
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_FORM_ONE_REQUIRED_SURVEY 41156
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SEE_CHROME_TIPS_ONE_REQUIRED_CHROME_FEATURES 41157
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SEE_CHROME_TIPS_ONE_OPTIONAL_MAKE_THE_MOST_OF 41158
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SEE_CHROME_TIPS_ANY_OPTIONAL_BROWSER 41159
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SEE_CHROME_TIPS_ONE_REQUIRED_NEW_CHROME_FEATURES 41160
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_ACCOUNT_ONE_REQUIRED_CONTROL_MY_GOOGLE_ACCOUNT 41161
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_ACCOUNT_ONE_REQUIRED_GOOGLE_ACCOUNT 41162
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_ACCOUNT_ANY_OPTIONAL_BROWSER 41163
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_ACCOUNT_ONE_REQUIRED_CONTROL 41164
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CHANGE_GOOGLE_PASSWORD_ONE_REQUIRED_CHANGE_GMAIL_PASSWORD 41165
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CHANGE_GOOGLE_PASSWORD_ONE_REQUIRED_GOOGLE_ACCOUNT_PASSWORD 41166
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CHANGE_GOOGLE_PASSWORD_ANY_OPTIONAL_BROWSER 41167
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CHANGE_GOOGLE_PASSWORD_ONE_REQUIRED_CHANGE 41168
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLOSE_INCOGNITO_WINDOWS_ONE_REQUIRED_CLOSE_INCOGNITO_WINDOW 41169
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLOSE_INCOGNITO_WINDOWS_ONE_REQUIRED_DELETE 41170
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLOSE_INCOGNITO_WINDOWS_ONE_REQUIRED_INCOGNITO_WINDOW 41171
#define IDS_OMNIBOX_PEDAL_SYNONYMS_PLAY_CHROME_DINO_GAME_ONE_REQUIRED_CHROME_DINO 41172
#define IDS_OMNIBOX_PEDAL_SYNONYMS_PLAY_CHROME_DINO_GAME_ONE_REQUIRED_PLAY_CHROME_DINO_GAME 41173
#define IDS_OMNIBOX_PEDAL_SYNONYMS_FIND_MY_PHONE_ONE_REQUIRED_FIND_LOST_PHONE 41174
#define IDS_OMNIBOX_PEDAL_SYNONYMS_FIND_MY_PHONE_ONE_REQUIRED_HELP_ME_LOCATE 41175
#define IDS_OMNIBOX_PEDAL_SYNONYMS_FIND_MY_PHONE_ONE_REQUIRED_LOST_DEVICE 41176
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_PRIVACY_ONE_REQUIRED_CHANGE_GOOGLE_PRIVACY_SETTINGS 41177
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_PRIVACY_ONE_REQUIRED_MANAGE_GOOGLE_PRIVACY_SETTINGS 41178
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_SETTINGS_ONE_REQUIRED_CHANGE_CHROME_SETTINGS 41179
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_SETTINGS_ONE_OPTIONAL_CONTROL 41180
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_SETTINGS_ONE_REQUIRED_CHROME_BROWSER_SETTINGS 41181
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_DOWNLOADS_ONE_REQUIRED_MANAGE_CHROME_DOWNLOADS 41182
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_DOWNLOADS_ONE_REQUIRED_CONTROL 41183
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_DOWNLOADS_ONE_REQUIRED_CHROME_BROWSER_DOWNLOADS 41184
#define IDS_OMNIBOX_PEDAL_SYNONYMS_VIEW_CHROME_HISTORY_ONE_REQUIRED_SEE_CHROME_HISTORY 41185
#define IDS_OMNIBOX_PEDAL_SYNONYMS_VIEW_CHROME_HISTORY_ONE_REQUIRED_REVISIT 41186
#define IDS_OMNIBOX_PEDAL_SYNONYMS_VIEW_CHROME_HISTORY_ONE_REQUIRED_GOOGLE_CHROME_BROWSING_HISTORY 41187
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SHARE_THIS_PAGE_ONE_REQUIRED_SHARE_THIS_PAGE 41188
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SHARE_THIS_PAGE_ONE_REQUIRED_SHARE_LINK_WITH_QR_CODE 41189
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_ACCESSIBILITY_ONE_REQUIRED_CUSTOMIZE_CHROME_ACCESSIBILITY 41190
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_ACCESSIBILITY_ONE_OPTIONAL_CUSTOMIZE 41191
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_ACCESSIBILITY_ONE_REQUIRED_ACCESSIBILITY_SETTINGS 41192
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_CHROME_FONTS_ONE_REQUIRED_CHANGE_BROWSER_FONT 41193
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_CHROME_FONTS_ONE_OPTIONAL_CUSTOMIZE 41194
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_CHROME_FONTS_ONE_REQUIRED_GOOGLE_CHROME 41195
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_CHROME_FONTS_ONE_REQUIRED_FONT_SIZING 41196
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_THEMES_ONE_REQUIRED_CUSTOMIZE_CHROME_APPEARANCE 41197
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_THEMES_ONE_OPTIONAL_CUSTOMIZE 41198
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_THEMES_ONE_REQUIRED_CHROME_BACKGROUNDS 41199
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_SEARCH_ENGINES_ONE_REQUIRED_ADD_CUSTOM_SEARCH 41200
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_SEARCH_ENGINES_ONE_OPTIONAL_CUSTOMIZE 41201
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_SEARCH_ENGINES_ONE_REQUIRED_CUSTOM_SEARCH_ENGINES 41202
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_SEARCH_ENGINES_ONE_OPTIONAL_GOOGLE_CHROME 41203
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROMEOS_ACCESSIBILITY_ONE_REQUIRED_CUSTOMIZE_CHROMEOS_ACCESSIBILITY 41204
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROMEOS_ACCESSIBILITY_ONE_OPTIONAL_CUSTOMIZE 41205
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROMEOS_ACCESSIBILITY_ONE_REQUIRED_ACCESSIBILITY_SETTINGS 41206
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SET_CHROME_AS_DEFAULT_BROWSER_ONE_REQUIRED_ALWAYS_OPEN_LINKS_IN_CHROME 41207
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SET_CHROME_AS_DEFAULT_BROWSER_ONE_REQUIRED_HOW_TO_MAKE_CHROME_MY_DEFAULT_BROWSER 41208
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SET_CHROME_AS_DEFAULT_BROWSER_ONE_OPTIONAL_SELECT 41209
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SET_CHROME_AS_DEFAULT_BROWSER_ONE_OPTIONAL_DEFAULT_BROWSER 41210

// ---------------------------------------------------------------------------
// From permission_element_generated_strings.h:

#define IDS_PERMISSION_REQUEST_LAUNCH_af 56300
#define IDS_PERMISSION_REQUEST_CAMERA_af 56301
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_af 56302
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_af 56303
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_af 56304
#define IDS_PERMISSION_REQUEST_INSTALL_af 56305
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_af 56306
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_af 56307
#define IDS_PERMISSION_REQUEST_MICROPHONE_af 56308
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_af 56309
#define IDS_PERMISSION_REQUEST_GEOLOCATION_af 56310
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_af 56311
#define IDS_PERMISSION_REQUEST_USING_LOCATION_af 56312
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_af 56313
#define IDS_PERMISSION_REQUEST_LAUNCH_am 56314
#define IDS_PERMISSION_REQUEST_CAMERA_am 56315
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_am 56316
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_am 56317
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_am 56318
#define IDS_PERMISSION_REQUEST_INSTALL_am 56319
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_am 56320
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_am 56321
#define IDS_PERMISSION_REQUEST_MICROPHONE_am 56322
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_am 56323
#define IDS_PERMISSION_REQUEST_GEOLOCATION_am 56324
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_am 56325
#define IDS_PERMISSION_REQUEST_USING_LOCATION_am 56326
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_am 56327
#define IDS_PERMISSION_REQUEST_LAUNCH_ar 56328
#define IDS_PERMISSION_REQUEST_CAMERA_ar 56329
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ar 56330
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ar 56331
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ar 56332
#define IDS_PERMISSION_REQUEST_INSTALL_ar 56333
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ar 56334
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ar 56335
#define IDS_PERMISSION_REQUEST_MICROPHONE_ar 56336
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ar 56337
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ar 56338
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ar 56339
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ar 56340
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ar 56341
#define IDS_PERMISSION_REQUEST_LAUNCH_as 56342
#define IDS_PERMISSION_REQUEST_CAMERA_as 56343
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_as 56344
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_as 56345
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_as 56346
#define IDS_PERMISSION_REQUEST_INSTALL_as 56347
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_as 56348
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_as 56349
#define IDS_PERMISSION_REQUEST_MICROPHONE_as 56350
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_as 56351
#define IDS_PERMISSION_REQUEST_GEOLOCATION_as 56352
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_as 56353
#define IDS_PERMISSION_REQUEST_USING_LOCATION_as 56354
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_as 56355
#define IDS_PERMISSION_REQUEST_LAUNCH_az 56356
#define IDS_PERMISSION_REQUEST_CAMERA_az 56357
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_az 56358
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_az 56359
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_az 56360
#define IDS_PERMISSION_REQUEST_INSTALL_az 56361
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_az 56362
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_az 56363
#define IDS_PERMISSION_REQUEST_MICROPHONE_az 56364
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_az 56365
#define IDS_PERMISSION_REQUEST_GEOLOCATION_az 56366
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_az 56367
#define IDS_PERMISSION_REQUEST_USING_LOCATION_az 56368
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_az 56369
#define IDS_PERMISSION_REQUEST_LAUNCH_be 56370
#define IDS_PERMISSION_REQUEST_CAMERA_be 56371
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_be 56372
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_be 56373
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_be 56374
#define IDS_PERMISSION_REQUEST_INSTALL_be 56375
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_be 56376
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_be 56377
#define IDS_PERMISSION_REQUEST_MICROPHONE_be 56378
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_be 56379
#define IDS_PERMISSION_REQUEST_GEOLOCATION_be 56380
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_be 56381
#define IDS_PERMISSION_REQUEST_USING_LOCATION_be 56382
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_be 56383
#define IDS_PERMISSION_REQUEST_LAUNCH_bg 56384
#define IDS_PERMISSION_REQUEST_CAMERA_bg 56385
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_bg 56386
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_bg 56387
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_bg 56388
#define IDS_PERMISSION_REQUEST_INSTALL_bg 56389
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_bg 56390
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_bg 56391
#define IDS_PERMISSION_REQUEST_MICROPHONE_bg 56392
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_bg 56393
#define IDS_PERMISSION_REQUEST_GEOLOCATION_bg 56394
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_bg 56395
#define IDS_PERMISSION_REQUEST_USING_LOCATION_bg 56396
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_bg 56397
#define IDS_PERMISSION_REQUEST_LAUNCH_bn 56398
#define IDS_PERMISSION_REQUEST_CAMERA_bn 56399
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_bn 56400
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_bn 56401
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_bn 56402
#define IDS_PERMISSION_REQUEST_INSTALL_bn 56403
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_bn 56404
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_bn 56405
#define IDS_PERMISSION_REQUEST_MICROPHONE_bn 56406
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_bn 56407
#define IDS_PERMISSION_REQUEST_GEOLOCATION_bn 56408
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_bn 56409
#define IDS_PERMISSION_REQUEST_USING_LOCATION_bn 56410
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_bn 56411
#define IDS_PERMISSION_REQUEST_LAUNCH_bs 56412
#define IDS_PERMISSION_REQUEST_CAMERA_bs 56413
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_bs 56414
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_bs 56415
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_bs 56416
#define IDS_PERMISSION_REQUEST_INSTALL_bs 56417
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_bs 56418
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_bs 56419
#define IDS_PERMISSION_REQUEST_MICROPHONE_bs 56420
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_bs 56421
#define IDS_PERMISSION_REQUEST_GEOLOCATION_bs 56422
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_bs 56423
#define IDS_PERMISSION_REQUEST_USING_LOCATION_bs 56424
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_bs 56425
#define IDS_PERMISSION_REQUEST_LAUNCH_ca 56426
#define IDS_PERMISSION_REQUEST_CAMERA_ca 56427
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ca 56428
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ca 56429
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ca 56430
#define IDS_PERMISSION_REQUEST_INSTALL_ca 56431
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ca 56432
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ca 56433
#define IDS_PERMISSION_REQUEST_MICROPHONE_ca 56434
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ca 56435
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ca 56436
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ca 56437
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ca 56438
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ca 56439
#define IDS_PERMISSION_REQUEST_LAUNCH_cs 56440
#define IDS_PERMISSION_REQUEST_CAMERA_cs 56441
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_cs 56442
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_cs 56443
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_cs 56444
#define IDS_PERMISSION_REQUEST_INSTALL_cs 56445
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_cs 56446
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_cs 56447
#define IDS_PERMISSION_REQUEST_MICROPHONE_cs 56448
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_cs 56449
#define IDS_PERMISSION_REQUEST_GEOLOCATION_cs 56450
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_cs 56451
#define IDS_PERMISSION_REQUEST_USING_LOCATION_cs 56452
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_cs 56453
#define IDS_PERMISSION_REQUEST_LAUNCH_cy 56454
#define IDS_PERMISSION_REQUEST_CAMERA_cy 56455
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_cy 56456
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_cy 56457
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_cy 56458
#define IDS_PERMISSION_REQUEST_INSTALL_cy 56459
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_cy 56460
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_cy 56461
#define IDS_PERMISSION_REQUEST_MICROPHONE_cy 56462
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_cy 56463
#define IDS_PERMISSION_REQUEST_GEOLOCATION_cy 56464
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_cy 56465
#define IDS_PERMISSION_REQUEST_USING_LOCATION_cy 56466
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_cy 56467
#define IDS_PERMISSION_REQUEST_LAUNCH_da 56468
#define IDS_PERMISSION_REQUEST_CAMERA_da 56469
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_da 56470
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_da 56471
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_da 56472
#define IDS_PERMISSION_REQUEST_INSTALL_da 56473
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_da 56474
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_da 56475
#define IDS_PERMISSION_REQUEST_MICROPHONE_da 56476
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_da 56477
#define IDS_PERMISSION_REQUEST_GEOLOCATION_da 56478
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_da 56479
#define IDS_PERMISSION_REQUEST_USING_LOCATION_da 56480
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_da 56481
#define IDS_PERMISSION_REQUEST_LAUNCH_de 56482
#define IDS_PERMISSION_REQUEST_CAMERA_de 56483
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_de 56484
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_de 56485
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_de 56486
#define IDS_PERMISSION_REQUEST_INSTALL_de 56487
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_de 56488
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_de 56489
#define IDS_PERMISSION_REQUEST_MICROPHONE_de 56490
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_de 56491
#define IDS_PERMISSION_REQUEST_GEOLOCATION_de 56492
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_de 56493
#define IDS_PERMISSION_REQUEST_USING_LOCATION_de 56494
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_de 56495
#define IDS_PERMISSION_REQUEST_LAUNCH_el 56496
#define IDS_PERMISSION_REQUEST_CAMERA_el 56497
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_el 56498
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_el 56499
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_el 56500
#define IDS_PERMISSION_REQUEST_INSTALL_el 56501
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_el 56502
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_el 56503
#define IDS_PERMISSION_REQUEST_MICROPHONE_el 56504
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_el 56505
#define IDS_PERMISSION_REQUEST_GEOLOCATION_el 56506
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_el 56507
#define IDS_PERMISSION_REQUEST_USING_LOCATION_el 56508
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_el 56509
#define IDS_PERMISSION_REQUEST_LAUNCH_en_GB 56510
#define IDS_PERMISSION_REQUEST_CAMERA_en_GB 56511
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_en_GB 56512
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_en_GB 56513
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_en_GB 56514
#define IDS_PERMISSION_REQUEST_INSTALL_en_GB 56515
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_en_GB 56516
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_en_GB 56517
#define IDS_PERMISSION_REQUEST_MICROPHONE_en_GB 56518
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_en_GB 56519
#define IDS_PERMISSION_REQUEST_GEOLOCATION_en_GB 56520
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_en_GB 56521
#define IDS_PERMISSION_REQUEST_USING_LOCATION_en_GB 56522
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_en_GB 56523
#define IDS_PERMISSION_REQUEST_LAUNCH_es_419 56524
#define IDS_PERMISSION_REQUEST_CAMERA_es_419 56525
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_es_419 56526
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_es_419 56527
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_es_419 56528
#define IDS_PERMISSION_REQUEST_INSTALL_es_419 56529
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_es_419 56530
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_es_419 56531
#define IDS_PERMISSION_REQUEST_MICROPHONE_es_419 56532
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_es_419 56533
#define IDS_PERMISSION_REQUEST_GEOLOCATION_es_419 56534
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_es_419 56535
#define IDS_PERMISSION_REQUEST_USING_LOCATION_es_419 56536
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_es_419 56537
#define IDS_PERMISSION_REQUEST_LAUNCH_es 56538
#define IDS_PERMISSION_REQUEST_CAMERA_es 56539
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_es 56540
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_es 56541
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_es 56542
#define IDS_PERMISSION_REQUEST_INSTALL_es 56543
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_es 56544
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_es 56545
#define IDS_PERMISSION_REQUEST_MICROPHONE_es 56546
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_es 56547
#define IDS_PERMISSION_REQUEST_GEOLOCATION_es 56548
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_es 56549
#define IDS_PERMISSION_REQUEST_USING_LOCATION_es 56550
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_es 56551
#define IDS_PERMISSION_REQUEST_LAUNCH_et 56552
#define IDS_PERMISSION_REQUEST_CAMERA_et 56553
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_et 56554
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_et 56555
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_et 56556
#define IDS_PERMISSION_REQUEST_INSTALL_et 56557
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_et 56558
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_et 56559
#define IDS_PERMISSION_REQUEST_MICROPHONE_et 56560
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_et 56561
#define IDS_PERMISSION_REQUEST_GEOLOCATION_et 56562
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_et 56563
#define IDS_PERMISSION_REQUEST_USING_LOCATION_et 56564
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_et 56565
#define IDS_PERMISSION_REQUEST_LAUNCH_eu 56566
#define IDS_PERMISSION_REQUEST_CAMERA_eu 56567
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_eu 56568
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_eu 56569
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_eu 56570
#define IDS_PERMISSION_REQUEST_INSTALL_eu 56571
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_eu 56572
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_eu 56573
#define IDS_PERMISSION_REQUEST_MICROPHONE_eu 56574
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_eu 56575
#define IDS_PERMISSION_REQUEST_GEOLOCATION_eu 56576
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_eu 56577
#define IDS_PERMISSION_REQUEST_USING_LOCATION_eu 56578
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_eu 56579
#define IDS_PERMISSION_REQUEST_LAUNCH_fa 56580
#define IDS_PERMISSION_REQUEST_CAMERA_fa 56581
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fa 56582
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fa 56583
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fa 56584
#define IDS_PERMISSION_REQUEST_INSTALL_fa 56585
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fa 56586
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fa 56587
#define IDS_PERMISSION_REQUEST_MICROPHONE_fa 56588
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fa 56589
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fa 56590
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fa 56591
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fa 56592
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fa 56593
#define IDS_PERMISSION_REQUEST_LAUNCH_fi 56594
#define IDS_PERMISSION_REQUEST_CAMERA_fi 56595
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fi 56596
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fi 56597
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fi 56598
#define IDS_PERMISSION_REQUEST_INSTALL_fi 56599
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fi 56600
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fi 56601
#define IDS_PERMISSION_REQUEST_MICROPHONE_fi 56602
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fi 56603
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fi 56604
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fi 56605
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fi 56606
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fi 56607
#define IDS_PERMISSION_REQUEST_LAUNCH_fil 56608
#define IDS_PERMISSION_REQUEST_CAMERA_fil 56609
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fil 56610
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fil 56611
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fil 56612
#define IDS_PERMISSION_REQUEST_INSTALL_fil 56613
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fil 56614
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fil 56615
#define IDS_PERMISSION_REQUEST_MICROPHONE_fil 56616
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fil 56617
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fil 56618
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fil 56619
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fil 56620
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fil 56621
#define IDS_PERMISSION_REQUEST_LAUNCH_fr_CA 56622
#define IDS_PERMISSION_REQUEST_CAMERA_fr_CA 56623
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fr_CA 56624
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fr_CA 56625
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fr_CA 56626
#define IDS_PERMISSION_REQUEST_INSTALL_fr_CA 56627
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fr_CA 56628
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fr_CA 56629
#define IDS_PERMISSION_REQUEST_MICROPHONE_fr_CA 56630
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fr_CA 56631
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fr_CA 56632
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fr_CA 56633
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fr_CA 56634
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fr_CA 56635
#define IDS_PERMISSION_REQUEST_LAUNCH_fr 56636
#define IDS_PERMISSION_REQUEST_CAMERA_fr 56637
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fr 56638
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fr 56639
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fr 56640
#define IDS_PERMISSION_REQUEST_INSTALL_fr 56641
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fr 56642
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fr 56643
#define IDS_PERMISSION_REQUEST_MICROPHONE_fr 56644
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fr 56645
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fr 56646
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fr 56647
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fr 56648
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fr 56649
#define IDS_PERMISSION_REQUEST_LAUNCH_gl 56650
#define IDS_PERMISSION_REQUEST_CAMERA_gl 56651
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_gl 56652
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_gl 56653
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_gl 56654
#define IDS_PERMISSION_REQUEST_INSTALL_gl 56655
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_gl 56656
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_gl 56657
#define IDS_PERMISSION_REQUEST_MICROPHONE_gl 56658
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_gl 56659
#define IDS_PERMISSION_REQUEST_GEOLOCATION_gl 56660
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_gl 56661
#define IDS_PERMISSION_REQUEST_USING_LOCATION_gl 56662
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_gl 56663
#define IDS_PERMISSION_REQUEST_LAUNCH_gu 56664
#define IDS_PERMISSION_REQUEST_CAMERA_gu 56665
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_gu 56666
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_gu 56667
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_gu 56668
#define IDS_PERMISSION_REQUEST_INSTALL_gu 56669
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_gu 56670
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_gu 56671
#define IDS_PERMISSION_REQUEST_MICROPHONE_gu 56672
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_gu 56673
#define IDS_PERMISSION_REQUEST_GEOLOCATION_gu 56674
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_gu 56675
#define IDS_PERMISSION_REQUEST_USING_LOCATION_gu 56676
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_gu 56677
#define IDS_PERMISSION_REQUEST_LAUNCH_hi 56678
#define IDS_PERMISSION_REQUEST_CAMERA_hi 56679
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hi 56680
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_hi 56681
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hi 56682
#define IDS_PERMISSION_REQUEST_INSTALL_hi 56683
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hi 56684
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hi 56685
#define IDS_PERMISSION_REQUEST_MICROPHONE_hi 56686
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hi 56687
#define IDS_PERMISSION_REQUEST_GEOLOCATION_hi 56688
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hi 56689
#define IDS_PERMISSION_REQUEST_USING_LOCATION_hi 56690
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hi 56691
#define IDS_PERMISSION_REQUEST_LAUNCH_hr 56692
#define IDS_PERMISSION_REQUEST_CAMERA_hr 56693
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hr 56694
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_hr 56695
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hr 56696
#define IDS_PERMISSION_REQUEST_INSTALL_hr 56697
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hr 56698
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hr 56699
#define IDS_PERMISSION_REQUEST_MICROPHONE_hr 56700
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hr 56701
#define IDS_PERMISSION_REQUEST_GEOLOCATION_hr 56702
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hr 56703
#define IDS_PERMISSION_REQUEST_USING_LOCATION_hr 56704
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hr 56705
#define IDS_PERMISSION_REQUEST_LAUNCH_hu 56706
#define IDS_PERMISSION_REQUEST_CAMERA_hu 56707
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hu 56708
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_hu 56709
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hu 56710
#define IDS_PERMISSION_REQUEST_INSTALL_hu 56711
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hu 56712
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hu 56713
#define IDS_PERMISSION_REQUEST_MICROPHONE_hu 56714
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hu 56715
#define IDS_PERMISSION_REQUEST_GEOLOCATION_hu 56716
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hu 56717
#define IDS_PERMISSION_REQUEST_USING_LOCATION_hu 56718
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hu 56719
#define IDS_PERMISSION_REQUEST_LAUNCH_hy 56720
#define IDS_PERMISSION_REQUEST_CAMERA_hy 56721
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hy 56722
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_hy 56723
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hy 56724
#define IDS_PERMISSION_REQUEST_INSTALL_hy 56725
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hy 56726
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hy 56727
#define IDS_PERMISSION_REQUEST_MICROPHONE_hy 56728
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hy 56729
#define IDS_PERMISSION_REQUEST_GEOLOCATION_hy 56730
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hy 56731
#define IDS_PERMISSION_REQUEST_USING_LOCATION_hy 56732
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hy 56733
#define IDS_PERMISSION_REQUEST_LAUNCH_id 56734
#define IDS_PERMISSION_REQUEST_CAMERA_id 56735
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_id 56736
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_id 56737
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_id 56738
#define IDS_PERMISSION_REQUEST_INSTALL_id 56739
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_id 56740
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_id 56741
#define IDS_PERMISSION_REQUEST_MICROPHONE_id 56742
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_id 56743
#define IDS_PERMISSION_REQUEST_GEOLOCATION_id 56744
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_id 56745
#define IDS_PERMISSION_REQUEST_USING_LOCATION_id 56746
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_id 56747
#define IDS_PERMISSION_REQUEST_LAUNCH_is 56748
#define IDS_PERMISSION_REQUEST_CAMERA_is 56749
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_is 56750
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_is 56751
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_is 56752
#define IDS_PERMISSION_REQUEST_INSTALL_is 56753
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_is 56754
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_is 56755
#define IDS_PERMISSION_REQUEST_MICROPHONE_is 56756
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_is 56757
#define IDS_PERMISSION_REQUEST_GEOLOCATION_is 56758
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_is 56759
#define IDS_PERMISSION_REQUEST_USING_LOCATION_is 56760
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_is 56761
#define IDS_PERMISSION_REQUEST_LAUNCH_it 56762
#define IDS_PERMISSION_REQUEST_CAMERA_it 56763
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_it 56764
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_it 56765
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_it 56766
#define IDS_PERMISSION_REQUEST_INSTALL_it 56767
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_it 56768
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_it 56769
#define IDS_PERMISSION_REQUEST_MICROPHONE_it 56770
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_it 56771
#define IDS_PERMISSION_REQUEST_GEOLOCATION_it 56772
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_it 56773
#define IDS_PERMISSION_REQUEST_USING_LOCATION_it 56774
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_it 56775
#define IDS_PERMISSION_REQUEST_LAUNCH_iw 56776
#define IDS_PERMISSION_REQUEST_CAMERA_iw 56777
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_iw 56778
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_iw 56779
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_iw 56780
#define IDS_PERMISSION_REQUEST_INSTALL_iw 56781
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_iw 56782
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_iw 56783
#define IDS_PERMISSION_REQUEST_MICROPHONE_iw 56784
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_iw 56785
#define IDS_PERMISSION_REQUEST_GEOLOCATION_iw 56786
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_iw 56787
#define IDS_PERMISSION_REQUEST_USING_LOCATION_iw 56788
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_iw 56789
#define IDS_PERMISSION_REQUEST_LAUNCH_ja 56790
#define IDS_PERMISSION_REQUEST_CAMERA_ja 56791
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ja 56792
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ja 56793
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ja 56794
#define IDS_PERMISSION_REQUEST_INSTALL_ja 56795
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ja 56796
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ja 56797
#define IDS_PERMISSION_REQUEST_MICROPHONE_ja 56798
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ja 56799
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ja 56800
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ja 56801
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ja 56802
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ja 56803
#define IDS_PERMISSION_REQUEST_LAUNCH_ka 56804
#define IDS_PERMISSION_REQUEST_CAMERA_ka 56805
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ka 56806
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ka 56807
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ka 56808
#define IDS_PERMISSION_REQUEST_INSTALL_ka 56809
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ka 56810
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ka 56811
#define IDS_PERMISSION_REQUEST_MICROPHONE_ka 56812
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ka 56813
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ka 56814
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ka 56815
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ka 56816
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ka 56817
#define IDS_PERMISSION_REQUEST_LAUNCH_kk 56818
#define IDS_PERMISSION_REQUEST_CAMERA_kk 56819
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_kk 56820
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_kk 56821
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_kk 56822
#define IDS_PERMISSION_REQUEST_INSTALL_kk 56823
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_kk 56824
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_kk 56825
#define IDS_PERMISSION_REQUEST_MICROPHONE_kk 56826
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_kk 56827
#define IDS_PERMISSION_REQUEST_GEOLOCATION_kk 56828
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_kk 56829
#define IDS_PERMISSION_REQUEST_USING_LOCATION_kk 56830
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_kk 56831
#define IDS_PERMISSION_REQUEST_LAUNCH_km 56832
#define IDS_PERMISSION_REQUEST_CAMERA_km 56833
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_km 56834
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_km 56835
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_km 56836
#define IDS_PERMISSION_REQUEST_INSTALL_km 56837
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_km 56838
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_km 56839
#define IDS_PERMISSION_REQUEST_MICROPHONE_km 56840
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_km 56841
#define IDS_PERMISSION_REQUEST_GEOLOCATION_km 56842
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_km 56843
#define IDS_PERMISSION_REQUEST_USING_LOCATION_km 56844
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_km 56845
#define IDS_PERMISSION_REQUEST_LAUNCH_kn 56846
#define IDS_PERMISSION_REQUEST_CAMERA_kn 56847
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_kn 56848
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_kn 56849
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_kn 56850
#define IDS_PERMISSION_REQUEST_INSTALL_kn 56851
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_kn 56852
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_kn 56853
#define IDS_PERMISSION_REQUEST_MICROPHONE_kn 56854
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_kn 56855
#define IDS_PERMISSION_REQUEST_GEOLOCATION_kn 56856
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_kn 56857
#define IDS_PERMISSION_REQUEST_USING_LOCATION_kn 56858
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_kn 56859
#define IDS_PERMISSION_REQUEST_LAUNCH_ko 56860
#define IDS_PERMISSION_REQUEST_CAMERA_ko 56861
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ko 56862
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ko 56863
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ko 56864
#define IDS_PERMISSION_REQUEST_INSTALL_ko 56865
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ko 56866
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ko 56867
#define IDS_PERMISSION_REQUEST_MICROPHONE_ko 56868
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ko 56869
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ko 56870
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ko 56871
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ko 56872
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ko 56873
#define IDS_PERMISSION_REQUEST_LAUNCH_ky 56874
#define IDS_PERMISSION_REQUEST_CAMERA_ky 56875
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ky 56876
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ky 56877
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ky 56878
#define IDS_PERMISSION_REQUEST_INSTALL_ky 56879
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ky 56880
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ky 56881
#define IDS_PERMISSION_REQUEST_MICROPHONE_ky 56882
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ky 56883
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ky 56884
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ky 56885
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ky 56886
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ky 56887
#define IDS_PERMISSION_REQUEST_LAUNCH_lo 56888
#define IDS_PERMISSION_REQUEST_CAMERA_lo 56889
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_lo 56890
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_lo 56891
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_lo 56892
#define IDS_PERMISSION_REQUEST_INSTALL_lo 56893
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_lo 56894
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_lo 56895
#define IDS_PERMISSION_REQUEST_MICROPHONE_lo 56896
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_lo 56897
#define IDS_PERMISSION_REQUEST_GEOLOCATION_lo 56898
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_lo 56899
#define IDS_PERMISSION_REQUEST_USING_LOCATION_lo 56900
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_lo 56901
#define IDS_PERMISSION_REQUEST_LAUNCH_lt 56902
#define IDS_PERMISSION_REQUEST_CAMERA_lt 56903
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_lt 56904
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_lt 56905
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_lt 56906
#define IDS_PERMISSION_REQUEST_INSTALL_lt 56907
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_lt 56908
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_lt 56909
#define IDS_PERMISSION_REQUEST_MICROPHONE_lt 56910
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_lt 56911
#define IDS_PERMISSION_REQUEST_GEOLOCATION_lt 56912
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_lt 56913
#define IDS_PERMISSION_REQUEST_USING_LOCATION_lt 56914
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_lt 56915
#define IDS_PERMISSION_REQUEST_LAUNCH_lv 56916
#define IDS_PERMISSION_REQUEST_CAMERA_lv 56917
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_lv 56918
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_lv 56919
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_lv 56920
#define IDS_PERMISSION_REQUEST_INSTALL_lv 56921
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_lv 56922
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_lv 56923
#define IDS_PERMISSION_REQUEST_MICROPHONE_lv 56924
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_lv 56925
#define IDS_PERMISSION_REQUEST_GEOLOCATION_lv 56926
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_lv 56927
#define IDS_PERMISSION_REQUEST_USING_LOCATION_lv 56928
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_lv 56929
#define IDS_PERMISSION_REQUEST_LAUNCH_mk 56930
#define IDS_PERMISSION_REQUEST_CAMERA_mk 56931
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_mk 56932
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_mk 56933
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_mk 56934
#define IDS_PERMISSION_REQUEST_INSTALL_mk 56935
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_mk 56936
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_mk 56937
#define IDS_PERMISSION_REQUEST_MICROPHONE_mk 56938
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_mk 56939
#define IDS_PERMISSION_REQUEST_GEOLOCATION_mk 56940
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_mk 56941
#define IDS_PERMISSION_REQUEST_USING_LOCATION_mk 56942
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_mk 56943
#define IDS_PERMISSION_REQUEST_LAUNCH_ml 56944
#define IDS_PERMISSION_REQUEST_CAMERA_ml 56945
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ml 56946
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ml 56947
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ml 56948
#define IDS_PERMISSION_REQUEST_INSTALL_ml 56949
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ml 56950
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ml 56951
#define IDS_PERMISSION_REQUEST_MICROPHONE_ml 56952
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ml 56953
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ml 56954
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ml 56955
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ml 56956
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ml 56957
#define IDS_PERMISSION_REQUEST_LAUNCH_mn 56958
#define IDS_PERMISSION_REQUEST_CAMERA_mn 56959
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_mn 56960
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_mn 56961
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_mn 56962
#define IDS_PERMISSION_REQUEST_INSTALL_mn 56963
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_mn 56964
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_mn 56965
#define IDS_PERMISSION_REQUEST_MICROPHONE_mn 56966
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_mn 56967
#define IDS_PERMISSION_REQUEST_GEOLOCATION_mn 56968
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_mn 56969
#define IDS_PERMISSION_REQUEST_USING_LOCATION_mn 56970
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_mn 56971
#define IDS_PERMISSION_REQUEST_LAUNCH_mr 56972
#define IDS_PERMISSION_REQUEST_CAMERA_mr 56973
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_mr 56974
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_mr 56975
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_mr 56976
#define IDS_PERMISSION_REQUEST_INSTALL_mr 56977
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_mr 56978
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_mr 56979
#define IDS_PERMISSION_REQUEST_MICROPHONE_mr 56980
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_mr 56981
#define IDS_PERMISSION_REQUEST_GEOLOCATION_mr 56982
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_mr 56983
#define IDS_PERMISSION_REQUEST_USING_LOCATION_mr 56984
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_mr 56985
#define IDS_PERMISSION_REQUEST_LAUNCH_ms 56986
#define IDS_PERMISSION_REQUEST_CAMERA_ms 56987
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ms 56988
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ms 56989
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ms 56990
#define IDS_PERMISSION_REQUEST_INSTALL_ms 56991
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ms 56992
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ms 56993
#define IDS_PERMISSION_REQUEST_MICROPHONE_ms 56994
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ms 56995
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ms 56996
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ms 56997
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ms 56998
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ms 56999
#define IDS_PERMISSION_REQUEST_LAUNCH_my 57000
#define IDS_PERMISSION_REQUEST_CAMERA_my 57001
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_my 57002
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_my 57003
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_my 57004
#define IDS_PERMISSION_REQUEST_INSTALL_my 57005
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_my 57006
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_my 57007
#define IDS_PERMISSION_REQUEST_MICROPHONE_my 57008
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_my 57009
#define IDS_PERMISSION_REQUEST_GEOLOCATION_my 57010
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_my 57011
#define IDS_PERMISSION_REQUEST_USING_LOCATION_my 57012
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_my 57013
#define IDS_PERMISSION_REQUEST_LAUNCH_ne 57014
#define IDS_PERMISSION_REQUEST_CAMERA_ne 57015
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ne 57016
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ne 57017
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ne 57018
#define IDS_PERMISSION_REQUEST_INSTALL_ne 57019
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ne 57020
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ne 57021
#define IDS_PERMISSION_REQUEST_MICROPHONE_ne 57022
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ne 57023
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ne 57024
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ne 57025
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ne 57026
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ne 57027
#define IDS_PERMISSION_REQUEST_LAUNCH_nl 57028
#define IDS_PERMISSION_REQUEST_CAMERA_nl 57029
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_nl 57030
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_nl 57031
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_nl 57032
#define IDS_PERMISSION_REQUEST_INSTALL_nl 57033
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_nl 57034
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_nl 57035
#define IDS_PERMISSION_REQUEST_MICROPHONE_nl 57036
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_nl 57037
#define IDS_PERMISSION_REQUEST_GEOLOCATION_nl 57038
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_nl 57039
#define IDS_PERMISSION_REQUEST_USING_LOCATION_nl 57040
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_nl 57041
#define IDS_PERMISSION_REQUEST_LAUNCH_no 57042
#define IDS_PERMISSION_REQUEST_CAMERA_no 57043
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_no 57044
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_no 57045
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_no 57046
#define IDS_PERMISSION_REQUEST_INSTALL_no 57047
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_no 57048
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_no 57049
#define IDS_PERMISSION_REQUEST_MICROPHONE_no 57050
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_no 57051
#define IDS_PERMISSION_REQUEST_GEOLOCATION_no 57052
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_no 57053
#define IDS_PERMISSION_REQUEST_USING_LOCATION_no 57054
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_no 57055
#define IDS_PERMISSION_REQUEST_LAUNCH_or 57056
#define IDS_PERMISSION_REQUEST_CAMERA_or 57057
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_or 57058
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_or 57059
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_or 57060
#define IDS_PERMISSION_REQUEST_INSTALL_or 57061
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_or 57062
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_or 57063
#define IDS_PERMISSION_REQUEST_MICROPHONE_or 57064
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_or 57065
#define IDS_PERMISSION_REQUEST_GEOLOCATION_or 57066
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_or 57067
#define IDS_PERMISSION_REQUEST_USING_LOCATION_or 57068
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_or 57069
#define IDS_PERMISSION_REQUEST_LAUNCH_pa 57070
#define IDS_PERMISSION_REQUEST_CAMERA_pa 57071
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pa 57072
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_pa 57073
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pa 57074
#define IDS_PERMISSION_REQUEST_INSTALL_pa 57075
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pa 57076
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pa 57077
#define IDS_PERMISSION_REQUEST_MICROPHONE_pa 57078
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pa 57079
#define IDS_PERMISSION_REQUEST_GEOLOCATION_pa 57080
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pa 57081
#define IDS_PERMISSION_REQUEST_USING_LOCATION_pa 57082
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pa 57083
#define IDS_PERMISSION_REQUEST_LAUNCH_pl 57084
#define IDS_PERMISSION_REQUEST_CAMERA_pl 57085
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pl 57086
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_pl 57087
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pl 57088
#define IDS_PERMISSION_REQUEST_INSTALL_pl 57089
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pl 57090
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pl 57091
#define IDS_PERMISSION_REQUEST_MICROPHONE_pl 57092
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pl 57093
#define IDS_PERMISSION_REQUEST_GEOLOCATION_pl 57094
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pl 57095
#define IDS_PERMISSION_REQUEST_USING_LOCATION_pl 57096
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pl 57097
#define IDS_PERMISSION_REQUEST_LAUNCH_pt_BR 57098
#define IDS_PERMISSION_REQUEST_CAMERA_pt_BR 57099
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pt_BR 57100
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_pt_BR 57101
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pt_BR 57102
#define IDS_PERMISSION_REQUEST_INSTALL_pt_BR 57103
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pt_BR 57104
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pt_BR 57105
#define IDS_PERMISSION_REQUEST_MICROPHONE_pt_BR 57106
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pt_BR 57107
#define IDS_PERMISSION_REQUEST_GEOLOCATION_pt_BR 57108
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pt_BR 57109
#define IDS_PERMISSION_REQUEST_USING_LOCATION_pt_BR 57110
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pt_BR 57111
#define IDS_PERMISSION_REQUEST_LAUNCH_pt_PT 57112
#define IDS_PERMISSION_REQUEST_CAMERA_pt_PT 57113
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pt_PT 57114
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_pt_PT 57115
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pt_PT 57116
#define IDS_PERMISSION_REQUEST_INSTALL_pt_PT 57117
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pt_PT 57118
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pt_PT 57119
#define IDS_PERMISSION_REQUEST_MICROPHONE_pt_PT 57120
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pt_PT 57121
#define IDS_PERMISSION_REQUEST_GEOLOCATION_pt_PT 57122
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pt_PT 57123
#define IDS_PERMISSION_REQUEST_USING_LOCATION_pt_PT 57124
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pt_PT 57125
#define IDS_PERMISSION_REQUEST_LAUNCH_ro 57126
#define IDS_PERMISSION_REQUEST_CAMERA_ro 57127
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ro 57128
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ro 57129
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ro 57130
#define IDS_PERMISSION_REQUEST_INSTALL_ro 57131
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ro 57132
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ro 57133
#define IDS_PERMISSION_REQUEST_MICROPHONE_ro 57134
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ro 57135
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ro 57136
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ro 57137
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ro 57138
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ro 57139
#define IDS_PERMISSION_REQUEST_LAUNCH_ru 57140
#define IDS_PERMISSION_REQUEST_CAMERA_ru 57141
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ru 57142
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ru 57143
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ru 57144
#define IDS_PERMISSION_REQUEST_INSTALL_ru 57145
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ru 57146
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ru 57147
#define IDS_PERMISSION_REQUEST_MICROPHONE_ru 57148
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ru 57149
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ru 57150
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ru 57151
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ru 57152
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ru 57153
#define IDS_PERMISSION_REQUEST_LAUNCH_si 57154
#define IDS_PERMISSION_REQUEST_CAMERA_si 57155
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_si 57156
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_si 57157
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_si 57158
#define IDS_PERMISSION_REQUEST_INSTALL_si 57159
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_si 57160
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_si 57161
#define IDS_PERMISSION_REQUEST_MICROPHONE_si 57162
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_si 57163
#define IDS_PERMISSION_REQUEST_GEOLOCATION_si 57164
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_si 57165
#define IDS_PERMISSION_REQUEST_USING_LOCATION_si 57166
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_si 57167
#define IDS_PERMISSION_REQUEST_LAUNCH_sk 57168
#define IDS_PERMISSION_REQUEST_CAMERA_sk 57169
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sk 57170
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sk 57171
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sk 57172
#define IDS_PERMISSION_REQUEST_INSTALL_sk 57173
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sk 57174
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sk 57175
#define IDS_PERMISSION_REQUEST_MICROPHONE_sk 57176
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sk 57177
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sk 57178
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sk 57179
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sk 57180
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sk 57181
#define IDS_PERMISSION_REQUEST_LAUNCH_sl 57182
#define IDS_PERMISSION_REQUEST_CAMERA_sl 57183
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sl 57184
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sl 57185
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sl 57186
#define IDS_PERMISSION_REQUEST_INSTALL_sl 57187
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sl 57188
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sl 57189
#define IDS_PERMISSION_REQUEST_MICROPHONE_sl 57190
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sl 57191
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sl 57192
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sl 57193
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sl 57194
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sl 57195
#define IDS_PERMISSION_REQUEST_LAUNCH_sq 57196
#define IDS_PERMISSION_REQUEST_CAMERA_sq 57197
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sq 57198
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sq 57199
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sq 57200
#define IDS_PERMISSION_REQUEST_INSTALL_sq 57201
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sq 57202
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sq 57203
#define IDS_PERMISSION_REQUEST_MICROPHONE_sq 57204
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sq 57205
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sq 57206
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sq 57207
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sq 57208
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sq 57209
#define IDS_PERMISSION_REQUEST_LAUNCH_sr_Latn 57210
#define IDS_PERMISSION_REQUEST_CAMERA_sr_Latn 57211
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sr_Latn 57212
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sr_Latn 57213
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sr_Latn 57214
#define IDS_PERMISSION_REQUEST_INSTALL_sr_Latn 57215
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sr_Latn 57216
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sr_Latn 57217
#define IDS_PERMISSION_REQUEST_MICROPHONE_sr_Latn 57218
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sr_Latn 57219
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sr_Latn 57220
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sr_Latn 57221
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sr_Latn 57222
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sr_Latn 57223
#define IDS_PERMISSION_REQUEST_LAUNCH_sr 57224
#define IDS_PERMISSION_REQUEST_CAMERA_sr 57225
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sr 57226
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sr 57227
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sr 57228
#define IDS_PERMISSION_REQUEST_INSTALL_sr 57229
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sr 57230
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sr 57231
#define IDS_PERMISSION_REQUEST_MICROPHONE_sr 57232
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sr 57233
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sr 57234
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sr 57235
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sr 57236
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sr 57237
#define IDS_PERMISSION_REQUEST_LAUNCH_sv 57238
#define IDS_PERMISSION_REQUEST_CAMERA_sv 57239
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sv 57240
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sv 57241
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sv 57242
#define IDS_PERMISSION_REQUEST_INSTALL_sv 57243
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sv 57244
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sv 57245
#define IDS_PERMISSION_REQUEST_MICROPHONE_sv 57246
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sv 57247
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sv 57248
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sv 57249
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sv 57250
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sv 57251
#define IDS_PERMISSION_REQUEST_LAUNCH_sw 57252
#define IDS_PERMISSION_REQUEST_CAMERA_sw 57253
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sw 57254
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sw 57255
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sw 57256
#define IDS_PERMISSION_REQUEST_INSTALL_sw 57257
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sw 57258
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sw 57259
#define IDS_PERMISSION_REQUEST_MICROPHONE_sw 57260
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sw 57261
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sw 57262
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sw 57263
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sw 57264
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sw 57265
#define IDS_PERMISSION_REQUEST_LAUNCH_ta 57266
#define IDS_PERMISSION_REQUEST_CAMERA_ta 57267
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ta 57268
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ta 57269
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ta 57270
#define IDS_PERMISSION_REQUEST_INSTALL_ta 57271
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ta 57272
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ta 57273
#define IDS_PERMISSION_REQUEST_MICROPHONE_ta 57274
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ta 57275
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ta 57276
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ta 57277
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ta 57278
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ta 57279
#define IDS_PERMISSION_REQUEST_LAUNCH_te 57280
#define IDS_PERMISSION_REQUEST_CAMERA_te 57281
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_te 57282
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_te 57283
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_te 57284
#define IDS_PERMISSION_REQUEST_INSTALL_te 57285
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_te 57286
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_te 57287
#define IDS_PERMISSION_REQUEST_MICROPHONE_te 57288
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_te 57289
#define IDS_PERMISSION_REQUEST_GEOLOCATION_te 57290
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_te 57291
#define IDS_PERMISSION_REQUEST_USING_LOCATION_te 57292
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_te 57293
#define IDS_PERMISSION_REQUEST_LAUNCH_th 57294
#define IDS_PERMISSION_REQUEST_CAMERA_th 57295
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_th 57296
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_th 57297
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_th 57298
#define IDS_PERMISSION_REQUEST_INSTALL_th 57299
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_th 57300
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_th 57301
#define IDS_PERMISSION_REQUEST_MICROPHONE_th 57302
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_th 57303
#define IDS_PERMISSION_REQUEST_GEOLOCATION_th 57304
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_th 57305
#define IDS_PERMISSION_REQUEST_USING_LOCATION_th 57306
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_th 57307
#define IDS_PERMISSION_REQUEST_LAUNCH_tr 57308
#define IDS_PERMISSION_REQUEST_CAMERA_tr 57309
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_tr 57310
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_tr 57311
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_tr 57312
#define IDS_PERMISSION_REQUEST_INSTALL_tr 57313
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_tr 57314
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_tr 57315
#define IDS_PERMISSION_REQUEST_MICROPHONE_tr 57316
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_tr 57317
#define IDS_PERMISSION_REQUEST_GEOLOCATION_tr 57318
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_tr 57319
#define IDS_PERMISSION_REQUEST_USING_LOCATION_tr 57320
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_tr 57321
#define IDS_PERMISSION_REQUEST_LAUNCH_uk 57322
#define IDS_PERMISSION_REQUEST_CAMERA_uk 57323
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_uk 57324
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_uk 57325
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_uk 57326
#define IDS_PERMISSION_REQUEST_INSTALL_uk 57327
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_uk 57328
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_uk 57329
#define IDS_PERMISSION_REQUEST_MICROPHONE_uk 57330
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_uk 57331
#define IDS_PERMISSION_REQUEST_GEOLOCATION_uk 57332
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_uk 57333
#define IDS_PERMISSION_REQUEST_USING_LOCATION_uk 57334
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_uk 57335
#define IDS_PERMISSION_REQUEST_LAUNCH_ur 57336
#define IDS_PERMISSION_REQUEST_CAMERA_ur 57337
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ur 57338
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ur 57339
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ur 57340
#define IDS_PERMISSION_REQUEST_INSTALL_ur 57341
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ur 57342
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ur 57343
#define IDS_PERMISSION_REQUEST_MICROPHONE_ur 57344
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ur 57345
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ur 57346
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ur 57347
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ur 57348
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ur 57349
#define IDS_PERMISSION_REQUEST_LAUNCH_uz 57350
#define IDS_PERMISSION_REQUEST_CAMERA_uz 57351
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_uz 57352
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_uz 57353
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_uz 57354
#define IDS_PERMISSION_REQUEST_INSTALL_uz 57355
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_uz 57356
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_uz 57357
#define IDS_PERMISSION_REQUEST_MICROPHONE_uz 57358
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_uz 57359
#define IDS_PERMISSION_REQUEST_GEOLOCATION_uz 57360
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_uz 57361
#define IDS_PERMISSION_REQUEST_USING_LOCATION_uz 57362
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_uz 57363
#define IDS_PERMISSION_REQUEST_LAUNCH_vi 57364
#define IDS_PERMISSION_REQUEST_CAMERA_vi 57365
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_vi 57366
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_vi 57367
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_vi 57368
#define IDS_PERMISSION_REQUEST_INSTALL_vi 57369
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_vi 57370
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_vi 57371
#define IDS_PERMISSION_REQUEST_MICROPHONE_vi 57372
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_vi 57373
#define IDS_PERMISSION_REQUEST_GEOLOCATION_vi 57374
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_vi 57375
#define IDS_PERMISSION_REQUEST_USING_LOCATION_vi 57376
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_vi 57377
#define IDS_PERMISSION_REQUEST_LAUNCH_zh_CN 57378
#define IDS_PERMISSION_REQUEST_CAMERA_zh_CN 57379
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zh_CN 57380
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_zh_CN 57381
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zh_CN 57382
#define IDS_PERMISSION_REQUEST_INSTALL_zh_CN 57383
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zh_CN 57384
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zh_CN 57385
#define IDS_PERMISSION_REQUEST_MICROPHONE_zh_CN 57386
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zh_CN 57387
#define IDS_PERMISSION_REQUEST_GEOLOCATION_zh_CN 57388
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zh_CN 57389
#define IDS_PERMISSION_REQUEST_USING_LOCATION_zh_CN 57390
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zh_CN 57391
#define IDS_PERMISSION_REQUEST_LAUNCH_zh_HK 57392
#define IDS_PERMISSION_REQUEST_CAMERA_zh_HK 57393
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zh_HK 57394
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_zh_HK 57395
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zh_HK 57396
#define IDS_PERMISSION_REQUEST_INSTALL_zh_HK 57397
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zh_HK 57398
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zh_HK 57399
#define IDS_PERMISSION_REQUEST_MICROPHONE_zh_HK 57400
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zh_HK 57401
#define IDS_PERMISSION_REQUEST_GEOLOCATION_zh_HK 57402
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zh_HK 57403
#define IDS_PERMISSION_REQUEST_USING_LOCATION_zh_HK 57404
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zh_HK 57405
#define IDS_PERMISSION_REQUEST_LAUNCH_zh_TW 57406
#define IDS_PERMISSION_REQUEST_CAMERA_zh_TW 57407
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zh_TW 57408
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_zh_TW 57409
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zh_TW 57410
#define IDS_PERMISSION_REQUEST_INSTALL_zh_TW 57411
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zh_TW 57412
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zh_TW 57413
#define IDS_PERMISSION_REQUEST_MICROPHONE_zh_TW 57414
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zh_TW 57415
#define IDS_PERMISSION_REQUEST_GEOLOCATION_zh_TW 57416
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zh_TW 57417
#define IDS_PERMISSION_REQUEST_USING_LOCATION_zh_TW 57418
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zh_TW 57419
#define IDS_PERMISSION_REQUEST_LAUNCH_zu 57420
#define IDS_PERMISSION_REQUEST_CAMERA_zu 57421
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zu 57422
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_zu 57423
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zu 57424
#define IDS_PERMISSION_REQUEST_INSTALL_zu 57425
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zu 57426
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zu 57427
#define IDS_PERMISSION_REQUEST_MICROPHONE_zu 57428
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zu 57429
#define IDS_PERMISSION_REQUEST_GEOLOCATION_zu 57430
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zu 57431
#define IDS_PERMISSION_REQUEST_USING_LOCATION_zu 57432
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zu 57433

// ---------------------------------------------------------------------------
// From permission_element_strings.h:

#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED 46620
#define IDS_PERMISSION_REQUEST_CAMERA 46621
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED 46622
#define IDS_PERMISSION_REQUEST_MICROPHONE 46623
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED 46624
#define IDS_PERMISSION_REQUEST_GEOLOCATION 46625
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED 46626
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE 46627
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED 46628
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION 46629
#define IDS_PERMISSION_REQUEST_USING_LOCATION 46630
#define IDS_PERMISSION_REQUEST_INSTALL 46631
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST 46632
#define IDS_PERMISSION_REQUEST_LAUNCH 46633

// ---------------------------------------------------------------------------
// From platform_locale_settings.h:

#define IDS_STANDARD_FONT_FAMILY 16100
#define IDS_FIXED_FONT_FAMILY 16101
#define IDS_SERIF_FONT_FAMILY 16102
#define IDS_SANS_SERIF_FONT_FAMILY 16103
#define IDS_NTP_FONT_FAMILY 16104
#define IDS_CURSIVE_FONT_FAMILY 16105
#define IDS_FANTASY_FONT_FAMILY 16106
#define IDS_MATH_FONT_FAMILY 16107
#define IDS_FIXED_FONT_FAMILY_JAPANESE 16108
#define IDS_STANDARD_FONT_FAMILY_JAPANESE 16109
#define IDS_SERIF_FONT_FAMILY_JAPANESE 16110
#define IDS_SANS_SERIF_FONT_FAMILY_JAPANESE 16111
#define IDS_STANDARD_FONT_FAMILY_KOREAN 16112
#define IDS_SERIF_FONT_FAMILY_KOREAN 16113
#define IDS_SANS_SERIF_FONT_FAMILY_KOREAN 16114
#define IDS_STANDARD_FONT_FAMILY_SIMPLIFIED_HAN 16115
#define IDS_SERIF_FONT_FAMILY_SIMPLIFIED_HAN 16116
#define IDS_SANS_SERIF_FONT_FAMILY_SIMPLIFIED_HAN 16117
#define IDS_STANDARD_FONT_FAMILY_TRADITIONAL_HAN 16118
#define IDS_SERIF_FONT_FAMILY_TRADITIONAL_HAN 16119
#define IDS_SANS_SERIF_FONT_FAMILY_TRADITIONAL_HAN 16120
#define IDS_STANDARD_FONT_FAMILY_DEVANAGARI 16121
#define IDS_FIXED_FONT_FAMILY_DEVANAGARI 16122
#define IDS_SERIF_FONT_FAMILY_DEVANAGARI 16123
#define IDS_SANS_SERIF_FONT_FAMILY_DEVANAGARI 16124
#define IDS_MINIMUM_FONT_SIZE 16125
#define IDS_MINIMUM_LOGICAL_FONT_SIZE 16126

// ---------------------------------------------------------------------------
// From services_strings.h:

#define IDS_PROXY_RESOLVER_DISPLAY_NAME 46440
#define IDS_WINDOWS_SYSTEM_PROXY_RESOLVER_DISPLAY_NAME 46441
#define IDS_PDF_OCR_RESULT_BEGIN 46442
#define IDS_PDF_OCR_RESULT_END 46443

// ---------------------------------------------------------------------------
// From ui_strings.h:

#define IDS_TIME_SECS 50380
#define IDS_TIME_LONG_SECS 50381
#define IDS_TIME_LONG_SECS_2ND 50382
#define IDS_TIME_MINS 50383
#define IDS_TIME_LONG_MINS 50384
#define IDS_TIME_LONG_MINS_1ST 50385
#define IDS_TIME_LONG_MINS_2ND 50386
#define IDS_TIME_HOURS 50387
#define IDS_TIME_HOURS_1ST 50388
#define IDS_TIME_HOURS_2ND 50389
#define IDS_TIME_DAYS 50390
#define IDS_TIME_DAYS_1ST 50391
#define IDS_TIME_MONTHS 50392
#define IDS_TIME_YEARS 50393
#define IDS_TIME_REMAINING_SECS 50394
#define IDS_TIME_REMAINING_LONG_SECS 50395
#define IDS_TIME_REMAINING_MINS 50396
#define IDS_TIME_REMAINING_LONG_MINS 50397
#define IDS_TIME_REMAINING_HOURS 50398
#define IDS_TIME_REMAINING_DAYS 50399
#define IDS_TIME_REMAINING_MONTHS 50400
#define IDS_TIME_REMAINING_YEARS 50401
#define IDS_TIME_ELAPSED_SECS 50402
#define IDS_TIME_ELAPSED_LONG_SECS 50403
#define IDS_TIME_ELAPSED_MINS 50404
#define IDS_TIME_ELAPSED_LONG_MINS 50405
#define IDS_TIME_ELAPSED_HOURS 50406
#define IDS_TIME_ELAPSED_DAYS 50407
#define IDS_TIME_ELAPSED_MONTHS 50408
#define IDS_TIME_ELAPSED_YEARS 50409
#define IDS_TIME_TITLE_CASE_ELAPSED_LONG_SECS 50410
#define IDS_TIME_TITLE_CASE_ELAPSED_LONG_MINS 50411
#define IDS_TIME_TITLE_CASE_ELAPSED_HOURS 50412
#define IDS_TIME_TITLE_CASE_ELAPSED_DAYS 50413
#define IDS_TIME_TITLE_CASE_ELAPSED_MONTHS 50414
#define IDS_TIME_TITLE_CASE_ELAPSED_YEARS 50415
#define IDS_PAST_TIME_TODAY 50416
#define IDS_PAST_TIME_YESTERDAY 50417
#define IDS_TIME_TOMORROW 50418
#define IDS_APP_MENU_EMPTY_SUBMENU 50419
#define IDS_APP_MENU_AX_ANNOUNCE_EMPTY_SUBMENU 50420
#define IDS_CLIPBOARD_MENU_HTML 50421
#define IDS_CLIPBOARD_MENU_IMAGE 50422
#define IDS_CLIPBOARD_MENU_RTF_CONTENT 50423
#define IDS_CLIPBOARD_MENU_WEB_SMART_PASTE 50424
#define IDS_CLIPBOARD_MENU_CLIPBOARD 50425
#define IDS_CLIPBOARD_MENU_DELETE_ALL 50426
#define IDS_EXTENSION_PINNED 50427
#define IDS_EXTENSION_UNPINNED 50428
#define IDS_NEW_BADGE 50429
#define IDS_NEW_BADGE_SCREEN_READER_MESSAGE 50430
#define IDS_PREVIEW_BADGE 50431
#define IDS_PREVIEW_BADGE_SCREEN_READER_MESSAGE 50432
#define IDS_SENTENCE_END 50433
#define IDS_CONCAT_TWO_STRINGS_WITH_COMMA 50434
#define IDS_CONCAT_THREE_STRINGS_WITH_COMMA 50435
#define IDS_CONCAT_TWO_STRINGS_WITH_PERIODS 50436
#define IDS_SELECT_UPLOAD_FOLDER_DIALOG_TITLE 50440
#define IDS_CONTENT_CONTEXT_WRITING_DIRECTION_MENU 50448
#define IDS_CONTENT_CONTEXT_WRITING_DIRECTION_DEFAULT 50449
#define IDS_CONTENT_CONTEXT_WRITING_DIRECTION_LTR 50450
#define IDS_CONTENT_CONTEXT_WRITING_DIRECTION_RTL 50451
#define IDS_SELECT_FOLDER_DIALOG_TITLE 50452
#define IDS_SAVE_AS_DIALOG_TITLE 50453
#define IDS_OPEN_FILE_DIALOG_TITLE 50454
#define IDS_OPEN_FILES_DIALOG_TITLE 50455
#define IDS_SAVEAS_ALL_FILES 50456
#define IDS_SELECT_UPLOAD_FOLDER_DIALOG_UPLOAD_BUTTON 50457
#define IDS_APP_ACCNAME_BACK 50458
#define IDS_APP_ACCNAME_CENTER 50459
#define IDS_APP_ACCNAME_CLOSE 50460
#define IDS_APP_ACCNAME_MINIMIZE 50461
#define IDS_APP_ACCNAME_MAXIMIZE 50462
#define IDS_APP_ACCNAME_RESTORE 50463
#define IDS_APP_ACCNAME_MENU 50464
#define IDS_APP_ACCNAME_COLOR_CHOOSER_HEX_INPUT 50465
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLHERE 50466
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLLEFTEDGE 50467
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLRIGHTEDGE 50468
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLHOME 50469
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLEND 50470
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLPAGEUP 50471
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLPAGEDOWN 50472
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLLEFT 50473
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLRIGHT 50474
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLUP 50475
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLDOWN 50476
#define IDS_APP_TABLE_COLUMN_NOT_SORTED_ACCNAME 50477
#define IDS_APP_TABLE_COLUMN_SORTED_ASC_ACCNAME 50478
#define IDS_APP_TABLE_COLUMN_SORTED_DESC_ACCNAME 50479
#define IDS_APP_TABLE_HEADER_NOT_SORTED_ACCNAME 50480
#define IDS_APP_TABLE_HEADER_NOT_SORTED_ACCNAME_MAC 50481
#define IDS_APP_TABLE_HEADER_SORTED_ASC_ACCNAME 50482
#define IDS_APP_TABLE_HEADER_SORTED_DESC_ACCNAME 50483
#define IDS_APP_UNDO 50484
#define IDS_APP_CUT 50485
#define IDS_APP_COPY 50486
#define IDS_APP_PASTE 50487
#define IDS_APP_DELETE 50488
#define IDS_APP_SELECT_ALL 50489
#define IDS_APP_SELECT 50490
#define IDS_CONTENT_CONTEXT_EMOJI 50491
#define IDS_APP_OK 50494
#define IDS_APP_CANCEL 50495
#define IDS_APP_CLOSE 50496
#define IDS_APP_CONTINUE 50497
#define IDS_APP_TURN_ON 50498
#define IDS_APP_ESC_KEY 50499
#define IDS_APP_TAB_KEY 50500
#define IDS_APP_INSERT_KEY 50501
#define IDS_APP_HOME_KEY 50502
#define IDS_APP_DELETE_KEY 50503
#define IDS_APP_END_KEY 50504
#define IDS_APP_PAGEUP_KEY 50505
#define IDS_APP_PAGEDOWN_KEY 50506
#define IDS_APP_LEFT_ARROW_KEY 50507
#define IDS_APP_RIGHT_ARROW_KEY 50508
#define IDS_APP_UP_ARROW_KEY 50509
#define IDS_APP_DOWN_ARROW_KEY 50510
#define IDS_APP_ENTER_KEY 50511
#define IDS_APP_SPACE_KEY 50512
#define IDS_APP_F1_KEY 50513
#define IDS_APP_F5_KEY 50514
#define IDS_APP_F6_KEY 50515
#define IDS_APP_F11_KEY 50516
#define IDS_APP_BACKSPACE_KEY 50517
#define IDS_APP_COMMA_KEY 50518
#define IDS_APP_PERIOD_KEY 50519
#define IDS_APP_MEDIA_NEXT_TRACK_KEY 50520
#define IDS_APP_MEDIA_PLAY_PAUSE_KEY 50521
#define IDS_APP_MEDIA_PREV_TRACK_KEY 50522
#define IDS_APP_MEDIA_STOP_KEY 50523
#define IDS_APP_ALT_KEY 50524
#define IDS_APP_COMMAND_KEY 50525
#define IDS_APP_CTRL_KEY 50526
#define IDS_APP_SEARCH_KEY 50527
#define IDS_APP_SHIFT_KEY 50528
#define IDS_APP_SUPER_KEY 50530
#define IDS_APP_BYTES 50534
#define IDS_APP_KIBIBYTES 50535
#define IDS_APP_MEBIBYTES 50536
#define IDS_APP_GIBIBYTES 50537
#define IDS_APP_TEBIBYTES 50538
#define IDS_APP_PEBIBYTES 50539
#define IDS_APP_BYTES_PER_SECOND 50540
#define IDS_APP_KIBIBYTES_PER_SECOND 50541
#define IDS_APP_MEBIBYTES_PER_SECOND 50542
#define IDS_APP_GIBIBYTES_PER_SECOND 50543
#define IDS_APP_TEBIBYTES_PER_SECOND 50544
#define IDS_APP_PEBIBYTES_PER_SECOND 50545
#define IDS_MESSAGE_CENTER_ACCESSIBLE_NAME 50546
#define IDS_MESSAGE_CENTER_NOTIFICATION_ACCESSIBLE_NAME 50547
#define IDS_MESSAGE_CENTER_NOTIFICATION_ACCESSIBLE_NAME_PLURAL 50548
#define IDS_MESSAGE_CENTER_EXPAND_NOTIFICATION 50549
#define IDS_MESSAGE_CENTER_COLLAPSE_NOTIFICATION 50550
#define IDS_MESSAGE_CENTER_LIST_NOTIFICATION_MESSAGE_WITH_DIVIDER 50551
#define IDS_MESSAGE_CENTER_LIST_NOTIFICATION_HEADER_OVERFLOW_INDICATOR 50552
#define IDS_MESSAGE_CENTER_NOTIFICATION_PROGRESS_PERCENTAGE 50553
#define IDS_MESSAGE_CENTER_NOTIFICATION_CHROMEOS_SYSTEM 50554
#define IDS_MESSAGE_CENTER_NOTIFICATION_INLINE_REPLY_PLACEHOLDER 50555
#define IDS_MESSAGE_CENTER_NOTIFICATION_INLINE_REPLY_ACCESSIBLE_NAME 50556
#define IDS_MESSAGE_NOTIFICATION_NOW_STRING_SHORTEST 50557
#define IDS_MESSAGE_NOTIFICATION_DURATION_MINUTES_SHORTEST 50558
#define IDS_MESSAGE_NOTIFICATION_DURATION_HOURS_SHORTEST 50559
#define IDS_MESSAGE_NOTIFICATION_DURATION_DAYS_SHORTEST 50560
#define IDS_MESSAGE_NOTIFICATION_DURATION_YEARS_SHORTEST 50561
#define IDS_MESSAGE_NOTIFICATION_DURATION_MINUTES_SHORTEST_FUTURE 50562
#define IDS_MESSAGE_NOTIFICATION_DURATION_HOURS_SHORTEST_FUTURE 50563
#define IDS_MESSAGE_NOTIFICATION_DURATION_DAYS_SHORTEST_FUTURE 50564
#define IDS_MESSAGE_NOTIFICATION_DURATION_YEARS_SHORTEST_FUTURE 50565
#define IDS_MESSAGE_CENTER_BLOCK_ALL_NOTIFICATIONS_SITE 50566
#define IDS_MESSAGE_CENTER_BLOCK_ALL_NOTIFICATIONS_APP 50567
#define IDS_MESSAGE_CENTER_BLOCK_ALL_NOTIFICATIONS 50568
#define IDS_MESSAGE_CENTER_DONT_BLOCK_NOTIFICATIONS 50569
#define IDS_MESSAGE_CENTER_SETTINGS_DONE 50570
#define IDS_MESSAGE_CENTER_CLOSE_NOTIFICATION_BUTTON_ACCESSIBLE_NAME 50571
#define IDS_MESSAGE_CENTER_CLOSE_NOTIFICATION_BUTTON_TOOLTIP 50572
#define IDS_MESSAGE_CENTER_NOTIFICATION_SNOOZE_BUTTON_TOOLTIP 50573
#define IDS_MESSAGE_NOTIFICATION_SETTINGS_BUTTON_ACCESSIBLE_NAME 50574
#define IDS_MESSAGE_NOTIFICATION_ACCESSIBLE_NAME 50575
#define IDS_MESSAGE_NOTIFICATION_SEND_TAB_TO_SELF_DEVICE_INFO 50576
#define IDS_MESSAGE_NOTIFICATION_SEND_TAB_TO_SELF_CONFIRMATION_SUCCESS 50577
#define IDS_MESSAGE_NOTIFICATION_SEND_TAB_TO_SELF_CONFIRMATION_FAILURE_TITLE 50578
#define IDS_MESSAGE_NOTIFICATION_SEND_TAB_TO_SELF_CONFIRMATION_FAILURE_MESSAGE 50579
#define IDS_CLIPBOARD_HISTORY_MENU_PNG_IMAGE 50581
#define IDS_CLIPBOARD_HISTORY_MENU_HTML_IMAGE 50582
#define IDS_CLIPBOARD_HISTORY_MENU_TITLE 50583
#define IDS_CLIPBOARD_HISTORY_DELETE_ITEM_TEXT 50584
#define IDS_CLIPBOARD_HISTORY_DELETE_BUTTON_HOVER_TEXT 50585
#define IDS_CLIPBOARD_HISTORY_ITEM_DELETION 50586
#define IDS_DISPLAY_TOUCH_CALIBRATION_EXIT_LABEL 50587
#define IDS_DISPLAY_TOUCH_CALIBRATION_SECONDARY_SKIP_LABEL 50588
#define IDS_DISPLAY_TOUCH_CALIBRATION_PRIMARY_SKIP_LABEL 50589
#define IDS_DISPLAY_TOUCH_CALIBRATION_HINT_LABEL_TEXT 50590
#define IDS_DISPLAY_TOUCH_CALIBRATION_HINT_SUBLABEL_TEXT 50591
#define IDS_DISPLAY_TOUCH_CALIBRATION_TAP_HERE_LABEL 50592
#define IDS_DISPLAY_TOUCH_CALIBRATION_FINISH_LABEL 50593
#define IDS_DISPLAY_TOUCH_CALIBRATION_A11Y_TARGET_MOVED_TOP_RIGHT 50594
#define IDS_DISPLAY_TOUCH_CALIBRATION_A11Y_TARGET_MOVED_BOTTOM_LEFT 50595
#define IDS_DISPLAY_TOUCH_CALIBRATION_A11Y_TARGET_MOVED_BOTTOM_RIGHT 50596
#define IDS_DISPLAY_NAME_UNKNOWN 50597
#define IDS_DISPLAY_NAME_INTERNAL 50598
#define IDS_CROSTINI_USE_LOW_DENSITY 50599
#define IDS_CROSTINI_USE_HIGH_DENSITY 50600
#define IDS_CROSTINI_APP_RESTART_BODY 50601
#define IDS_SATURATED_BADGE_CONTENT 50602
#define IDS_BADGE_UNREAD_NOTIFICATIONS_SATURATED 50603
#define IDS_BADGE_UNREAD_NOTIFICATIONS_UNSPECIFIED 50604
#define IDS_BADGE_UNREAD_NOTIFICATIONS 50605
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_TITLE_LABEL 50606
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_TITLE_NO_DEVICES 50607
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_CALL_BUTTON_LABEL 50608
#define IDS_BROWSER_SHARING_OMNIBOX_SENDING_LABEL 50609
#define IDS_BROWSER_SHARING_DIALOG_DEVICE_SUBTITLE_LAST_ACTIVE_DAYS 50610
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_INITIATING_ORIGIN 50611
#define IDS_BROWSER_SHARING_CONTENT_TYPE_TEXT 50612
#define IDS_BROWSER_SHARING_CONTENT_TYPE_NUMBER 50613
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TITLE_GENERIC_ERROR 50614
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TITLE_INTERNAL_ERROR 50615
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TEXT_NETWORK_ERROR 50616
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TEXT_DEVICE_ACK_TIMEOUT 50617
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TEXT_INTERNAL_ERROR 50618
#define IDS_BROWSER_SHARING_SHARED_CLIPBOARD_ERROR_DIALOG_TITLE_PAYLOAD_TOO_LARGE 50619
#define IDS_BROWSER_SHARING_SHARED_CLIPBOARD_ERROR_DIALOG_TEXT_PAYLOAD_TOO_LARGE 50620
#define IDS_SETTINGS_PASSWORD_SHOW 50624
#define IDS_SETTINGS_PASSWORD_HIDE 50625
#define IDS_TABLE_VIEW_AX_ANNOUNCE_ROW_SELECTED 50626
#define IDS_LINK_COPIED 50627
#define IDS_INCOGNITO_NAVIGATION_BLOCKED_PAGE_TITLE 50628
#define IDS_INCOGNITO_NAVIGATION_MESSAGE 50629
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS 50630
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS_STEP_1 50631
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS_STEP_2 50632
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS_STEP_3 50633
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS_STEP_4 50634
#define IDS_INCOGNITO_NAVIGATION_MISSING_TITLE 50635
#define IDS_INCOGNITO_NAVIGATION_MISSING_EXTENSIONS 50636

#endif  // CEF_INCLUDE_CEF_PACK_STRINGS_H_
